(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    546984,      16410]*)
(*NotebookOutlinePosition[    547925,      16441]*)
(*  CellTagsIndexPosition[    547881,      16437]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Runge Kutta Tracking of an Electron in a Magnetic Field.", "Title"],

Cell["\<\
March 1999,
Pascal Elleaume, ESRF\
\>", "Text"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
Here is an example of tracking  of an electron inside a magnetic \
field. The Field is that of a conventionnal pure permanent magnet undulator \
with a variable number of period. In such a situation, the trajectory can \
(almost) be computed analytically and compared with expectations. \
\>", 
  "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< Radia`; \nOff[General::"\<spell1\>"]; \)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Radia Version: \"\>", "\[InvisibleSpace]", 
        StyleBox["4.09700000000000041`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", "\<\" is loaded\"\>"}],
      SequenceForm[ "Radia Version: ", 4.0970000000000004, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright 1997 \
Wolfram Research, Inc."\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell["\<\
Here are a set of function definitions  which will be used later to \
create the magnetic structure.\
\>", "Text"],

Cell[BoxData[{
    \(peri[grp_, p_List, per_, air_, lx_, lz_, mag_] := 
      Module[{m1, m2, m3, m4, l, lf, d}, \n\t\tl = {lx, per/4 - air, lz}; \n
        \t\t\tlf = {lx, per/8 - air/2, lz}; \n\t\t
        m1 = radObjRecMag[p, l, {0, 0, mag}]; radObjDrwAtr[m1, {0, 1, 0.5}]; 
        \n\t\t\tm2 = radObjRecMag[p - {0, per/4, 0}, l, {0, mag, 0}]; 
        radObjDrwAtr[m2, {1, 0, 0.5}]; \n\t\t\t
        m3 = radObjRecMag[p + {0, per/4, 0}, l, {0, \(-mag\), 0}]; 
        radObjDrwAtr[m3, {1, 0, 0.5}]; \n\t\t\n\t\t
        d = {0, per/2 - per/16 + air/4, 0}; \n\t\t\t
        m4 = radObjRecMag[p - d, lf, {0, 0, \(-mag\)}]; 
        radObjDrwAtr[m4, {0, 1, 0.5}]; \n\t\t\t
        m5 = radObjRecMag[p + d, lf, {0, 0, \(-mag\)}]; 
        radObjDrwAtr[m5, {0, 1, 0.5}]; \n\n\t\t
        radObjAddToCnt[g, {m1, m2, m3, m4, m5}]; \n\t\t]\n
    \n (*___  ___  ___  ___  ___*) \n\), 
    \(und[gw_, p_List, nper_, per_, air_, lx_, lz_, mag_] := 
      \((\n\n\t\t
        Table[\nperi[gw, p + {0, per*\((i - \((nper + 1)\)/2)\), 0}, per, 
            air, lx, lz, mag]\n, {i, nper}]; \t)\); \n
    \n (*___  ___  ___  ___  ___  _*) \n\n
    integ[t_List] := \n
      Module[{a, t1}, \nt1 = t; a = 0; 
        Do[a += t[\([i]\)]; \(t1[\([i]\)] = a; \), {i, Length[t]}]; t1]\)}], 
  "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Creates the Geometry", "Section"],

Cell["Creation of an undulator  and display of its geometry", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Period = 34. ; NumberOfPeriod = 10; Gap = 10. ; \nHorWidth = 35. ; 
    VertWidth = Period/2; Airgap = 1. ; \nMagnetization = 1.2; \n
    radUtiDelAll[]; \n\tg = radObjCnt[{}]; \n
    und[g, {0, 0, \(-Gap\)/2 - VertWidth/2}, NumberOfPeriod, Period, Airgap, 
      HorWidth, VertWidth, Magnetization]; \n
    RadTrfZerPara[g, {0, 0, 0}, {0, 0, 1}]; \nRadPlot3DOptions[]; \n
    Show[Graphics3D[radObjDrw[g]]]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.891 .65715 -11.7121 0 ]
[.891 .65715 12.5379 14 ]
[.90597 .64996 -4.8231 0 ]
[.90597 .64996 5.1769 14 ]
[.9211 .64269 -7.70623 0 ]
[.9211 .64269 8.29377 14 ]
[.90818 .71242 -7.5361 0 ]
[.90818 .71242 8.0889 14 ]
[.27931 .36093 -14.8266 -14 ]
[.27931 .36093 15.4234 0 ]
[.5251 .41248 -5.01117 -14 ]
[.5251 .41248 4.98883 0 ]
[.75639 .46099 -11.2499 -14 ]
[.75639 .46099 10.7501 0 ]
[.52496 .34998 -7.82995 -14 ]
[.52496 .34998 7.79505 0 ]
[.01876 .37157 -24.25 -8.42224 ]
[.01876 .37157 0 5.57776 ]
[.01764 .39816 -24.25 -8.39976 ]
[.01764 .39816 0 5.60024 ]
[.01651 .42487 -10 -8.37718 ]
[.01651 .42487 0 5.62282 ]
[.01538 .45172 -16 -8.3545 ]
[.01538 .45172 0 5.6455 ]
[.01425 .47869 -16 -8.33172 ]
[.01425 .47869 0 5.66828 ]
[-0.04481 .41281 -14.3125 -8.37718 ]
[-0.04481 .41281 0 5.62282 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.87816 .65062 m
.93341 .62406 L
s
.25 Mabswid
.89057 .64466 m
.89036 .63841 L
s
gsave
.891 .65715 -72.7121 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.90553 .63746 m
.90531 .63122 L
s
gsave
.90597 .64996 -65.8231 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.92064 .6302 m
.92041 .62395 L
s
gsave
.9211 .64269 -68.7062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.89355 .64322 m
.89342 .63948 L
s
.89654 .64179 m
.89641 .63804 L
s
.89953 .64035 m
.8994 .6366 L
s
.90253 .63891 m
.90239 .63516 L
s
.90854 .63602 m
.9084 .63227 L
s
.91155 .63457 m
.91142 .63082 L
s
.91457 .63311 m
.91444 .62937 L
s
.9176 .63166 m
.91747 .62791 L
s
.8876 .64609 m
.88747 .64234 L
s
.88463 .64751 m
.88451 .64376 L
s
.88167 .64894 m
.88155 .64519 L
s
.87872 .65036 m
.87859 .64661 L
s
.92368 .62874 m
.92354 .62499 L
s
.92672 .62727 m
.92658 .62352 L
s
.92977 .6258 m
.92963 .62206 L
s
.93283 .62433 m
.93269 .62059 L
s
gsave
.90818 .71242 -68.5361 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.0748 .33064 m
.92907 .5096 L
s
.25 Mabswid
.27906 .37343 m
.27894 .37968 L
s
gsave
.27931 .36093 -75.8266 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.52513 .42498 m
.52515 .43123 L
s
gsave
.5251 .41248 -66.0112 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.75667 .47348 m
.75682 .47973 L
s
gsave
.75639 .46099 -72.2499 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.3295 .384 m
.32945 .38775 L
s
.37932 .39443 m
.37928 .39818 L
s
.42852 .40474 m
.4285 .40849 L
s
.47712 .41492 m
.47711 .41867 L
s
.57256 .43492 m
.57258 .43867 L
s
.61942 .44473 m
.61946 .44848 L
s
.66572 .45443 m
.66577 .45818 L
s
.71147 .46401 m
.71154 .46776 L
s
.22798 .36273 m
.22789 .36648 L
s
.17625 .3519 m
.17615 .35564 L
s
.12386 .34092 m
.12374 .34467 L
s
.80135 .48284 m
.80145 .48659 L
s
.84551 .49209 m
.84562 .49584 L
s
.88915 .50124 m
.88928 .50498 L
s
gsave
.52496 .34998 -68.8299 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.03135 .36585 m
.02618 .4894 L
s
.25 Mabswid
.03101 .37406 m
.03713 .3753 L
s
gsave
.01876 .37157 -85.25 -12.4222 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02989 .40061 m
.03602 .40184 L
s
gsave
.01764 .39816 -85.25 -12.3998 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02878 .42729 m
.03491 .42849 L
s
gsave
.01651 .42487 -71 -12.3772 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02765 .45409 m
.03379 .45528 L
s
gsave
.01538 .45172 -77 -12.3545 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02653 .48102 m
.03267 .48219 L
s
gsave
.01425 .47869 -77 -12.3317 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.03078 .37936 m
.03446 .3801 L
s
.03056 .38467 m
.03424 .38541 L
s
.03034 .38998 m
.03402 .39072 L
s
.03012 .39529 m
.03379 .39603 L
s
.02967 .40594 m
.03335 .40667 L
s
.02945 .41127 m
.03313 .412 L
s
.02922 .4166 m
.0329 .41733 L
s
.029 .42194 m
.03268 .42267 L
s
.02855 .43264 m
.03223 .43336 L
s
.02833 .43799 m
.03201 .43871 L
s
.0281 .44336 m
.03178 .44407 L
s
.02788 .44872 m
.03156 .44944 L
s
.02743 .45947 m
.03111 .46018 L
s
.0272 .46485 m
.03089 .46556 L
s
.02698 .47024 m
.03066 .47094 L
s
.02675 .47563 m
.03044 .47633 L
s
.03123 .36877 m
.0349 .36951 L
s
.0263 .48643 m
.02998 .48712 L
s
gsave
-0.04481 .41281 -75.3125 -12.3772 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.03135 .36585 m
.02618 .4894 L
s
.02618 .4894 m
.87816 .65062 L
s
.87816 .65062 m
.87445 .53799 L
s
.87445 .53799 m
.03135 .36585 L
s
.0748 .33064 m
.92907 .5096 L
s
.92907 .5096 m
.93341 .62406 L
s
.93341 .62406 m
.07001 .45637 L
s
.07001 .45637 m
.0748 .33064 L
s
.03135 .36585 m
.02618 .4894 L
s
.02618 .4894 m
.07001 .45637 L
s
.07001 .45637 m
.0748 .33064 L
s
.0748 .33064 m
.03135 .36585 L
s
.87445 .53799 m
.92907 .5096 L
s
.92907 .5096 m
.93341 .62406 L
s
.93341 .62406 m
.87816 .65062 L
s
.87816 .65062 m
.87445 .53799 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.91108 .55111 m .90956 .50916 L .85772 .53629 L p 0 .415 .36 r
F P
0 g
s
.85772 .53629 m .85902 .5776 L .91108 .55111 L p 0 .415 .36 r
F P
0 g
s
.85902 .5776 m .85772 .53629 L .84971 .53466 L p 0 .701 .369 r
F P
0 g
s
.84971 .53466 m .85772 .53629 L .90956 .50916 L p 0 .892 .535 r
F P
0 g
s
.84971 .53466 m .85098 .57601 L .85902 .5776 L p 0 .701 .369 r
F P
0 g
s
.90295 .54945 m .85098 .57601 L .84971 .53466 L p 0 .414 .359 r
F P
0 g
s
.90956 .50916 m .90147 .50747 L .84971 .53466 L p 0 .892 .535 r
F P
0 g
s
.84971 .53466 m .90147 .50747 L .90295 .54945 L p 0 .414 .359 r
F P
0 g
s
.90078 .54901 m .8993 .50702 L .84757 .53422 L p .531 0 .359 r
F P
0 g
s
.84757 .53422 m .84884 .57558 L .90078 .54901 L p .531 0 .359 r
F P
0 g
s
.84884 .57558 m .84757 .53422 L .83149 .53094 L p .895 0 .369 r
F P
0 g
s
.83149 .53094 m .84757 .53422 L .8993 .50702 L p .706 0 .535 r
F P
0 g
s
.83149 .53094 m .8327 .57238 L .84884 .57558 L p .895 0 .369 r
F P
0 g
s
.88447 .54569 m .8327 .57238 L .83149 .53094 L p .528 0 .359 r
F P
0 g
s
.8993 .50702 m .88305 .50362 L .83149 .53094 L p .706 0 .535 r
F P
0 g
s
.83149 .53094 m .88305 .50362 L .88447 .54569 L p .528 0 .359 r
F P
0 g
s
.91108 .55111 m .85902 .5776 L .85098 .57601 L p 0 .895 .537 r
F P
0 g
s
.88229 .54525 m .88087 .50317 L .82934 .5305 L p 0 .411 .359 r
F P
0 g
s
.82934 .5305 m .83054 .57195 L .88229 .54525 L p 0 .411 .359 r
F P
0 g
s
.83054 .57195 m .82934 .5305 L .81318 .52721 L p 0 .701 .369 r
F P
0 g
s
.81318 .52721 m .82934 .5305 L .88087 .50317 L p 0 .892 .535 r
F P
0 g
s
.85098 .57601 m .90295 .54945 L .91108 .55111 L p 0 .895 .537 r
F P
0 g
s
.90078 .54901 m .84884 .57558 L .8327 .57238 L p .701 0 .537 r
F P
0 g
s
.91198 .57592 m .85979 .60204 L .86111 .64383 L p 0 .415 .36 r
F P
0 g
s
.85173 .60047 m .85979 .60204 L .91198 .57592 L p 0 .896 .538 r
F P
0 g
s
.85979 .60204 m .85173 .60047 L .85302 .6423 L p 0 .701 .369 r
F P
0 g
s
.85302 .6423 m .86111 .64383 L .85979 .60204 L p 0 .701 .369 r
F P
0 g
s
.81318 .52721 m .81432 .56873 L .83054 .57195 L p 0 .701 .369 r
F P
0 g
s
.86589 .54191 m .81432 .56873 L .81318 .52721 L p 0 .409 .358 r
F P
0 g
s
.88087 .50317 m .86454 .49975 L .81318 .52721 L p 0 .892 .535 r
F P
0 g
s
.81318 .52721 m .86454 .49975 L .86589 .54191 L p 0 .409 .358 r
F P
0 g
s
.8637 .54147 m .86235 .4993 L .81101 .52677 L p .525 0 .358 r
F P
0 g
s
.81101 .52677 m .81215 .5683 L .8637 .54147 L p .525 0 .358 r
F P
0 g
s
.81215 .5683 m .81101 .52677 L .79477 .52346 L p .895 0 .369 r
F P
0 g
s
.79477 .52346 m .81101 .52677 L .86235 .4993 L p .706 0 .535 r
F P
0 g
s
.91198 .57592 m .90383 .57429 L .85173 .60047 L p 0 .896 .538 r
F P
0 g
s
.85302 .6423 m .85173 .60047 L .90383 .57429 L p 0 .414 .359 r
F P
0 g
s
.8327 .57238 m .88447 .54569 L .90078 .54901 L p .701 0 .537 r
F P
0 g
s
.90166 .57386 m .84958 .60005 L .85086 .64189 L p .531 0 .359 r
F P
0 g
s
.83341 .59689 m .84958 .60005 L .90166 .57386 L p .698 0 .538 r
F P
0 g
s
.84958 .60005 m .83341 .59689 L .83463 .63881 L p .895 0 .369 r
F P
0 g
s
.83463 .63881 m .85086 .64189 L .84958 .60005 L p .895 0 .369 r
F P
0 g
s
.88229 .54525 m .83054 .57195 L .81432 .56873 L p 0 .895 .537 r
F P
0 g
s
.79477 .52346 m .79586 .56506 L .81215 .5683 L p .895 0 .369 r
F P
0 g
s
.84723 .53812 m .79586 .56506 L .79477 .52346 L p .523 0 .358 r
F P
0 g
s
.86235 .4993 m .84594 .49587 L .79477 .52346 L p .706 0 .535 r
F P
0 g
s
.79477 .52346 m .84594 .49587 L .84723 .53812 L p .523 0 .358 r
F P
0 g
s
.84502 .53767 m .84374 .49541 L .7926 .52301 L p 0 .406 .358 r
F P
0 g
s
.7926 .52301 m .79368 .56463 L .84502 .53767 L p 0 .406 .358 r
F P
0 g
s
.79368 .56463 m .7926 .52301 L .78445 .52135 L p 0 .701 .369 r
F P
0 g
s
.78445 .52135 m .7926 .52301 L .84374 .49541 L p 0 .892 .535 r
F P
0 g
s
.90166 .57386 m .88531 .57059 L .83341 .59689 L p .698 0 .538 r
F P
0 g
s
.83463 .63881 m .83341 .59689 L .88531 .57059 L p .528 0 .359 r
F P
0 g
s
.86111 .64383 m .91351 .61836 L .91198 .57592 L p 0 .415 .36 r
F P
0 g
s
.91351 .61836 m .86111 .64383 L .85302 .6423 L p 0 .899 .539 r
F P
0 g
s
.88313 .57015 m .83125 .59647 L .83247 .6384 L p 0 .411 .359 r
F P
0 g
s
.815 .5933 m .83125 .59647 L .88313 .57015 L p 0 .896 .538 r
F P
0 g
s
.83125 .59647 m .815 .5933 L .81616 .6353 L p 0 .701 .369 r
F P
0 g
s
.81616 .6353 m .83247 .6384 L .83125 .59647 L p 0 .701 .369 r
F P
0 g
s
.81432 .56873 m .86589 .54191 L .88229 .54525 L p 0 .895 .537 r
F P
0 g
s
.78445 .52135 m .7855 .56301 L .79368 .56463 L p 0 .701 .369 r
F P
0 g
s
.83675 .53599 m .7855 .56301 L .78445 .52135 L p 0 .404 .357 r
F P
0 g
s
.84374 .49541 m .8355 .49368 L .78445 .52135 L p 0 .892 .535 r
F P
0 g
s
.78445 .52135 m .8355 .49368 L .83675 .53599 L p 0 .404 .357 r
F P
0 g
s
.83675 .53599 m .8355 .49368 L .78445 .52135 L p 0 .404 .357 r
F P
0 g
s
.78445 .52135 m .7855 .56301 L .83675 .53599 L p 0 .404 .357 r
F P
0 g
s
.7855 .56301 m .78445 .52135 L .77628 .51969 L p 0 .701 .369 r
F P
0 g
s
.77628 .51969 m .78445 .52135 L .8355 .49368 L p 0 .892 .535 r
F P
0 g
s
.8637 .54147 m .81215 .5683 L .79586 .56506 L p .701 0 .537 r
F P
0 g
s
.90383 .57429 m .90534 .61677 L .85302 .6423 L p 0 .414 .359 r
F P
0 g
s
.85302 .6423 m .90534 .61677 L .91351 .61836 L p 0 .899 .539 r
F P
0 g
s
.85086 .64189 m .90316 .61635 L .90166 .57386 L p .531 0 .359 r
F P
0 g
s
.90316 .61635 m .85086 .64189 L .83463 .63881 L p .692 0 .539 r
F P
0 g
s
.77628 .51969 m .7773 .56138 L .7855 .56301 L p 0 .701 .369 r
F P
0 g
s
.82847 .5343 m .7773 .56138 L .77628 .51969 L p 0 .403 .357 r
F P
0 g
s
.8355 .49368 m .82724 .49196 L .77628 .51969 L p 0 .892 .535 r
F P
0 g
s
.77628 .51969 m .82724 .49196 L .82847 .5343 L p 0 .403 .357 r
F P
0 g
s
.82625 .53385 m .82504 .4915 L .7741 .51924 L p .519 0 .357 r
F P
0 g
s
.7741 .51924 m .77511 .56095 L .82625 .53385 L p .519 0 .357 r
F P
0 g
s
.77511 .56095 m .7741 .51924 L .7577 .5159 L p .895 0 .369 r
F P
0 g
s
.7577 .5159 m .7741 .51924 L .82504 .4915 L p .706 0 .535 r
F P
0 g
s
.88313 .57015 m .8667 .56686 L .815 .5933 L p 0 .896 .538 r
F P
0 g
s
.81616 .6353 m .815 .5933 L .8667 .56686 L p 0 .409 .358 r
F P
0 g
s
.8645 .56642 m .81283 .59287 L .81398 .63489 L p .525 0 .358 r
F P
0 g
s
.79649 .58968 m .81283 .59287 L .8645 .56642 L p .698 0 .538 r
F P
0 g
s
.81283 .59287 m .79649 .58968 L .79759 .63178 L p .895 0 .369 r
F P
0 g
s
.79759 .63178 m .81398 .63489 L .81283 .59287 L p .895 0 .369 r
F P
0 g
s
.79586 .56506 m .84723 .53812 L .8637 .54147 L p .701 0 .537 r
F P
0 g
s
.84502 .53767 m .79368 .56463 L .7855 .56301 L p 0 .895 .537 r
F P
0 g
s
.88531 .57059 m .88675 .61316 L .83463 .63881 L p .528 0 .359 r
F P
0 g
s
.83463 .63881 m .88675 .61316 L .90316 .61635 L p .692 0 .539 r
F P
0 g
s
.7577 .5159 m .75865 .55768 L .77511 .56095 L p .895 0 .369 r
F P
0 g
s
.80961 .53047 m .75865 .55768 L .7577 .5159 L p .517 0 .356 r
F P
0 g
s
.82504 .4915 m .80845 .48803 L .7577 .5159 L p .706 0 .535 r
F P
0 g
s
.7577 .5159 m .80845 .48803 L .80961 .53047 L p .517 0 .356 r
F P
0 g
s
.83247 .6384 m .88456 .61273 L .88313 .57015 L p 0 .411 .359 r
F P
0 g
s
.88456 .61273 m .83247 .6384 L .81616 .6353 L p 0 .899 .539 r
F P
0 g
s
.7855 .56301 m .83675 .53599 L .84502 .53767 L p 0 .895 .537 r
F P
0 g
s
.83675 .53599 m .7855 .56301 L .7773 .56138 L p 0 .895 .537 r
F P
0 g
s
.80739 .53001 m .80624 .48757 L .75551 .51545 L p 0 .4 .356 r
F P
0 g
s
.75551 .51545 m .75645 .55724 L .80739 .53001 L p 0 .4 .356 r
F P
0 g
s
.75645 .55724 m .75551 .51545 L .73903 .51209 L p 0 .701 .369 r
F P
0 g
s
.73903 .51209 m .75551 .51545 L .80624 .48757 L p 0 .892 .535 r
F P
0 g
s
.8645 .56642 m .84799 .56312 L .79649 .58968 L p .698 0 .538 r
F P
0 g
s
.79759 .63178 m .79649 .58968 L .84799 .56312 L p .523 0 .358 r
F P
0 g
s
.84578 .56268 m .79431 .58926 L .7954 .63136 L p 0 .406 .358 r
F P
0 g
s
.78612 .58766 m .79431 .58926 L .84578 .56268 L p 0 .896 .538 r
F P
0 g
s
.79431 .58926 m .78612 .58766 L .78717 .6298 L p 0 .701 .369 r
F P
0 g
s
.78717 .6298 m .7954 .63136 L .79431 .58926 L p 0 .701 .369 r
F P
0 g
s
.7773 .56138 m .82847 .5343 L .83675 .53599 L p 0 .895 .537 r
F P
0 g
s
.82625 .53385 m .77511 .56095 L .75865 .55768 L p .701 0 .537 r
F P
0 g
s
.8667 .56686 m .86807 .60953 L .81616 .6353 L p 0 .409 .358 r
F P
0 g
s
.81616 .6353 m .86807 .60953 L .88456 .61273 L p 0 .899 .539 r
F P
0 g
s
.84578 .56268 m .8375 .56102 L .78612 .58766 L p 0 .896 .538 r
F P
0 g
s
.78717 .6298 m .78612 .58766 L .8375 .56102 L p 0 .404 .357 r
F P
0 g
s
.8375 .56102 m .78612 .58766 L .78717 .6298 L p 0 .404 .357 r
F P
0 g
s
.7779 .58605 m .78612 .58766 L .8375 .56102 L p 0 .896 .538 r
F P
0 g
s
.78612 .58766 m .7779 .58605 L .77893 .62824 L p 0 .701 .369 r
F P
0 g
s
.77893 .62824 m .78717 .6298 L .78612 .58766 L p 0 .701 .369 r
F P
0 g
s
.73903 .51209 m .73991 .55396 L .75645 .55724 L p 0 .701 .369 r
F P
0 g
s
.79066 .52661 m .73991 .55396 L .73903 .51209 L p 0 .398 .356 r
F P
0 g
s
.80624 .48757 m .78957 .48409 L .73903 .51209 L p 0 .892 .535 r
F P
0 g
s
.73903 .51209 m .78957 .48409 L .79066 .52661 L p 0 .398 .356 r
F P
0 g
s
.81398 .63489 m .86587 .6091 L .8645 .56642 L p .525 0 .358 r
F P
0 g
s
.86587 .6091 m .81398 .63489 L .79759 .63178 L p .692 0 .539 r
F P
0 g
s
.78843 .52616 m .78734 .48362 L .73683 .51164 L p .513 0 .356 r
F P
0 g
s
.73683 .51164 m .7377 .55352 L .78843 .52616 L p .513 0 .356 r
F P
0 g
s
.7377 .55352 m .73683 .51164 L .72027 .50826 L p .895 0 .369 r
F P
0 g
s
.72027 .50826 m .73683 .51164 L .78734 .48362 L p .706 0 .535 r
F P
0 g
s
.8375 .56102 m .82919 .55936 L .7779 .58605 L p 0 .896 .538 r
F P
0 g
s
.77893 .62824 m .7779 .58605 L .82919 .55936 L p 0 .403 .357 r
F P
0 g
s
.82697 .55891 m .77571 .58562 L .77673 .62782 L p .519 0 .357 r
F P
0 g
s
.75921 .5824 m .77571 .58562 L .82697 .55891 L p .698 0 .538 r
F P
0 g
s
.77571 .58562 m .75921 .5824 L .76018 .62468 L p .895 0 .369 r
F P
0 g
s
.76018 .62468 m .77673 .62782 L .77571 .58562 L p .895 0 .369 r
F P
0 g
s
.75865 .55768 m .80961 .53047 L .82625 .53385 L p .701 0 .537 r
F P
0 g
s
.80739 .53001 m .75645 .55724 L .73991 .55396 L p 0 .895 .537 r
F P
0 g
s
.90147 .50747 m .90956 .50916 L .91108 .55111 L p 0 .701 .368 r
F P
0 g
s
.84799 .56312 m .8493 .60587 L .79759 .63178 L p .523 0 .358 r
F P
0 g
s
.79759 .63178 m .8493 .60587 L .86587 .6091 L p .692 0 .539 r
F P
0 g
s
.7954 .63136 m .84708 .60544 L .84578 .56268 L p 0 .406 .358 r
F P
0 g
s
.84708 .60544 m .7954 .63136 L .78717 .6298 L p 0 .899 .539 r
F P
0 g
s
.72027 .50826 m .72108 .55022 L .7377 .55352 L p .895 0 .369 r
F P
0 g
s
.77162 .52274 m .72108 .55022 L .72027 .50826 L p .511 0 .355 r
F P
0 g
s
.78734 .48362 m .7706 .48012 L .72027 .50826 L p .706 0 .535 r
F P
0 g
s
.72027 .50826 m .7706 .48012 L .77162 .52274 L p .511 0 .355 r
F P
0 g
s
.76937 .52228 m .76836 .47965 L .71805 .50781 L p 0 .394 .355 r
F P
0 g
s
.71805 .50781 m .71886 .54978 L .76937 .52228 L p 0 .394 .355 r
F P
0 g
s
.71886 .54978 m .71805 .50781 L .70974 .50611 L p 0 .701 .369 r
F P
0 g
s
.70974 .50611 m .71805 .50781 L .76836 .47965 L p 0 .892 .535 r
F P
0 g
s
.76836 .47965 m .75995 .47789 L .70974 .50611 L p 0 .892 .535 r
F P
0 g
s
.76093 .52056 m .75995 .47789 L .70974 .50611 L p 0 .393 .355 r
F P
0 g
s
.91108 .55111 m .90295 .54945 L .90147 .50747 L p 0 .701 .368 r
F P
0 g
s
.88305 .50362 m .8993 .50702 L .90078 .54901 L p .898 0 .368 r
F P
0 g
s
.82697 .55891 m .8103 .55558 L .75921 .5824 L p .698 0 .538 r
F P
0 g
s
.76018 .62468 m .75921 .5824 L .8103 .55558 L p .517 0 .356 r
F P
0 g
s
.8375 .56102 m .83876 .60383 L .78717 .6298 L p 0 .404 .357 r
F P
0 g
s
.78717 .6298 m .83876 .60383 L .84708 .60544 L p 0 .899 .539 r
F P
0 g
s
.78717 .6298 m .83876 .60383 L .8375 .56102 L p 0 .404 .357 r
F P
0 g
s
.83876 .60383 m .78717 .6298 L .77893 .62824 L p 0 .899 .539 r
F P
0 g
s
.73991 .55396 m .79066 .52661 L .80739 .53001 L p 0 .895 .537 r
F P
0 g
s
.80807 .55513 m .75701 .58197 L .75796 .62426 L p 0 .4 .356 r
F P
0 g
s
.74044 .57874 m .75701 .58197 L .80807 .55513 L p 0 .896 .538 r
F P
0 g
s
.75701 .58197 m .74044 .57874 L .74133 .62111 L p 0 .701 .369 r
F P
0 g
s
.74133 .62111 m .75796 .62426 L .75701 .58197 L p 0 .701 .369 r
F P
0 g
s
.70974 .50611 m .71052 .54813 L .71886 .54978 L p 0 .701 .369 r
F P
0 g
s
.70974 .50611 m .71052 .54813 L .76093 .52056 L p 0 .393 .355 r
F P
0 g
s
.71052 .54813 m .70974 .50611 L .70141 .50442 L p 0 .701 .369 r
F P
0 g
s
.76093 .52056 m .71052 .54813 L .71052 .54813 L p 0 .393 .355 r
F P
0 g
s
.71052 .54813 m .70974 .50611 L p .76093 .52056 L 0 .393 .355 r
F P
0 g
s
.76093 .52056 m .76093 .52056 L .71052 .54813 L 0 .393 .355 r
F
.70141 .50442 m .70216 .54647 L .71052 .54813 L p 0 .701 .369 r
F P
0 g
s
.76093 .52056 m .71052 .54813 L .70216 .54647 L p 0 .895 .537 r
F P
0 g
s
.70141 .50442 m .70974 .50611 L .75995 .47789 L p 0 .892 .535 r
F P
0 g
s
.70974 .50611 m .75995 .47789 L .76093 .52056 L p 0 .393 .355 r
F P
0 g
s
.78843 .52616 m .7377 .55352 L .72108 .55022 L p .701 0 .537 r
F P
0 g
s
.82919 .55936 m .83043 .60221 L .77893 .62824 L p 0 .403 .357 r
F P
0 g
s
.77893 .62824 m .83043 .60221 L .83876 .60383 L p 0 .899 .539 r
F P
0 g
s
.77673 .62782 m .8282 .60177 L .82697 .55891 L p .519 0 .357 r
F P
0 g
s
.8282 .60177 m .77673 .62782 L .76018 .62468 L p .692 0 .539 r
F P
0 g
s
.75248 .51884 m .70216 .54647 L .70141 .50442 L p 0 .392 .354 r
F P
0 g
s
.75995 .47789 m .75153 .47613 L .70141 .50442 L p 0 .892 .535 r
F P
0 g
s
.70141 .50442 m .75153 .47613 L .75248 .51884 L p 0 .392 .354 r
F P
0 g
s
.75022 .51838 m .74928 .47566 L .69919 .50396 L p .507 0 .354 r
F P
0 g
s
.69919 .50396 m .69993 .54603 L .75022 .51838 L p .507 0 .354 r
F P
0 g
s
.69993 .54603 m .69919 .50396 L .68246 .50055 L p .895 0 .369 r
F P
0 g
s
.68246 .50055 m .69919 .50396 L .74928 .47566 L p .706 0 .535 r
F P
0 g
s
.90078 .54901 m .88447 .54569 L .88305 .50362 L p .898 0 .368 r
F P
0 g
s
.86454 .49975 m .88087 .50317 L .88229 .54525 L p 0 .701 .368 r
F P
0 g
s
.80807 .55513 m .79131 .55178 L .74044 .57874 L p 0 .896 .538 r
F P
0 g
s
.74133 .62111 m .74044 .57874 L .79131 .55178 L p 0 .398 .356 r
F P
0 g
s
.72108 .55022 m .77162 .52274 L .78843 .52616 L p .701 0 .537 r
F P
0 g
s
.78907 .55133 m .73822 .57831 L .73911 .62069 L p .513 0 .356 r
F P
0 g
s
.72157 .57505 m .73822 .57831 L .78907 .55133 L p .698 0 .538 r
F P
0 g
s
.73822 .57831 m .72157 .57505 L .72239 .61751 L p .895 0 .369 r
F P
0 g
s
.72239 .61751 m .73911 .62069 L .73822 .57831 L p .895 0 .369 r
F P
0 g
s
.76937 .52228 m .71886 .54978 L .71052 .54813 L p 0 .895 .537 r
F P
0 g
s
.8103 .55558 m .81147 .59852 L .76018 .62468 L p .517 0 .356 r
F P
0 g
s
.76018 .62468 m .81147 .59852 L .8282 .60177 L p .692 0 .539 r
F P
0 g
s
.75796 .62426 m .80923 .59808 L .80807 .55513 L p 0 .4 .356 r
F P
0 g
s
.80923 .59808 m .75796 .62426 L .74133 .62111 L p 0 .899 .539 r
F P
0 g
s
.68246 .50055 m .68314 .54269 L .69993 .54603 L p .895 0 .369 r
F P
0 g
s
.73324 .51493 m .68314 .54269 L .68246 .50055 L p .504 0 .354 r
F P
0 g
s
.74928 .47566 m .73236 .47213 L .68246 .50055 L p .706 0 .535 r
F P
0 g
s
.68246 .50055 m .73236 .47213 L .73324 .51493 L p .504 0 .354 r
F P
0 g
s
.71052 .54813 m .76093 .52056 L .76937 .52228 L p 0 .895 .537 r
F P
0 g
s
.73097 .51447 m .7301 .47166 L .68023 .5001 L p 0 .388 .354 r
F P
0 g
s
.68023 .5001 m .6809 .54225 L .73097 .51447 L p 0 .388 .354 r
F P
0 g
s
.6809 .54225 m .68023 .5001 L .66342 .49667 L p 0 .701 .369 r
F P
0 g
s
.66342 .49667 m .68023 .5001 L .7301 .47166 L p 0 .892 .535 r
F P
0 g
s
.91198 .57592 m .91351 .61836 L .90534 .61677 L p 0 .701 .368 r
F P
0 g
s
.90534 .61677 m .90383 .57429 L .91198 .57592 L p 0 .701 .368 r
F P
0 g
s
.88229 .54525 m .86589 .54191 L .86454 .49975 L p 0 .701 .368 r
F P
0 g
s
.84594 .49587 m .86235 .4993 L .8637 .54147 L p .898 0 .368 r
F P
0 g
s
.78907 .55133 m .77222 .54796 L .72157 .57505 L p .698 0 .538 r
F P
0 g
s
.72239 .61751 m .72157 .57505 L .77222 .54796 L p .511 0 .355 r
F P
0 g
s
.70216 .54647 m .75248 .51884 L .76093 .52056 L p 0 .895 .537 r
F P
0 g
s
.76997 .54751 m .71934 .57462 L .72016 .61709 L p 0 .394 .355 r
F P
0 g
s
.71098 .57299 m .71934 .57462 L .76997 .54751 L p 0 .896 .538 r
F P
0 g
s
.71934 .57462 m .71098 .57299 L .71177 .6155 L p 0 .701 .369 r
F P
0 g
s
.71177 .6155 m .72016 .61709 L .71934 .57462 L p 0 .701 .369 r
F P
0 g
s
.76997 .54751 m .76151 .54581 L .71098 .57299 L p 0 .896 .538 r
F P
0 g
s
.79131 .55178 m .79241 .59481 L .74133 .62111 L p 0 .398 .356 r
F P
0 g
s
.73911 .62069 m .79016 .59438 L .78907 .55133 L p .513 0 .356 r
F P
0 g
s
.77222 .54796 m .77325 .59109 L .72239 .61751 L p .511 0 .355 r
F P
0 g
s
.72016 .61709 m .77099 .59065 L .76997 .54751 L p 0 .394 .355 r
F P
0 g
s
.71177 .6155 m .76251 .589 L .76151 .54581 L p 0 .393 .355 r
F P
0 g
s
.76151 .54581 m .71098 .57299 L .71177 .6155 L p 0 .393 .355 r
F P
0 g
s
.75022 .51838 m .69993 .54603 L .68314 .54269 L p .701 0 .537 r
F P
0 g
s
.90166 .57386 m .90316 .61635 L .88675 .61316 L p .898 0 .368 r
F P
0 g
s
.88675 .61316 m .88531 .57059 L .90166 .57386 L p .898 0 .368 r
F P
0 g
s
.74133 .62111 m .79241 .59481 L .80923 .59808 L p 0 .899 .539 r
F P
0 g
s
.71177 .6155 m .71098 .57299 L .76151 .54581 L p 0 .393 .355 r
F P
0 g
s
.7026 .57135 m .71098 .57299 L .76151 .54581 L p 0 .896 .538 r
F P
0 g
s
.71098 .57299 m .7026 .57135 L .70336 .6139 L p 0 .701 .369 r
F P
0 g
s
.70336 .6139 m .71177 .6155 L .71098 .57299 L p 0 .701 .369 r
F P
0 g
s
.66342 .49667 m .66403 .5389 L .6809 .54225 L p 0 .701 .369 r
F P
0 g
s
.7139 .511 m .66403 .5389 L .66342 .49667 L p 0 .386 .353 r
F P
0 g
s
.7301 .47166 m .71309 .4681 L .66342 .49667 L p 0 .892 .535 r
F P
0 g
s
.66342 .49667 m .71309 .4681 L .7139 .511 L p 0 .386 .353 r
F P
0 g
s
.79016 .59438 m .73911 .62069 L .72239 .61751 L p .692 0 .539 r
F P
0 g
s
.71162 .51053 m .71082 .46763 L .66117 .49621 L p .501 0 .353 r
F P
0 g
s
.66117 .49621 m .66177 .53845 L .71162 .51053 L p .501 0 .353 r
F P
0 g
s
.66177 .53845 m .66117 .49621 L .64428 .49276 L p .895 0 .369 r
F P
0 g
s
.64428 .49276 m .66117 .49621 L .71082 .46763 L p .706 0 .535 r
F P
0 g
s
.8637 .54147 m .84723 .53812 L .84594 .49587 L p .898 0 .368 r
F P
0 g
s
.8355 .49368 m .84374 .49541 L .84502 .53767 L p 0 .701 .368 r
F P
0 g
s
.76151 .54581 m .75304 .54412 L .7026 .57135 L p 0 .896 .538 r
F P
0 g
s
.70336 .6139 m .7026 .57135 L .75304 .54412 L p 0 .392 .354 r
F P
0 g
s
.68314 .54269 m .73324 .51493 L .75022 .51838 L p .701 0 .537 r
F P
0 g
s
.75078 .54367 m .70036 .57091 L .70111 .61348 L p .507 0 .354 r
F P
0 g
s
.68354 .56763 m .70036 .57091 L .75078 .54367 L p .698 0 .538 r
F P
0 g
s
.70036 .57091 m .68354 .56763 L .68423 .61028 L p .895 0 .369 r
F P
0 g
s
.68423 .61028 m .70111 .61348 L .70036 .57091 L p .895 0 .369 r
F P
0 g
s
.73097 .51447 m .6809 .54225 L .66403 .5389 L p 0 .895 .537 r
F P
0 g
s
.88313 .57015 m .88456 .61273 L .86807 .60953 L p 0 .701 .368 r
F P
0 g
s
.86807 .60953 m .8667 .56686 L .88313 .57015 L p 0 .701 .368 r
F P
0 g
s
.84502 .53767 m .83675 .53599 L .8355 .49368 L p 0 .701 .368 r
F P
0 g
s
.82724 .49196 m .8355 .49368 L .83675 .53599 L p 0 .701 .368 r
F P
0 g
s
.72239 .61751 m .77325 .59109 L .79016 .59438 L p .692 0 .539 r
F P
0 g
s
.64428 .49276 m .64482 .53509 L .66177 .53845 L p .895 0 .369 r
F P
0 g
s
.69447 .50704 m .64482 .53509 L .64428 .49276 L p .498 0 .352 r
F P
0 g
s
.71082 .46763 m .69373 .46406 L .64428 .49276 L p .706 0 .535 r
F P
0 g
s
.64428 .49276 m .69373 .46406 L .69447 .50704 L p .498 0 .352 r
F P
0 g
s
.77099 .59065 m .72016 .61709 L .71177 .6155 L p 0 .899 .539 r
F P
0 g
s
.69218 .50658 m .69145 .46358 L .64202 .4923 L p 0 .382 .352 r
F P
0 g
s
.64202 .4923 m .64255 .53464 L .69218 .50658 L p 0 .382 .352 r
F P
0 g
s
.64255 .53464 m .64202 .4923 L .63354 .49057 L p 0 .701 .369 r
F P
0 g
s
.63354 .49057 m .64202 .4923 L .69145 .46358 L p 0 .892 .535 r
F P
0 g
s
.69145 .46358 m .68287 .46179 L .63354 .49057 L p 0 .892 .535 r
F P
0 g
s
.68357 .50483 m .68287 .46179 L .63354 .49057 L p 0 .381 .352 r
F P
0 g
s
.83675 .53599 m .82847 .5343 L .82724 .49196 L p 0 .701 .368 r
F P
0 g
s
.80845 .48803 m .82504 .4915 L .82625 .53385 L p .898 0 .368 r
F P
0 g
s
.75078 .54367 m .73376 .54026 L .68354 .56763 L p .698 0 .538 r
F P
0 g
s
.68423 .61028 m .68354 .56763 L .73376 .54026 L p .504 0 .354 r
F P
0 g
s
.76151 .54581 m .76251 .589 L .71177 .6155 L p 0 .393 .355 r
F P
0 g
s
.76251 .589 m .71177 .6155 L .70336 .6139 L p 0 .899 .539 r
F P
0 g
s
.71177 .6155 m .76251 .589 L .77099 .59065 L p 0 .899 .539 r
F P
0 g
s
.66403 .5389 m .7139 .511 L .73097 .51447 L p 0 .895 .537 r
F P
0 g
s
.73149 .5398 m .68129 .56719 L .68197 .60985 L p 0 .388 .354 r
F P
0 g
s
.66439 .56389 m .68129 .56719 L .73149 .5398 L p 0 .896 .538 r
F P
0 g
s
.68129 .56719 m .66439 .56389 L .66501 .60663 L p 0 .701 .369 r
F P
0 g
s
.66501 .60663 m .68197 .60985 L .68129 .56719 L p 0 .701 .369 r
F P
0 g
s
.63354 .49057 m .63404 .53295 L .64255 .53464 L p 0 .701 .369 r
F P
0 g
s
.63354 .49057 m .63404 .53295 L .68357 .50483 L p 0 .381 .352 r
F P
0 g
s
.63404 .53295 m .63354 .49057 L .62505 .48884 L p 0 .701 .369 r
F P
0 g
s
.68357 .50483 m .63404 .53295 L .63354 .49057 L p 0 .381 .352 r
F P
0 g
s
.62505 .48884 m .62552 .53126 L .63404 .53295 L p 0 .701 .369 r
F P
0 g
s
.68357 .50483 m .63404 .53295 L .62552 .53126 L p 0 .895 .537 r
F P
0 g
s
.62505 .48884 m .63354 .49057 L .68287 .46179 L p 0 .892 .535 r
F P
0 g
s
.63354 .49057 m .68287 .46179 L .68357 .50483 L p 0 .381 .352 r
F P
0 g
s
.71162 .51053 m .66177 .53845 L .64482 .53509 L p .701 0 .537 r
F P
0 g
s
.8645 .56642 m .86587 .6091 L .8493 .60587 L p .898 0 .368 r
F P
0 g
s
.8493 .60587 m .84799 .56312 L .8645 .56642 L p .898 0 .368 r
F P
0 g
s
.75304 .54412 m .754 .58734 L .70336 .6139 L p 0 .392 .354 r
F P
0 g
s
.70336 .6139 m .754 .58734 L .76251 .589 L p 0 .899 .539 r
F P
0 g
s
.67494 .50307 m .62552 .53126 L .62505 .48884 L p 0 .379 .352 r
F P
0 g
s
.68287 .46179 m .67427 .45999 L .62505 .48884 L p 0 .892 .535 r
F P
0 g
s
.62505 .48884 m .67427 .45999 L .67494 .50307 L p 0 .379 .352 r
F P
0 g
s
.70111 .61348 m .75173 .5869 L .75078 .54367 L p .507 0 .354 r
F P
0 g
s
.75173 .5869 m .70111 .61348 L .68423 .61028 L p .692 0 .539 r
F P
0 g
s
.67264 .5026 m .67198 .45951 L .62278 .48838 L p .494 0 .351 r
F P
0 g
s
.62278 .48838 m .62324 .5308 L .67264 .5026 L p .494 0 .351 r
F P
0 g
s
.62324 .5308 m .62278 .48838 L .60572 .4849 L p .895 0 .369 r
F P
0 g
s
.60572 .4849 m .62278 .48838 L .67198 .45951 L p .706 0 .535 r
F P
0 g
s
.82625 .53385 m .80961 .53047 L .80845 .48803 L p .898 0 .368 r
F P
0 g
s
.78957 .48409 m .80624 .48757 L .80739 .53001 L p 0 .701 .368 r
F P
0 g
s
.73149 .5398 m .71438 .53638 L .66439 .56389 L p 0 .896 .538 r
F P
0 g
s
.66501 .60663 m .66439 .56389 L .71438 .53638 L p 0 .386 .353 r
F P
0 g
s
.7121 .53593 m .66213 .56345 L .66274 .6062 L p .501 0 .353 r
F P
0 g
s
.64514 .56013 m .66213 .56345 L .7121 .53593 L p .698 0 .538 r
F P
0 g
s
.66213 .56345 m .64514 .56013 L .64569 .60296 L p .895 0 .369 r
F P
0 g
s
.64569 .60296 m .66274 .6062 L .66213 .56345 L p .895 0 .369 r
F P
0 g
s
.64482 .53509 m .69447 .50704 L .71162 .51053 L p .701 0 .537 r
F P
0 g
s
.69218 .50658 m .64255 .53464 L .63404 .53295 L p 0 .895 .537 r
F P
0 g
s
.84578 .56268 m .84708 .60544 L .83876 .60383 L p 0 .701 .368 r
F P
0 g
s
.83876 .60383 m .8375 .56102 L .84578 .56268 L p 0 .701 .368 r
F P
0 g
s
.73376 .54026 m .73465 .58358 L .68423 .61028 L p .504 0 .354 r
F P
0 g
s
.68423 .61028 m .73465 .58358 L .75173 .5869 L p .692 0 .539 r
F P
0 g
s
.68197 .60985 m .73237 .58314 L .73149 .5398 L p 0 .388 .354 r
F P
0 g
s
.73237 .58314 m .68197 .60985 L .66501 .60663 L p 0 .899 .539 r
F P
0 g
s
.60572 .4849 m .60611 .52741 L .62324 .5308 L p .895 0 .369 r
F P
0 g
s
.65531 .49908 m .60611 .52741 L .60572 .4849 L p .491 0 .351 r
F P
0 g
s
.67198 .45951 m .65472 .4559 L .60572 .4849 L p .706 0 .535 r
F P
0 g
s
.60572 .4849 m .65472 .4559 L .65531 .49908 L p .491 0 .351 r
F P
0 g
s
.63404 .53295 m .68357 .50483 L .69218 .50658 L p 0 .895 .537 r
F P
0 g
s
.65299 .49861 m .65241 .45542 L .60344 .48443 L p 0 .376 .351 r
F P
0 g
s
.60344 .48443 m .60383 .52695 L .65299 .49861 L p 0 .376 .351 r
F P
0 g
s
.60383 .52695 m .60344 .48443 L .58629 .48094 L p 0 .701 .369 r
F P
0 g
s
.58629 .48094 m .60344 .48443 L .65241 .45542 L p 0 .892 .535 r
F P
0 g
s
.8375 .56102 m .83876 .60383 L .83043 .60221 L p 0 .701 .368 r
F P
0 g
s
.83043 .60221 m .82919 .55936 L .8375 .56102 L p 0 .701 .368 r
F P
0 g
s
.80739 .53001 m .79066 .52661 L .78957 .48409 L p 0 .701 .368 r
F P
0 g
s
.7706 .48012 m .78734 .48362 L .78843 .52616 L p .898 0 .368 r
F P
0 g
s
.7121 .53593 m .69491 .53249 L .64514 .56013 L p .698 0 .538 r
F P
0 g
s
.64569 .60296 m .64514 .56013 L .69491 .53249 L p .498 0 .352 r
F P
0 g
s
.62552 .53126 m .67494 .50307 L .68357 .50483 L p 0 .895 .537 r
F P
0 g
s
.69261 .53203 m .64287 .55969 L .64341 .60253 L p 0 .382 .352 r
F P
0 g
s
.63434 .55802 m .64287 .55969 L .69261 .53203 L p 0 .896 .538 r
F P
0 g
s
.64287 .55969 m .63434 .55802 L .63485 .60091 L p 0 .701 .369 r
F P
0 g
s
.63485 .60091 m .64341 .60253 L .64287 .55969 L p 0 .701 .369 r
F P
0 g
s
.69261 .53203 m .68398 .5303 L .63434 .55802 L p 0 .896 .538 r
F P
0 g
s
.71438 .53638 m .7152 .5798 L .66501 .60663 L p 0 .386 .353 r
F P
0 g
s
.66274 .6062 m .71291 .57935 L .7121 .53593 L p .501 0 .353 r
F P
0 g
s
.69491 .53249 m .69565 .576 L .64569 .60296 L p .498 0 .352 r
F P
0 g
s
.64341 .60253 m .69335 .57555 L .69261 .53203 L p 0 .382 .352 r
F P
0 g
s
.63485 .60091 m .68469 .57387 L .68398 .5303 L p 0 .381 .352 r
F P
0 g
s
.68398 .5303 m .63434 .55802 L .63485 .60091 L p 0 .381 .352 r
F P
0 g
s
.67264 .5026 m .62324 .5308 L .60611 .52741 L p .701 0 .537 r
F P
0 g
s
.82697 .55891 m .8282 .60177 L .81147 .59852 L p .898 0 .368 r
F P
0 g
s
.81147 .59852 m .8103 .55558 L .82697 .55891 L p .898 0 .368 r
F P
0 g
s
.66501 .60663 m .7152 .5798 L .73237 .58314 L p 0 .899 .539 r
F P
0 g
s
.62579 .55636 m .63434 .55802 L .68398 .5303 L p 0 .896 .538 r
F P
0 g
s
.63434 .55802 m .62579 .55636 L .62627 .59928 L p 0 .701 .369 r
F P
0 g
s
.62627 .59928 m .63485 .60091 L .63434 .55802 L p 0 .701 .369 r
F P
0 g
s
.63485 .60091 m .63434 .55802 L .68398 .5303 L p 0 .381 .352 r
F P
0 g
s
.71291 .57935 m .66274 .6062 L .64569 .60296 L p .692 0 .539 r
F P
0 g
s
.58629 .48094 m .58662 .52354 L .60383 .52695 L p 0 .701 .369 r
F P
0 g
s
.63558 .49506 m .58662 .52354 L .58629 .48094 L p 0 .373 .35 r
F P
0 g
s
.65241 .45542 m .63506 .45179 L .58629 .48094 L p 0 .892 .535 r
F P
0 g
s
.58629 .48094 m .63506 .45179 L .63558 .49506 L p 0 .373 .35 r
F P
0 g
s
.63325 .49459 m .63274 .45131 L .584 .48047 L p .487 0 .35 r
F P
0 g
s
.584 .48047 m .58432 .52308 L .63325 .49459 L p .487 0 .35 r
F P
0 g
s
.58432 .52308 m .584 .48047 L .56677 .47696 L p .895 0 .369 r
F P
0 g
s
.56677 .47696 m .584 .48047 L .63274 .45131 L p .706 0 .535 r
F P
0 g
s
.78843 .52616 m .77162 .52274 L .7706 .48012 L p .898 0 .368 r
F P
0 g
s
.75995 .47789 m .76836 .47965 L .76937 .52228 L p 0 .701 .368 r
F P
0 g
s
.68398 .5303 m .67533 .52857 L .62579 .55636 L p 0 .896 .538 r
F P
0 g
s
.62627 .59928 m .62579 .55636 L .67533 .52857 L p 0 .379 .352 r
F P
0 g
s
.60611 .52741 m .65531 .49908 L .67264 .5026 L p .701 0 .537 r
F P
0 g
s
.67302 .52811 m .62351 .55591 L .62398 .59884 L p .494 0 .351 r
F P
0 g
s
.60635 .55256 m .62351 .55591 L .67302 .52811 L p .698 0 .538 r
F P
0 g
s
.62351 .55591 m .60635 .55256 L .60675 .59558 L p .895 0 .369 r
F P
0 g
s
.60675 .59558 m .62398 .59884 L .62351 .55591 L p .895 0 .369 r
F P
0 g
s
.65299 .49861 m .60383 .52695 L .58662 .52354 L p 0 .895 .537 r
F P
0 g
s
.80807 .55513 m .80923 .59808 L .79241 .59481 L p 0 .701 .368 r
F P
0 g
s
.79241 .59481 m .79131 .55178 L .80807 .55513 L p 0 .701 .368 r
F P
0 g
s
.75153 .47613 m .75995 .47789 L .76093 .52056 L p 0 .701 .368 r
F P
0 g
s
.76937 .52228 m .76093 .52056 L .75995 .47789 L p 0 .701 .368 r
F P
0 g
s
.64569 .60296 m .69565 .576 L .71291 .57935 L p .692 0 .539 r
F P
0 g
s
.56677 .47696 m .56702 .51965 L .58432 .52308 L p .895 0 .369 r
F P
0 g
s
.61574 .49103 m .56702 .51965 L .56677 .47696 L p .484 0 .349 r
F P
0 g
s
.63274 .45131 m .6153 .44766 L .56677 .47696 L p .706 0 .535 r
F P
0 g
s
.56677 .47696 m .6153 .44766 L .61574 .49103 L p .484 0 .349 r
F P
0 g
s
.69335 .57555 m .64341 .60253 L .63485 .60091 L p 0 .899 .539 r
F P
0 g
s
.6134 .49055 m .61297 .44718 L .56446 .47649 L p 0 .369 .349 r
F P
0 g
s
.56446 .47649 m .56471 .51919 L .6134 .49055 L p 0 .369 .349 r
F P
0 g
s
.56471 .51919 m .56446 .47649 L .55581 .47472 L p 0 .701 .369 r
F P
0 g
s
.55581 .47472 m .56446 .47649 L .61297 .44718 L p 0 .892 .535 r
F P
0 g
s
.76093 .52056 m .75248 .51884 L .75153 .47613 L p 0 .701 .368 r
F P
0 g
s
.73236 .47213 m .74928 .47566 L .75022 .51838 L p .898 0 .368 r
F P
0 g
s
.67302 .52811 m .65566 .52463 L .60635 .55256 L p .698 0 .538 r
F P
0 g
s
.60675 .59558 m .60635 .55256 L .65566 .52463 L p .491 0 .351 r
F P
0 g
s
.68398 .5303 m .68469 .57387 L .63485 .60091 L p 0 .381 .352 r
F P
0 g
s
.68469 .57387 m .63485 .60091 L .62627 .59928 L p 0 .899 .539 r
F P
0 g
s
.63485 .60091 m .68469 .57387 L .69335 .57555 L p 0 .899 .539 r
F P
0 g
s
.65334 .52417 m .60406 .55211 L .60445 .59514 L p 0 .376 .351 r
F P
0 g
s
.58681 .54874 m .60406 .55211 L .65334 .52417 L p 0 .896 .538 r
F P
0 g
s
.60406 .55211 m .58681 .54874 L .58714 .59186 L p 0 .701 .369 r
F P
0 g
s
.58714 .59186 m .60445 .59514 L .60406 .55211 L p 0 .701 .369 r
F P
0 g
s
.58662 .52354 m .63558 .49506 L .65299 .49861 L p 0 .895 .537 r
F P
0 g
s
.55581 .47472 m .55603 .51746 L .56471 .51919 L p 0 .701 .369 r
F P
0 g
s
.60462 .48877 m .55603 .51746 L .55581 .47472 L p 0 .368 .349 r
F P
0 g
s
.61297 .44718 m .60421 .44535 L .55581 .47472 L p 0 .892 .535 r
F P
0 g
s
.55581 .47472 m .60421 .44535 L .60462 .48877 L p 0 .368 .349 r
F P
0 g
s
.60462 .48877 m .60421 .44535 L .55581 .47472 L p 0 .368 .349 r
F P
0 g
s
.54715 .47295 m .55581 .47472 L .60421 .44535 L p 0 .892 .535 r
F P
0 g
s
.60421 .44535 m .59544 .44351 L .54715 .47295 L p 0 .892 .535 r
F P
0 g
s
.59544 .44351 m .60421 .44535 L .60462 .48877 L p 0 .701 .368 r
F P
0 g
s
.55581 .47472 m .55603 .51746 L .60462 .48877 L p 0 .368 .349 r
F P
0 g
s
.55603 .51746 m .55581 .47472 L .54715 .47295 L p 0 .701 .369 r
F P
0 g
s
.63325 .49459 m .58432 .52308 L .56702 .51965 L p .701 0 .537 r
F P
0 g
s
.78907 .55133 m .79016 .59438 L .77325 .59109 L p .898 0 .368 r
F P
0 g
s
.77325 .59109 m .77222 .54796 L .78907 .55133 L p .898 0 .368 r
F P
0 g
s
.67533 .52857 m .67601 .57218 L .62627 .59928 L p 0 .379 .352 r
F P
0 g
s
.62627 .59928 m .67601 .57218 L .68469 .57387 L p 0 .899 .539 r
F P
0 g
s
.54715 .47295 m .54732 .51574 L .55603 .51746 L p 0 .701 .369 r
F P
0 g
s
.59581 .48698 m .54732 .51574 L .54715 .47295 L p 0 .366 .348 r
F P
0 g
s
.54715 .47295 m .59544 .44351 L .59581 .48698 L p 0 .366 .348 r
F P
0 g
s
.62398 .59884 m .67369 .57173 L .67302 .52811 L p .494 0 .351 r
F P
0 g
s
.67369 .57173 m .62398 .59884 L .60675 .59558 L p .692 0 .539 r
F P
0 g
s
.59346 .4865 m .5931 .44302 L .54483 .47248 L p .479 0 .348 r
F P
0 g
s
.54483 .47248 m .545 .51528 L .59346 .4865 L p .479 0 .348 r
F P
0 g
s
.545 .51528 m .54483 .47248 L .52743 .46893 L p .895 0 .369 r
F P
0 g
s
.52743 .46893 m .54483 .47248 L .5931 .44302 L p .706 0 .535 r
F P
0 g
s
.75022 .51838 m .73324 .51493 L .73236 .47213 L p .898 0 .368 r
F P
0 g
s
.71309 .4681 m .7301 .47166 L .73097 .51447 L p 0 .701 .368 r
F P
0 g
s
.65334 .52417 m .63588 .52067 L .58681 .54874 L p 0 .896 .538 r
F P
0 g
s
.58714 .59186 m .58681 .54874 L .63588 .52067 L p 0 .373 .35 r
F P
0 g
s
.63355 .52021 m .5845 .54829 L .58482 .59142 L p .487 0 .35 r
F P
0 g
s
.56717 .54491 m .5845 .54829 L .63355 .52021 L p .698 0 .538 r
F P
0 g
s
.5845 .54829 m .56717 .54491 L .56742 .58812 L p .895 0 .369 r
F P
0 g
s
.56742 .58812 m .58482 .59142 L .5845 .54829 L p .895 0 .369 r
F P
0 g
s
.56702 .51965 m .61574 .49103 L .63325 .49459 L p .701 0 .537 r
F P
0 g
s
.6134 .49055 m .56471 .51919 L .55603 .51746 L p 0 .895 .537 r
F P
0 g
s
.76997 .54751 m .77099 .59065 L .76251 .589 L p 0 .701 .368 r
F P
0 g
s
.76251 .589 m .76151 .54581 L .76997 .54751 L p 0 .701 .368 r
F P
0 g
s
.65566 .52463 m .65626 .56834 L .60675 .59558 L p .491 0 .351 r
F P
0 g
s
.60675 .59558 m .65626 .56834 L .67369 .57173 L p .692 0 .539 r
F P
0 g
s
.52743 .46893 m .52753 .51181 L .545 .51528 L p .895 0 .369 r
F P
0 g
s
.57577 .4829 m .52753 .51181 L .52743 .46893 L p .476 0 .348 r
F P
0 g
s
.5931 .44302 m .57548 .43934 L .52743 .46893 L p .706 0 .535 r
F P
0 g
s
.52743 .46893 m .57548 .43934 L .57577 .4829 L p .476 0 .348 r
F P
0 g
s
.60445 .59514 m .65393 .56788 L .65334 .52417 L p 0 .376 .351 r
F P
0 g
s
.65393 .56788 m .60445 .59514 L .58714 .59186 L p 0 .899 .539 r
F P
0 g
s
.55603 .51746 m .60462 .48877 L .6134 .49055 L p 0 .895 .537 r
F P
0 g
s
.60462 .48877 m .55603 .51746 L .54732 .51574 L p 0 .895 .537 r
F P
0 g
s
.57341 .48242 m .57312 .43885 L .5251 .46846 L p 0 .362 .347 r
F P
0 g
s
.5251 .46846 m .52519 .51135 L .57341 .48242 L p 0 .362 .347 r
F P
0 g
s
.52519 .51135 m .5251 .46846 L .5076 .46489 L p 0 .701 .369 r
F P
0 g
s
.5076 .46489 m .5251 .46846 L .57312 .43885 L p 0 .892 .535 r
F P
0 g
s
.76151 .54581 m .76251 .589 L .754 .58734 L p 0 .701 .368 r
F P
0 g
s
.754 .58734 m .75304 .54412 L .76151 .54581 L p 0 .701 .368 r
F P
0 g
s
.73097 .51447 m .7139 .511 L .71309 .4681 L p 0 .701 .368 r
F P
0 g
s
.69373 .46406 m .71082 .46763 L .71162 .51053 L p .898 0 .368 r
F P
0 g
s
.63355 .52021 m .61601 .5167 L .56717 .54491 L p .698 0 .538 r
F P
0 g
s
.56742 .58812 m .56717 .54491 L .61601 .5167 L p .484 0 .349 r
F P
0 g
s
.61366 .51623 m .56485 .54446 L .5651 .58767 L p 0 .369 .349 r
F P
0 g
s
.55615 .54276 m .56485 .54446 L .61366 .51623 L p 0 .896 .538 r
F P
0 g
s
.56485 .54446 m .55615 .54276 L .55636 .58602 L p 0 .701 .369 r
F P
0 g
s
.55636 .58602 m .5651 .58767 L .56485 .54446 L p 0 .701 .369 r
F P
0 g
s
.54732 .51574 m .59581 .48698 L .60462 .48877 L p 0 .895 .537 r
F P
0 g
s
.59346 .4865 m .545 .51528 L .52753 .51181 L p .701 0 .537 r
F P
0 g
s
.75078 .54367 m .75173 .5869 L .73465 .58358 L p .898 0 .368 r
F P
0 g
s
.73465 .58358 m .73376 .54026 L .75078 .54367 L p .898 0 .368 r
F P
0 g
s
.63588 .52067 m .63641 .56448 L .58714 .59186 L p 0 .373 .35 r
F P
0 g
s
.58714 .59186 m .63641 .56448 L .65393 .56788 L p 0 .899 .539 r
F P
0 g
s
.61366 .51623 m .60485 .51446 L .55615 .54276 L p 0 .896 .538 r
F P
0 g
s
.58482 .59142 m .63407 .56402 L .63355 .52021 L p .487 0 .35 r
F P
0 g
s
.61601 .5167 m .61645 .5606 L .56742 .58812 L p .484 0 .349 r
F P
0 g
s
.5651 .58767 m .6141 .56014 L .61366 .51623 L p 0 .369 .349 r
F P
0 g
s
.60485 .51446 m .60526 .55842 L .55636 .58602 L p 0 .368 .349 r
F P
0 g
s
.55636 .58602 m .60526 .55842 L .60485 .51446 L p 0 .368 .349 r
F P
0 g
s
.60485 .51446 m .60526 .55842 L .5964 .5567 L p 0 .701 .368 r
F P
0 g
s
.55636 .58602 m .55615 .54276 L .60485 .51446 L p 0 .368 .349 r
F P
0 g
s
.60485 .51446 m .55615 .54276 L .55636 .58602 L p 0 .368 .349 r
F P
0 g
s
.54743 .54106 m .55615 .54276 L .60485 .51446 L p 0 .896 .538 r
F P
0 g
s
.55615 .54276 m .54743 .54106 L .54761 .58436 L p 0 .701 .369 r
F P
0 g
s
.54761 .58436 m .55636 .58602 L .55615 .54276 L p 0 .701 .369 r
F P
0 g
s
.5076 .46489 m .50763 .50786 L .52519 .51135 L p 0 .701 .369 r
F P
0 g
s
.55563 .4788 m .50763 .50786 L .5076 .46489 L p 0 .359 .347 r
F P
0 g
s
.57312 .43885 m .55541 .43515 L .5076 .46489 L p 0 .892 .535 r
F P
0 g
s
.5076 .46489 m .55541 .43515 L .55563 .4788 L p 0 .359 .347 r
F P
0 g
s
.63407 .56402 m .58482 .59142 L .56742 .58812 L p .692 0 .539 r
F P
0 g
s
.55325 .47832 m .55305 .43465 L .50527 .46441 L p .472 0 .347 r
F P
0 g
s
.50527 .46441 m .50529 .50739 L .55325 .47832 L p .472 0 .347 r
F P
0 g
s
.50529 .50739 m .50527 .46441 L .48768 .46083 L p .895 0 .369 r
F P
0 g
s
.48768 .46083 m .50527 .46441 L .55305 .43465 L p .706 0 .535 r
F P
0 g
s
.71162 .51053 m .69447 .50704 L .69373 .46406 L p .898 0 .368 r
F P
0 g
s
.68287 .46179 m .69145 .46358 L .69218 .50658 L p 0 .701 .368 r
F P
0 g
s
.60485 .51446 m .59603 .5127 L .54743 .54106 L p 0 .896 .538 r
F P
0 g
s
.54761 .58436 m .54743 .54106 L .59603 .5127 L p 0 .366 .348 r
F P
0 g
s
.52753 .51181 m .57577 .4829 L .59346 .4865 L p .701 0 .537 r
F P
0 g
s
.59367 .51223 m .5451 .5406 L .54527 .58391 L p .479 0 .348 r
F P
0 g
s
.52759 .53718 m .5451 .5406 L .59367 .51223 L p .698 0 .538 r
F P
0 g
s
.5451 .5406 m .52759 .53718 L .5277 .58058 L p .895 0 .369 r
F P
0 g
s
.5277 .58058 m .54527 .58391 L .5451 .5406 L p .895 0 .369 r
F P
0 g
s
.57341 .48242 m .52519 .51135 L .50763 .50786 L p 0 .895 .537 r
F P
0 g
s
.73149 .5398 m .73237 .58314 L .7152 .5798 L p 0 .701 .368 r
F P
0 g
s
.7152 .5798 m .71438 .53638 L .73149 .5398 L p 0 .701 .368 r
F P
0 g
s
.67427 .45999 m .68287 .46179 L .68357 .50483 L p 0 .701 .368 r
F P
0 g
s
.69218 .50658 m .68357 .50483 L .68287 .46179 L p 0 .701 .368 r
F P
0 g
s
.56742 .58812 m .61645 .5606 L .63407 .56402 L p .692 0 .539 r
F P
0 g
s
.6141 .56014 m .5651 .58767 L .55636 .58602 L p 0 .899 .539 r
F P
0 g
s
.48768 .46083 m .48764 .50389 L .50529 .50739 L p .895 0 .369 r
F P
0 g
s
.53538 .47468 m .48764 .50389 L .48768 .46083 L p .468 0 .346 r
F P
0 g
s
.55305 .43465 m .53525 .43093 L .48768 .46083 L p .706 0 .535 r
F P
0 g
s
.48768 .46083 m .53525 .43093 L .53538 .47468 L p .468 0 .346 r
F P
0 g
s
.53299 .4742 m .53287 .43044 L .48533 .46035 L p 0 .355 .346 r
F P
0 g
s
.48533 .46035 m .48528 .50342 L .53299 .4742 L p 0 .355 .346 r
F P
0 g
s
.48528 .50342 m .48533 .46035 L .47651 .45855 L p 0 .701 .369 r
F P
0 g
s
.47651 .45855 m .48533 .46035 L .53287 .43044 L p 0 .892 .535 r
F P
0 g
s
.68357 .50483 m .67494 .50307 L .67427 .45999 L p 0 .701 .368 r
F P
0 g
s
.65472 .4559 m .67198 .45951 L .67264 .5026 L p .898 0 .368 r
F P
0 g
s
.59367 .51223 m .57594 .50868 L .52759 .53718 L p .698 0 .538 r
F P
0 g
s
.5277 .58058 m .52759 .53718 L .57594 .50868 L p .476 0 .348 r
F P
0 g
s
.55636 .58602 m .60526 .55842 L .6141 .56014 L p 0 .899 .539 r
F P
0 g
s
.60526 .55842 m .55636 .58602 L .54761 .58436 L p 0 .899 .539 r
F P
0 g
s
.57357 .50821 m .52525 .53673 L .52535 .58013 L p 0 .362 .347 r
F P
0 g
s
.50765 .53329 m .52525 .53673 L .57357 .50821 L p 0 .896 .538 r
F P
0 g
s
.52525 .53673 m .50765 .53329 L .50768 .57678 L p 0 .701 .369 r
F P
0 g
s
.50768 .57678 m .52535 .58013 L .52525 .53673 L p 0 .701 .369 r
F P
0 g
s
.50763 .50786 m .55563 .4788 L .57341 .48242 L p 0 .895 .537 r
F P
0 g
s
.53287 .43044 m .52393 .42857 L .47651 .45855 L p 0 .892 .535 r
F P
0 g
s
.52402 .47237 m .52393 .42857 L .47651 .45855 L p 0 .353 .345 r
F P
0 g
s
.47651 .45855 m .47642 .50166 L .48528 .50342 L p 0 .701 .369 r
F P
0 g
s
.47651 .45855 m .47642 .50166 L .52402 .47237 L p 0 .353 .345 r
F P
0 g
s
.47642 .50166 m .47651 .45855 L .46766 .45674 L p 0 .701 .369 r
F P
0 g
s
.46766 .45674 m .47651 .45855 L .52393 .42857 L p 0 .892 .535 r
F P
0 g
s
.52402 .47237 m .47642 .50166 L .47651 .45855 L p 0 .353 .345 r
F P
0 g
s
.47651 .45855 m .52393 .42857 L .52402 .47237 L p 0 .353 .345 r
F P
0 g
s
.55325 .47832 m .50529 .50739 L .48764 .50389 L p .701 0 .537 r
F P
0 g
s
.7121 .53593 m .71291 .57935 L .69565 .576 L p .898 0 .368 r
F P
0 g
s
.69565 .576 m .69491 .53249 L .7121 .53593 L p .898 0 .368 r
F P
0 g
s
.59603 .5127 m .5964 .5567 L .54761 .58436 L p 0 .366 .348 r
F P
0 g
s
.54761 .58436 m .5964 .5567 L .60526 .55842 L p 0 .899 .539 r
F P
0 g
s
.54527 .58391 m .59403 .55624 L .59367 .51223 L p .479 0 .348 r
F P
0 g
s
.59403 .55624 m .54527 .58391 L .5277 .58058 L p .692 0 .539 r
F P
0 g
s
.46766 .45674 m .46754 .4999 L .47642 .50166 L p 0 .701 .369 r
F P
0 g
s
.51503 .47054 m .46754 .4999 L .46766 .45674 L p 0 .351 .345 r
F P
0 g
s
.52393 .42857 m .51497 .4267 L .46766 .45674 L p 0 .892 .535 r
F P
0 g
s
.46766 .45674 m .51497 .4267 L .51503 .47054 L p 0 .351 .345 r
F P
0 g
s
.51263 .47006 m .51258 .4262 L .4653 .45626 L p .464 0 .345 r
F P
0 g
s
.4653 .45626 m .46517 .49943 L .51263 .47006 L p .464 0 .345 r
F P
0 g
s
.46517 .49943 m .4653 .45626 L .44754 .45264 L p .895 0 .369 r
F P
0 g
s
.44754 .45264 m .4653 .45626 L .51258 .4262 L p .706 0 .535 r
F P
0 g
s
.67264 .5026 m .65531 .49908 L .65472 .4559 L p .898 0 .368 r
F P
0 g
s
.63506 .45179 m .65241 .45542 L .65299 .49861 L p 0 .701 .368 r
F P
0 g
s
.57357 .50821 m .55576 .50464 L .50765 .53329 L p 0 .896 .538 r
F P
0 g
s
.50768 .57678 m .50765 .53329 L .55576 .50464 L p 0 .359 .347 r
F P
0 g
s
.48764 .50389 m .53538 .47468 L .55325 .47832 L p .701 0 .537 r
F P
0 g
s
.55337 .50416 m .5053 .53283 L .50532 .57633 L p .472 0 .347 r
F P
0 g
s
.48761 .52938 m .5053 .53283 L .55337 .50416 L p .698 0 .538 r
F P
0 g
s
.5053 .53283 m .48761 .52938 L .48756 .57297 L p .895 0 .369 r
F P
0 g
s
.48756 .57297 m .50532 .57633 L .5053 .53283 L p .895 0 .369 r
F P
0 g
s
.53299 .4742 m .48528 .50342 L .47642 .50166 L p 0 .895 .537 r
F P
0 g
s
.69261 .53203 m .69335 .57555 L .68469 .57387 L p 0 .701 .368 r
F P
0 g
s
.68469 .57387 m .68398 .5303 L .69261 .53203 L p 0 .701 .368 r
F P
0 g
s
.57594 .50868 m .57624 .55278 L .5277 .58058 L p .476 0 .348 r
F P
0 g
s
.5277 .58058 m .57624 .55278 L .59403 .55624 L p .692 0 .539 r
F P
0 g
s
.52535 .58013 m .57386 .55231 L .57357 .50821 L p 0 .362 .347 r
F P
0 g
s
.57386 .55231 m .52535 .58013 L .50768 .57678 L p 0 .899 .539 r
F P
0 g
s
.44754 .45264 m .44734 .49589 L .46517 .49943 L p .895 0 .369 r
F P
0 g
s
.49457 .46638 m .44734 .49589 L .44754 .45264 L p .46 0 .344 r
F P
0 g
s
.51258 .4262 m .4946 .42244 L .44754 .45264 L p .706 0 .535 r
F P
0 g
s
.44754 .45264 m .4946 .42244 L .49457 .46638 L p .46 0 .344 r
F P
0 g
s
.52402 .47237 m .47642 .50166 L .46754 .4999 L p 0 .895 .537 r
F P
0 g
s
.47642 .50166 m .52402 .47237 L .53299 .4742 L p 0 .895 .537 r
F P
0 g
s
.49216 .46589 m .49219 .42193 L .44516 .45216 L p 0 .347 .344 r
F P
0 g
s
.44516 .45216 m .44495 .49542 L .49216 .46589 L p 0 .347 .344 r
F P
0 g
s
.44495 .49542 m .44516 .45216 L .42731 .44852 L p 0 .701 .369 r
F P
0 g
s
.42731 .44852 m .44516 .45216 L .49219 .42193 L p 0 .892 .535 r
F P
0 g
s
.68398 .5303 m .68469 .57387 L .67601 .57218 L p 0 .701 .368 r
F P
0 g
s
.67601 .57218 m .67533 .52857 L .68398 .5303 L p 0 .701 .368 r
F P
0 g
s
.65299 .49861 m .63558 .49506 L .63506 .45179 L p 0 .701 .368 r
F P
0 g
s
.6153 .44766 m .63274 .45131 L .63325 .49459 L p .898 0 .368 r
F P
0 g
s
.55337 .50416 m .53546 .50058 L .48761 .52938 L p .698 0 .538 r
F P
0 g
s
.48756 .57297 m .48761 .52938 L .53546 .50058 L p .468 0 .346 r
F P
0 g
s
.46754 .4999 m .51503 .47054 L .52402 .47237 L p 0 .895 .537 r
F P
0 g
s
.53307 .5001 m .48524 .52891 L .48519 .57252 L p 0 .355 .346 r
F P
0 g
s
.47636 .52718 m .48524 .52891 L .53307 .5001 L p 0 .896 .538 r
F P
0 g
s
.48524 .52891 m .47636 .52718 L .47627 .57082 L p 0 .701 .369 r
F P
0 g
s
.47627 .57082 m .48519 .57252 L .48524 .52891 L p 0 .701 .369 r
F P
0 g
s
.53307 .5001 m .52408 .4983 L .47636 .52718 L p 0 .896 .538 r
F P
0 g
s
.52408 .4983 m .47636 .52718 L .47627 .57082 L p 0 .353 .345 r
F P
0 g
s
.46734 .56913 m .47627 .57082 L .47636 .52718 L p 0 .701 .369 r
F P
0 g
s
.47627 .57082 m .47636 .52718 L .52408 .4983 L p 0 .353 .345 r
F P
0 g
s
.55576 .50464 m .55597 .54884 L .50768 .57678 L p 0 .359 .347 r
F P
0 g
s
.50532 .57633 m .55358 .54837 L .55337 .50416 L p .472 0 .347 r
F P
0 g
s
.53546 .50058 m .5356 .54487 L .48756 .57297 L p .468 0 .346 r
F P
0 g
s
.48519 .57252 m .5332 .54441 L .53307 .5001 L p 0 .355 .346 r
F P
0 g
s
.47627 .57082 m .52417 .54265 L .52408 .4983 L p 0 .353 .345 r
F P
0 g
s
.52408 .4983 m .52417 .54265 L .47627 .57082 L p 0 .353 .345 r
F P
0 g
s
.52417 .54265 m .47627 .57082 L .46734 .56913 L p 0 .899 .539 r
F P
0 g
s
.51263 .47006 m .46517 .49943 L .44734 .49589 L p .701 0 .537 r
F P
0 g
s
.67302 .52811 m .67369 .57173 L .65626 .56834 L p .898 0 .368 r
F P
0 g
s
.65626 .56834 m .65566 .52463 L .67302 .52811 L p .898 0 .368 r
F P
0 g
s
.50768 .57678 m .55597 .54884 L .57386 .55231 L p 0 .899 .539 r
F P
0 g
s
.46746 .52544 m .47636 .52718 L .52408 .4983 L p 0 .896 .538 r
F P
0 g
s
.47636 .52718 m .46746 .52544 L .46734 .56913 L p 0 .701 .369 r
F P
0 g
s
.55358 .54837 m .50532 .57633 L .48756 .57297 L p .692 0 .539 r
F P
0 g
s
.42731 .44852 m .42703 .49186 L .44495 .49542 L p 0 .701 .369 r
F P
0 g
s
.47401 .4622 m .42703 .49186 L .42731 .44852 L p 0 .344 .343 r
F P
0 g
s
.49219 .42193 m .47411 .41816 L .42731 .44852 L p 0 .892 .535 r
F P
0 g
s
.42731 .44852 m .47411 .41816 L .47401 .4622 L p 0 .344 .343 r
F P
0 g
s
.47158 .46171 m .4717 .41765 L .42492 .44803 L p .455 0 .343 r
F P
0 g
s
.42492 .44803 m .42464 .49139 L .47158 .46171 L p .455 0 .343 r
F P
0 g
s
.42464 .49139 m .42492 .44803 L .40698 .44437 L p .895 0 .369 r
F P
0 g
s
.40698 .44437 m .42492 .44803 L .4717 .41765 L p .706 0 .535 r
F P
0 g
s
.63325 .49459 m .61574 .49103 L .6153 .44766 L p .898 0 .368 r
F P
0 g
s
.60421 .44535 m .61297 .44718 L .6134 .49055 L p 0 .701 .368 r
F P
0 g
s
.52408 .4983 m .51507 .4965 L .46746 .52544 L p 0 .896 .538 r
F P
0 g
s
.46734 .56913 m .46746 .52544 L .51507 .4965 L p 0 .351 .345 r
F P
0 g
s
.51266 .49602 m .46509 .52498 L .46495 .56868 L p .464 0 .345 r
F P
0 g
s
.44722 .52149 m .46509 .52498 L .51266 .49602 L p .698 0 .538 r
F P
0 g
s
.46509 .52498 m .44722 .52149 L .44701 .56527 L p .895 0 .369 r
F P
0 g
s
.44701 .56527 m .46495 .56868 L .46509 .52498 L p .895 0 .369 r
F P
0 g
s
.44734 .49589 m .49457 .46638 L .51263 .47006 L p .701 0 .537 r
F P
0 g
s
.49216 .46589 m .44495 .49542 L .42703 .49186 L p 0 .895 .537 r
F P
0 g
s
.65334 .52417 m .65393 .56788 L .63641 .56448 L p 0 .701 .368 r
F P
0 g
s
.63641 .56448 m .63588 .52067 L .65334 .52417 L p 0 .701 .368 r
F P
0 g
s
.6134 .49055 m .60462 .48877 L .60421 .44535 L p 0 .701 .368 r
F P
0 g
s
.48756 .57297 m .5356 .54487 L .55358 .54837 L p .692 0 .539 r
F P
0 g
s
.40698 .44437 m .40662 .48781 L .42464 .49139 L p .895 0 .369 r
F P
0 g
s
.45334 .45799 m .40662 .48781 L .40698 .44437 L p .451 0 .342 r
F P
0 g
s
.4717 .41765 m .45352 .41385 L .40698 .44437 L p .706 0 .535 r
F P
0 g
s
.40698 .44437 m .45352 .41385 L .45334 .45799 L p .451 0 .342 r
F P
0 g
s
.5332 .54441 m .48519 .57252 L .47627 .57082 L p 0 .899 .539 r
F P
0 g
s
.4509 .4575 m .45109 .41334 L .40458 .44388 L p 0 .339 .342 r
F P
0 g
s
.40458 .44388 m .40421 .48733 L .4509 .4575 L p 0 .339 .342 r
F P
0 g
s
.40421 .48733 m .40458 .44388 L .39557 .44204 L p 0 .701 .369 r
F P
0 g
s
.39557 .44204 m .40458 .44388 L .45109 .41334 L p 0 .892 .535 r
F P
0 g
s
.60462 .48877 m .59581 .48698 L .59544 .44351 L p 0 .701 .368 r
F P
0 g
s
.57548 .43934 m .5931 .44302 L .59346 .4865 L p .898 0 .368 r
F P
0 g
s
.51266 .49602 m .49456 .49239 L .44722 .52149 L p .698 0 .538 r
F P
0 g
s
.44701 .56527 m .44722 .52149 L .49456 .49239 L p .46 0 .344 r
F P
0 g
s
.47627 .57082 m .52417 .54265 L .5332 .54441 L p 0 .899 .539 r
F P
0 g
s
.49214 .49191 m .44483 .52102 L .44462 .56482 L p 0 .347 .344 r
F P
0 g
s
.42687 .51752 m .44483 .52102 L .49214 .49191 L p 0 .896 .538 r
F P
0 g
s
.44483 .52102 m .42687 .51752 L .42658 .5614 L p 0 .701 .369 r
F P
0 g
s
.42658 .5614 m .44462 .56482 L .44483 .52102 L p 0 .701 .369 r
F P
0 g
s
.42703 .49186 m .47401 .4622 L .49216 .46589 L p 0 .895 .537 r
F P
0 g
s
.39557 .44204 m .39517 .48554 L .40421 .48733 L p 0 .701 .369 r
F P
0 g
s
.44174 .45564 m .39517 .48554 L .39557 .44204 L p 0 .337 .341 r
F P
0 g
s
.45109 .41334 m .44197 .41144 L .39557 .44204 L p 0 .892 .535 r
F P
0 g
s
.39557 .44204 m .44197 .41144 L .44174 .45564 L p 0 .337 .341 r
F P
0 g
s
.44174 .45564 m .44197 .41144 L .39557 .44204 L p 0 .337 .341 r
F P
0 g
s
.39557 .44204 m .39517 .48554 L .44174 .45564 L p 0 .337 .341 r
F P
0 g
s
.39517 .48554 m .39557 .44204 L .38655 .4402 L p 0 .701 .369 r
F P
0 g
s
.38655 .4402 m .39557 .44204 L .44197 .41144 L p 0 .892 .535 r
F P
0 g
s
.47158 .46171 m .42464 .49139 L .40662 .48781 L p .701 0 .537 r
F P
0 g
s
.63355 .52021 m .63407 .56402 L .61645 .5606 L p .898 0 .368 r
F P
0 g
s
.61645 .5606 m .61601 .5167 L .63355 .52021 L p .898 0 .368 r
F P
0 g
s
.51507 .4965 m .51513 .54089 L .46734 .56913 L p 0 .351 .345 r
F P
0 g
s
.46734 .56913 m .51513 .54089 L .52417 .54265 L p 0 .899 .539 r
F P
0 g
s
.46495 .56868 m .51271 .54042 L .51266 .49602 L p .464 0 .345 r
F P
0 g
s
.51271 .54042 m .46495 .56868 L .44701 .56527 L p .692 0 .539 r
F P
0 g
s
.38655 .4402 m .38611 .48374 L .39517 .48554 L p 0 .701 .369 r
F P
0 g
s
.43256 .45377 m .38611 .48374 L .38655 .4402 L p 0 .336 .341 r
F P
0 g
s
.44197 .41144 m .43282 .40953 L .38655 .4402 L p 0 .892 .535 r
F P
0 g
s
.38655 .4402 m .43282 .40953 L .43256 .45377 L p 0 .336 .341 r
F P
0 g
s
.43011 .45327 m .43038 .40902 L .38413 .43971 L p .446 0 .341 r
F P
0 g
s
.38413 .43971 m .38369 .48326 L .43011 .45327 L p .446 0 .341 r
F P
0 g
s
.38369 .48326 m .38413 .43971 L .36601 .43601 L p .895 0 .369 r
F P
0 g
s
.36601 .43601 m .38413 .43971 L .43038 .40902 L p .706 0 .535 r
F P
0 g
s
.59346 .4865 m .57577 .4829 L .57548 .43934 L p .898 0 .368 r
F P
0 g
s
.55541 .43515 m .57312 .43885 L .57341 .48242 L p 0 .701 .368 r
F P
0 g
s
.49214 .49191 m .47395 .48827 L .42687 .51752 L p 0 .896 .538 r
F P
0 g
s
.42658 .5614 m .42687 .51752 L .47395 .48827 L p 0 .344 .343 r
F P
0 g
s
.40662 .48781 m .45334 .45799 L .47158 .46171 L p .701 0 .537 r
F P
0 g
s
.47152 .48778 m .42446 .51705 L .42417 .56094 L p .455 0 .343 r
F P
0 g
s
.40641 .51352 m .42446 .51705 L .47152 .48778 L p .698 0 .538 r
F P
0 g
s
.42446 .51705 m .40641 .51352 L .40605 .5575 L p .895 0 .369 r
F P
0 g
s
.40605 .5575 m .42417 .56094 L .42446 .51705 L p .895 0 .369 r
F P
0 g
s
.4509 .4575 m .40421 .48733 L .39517 .48554 L p 0 .895 .537 r
F P
0 g
s
.61366 .51623 m .6141 .56014 L .60526 .55842 L p 0 .701 .368 r
F P
0 g
s
.60526 .55842 m .60485 .51446 L .61366 .51623 L p 0 .701 .368 r
F P
0 g
s
.49456 .49239 m .49454 .53689 L .44701 .56527 L p .46 0 .344 r
F P
0 g
s
.44701 .56527 m .49454 .53689 L .51271 .54042 L p .692 0 .539 r
F P
0 g
s
.44462 .56482 m .49211 .53642 L .49214 .49191 L p 0 .347 .344 r
F P
0 g
s
.49211 .53642 m .44462 .56482 L .42658 .5614 L p 0 .899 .539 r
F P
0 g
s
.36601 .43601 m .36549 .47965 L .38369 .48326 L p .895 0 .369 r
F P
0 g
s
.41167 .44952 m .36549 .47965 L .36601 .43601 L p .442 0 .34 r
F P
0 g
s
.43038 .40902 m .41202 .40518 L .36601 .43601 L p .706 0 .535 r
F P
0 g
s
.36601 .43601 m .41202 .40518 L .41167 .44952 L p .442 0 .34 r
F P
0 g
s
.39517 .48554 m .44174 .45564 L .4509 .4575 L p 0 .895 .537 r
F P
0 g
s
.44174 .45564 m .39517 .48554 L .38611 .48374 L p 0 .895 .537 r
F P
0 g
s
.4092 .44902 m .40956 .40466 L .36358 .43552 L p 0 .331 .34 r
F P
0 g
s
.36358 .43552 m .36305 .47916 L .4092 .44902 L p 0 .331 .34 r
F P
0 g
s
.36305 .47916 m .36358 .43552 L .34536 .4318 L p 0 .701 .369 r
F P
0 g
s
.34536 .4318 m .36358 .43552 L .40956 .40466 L p 0 .892 .535 r
F P
0 g
s
.5964 .5567 m .59603 .5127 L .60485 .51446 L p 0 .701 .368 r
F P
0 g
s
.57341 .48242 m .55563 .4788 L .55541 .43515 L p 0 .701 .368 r
F P
0 g
s
.53525 .43093 m .55305 .43465 L .55325 .47832 L p .898 0 .368 r
F P
0 g
s
.47152 .48778 m .45323 .48412 L .40641 .51352 L p .698 0 .538 r
F P
0 g
s
.40605 .5575 m .40641 .51352 L .45323 .48412 L p .451 0 .342 r
F P
0 g
s
.45079 .48363 m .404 .51305 L .40362 .55704 L p 0 .339 .342 r
F P
0 g
s
.39493 .51128 m .404 .51305 L .45079 .48363 L p 0 .896 .538 r
F P
0 g
s
.404 .51305 m .39493 .51128 L .39452 .55532 L p 0 .701 .369 r
F P
0 g
s
.39452 .55532 m .40362 .55704 L .404 .51305 L p 0 .701 .369 r
F P
0 g
s
.45079 .48363 m .4416 .4818 L .39493 .51128 L p 0 .896 .538 r
F P
0 g
s
.39452 .55532 m .39493 .51128 L .4416 .4818 L p 0 .337 .341 r
F P
0 g
s
.4416 .4818 m .39493 .51128 L .39452 .55532 L p 0 .337 .341 r
F P
0 g
s
.3854 .55359 m .39452 .55532 L .39493 .51128 L p 0 .701 .369 r
F P
0 g
s
.47395 .48827 m .47385 .53287 L .42658 .5614 L p 0 .344 .343 r
F P
0 g
s
.42417 .56094 m .47141 .53239 L .47152 .48778 L p .455 0 .343 r
F P
0 g
s
.45323 .48412 m .45305 .52882 L .40605 .5575 L p .451 0 .342 r
F P
0 g
s
.40362 .55704 m .45059 .52834 L .45079 .48363 L p 0 .339 .342 r
F P
0 g
s
.4416 .4818 m .44137 .52655 L .39452 .55532 L p 0 .337 .341 r
F P
0 g
s
.39452 .55532 m .44137 .52655 L .4416 .4818 L p 0 .337 .341 r
F P
0 g
s
.44137 .52655 m .39452 .55532 L .3854 .55359 L p 0 .899 .539 r
F P
0 g
s
.38611 .48374 m .43256 .45377 L .44174 .45564 L p 0 .895 .537 r
F P
0 g
s
.43011 .45327 m .38369 .48326 L .36549 .47965 L p .701 0 .537 r
F P
0 g
s
.59367 .51223 m .59403 .55624 L .57624 .55278 L p .898 0 .368 r
F P
0 g
s
.57624 .55278 m .57594 .50868 L .59367 .51223 L p .898 0 .368 r
F P
0 g
s
.42658 .5614 m .47385 .53287 L .49211 .53642 L p 0 .899 .539 r
F P
0 g
s
.38585 .50951 m .39493 .51128 L .4416 .4818 L p 0 .896 .538 r
F P
0 g
s
.39493 .51128 m .38585 .50951 L .3854 .55359 L p 0 .701 .369 r
F P
0 g
s
.47141 .53239 m .42417 .56094 L .40605 .5575 L p .692 0 .539 r
F P
0 g
s
.34536 .4318 m .34476 .47553 L .36305 .47916 L p 0 .701 .369 r
F P
0 g
s
.39067 .44525 m .34476 .47553 L .34536 .4318 L p 0 .327 .339 r
F P
0 g
s
.40956 .40466 m .3911 .40081 L .34536 .4318 L p 0 .892 .535 r
F P
0 g
s
.34536 .4318 m .3911 .40081 L .39067 .44525 L p 0 .327 .339 r
F P
0 g
s
.38819 .44474 m .38863 .40029 L .34292 .43131 L p .437 0 .339 r
F P
0 g
s
.34292 .43131 m .34231 .47505 L .38819 .44474 L p .437 0 .339 r
F P
0 g
s
.34231 .47505 m .34292 .43131 L .32461 .42757 L p .895 0 .369 r
F P
0 g
s
.32461 .42757 m .34292 .43131 L .38863 .40029 L p .706 0 .535 r
F P
0 g
s
.55325 .47832 m .53538 .47468 L .53525 .43093 L p .898 0 .368 r
F P
0 g
s
.52393 .42857 m .53287 .43044 L .53299 .4742 L p 0 .701 .368 r
F P
0 g
s
.4416 .4818 m .4324 .47996 L .38585 .50951 L p 0 .896 .538 r
F P
0 g
s
.3854 .55359 m .38585 .50951 L .4324 .47996 L p 0 .336 .341 r
F P
0 g
s
.42994 .47946 m .38342 .50903 L .38297 .55312 L p .446 0 .341 r
F P
0 g
s
.36518 .50547 m .38342 .50903 L .42994 .47946 L p .698 0 .538 r
F P
0 g
s
.38342 .50903 m .36518 .50547 L .36465 .54965 L p .895 0 .369 r
F P
0 g
s
.36465 .54965 m .38297 .55312 L .38342 .50903 L p .895 0 .369 r
F P
0 g
s
.36549 .47965 m .41167 .44952 L .43011 .45327 L p .701 0 .537 r
F P
0 g
s
.4092 .44902 m .36305 .47916 L .34476 .47553 L p 0 .895 .537 r
F P
0 g
s
.57357 .50821 m .57386 .55231 L .55597 .54884 L p 0 .701 .368 r
F P
0 g
s
.55597 .54884 m .55576 .50464 L .57357 .50821 L p 0 .701 .368 r
F P
0 g
s
.53299 .4742 m .52402 .47237 L .52393 .42857 L p 0 .701 .368 r
F P
0 g
s
.51497 .4267 m .52393 .42857 L .52402 .47237 L p 0 .701 .368 r
F P
0 g
s
.40605 .5575 m .45305 .52882 L .47141 .53239 L p .692 0 .539 r
F P
0 g
s
.32461 .42757 m .32392 .4714 L .34231 .47505 L p .895 0 .369 r
F P
0 g
s
.36956 .44095 m .32392 .4714 L .32461 .42757 L p .433 0 .338 r
F P
0 g
s
.38863 .40029 m .37007 .39641 L .32461 .42757 L p .706 0 .535 r
F P
0 g
s
.32461 .42757 m .37007 .39641 L .36956 .44095 L p .433 0 .338 r
F P
0 g
s
.45059 .52834 m .40362 .55704 L .39452 .55532 L p 0 .899 .539 r
F P
0 g
s
.36707 .44045 m .36759 .39589 L .32216 .42707 L p 0 .322 .338 r
F P
0 g
s
.32216 .42707 m .32147 .47091 L .36707 .44045 L p 0 .322 .338 r
F P
0 g
s
.32147 .47091 m .32216 .42707 L .31296 .42519 L p 0 .701 .369 r
F P
0 g
s
.31296 .42519 m .32216 .42707 L .36759 .39589 L p 0 .892 .535 r
F P
0 g
s
.52402 .47237 m .51503 .47054 L .51497 .4267 L p 0 .701 .368 r
F P
0 g
s
.4946 .42244 m .51258 .4262 L .51263 .47006 L p .898 0 .368 r
F P
0 g
s
.42994 .47946 m .41146 .47577 L .36518 .50547 L p .698 0 .538 r
F P
0 g
s
.36465 .54965 m .36518 .50547 L .41146 .47577 L p .442 0 .34 r
F P
0 g
s
.39452 .55532 m .44137 .52655 L .45059 .52834 L p 0 .899 .539 r
F P
0 g
s
.40899 .47527 m .36274 .505 L .36221 .54918 L p 0 .331 .34 r
F P
0 g
s
.3444 .50142 m .36274 .505 L .40899 .47527 L p 0 .896 .538 r
F P
0 g
s
.36274 .505 m .3444 .50142 L .34379 .54569 L p 0 .701 .369 r
F P
0 g
s
.34379 .54569 m .36221 .54918 L .36274 .505 L p 0 .701 .369 r
F P
0 g
s
.34476 .47553 m .39067 .44525 L .4092 .44902 L p 0 .895 .537 r
F P
0 g
s
.36759 .39589 m .35828 .39395 L .31296 .42519 L p 0 .892 .535 r
F P
0 g
s
.31296 .42519 m .35828 .39395 L .35771 .43854 L p 0 .32 .337 r
F P
0 g
s
.35771 .43854 m .35828 .39395 L .31296 .42519 L p 0 .32 .337 r
F P
0 g
s
.31296 .42519 m .31223 .46908 L .32147 .47091 L p 0 .701 .369 r
F P
0 g
s
.35771 .43854 m .31223 .46908 L .31296 .42519 L p 0 .32 .337 r
F P
0 g
s
.31296 .42519 m .31223 .46908 L .35771 .43854 L p 0 .32 .337 r
F P
0 g
s
.31223 .46908 m .31296 .42519 L .30375 .42332 L p 0 .701 .369 r
F P
0 g
s
.30375 .42332 m .31296 .42519 L .35828 .39395 L p 0 .892 .535 r
F P
0 g
s
.38819 .44474 m .34231 .47505 L .32392 .4714 L p .701 0 .537 r
F P
0 g
s
.55337 .50416 m .55358 .54837 L .5356 .54487 L p .898 0 .368 r
F P
0 g
s
.5356 .54487 m .53546 .50058 L .55337 .50416 L p .898 0 .368 r
F P
0 g
s
.4324 .47996 m .43213 .52475 L .3854 .55359 L p 0 .336 .341 r
F P
0 g
s
.3854 .55359 m .43213 .52475 L .44137 .52655 L p 0 .899 .539 r
F P
0 g
s
.30375 .42332 m .30298 .46724 L .31223 .46908 L p 0 .701 .369 r
F P
0 g
s
.34834 .43664 m .30298 .46724 L .30375 .42332 L p 0 .318 .337 r
F P
0 g
s
.35828 .39395 m .34894 .39199 L .30375 .42332 L p 0 .892 .535 r
F P
0 g
s
.30375 .42332 m .34894 .39199 L .34834 .43664 L p 0 .318 .337 r
F P
0 g
s
.38297 .55312 m .42967 .52427 L .42994 .47946 L p .446 0 .341 r
F P
0 g
s
.42967 .52427 m .38297 .55312 L .36465 .54965 L p .692 0 .539 r
F P
0 g
s
.34583 .43613 m .34644 .39147 L .30129 .42281 L p .428 0 .337 r
F P
0 g
s
.30129 .42281 m .30051 .46675 L .34583 .43613 L p .428 0 .337 r
F P
0 g
s
.30051 .46675 m .30129 .42281 L .28278 .41904 L p .895 0 .369 r
F P
0 g
s
.28278 .41904 m .30129 .42281 L .34644 .39147 L p .706 0 .535 r
F P
0 g
s
.51263 .47006 m .49457 .46638 L .4946 .42244 L p .898 0 .368 r
F P
0 g
s
.47411 .41816 m .49219 .42193 L .49216 .46589 L p 0 .701 .368 r
F P
0 g
s
.40899 .47527 m .39041 .47155 L .3444 .50142 L p 0 .896 .538 r
F P
0 g
s
.34379 .54569 m .3444 .50142 L .39041 .47155 L p 0 .327 .339 r
F P
0 g
s
.38793 .47106 m .34195 .50094 L .34133 .54522 L p .437 0 .339 r
F P
0 g
s
.32352 .49734 m .34195 .50094 L .38793 .47106 L p .698 0 .538 r
F P
0 g
s
.34195 .50094 m .32352 .49734 L .32283 .54171 L p .895 0 .369 r
F P
0 g
s
.32283 .54171 m .34133 .54522 L .34195 .50094 L p .895 0 .369 r
F P
0 g
s
.32392 .4714 m .36956 .44095 L .38819 .44474 L p .701 0 .537 r
F P
0 g
s
.36707 .44045 m .32147 .47091 L .31223 .46908 L p 0 .895 .537 r
F P
0 g
s
.53307 .5001 m .5332 .54441 L .52417 .54265 L p 0 .701 .368 r
F P
0 g
s
.52417 .54265 m .52408 .4983 L .53307 .5001 L p 0 .701 .368 r
F P
0 g
s
.41146 .47577 m .41111 .52067 L .36465 .54965 L p .442 0 .34 r
F P
0 g
s
.36465 .54965 m .41111 .52067 L .42967 .52427 L p .692 0 .539 r
F P
0 g
s
.28278 .41904 m .28193 .46306 L .30051 .46675 L p .895 0 .369 r
F P
0 g
s
.327 .4323 m .28193 .46306 L .28278 .41904 L p .423 0 .336 r
F P
0 g
s
.34644 .39147 m .32769 .38755 L .28278 .41904 L p .706 0 .535 r
F P
0 g
s
.28278 .41904 m .32769 .38755 L .327 .4323 L p .423 0 .336 r
F P
0 g
s
.36221 .54918 m .40863 .52018 L .40899 .47527 L p 0 .331 .34 r
F P
0 g
s
.40863 .52018 m .36221 .54918 L .34379 .54569 L p 0 .899 .539 r
F P
0 g
s
.35771 .43854 m .31223 .46908 L .30298 .46724 L p 0 .895 .537 r
F P
0 g
s
.31223 .46908 m .35771 .43854 L .36707 .44045 L p 0 .895 .537 r
F P
0 g
s
.32448 .43178 m .32518 .38703 L .2803 .41853 L p 0 .313 .335 r
F P
0 g
s
.2803 .41853 m .27944 .46257 L .32448 .43178 L p 0 .313 .335 r
F P
0 g
s
.27944 .46257 m .2803 .41853 L .2617 .41474 L p 0 .701 .369 r
F P
0 g
s
.2617 .41474 m .2803 .41853 L .32518 .38703 L p 0 .892 .535 r
F P
0 g
s
.52408 .4983 m .52417 .54265 L .51513 .54089 L p 0 .701 .368 r
F P
0 g
s
.51513 .54089 m .51507 .4965 L .52408 .4983 L p 0 .701 .368 r
F P
0 g
s
.49216 .46589 m .47401 .4622 L .47411 .41816 L p 0 .701 .368 r
F P
0 g
s
.45352 .41385 m .4717 .41765 L .47158 .46171 L p .898 0 .368 r
F P
0 g
s
.38793 .47106 m .36925 .46732 L .32352 .49734 L p .698 0 .538 r
F P
0 g
s
.32283 .54171 m .32352 .49734 L .36925 .46732 L p .433 0 .338 r
F P
0 g
s
.30298 .46724 m .34834 .43664 L .35771 .43854 L p 0 .895 .537 r
F P
0 g
s
.36676 .46682 m .32106 .49686 L .32035 .54124 L p 0 .322 .338 r
F P
0 g
s
.3118 .49505 m .32106 .49686 L .36676 .46682 L p 0 .896 .538 r
F P
0 g
s
.32106 .49686 m .3118 .49505 L .31106 .53948 L p 0 .701 .369 r
F P
0 g
s
.31106 .53948 m .32035 .54124 L .32106 .49686 L p 0 .701 .369 r
F P
0 g
s
.36676 .46682 m .35738 .46494 L .3118 .49505 L p 0 .896 .538 r
F P
0 g
s
.31106 .53948 m .3118 .49505 L .35738 .46494 L p 0 .32 .337 r
F P
0 g
s
.35738 .46494 m .3118 .49505 L .31106 .53948 L p 0 .32 .337 r
F P
0 g
s
.30175 .53772 m .31106 .53948 L .3118 .49505 L p 0 .701 .369 r
F P
0 g
s
.39041 .47155 m .38998 .51656 L .34379 .54569 L p 0 .327 .339 r
F P
0 g
s
.34133 .54522 m .38748 .51607 L .38793 .47106 L p .437 0 .339 r
F P
0 g
s
.36925 .46732 m .36873 .51242 L .32283 .54171 L p .433 0 .338 r
F P
0 g
s
.32035 .54124 m .36622 .51194 L .36676 .46682 L p 0 .322 .338 r
F P
0 g
s
.35738 .46494 m .35681 .51011 L .31106 .53948 L p 0 .32 .337 r
F P
0 g
s
.31106 .53948 m .35681 .51011 L .35738 .46494 L p 0 .32 .337 r
F P
0 g
s
.35681 .51011 m .31106 .53948 L .30175 .53772 L p 0 .899 .539 r
F P
0 g
s
.34583 .43613 m .30051 .46675 L .28193 .46306 L p .701 0 .537 r
F P
0 g
s
.51266 .49602 m .51271 .54042 L .49454 .53689 L p .898 0 .368 r
F P
0 g
s
.49454 .53689 m .49456 .49239 L .51266 .49602 L p .898 0 .368 r
F P
0 g
s
.34379 .54569 m .38998 .51656 L .40863 .52018 L p 0 .899 .539 r
F P
0 g
s
.30253 .49324 m .3118 .49505 L .35738 .46494 L p 0 .896 .538 r
F P
0 g
s
.3118 .49505 m .30253 .49324 L .30175 .53772 L p 0 .701 .369 r
F P
0 g
s
.2617 .41474 m .26076 .45886 L .27944 .46257 L p 0 .701 .369 r
F P
0 g
s
.30555 .42793 m .26076 .45886 L .2617 .41474 L p 0 .309 .334 r
F P
0 g
s
.32518 .38703 m .30632 .38309 L .2617 .41474 L p 0 .892 .535 r
F P
0 g
s
.2617 .41474 m .30632 .38309 L .30555 .42793 L p 0 .309 .334 r
F P
0 g
s
.38748 .51607 m .34133 .54522 L .32283 .54171 L p .692 0 .539 r
F P
0 g
s
.30302 .42742 m .3038 .38256 L .25921 .41423 L p .418 0 .334 r
F P
0 g
s
.25921 .41423 m .25827 .45837 L .30302 .42742 L p .418 0 .334 r
F P
0 g
s
.25827 .45837 m .25921 .41423 L .24051 .41042 L p .895 0 .369 r
F P
0 g
s
.24051 .41042 m .25921 .41423 L .3038 .38256 L p .706 0 .535 r
F P
0 g
s
.47158 .46171 m .45334 .45799 L .45352 .41385 L p .898 0 .368 r
F P
0 g
s
.44197 .41144 m .45109 .41334 L .4509 .4575 L p 0 .701 .368 r
F P
0 g
s
.35738 .46494 m .34798 .46306 L .30253 .49324 L p 0 .896 .538 r
F P
0 g
s
.30175 .53772 m .30253 .49324 L .34798 .46306 L p 0 .318 .337 r
F P
0 g
s
.34547 .46256 m .30005 .49276 L .29926 .53724 L p .428 0 .337 r
F P
0 g
s
.28142 .48912 m .30005 .49276 L .34547 .46256 L p .698 0 .538 r
F P
0 g
s
.30005 .49276 m .28142 .48912 L .28056 .5337 L p .895 0 .369 r
F P
0 g
s
.28056 .5337 m .29926 .53724 L .30005 .49276 L p .895 0 .369 r
F P
0 g
s
.28193 .46306 m .327 .4323 L .34583 .43613 L p .701 0 .537 r
F P
0 g
s
.32448 .43178 m .27944 .46257 L .26076 .45886 L p 0 .895 .537 r
F P
0 g
s
.49214 .49191 m .49211 .53642 L .47385 .53287 L p 0 .701 .368 r
F P
0 g
s
.47385 .53287 m .47395 .48827 L .49214 .49191 L p 0 .701 .368 r
F P
0 g
s
.4509 .4575 m .44174 .45564 L .44197 .41144 L p 0 .701 .368 r
F P
0 g
s
.43282 .40953 m .44197 .41144 L .44174 .45564 L p 0 .701 .368 r
F P
0 g
s
.32283 .54171 m .36873 .51242 L .38748 .51607 L p .692 0 .539 r
F P
0 g
s
.36622 .51194 m .32035 .54124 L .31106 .53948 L p 0 .899 .539 r
F P
0 g
s
.24051 .41042 m .23949 .45464 L .25827 .45837 L p .895 0 .369 r
F P
0 g
s
.28399 .42355 m .23949 .45464 L .24051 .41042 L p .413 0 .333 r
F P
0 g
s
.3038 .38256 m .28485 .3786 L .24051 .41042 L p .706 0 .535 r
F P
0 g
s
.24051 .41042 m .28485 .3786 L .28399 .42355 L p .413 0 .333 r
F P
0 g
s
.28144 .42303 m .28231 .37807 L .23801 .40991 L p 0 .304 .333 r
F P
0 g
s
.23801 .40991 m .23698 .45414 L .28144 .42303 L p 0 .304 .333 r
F P
0 g
s
.23698 .45414 m .23801 .40991 L .22862 .40799 L p 0 .701 .369 r
F P
0 g
s
.22862 .40799 m .23801 .40991 L .28231 .37807 L p 0 .892 .535 r
F P
0 g
s
.44174 .45564 m .43256 .45377 L .43282 .40953 L p 0 .701 .368 r
F P
0 g
s
.41202 .40518 m .43038 .40902 L .43011 .45327 L p .898 0 .368 r
F P
0 g
s
.34547 .46256 m .32659 .45878 L .28142 .48912 L p .698 0 .538 r
F P
0 g
s
.28056 .5337 m .28142 .48912 L .32659 .45878 L p .423 0 .336 r
F P
0 g
s
.31106 .53948 m .35681 .51011 L .36622 .51194 L p 0 .899 .539 r
F P
0 g
s
.32407 .45828 m .27893 .48863 L .27806 .53322 L p 0 .313 .335 r
F P
0 g
s
.26021 .48498 m .27893 .48863 L .32407 .45828 L p 0 .896 .538 r
F P
0 g
s
.27893 .48863 m .26021 .48498 L .25926 .52966 L p 0 .701 .369 r
F P
0 g
s
.25926 .52966 m .27806 .53322 L .27893 .48863 L p 0 .701 .369 r
F P
0 g
s
.26076 .45886 m .30555 .42793 L .32448 .43178 L p 0 .895 .537 r
F P
0 g
s
.28231 .37807 m .2728 .37608 L .22862 .40799 L p 0 .892 .535 r
F P
0 g
s
.22862 .40799 m .2728 .37608 L .27188 .42108 L p 0 .301 .332 r
F P
0 g
s
.27188 .42108 m .2728 .37608 L .22862 .40799 L p 0 .301 .332 r
F P
0 g
s
.22862 .40799 m .22755 .45227 L .23698 .45414 L p 0 .701 .369 r
F P
0 g
s
.27188 .42108 m .22755 .45227 L .22862 .40799 L p 0 .301 .332 r
F P
0 g
s
.22862 .40799 m .22755 .45227 L .27188 .42108 L p 0 .301 .332 r
F P
0 g
s
.22755 .45227 m .22862 .40799 L .21921 .40608 L p 0 .701 .369 r
F P
0 g
s
.21921 .40608 m .2181 .4504 L .22755 .45227 L p 0 .701 .369 r
F P
0 g
s
.27188 .42108 m .22755 .45227 L .2181 .4504 L p 0 .895 .537 r
F P
0 g
s
.21921 .40608 m .22862 .40799 L .2728 .37608 L p 0 .892 .535 r
F P
0 g
s
.30302 .42742 m .25827 .45837 L .23949 .45464 L p .701 0 .537 r
F P
0 g
s
.47152 .48778 m .47141 .53239 L .45305 .52882 L p .898 0 .368 r
F P
0 g
s
.45305 .52882 m .45323 .48412 L .47152 .48778 L p .898 0 .368 r
F P
0 g
s
.34798 .46306 m .34737 .50827 L .30175 .53772 L p 0 .318 .337 r
F P
0 g
s
.30175 .53772 m .34737 .50827 L .35681 .51011 L p 0 .899 .539 r
F P
0 g
s
.2623 .41914 m .2181 .4504 L .21921 .40608 L p 0 .299 .332 r
F P
0 g
s
.2728 .37608 m .26326 .37409 L .21921 .40608 L p 0 .892 .535 r
F P
0 g
s
.21921 .40608 m .26326 .37409 L .2623 .41914 L p 0 .299 .332 r
F P
0 g
s
.29926 .53724 m .34485 .50778 L .34547 .46256 L p .428 0 .337 r
F P
0 g
s
.34485 .50778 m .29926 .53724 L .28056 .5337 L p .692 0 .539 r
F P
0 g
s
.25975 .41862 m .26071 .37356 L .2167 .40556 L p .407 0 .332 r
F P
0 g
s
.2167 .40556 m .21558 .44989 L .25975 .41862 L p .407 0 .332 r
F P
0 g
s
.21558 .44989 m .2167 .40556 L .1978 .40171 L p .895 0 .369 r
F P
0 g
s
.1978 .40171 m .2167 .40556 L .26071 .37356 L p .706 0 .535 r
F P
0 g
s
.43011 .45327 m .41167 .44952 L .41202 .40518 L p .898 0 .368 r
F P
0 g
s
.3911 .40081 m .40956 .40466 L .4092 .44902 L p 0 .701 .368 r
F P
0 g
s
.32407 .45828 m .30509 .45448 L .26021 .48498 L p 0 .896 .538 r
F P
0 g
s
.25926 .52966 m .26021 .48498 L .30509 .45448 L p 0 .309 .334 r
F P
0 g
s
.30255 .45397 m .25771 .48449 L .25675 .52918 L p .418 0 .334 r
F P
0 g
s
.23888 .48082 m .25771 .48449 L .30255 .45397 L p .698 0 .538 r
F P
0 g
s
.25771 .48449 m .23888 .48082 L .23785 .52559 L p .895 0 .369 r
F P
0 g
s
.23785 .52559 m .25675 .52918 L .25771 .48449 L p .895 0 .369 r
F P
0 g
s
.23949 .45464 m .28399 .42355 L .30302 .42742 L p .701 0 .537 r
F P
0 g
s
.28144 .42303 m .23698 .45414 L .22755 .45227 L p 0 .895 .537 r
F P
0 g
s
.45079 .48363 m .45059 .52834 L .44137 .52655 L p 0 .701 .368 r
F P
0 g
s
.44137 .52655 m .4416 .4818 L .45079 .48363 L p 0 .701 .368 r
F P
0 g
s
.32659 .45878 m .3259 .5041 L .28056 .5337 L p .423 0 .336 r
F P
0 g
s
.28056 .5337 m .3259 .5041 L .34485 .50778 L p .692 0 .539 r
F P
0 g
s
.27806 .53322 m .32336 .5036 L .32407 .45828 L p 0 .313 .335 r
F P
0 g
s
.32336 .5036 m .27806 .53322 L .25926 .52966 L p 0 .899 .539 r
F P
0 g
s
.1978 .40171 m .1966 .44613 L .21558 .44989 L p .895 0 .369 r
F P
0 g
s
.24051 .4147 m .1966 .44613 L .1978 .40171 L p .402 0 .331 r
F P
0 g
s
.26071 .37356 m .24155 .36955 L .1978 .40171 L p .706 0 .535 r
F P
0 g
s
.1978 .40171 m .24155 .36955 L .24051 .4147 L p .402 0 .331 r
F P
0 g
s
.22755 .45227 m .27188 .42108 L .28144 .42303 L p 0 .895 .537 r
F P
0 g
s
.23794 .41418 m .23899 .36902 L .19527 .40119 L p 0 .294 .33 r
F P
0 g
s
.19527 .40119 m .19407 .44562 L .23794 .41418 L p 0 .294 .33 r
F P
0 g
s
.19407 .44562 m .19527 .40119 L .17628 .39732 L p 0 .701 .369 r
F P
0 g
s
.17628 .39732 m .19527 .40119 L .23899 .36902 L p 0 .892 .535 r
F P
0 g
s
.4416 .4818 m .44137 .52655 L .43213 .52475 L p 0 .701 .368 r
F P
0 g
s
.43213 .52475 m .4324 .47996 L .4416 .4818 L p 0 .701 .368 r
F P
0 g
s
.4092 .44902 m .39067 .44525 L .3911 .40081 L p 0 .701 .368 r
F P
0 g
s
.37007 .39641 m .38863 .40029 L .38819 .44474 L p .898 0 .368 r
F P
0 g
s
.30255 .45397 m .28347 .45015 L .23888 .48082 L p .698 0 .538 r
F P
0 g
s
.23785 .52559 m .23888 .48082 L .28347 .45015 L p .413 0 .333 r
F P
0 g
s
.28092 .44964 m .23637 .48032 L .23532 .52511 L p 0 .304 .333 r
F P
0 g
s
.22692 .47848 m .23637 .48032 L .28092 .44964 L p 0 .896 .538 r
F P
0 g
s
.23637 .48032 m .22692 .47848 L .22584 .52331 L p 0 .701 .369 r
F P
0 g
s
.22584 .52331 m .23532 .52511 L .23637 .48032 L p 0 .701 .369 r
F P
0 g
s
.2181 .4504 m .2623 .41914 L .27188 .42108 L p 0 .895 .537 r
F P
0 g
s
.25975 .41862 m .21558 .44989 L .1966 .44613 L p .701 0 .537 r
F P
0 g
s
.42994 .47946 m .42967 .52427 L .41111 .52067 L p .898 0 .368 r
F P
0 g
s
.41111 .52067 m .41146 .47577 L .42994 .47946 L p .898 0 .368 r
F P
0 g
s
.30509 .45448 m .30431 .4999 L .25926 .52966 L p 0 .309 .334 r
F P
0 g
s
.25926 .52966 m .30431 .4999 L .32336 .5036 L p 0 .899 .539 r
F P
0 g
s
.28092 .44964 m .27134 .44773 L .22692 .47848 L p 0 .896 .538 r
F P
0 g
s
.22584 .52331 m .22692 .47848 L .27134 .44773 L p 0 .301 .332 r
F P
0 g
s
.27134 .44773 m .22692 .47848 L .22584 .52331 L p 0 .301 .332 r
F P
0 g
s
.21745 .47663 m .22692 .47848 L .27134 .44773 L p 0 .896 .538 r
F P
0 g
s
.22692 .47848 m .21745 .47663 L .21633 .52151 L p 0 .701 .369 r
F P
0 g
s
.21633 .52151 m .22584 .52331 L .22692 .47848 L p 0 .701 .369 r
F P
0 g
s
.17628 .39732 m .17499 .44184 L .19407 .44562 L p 0 .701 .369 r
F P
0 g
s
.21859 .41024 m .17499 .44184 L .17628 .39732 L p 0 .289 .329 r
F P
0 g
s
.23899 .36902 m .21973 .36499 L .17628 .39732 L p 0 .892 .535 r
F P
0 g
s
.17628 .39732 m .21973 .36499 L .21859 .41024 L p 0 .289 .329 r
F P
0 g
s
.25675 .52918 m .30176 .4994 L .30255 .45397 L p .418 0 .334 r
F P
0 g
s
.30176 .4994 m .25675 .52918 L .23785 .52559 L p .692 0 .539 r
F P
0 g
s
.21601 .40972 m .21715 .36445 L .17374 .3968 L p .396 0 .329 r
F P
0 g
s
.17374 .3968 m .17244 .44133 L .21601 .40972 L p .396 0 .329 r
F P
0 g
s
.17244 .44133 m .17374 .3968 L .15464 .39291 L p .895 0 .369 r
F P
0 g
s
.15464 .39291 m .17374 .3968 L .21715 .36445 L p .706 0 .535 r
F P
0 g
s
.38819 .44474 m .36956 .44095 L .37007 .39641 L p .898 0 .368 r
F P
0 g
s
.35828 .39395 m .36759 .39589 L .36707 .44045 L p 0 .701 .368 r
F P
0 g
s
.27134 .44773 m .26174 .4458 L .21745 .47663 L p 0 .896 .538 r
F P
0 g
s
.21633 .52151 m .21745 .47663 L .26174 .4458 L p 0 .299 .332 r
F P
0 g
s
.1966 .44613 m .24051 .4147 L .25975 .41862 L p .701 0 .537 r
F P
0 g
s
.25918 .44529 m .21492 .47614 L .21379 .52103 L p .407 0 .332 r
F P
0 g
s
.1959 .47242 m .21492 .47614 L .25918 .44529 L p .698 0 .538 r
F P
0 g
s
.21492 .47614 m .1959 .47242 L .19469 .5174 L p .895 0 .369 r
F P
0 g
s
.19469 .5174 m .21379 .52103 L .21492 .47614 L p .895 0 .369 r
F P
0 g
s
.23794 .41418 m .19407 .44562 L .17499 .44184 L p 0 .895 .537 r
F P
0 g
s
.40899 .47527 m .40863 .52018 L .38998 .51656 L p 0 .701 .368 r
F P
0 g
s
.38998 .51656 m .39041 .47155 L .40899 .47527 L p 0 .701 .368 r
F P
0 g
s
.36707 .44045 m .35771 .43854 L .35828 .39395 L p 0 .701 .368 r
F P
0 g
s
.34894 .39199 m .35828 .39395 L .35771 .43854 L p 0 .701 .368 r
F P
0 g
s
.28347 .45015 m .2826 .49568 L .23785 .52559 L p .413 0 .333 r
F P
0 g
s
.23785 .52559 m .2826 .49568 L .30176 .4994 L p .692 0 .539 r
F P
0 g
s
.23532 .52511 m .28004 .49518 L .28092 .44964 L p 0 .304 .333 r
F P
0 g
s
.28004 .49518 m .23532 .52511 L .22584 .52331 L p 0 .899 .539 r
F P
0 g
s
.15464 .39291 m .15326 .43753 L .17244 .44133 L p .895 0 .369 r
F P
0 g
s
.19656 .40576 m .15326 .43753 L .15464 .39291 L p .391 0 .328 r
F P
0 g
s
.21715 .36445 m .19779 .3604 L .15464 .39291 L p .706 0 .535 r
F P
0 g
s
.15464 .39291 m .19779 .3604 L .19656 .40576 L p .391 0 .328 r
F P
0 g
s
.19396 .40523 m .1952 .35986 L .15208 .39239 L p 0 .283 .328 r
F P
0 g
s
.15208 .39239 m .1507 .43702 L .19396 .40523 L p 0 .283 .328 r
F P
0 g
s
.1507 .43702 m .15208 .39239 L .1425 .39043 L p 0 .701 .369 r
F P
0 g
s
.1425 .39043 m .15208 .39239 L .1952 .35986 L p 0 .892 .535 r
F P
0 g
s
.35771 .43854 m .34834 .43664 L .34894 .39199 L p 0 .701 .368 r
F P
0 g
s
.32769 .38755 m .34644 .39147 L .34583 .43613 L p .898 0 .368 r
F P
0 g
s
.25918 .44529 m .23989 .44143 L .1959 .47242 L p .698 0 .538 r
F P
0 g
s
.19469 .5174 m .1959 .47242 L .23989 .44143 L p .402 0 .331 r
F P
0 g
s
.27134 .44773 m .27042 .49331 L .22584 .52331 L p 0 .301 .332 r
F P
0 g
s
.22584 .52331 m .27042 .49331 L .28004 .49518 L p 0 .899 .539 r
F P
0 g
s
.22584 .52331 m .27042 .49331 L .27134 .44773 L p 0 .301 .332 r
F P
0 g
s
.27042 .49331 m .22584 .52331 L .21633 .52151 L p 0 .899 .539 r
F P
0 g
s
.23731 .44092 m .19335 .47193 L .19213 .51692 L p 0 .294 .33 r
F P
0 g
s
.17423 .46819 m .19335 .47193 L .23731 .44092 L p 0 .896 .538 r
F P
0 g
s
.19335 .47193 m .17423 .46819 L .17293 .51328 L p 0 .701 .369 r
F P
0 g
s
.17293 .51328 m .19213 .51692 L .19335 .47193 L p 0 .701 .369 r
F P
0 g
s
.17499 .44184 m .21859 .41024 L .23794 .41418 L p 0 .895 .537 r
F P
0 g
s
.1425 .39043 m .14107 .43511 L .1507 .43702 L p 0 .701 .369 r
F P
0 g
s
.1842 .40325 m .14107 .43511 L .1425 .39043 L p 0 .281 .327 r
F P
0 g
s
.1952 .35986 m .18547 .35783 L .1425 .39043 L p 0 .892 .535 r
F P
0 g
s
.1425 .39043 m .18547 .35783 L .1842 .40325 L p 0 .281 .327 r
F P
0 g
s
.1842 .40325 m .18547 .35783 L .1425 .39043 L p 0 .281 .327 r
F P
0 g
s
.1425 .39043 m .14107 .43511 L .1842 .40325 L p 0 .281 .327 r
F P
0 g
s
.14107 .43511 m .1425 .39043 L .13289 .38847 L p 0 .701 .369 r
F P
0 g
s
.13289 .38847 m .1425 .39043 L .18547 .35783 L p 0 .892 .535 r
F P
0 g
s
.21601 .40972 m .17244 .44133 L .15326 .43753 L p .701 0 .537 r
F P
0 g
s
.38793 .47106 m .38748 .51607 L .36873 .51242 L p .898 0 .368 r
F P
0 g
s
.36873 .51242 m .36925 .46732 L .38793 .47106 L p .898 0 .368 r
F P
0 g
s
.26174 .4458 m .26078 .49143 L .21633 .52151 L p 0 .299 .332 r
F P
0 g
s
.21633 .52151 m .26078 .49143 L .27042 .49331 L p 0 .899 .539 r
F P
0 g
s
.13289 .38847 m .13142 .43319 L .14107 .43511 L p 0 .701 .369 r
F P
0 g
s
.17441 .40126 m .13142 .43319 L .13289 .38847 L p 0 .278 .326 r
F P
0 g
s
.18547 .35783 m .17573 .35579 L .13289 .38847 L p 0 .892 .535 r
F P
0 g
s
.13289 .38847 m .17573 .35579 L .17441 .40126 L p 0 .278 .326 r
F P
0 g
s
.21379 .52103 m .2582 .49093 L .25918 .44529 L p .407 0 .332 r
F P
0 g
s
.2582 .49093 m .21379 .52103 L .19469 .5174 L p .692 0 .539 r
F P
0 g
s
.17179 .40072 m .17312 .35525 L .13032 .38795 L p .384 0 .326 r
F P
0 g
s
.13032 .38795 m .12884 .43268 L .17179 .40072 L p .384 0 .326 r
F P
0 g
s
.12884 .43268 m .13032 .38795 L .11102 .38401 L p .895 0 .369 r
F P
0 g
s
.11102 .38401 m .13032 .38795 L .17312 .35525 L p .706 0 .535 r
F P
0 g
s
.34583 .43613 m .327 .4323 L .32769 .38755 L p .898 0 .368 r
F P
0 g
s
.30632 .38309 m .32518 .38703 L .32448 .43178 L p 0 .701 .368 r
F P
0 g
s
.23731 .44092 m .21792 .43704 L .17423 .46819 L p 0 .896 .538 r
F P
0 g
s
.17293 .51328 m .17423 .46819 L .21792 .43704 L p 0 .289 .329 r
F P
0 g
s
.21533 .43652 m .17167 .46769 L .17036 .51279 L p .396 0 .329 r
F P
0 g
s
.15245 .46394 m .17167 .46769 L .21533 .43652 L p .698 0 .538 r
F P
0 g
s
.17167 .46769 m .15245 .46394 L .15106 .50913 L p .895 0 .369 r
F P
0 g
s
.15106 .50913 m .17036 .51279 L .17167 .46769 L p .895 0 .369 r
F P
0 g
s
.15326 .43753 m .19656 .40576 L .21601 .40972 L p .701 0 .537 r
F P
0 g
s
.19396 .40523 m .1507 .43702 L .14107 .43511 L p 0 .895 .537 r
F P
0 g
s
.36676 .46682 m .36622 .51194 L .35681 .51011 L p 0 .701 .368 r
F P
0 g
s
.35681 .51011 m .35738 .46494 L .36676 .46682 L p 0 .701 .368 r
F P
0 g
s
.23989 .44143 m .23884 .48717 L .19469 .5174 L p .402 0 .331 r
F P
0 g
s
.19469 .5174 m .23884 .48717 L .2582 .49093 L p .692 0 .539 r
F P
0 g
s
.19213 .51692 m .23625 .48666 L .23731 .44092 L p 0 .294 .33 r
F P
0 g
s
.23625 .48666 m .19213 .51692 L .17293 .51328 L p 0 .899 .539 r
F P
0 g
s
.11102 .38401 m .10946 .42883 L .12884 .43268 L p .895 0 .369 r
F P
0 g
s
.15214 .39673 m .10946 .42883 L .11102 .38401 L p .379 0 .325 r
F P
0 g
s
.17312 .35525 m .15355 .35116 L .11102 .38401 L p .706 0 .535 r
F P
0 g
s
.11102 .38401 m .15355 .35116 L .15214 .39673 L p .379 0 .325 r
F P
0 g
s
.14107 .43511 m .1842 .40325 L .19396 .40523 L p 0 .895 .537 r
F P
0 g
s
.1842 .40325 m .14107 .43511 L .13142 .43319 L p 0 .895 .537 r
F P
0 g
s
.14951 .39619 m .15093 .35061 L .10844 .38348 L p 0 .272 .325 r
F P
0 g
s
.10844 .38348 m .10687 .42832 L .14951 .39619 L p 0 .272 .325 r
F P
0 g
s
.10687 .42832 m .10844 .38348 L .08903 .37953 L p 0 .701 .369 r
F P
0 g
s
.08903 .37953 m .10844 .38348 L .15093 .35061 L p 0 .892 .535 r
F P
0 g
s
.35738 .46494 m .35681 .51011 L .34737 .50827 L p 0 .701 .368 r
F P
0 g
s
.34737 .50827 m .34798 .46306 L .35738 .46494 L p 0 .701 .368 r
F P
0 g
s
.32448 .43178 m .30555 .42793 L .30632 .38309 L p 0 .701 .368 r
F P
0 g
s
.28485 .3786 m .3038 .38256 L .30302 .42742 L p .898 0 .368 r
F P
0 g
s
.21533 .43652 m .19584 .43262 L .15245 .46394 L p .698 0 .538 r
F P
0 g
s
.15106 .50913 m .15245 .46394 L .19584 .43262 L p .391 0 .328 r
F P
0 g
s
.19323 .43209 m .14988 .46344 L .14848 .50864 L p 0 .283 .328 r
F P
0 g
s
.14023 .46155 m .14988 .46344 L .19323 .43209 L p 0 .896 .538 r
F P
0 g
s
.14988 .46344 m .14023 .46155 L .13879 .5068 L p 0 .701 .369 r
F P
0 g
s
.13879 .5068 m .14848 .50864 L .14988 .46344 L p 0 .701 .369 r
F P
0 g
s
.19323 .43209 m .18344 .43014 L .14023 .46155 L p 0 .896 .538 r
F P
0 g
s
.13879 .5068 m .14023 .46155 L .18344 .43014 L p 0 .281 .327 r
F P
0 g
s
.18344 .43014 m .14023 .46155 L .13879 .5068 L p 0 .281 .327 r
F P
0 g
s
.12907 .50496 m .13879 .5068 L .14023 .46155 L p 0 .701 .369 r
F P
0 g
s
.21792 .43704 m .21677 .48288 L .17293 .51328 L p 0 .289 .329 r
F P
0 g
s
.17036 .51279 m .21417 .48237 L .21533 .43652 L p .396 0 .329 r
F P
0 g
s
.19584 .43262 m .19459 .47856 L .15106 .50913 L p .391 0 .328 r
F P
0 g
s
.14848 .50864 m .19198 .47805 L .19323 .43209 L p 0 .283 .328 r
F P
0 g
s
.18344 .43014 m .18215 .47614 L .13879 .5068 L p 0 .281 .327 r
F P
0 g
s
.13879 .5068 m .18215 .47614 L .18344 .43014 L p 0 .281 .327 r
F P
0 g
s
.18215 .47614 m .13879 .5068 L .12907 .50496 L p 0 .899 .539 r
F P
0 g
s
.13142 .43319 m .17441 .40126 L .1842 .40325 L p 0 .895 .537 r
F P
0 g
s
.17179 .40072 m .12884 .43268 L .10946 .42883 L p .701 0 .537 r
F P
0 g
s
.34547 .46256 m .34485 .50778 L .3259 .5041 L p .898 0 .368 r
F P
0 g
s
.3259 .5041 m .32659 .45878 L .34547 .46256 L p .898 0 .368 r
F P
0 g
s
.17293 .51328 m .21677 .48288 L .23625 .48666 L p 0 .899 .539 r
F P
0 g
s
.13055 .45966 m .14023 .46155 L .18344 .43014 L p 0 .896 .538 r
F P
0 g
s
.14023 .46155 m .13055 .45966 L .12907 .50496 L p 0 .701 .369 r
F P
0 g
s
.21417 .48237 m .17036 .51279 L .15106 .50913 L p .692 0 .539 r
F P
0 g
s
.08903 .37953 m .08738 .42445 L .10687 .42832 L p 0 .701 .369 r
F P
0 g
s
.12974 .39217 m .08738 .42445 L .08903 .37953 L p 0 .267 .323 r
F P
0 g
s
.15093 .35061 m .13125 .3465 L .08903 .37953 L p 0 .892 .535 r
F P
0 g
s
.08903 .37953 m .13125 .3465 L .12974 .39217 L p 0 .267 .323 r
F P
0 g
s
.1271 .39163 m .12862 .34595 L .08644 .379 L p .372 0 .323 r
F P
0 g
s
.08644 .379 m .08478 .42393 L .1271 .39163 L p .372 0 .323 r
F P
0 g
s
.08478 .42393 m .08644 .379 L .06693 .37502 L p .895 0 .369 r
F P
0 g
s
.06693 .37502 m .08644 .379 L .12862 .34595 L p .706 0 .535 r
F P
0 g
s
.30302 .42742 m .28399 .42355 L .28485 .3786 L p .898 0 .368 r
F P
0 g
s
.2728 .37608 m .28231 .37807 L .28144 .42303 L p 0 .701 .368 r
F P
0 g
s
.18344 .43014 m .17363 .42817 L .13055 .45966 L p 0 .896 .538 r
F P
0 g
s
.12907 .50496 m .13055 .45966 L .17363 .42817 L p 0 .278 .326 r
F P
0 g
s
.17101 .42765 m .12797 .45916 L .12648 .50446 L p .384 0 .326 r
F P
0 g
s
.10854 .45537 m .12797 .45916 L .17101 .42765 L p .698 0 .538 r
F P
0 g
s
.12797 .45916 m .10854 .45537 L .10697 .50076 L p .895 0 .369 r
F P
0 g
s
.10697 .50076 m .12648 .50446 L .12797 .45916 L p .895 0 .369 r
F P
0 g
s
.10946 .42883 m .15214 .39673 L .17179 .40072 L p .701 0 .537 r
F P
0 g
s
.14951 .39619 m .10687 .42832 L .08738 .42445 L p 0 .895 .537 r
F P
0 g
s
.32407 .45828 m .32336 .5036 L .30431 .4999 L p 0 .701 .368 r
F P
0 g
s
.30431 .4999 m .30509 .45448 L .32407 .45828 L p 0 .701 .368 r
F P
0 g
s
.28144 .42303 m .27188 .42108 L .2728 .37608 L p 0 .701 .368 r
F P
0 g
s
.26326 .37409 m .2728 .37608 L .27188 .42108 L p 0 .701 .368 r
F P
0 g
s
.15106 .50913 m .19459 .47856 L .21417 .48237 L p .692 0 .539 r
F P
0 g
s
.19198 .47805 m .14848 .50864 L .13879 .5068 L p 0 .899 .539 r
F P
0 g
s
.06693 .37502 m .06519 .42005 L .08478 .42393 L p .895 0 .369 r
F P
0 g
s
.10723 .38759 m .06519 .42005 L .06693 .37502 L p .367 0 .322 r
F P
0 g
s
.12862 .34595 m .10883 .34181 L .06693 .37502 L p .706 0 .535 r
F P
0 g
s
.06693 .37502 m .10883 .34181 L .10723 .38759 L p .367 0 .322 r
F P
0 g
s
.10457 .38705 m .10618 .34126 L .06432 .37449 L p 0 .261 .322 r
F P
0 g
s
.06432 .37449 m .06257 .41953 L .10457 .38705 L p 0 .261 .322 r
F P
0 g
s
.06257 .41953 m .06432 .37449 L .05453 .37249 L p 0 .701 .369 r
F P
0 g
s
.05453 .37249 m .06432 .37449 L .10618 .34126 L p 0 .892 .535 r
F P
0 g
s
.27188 .42108 m .2623 .41914 L .26326 .37409 L p 0 .701 .368 r
F P
0 g
s
.24155 .36955 m .26071 .37356 L .25975 .41862 L p .898 0 .368 r
F P
0 g
s
.17101 .42765 m .1513 .4237 L .10854 .45537 L p .698 0 .538 r
F P
0 g
s
.10697 .50076 m .10854 .45537 L .1513 .4237 L p .379 0 .325 r
F P
0 g
s
.13879 .5068 m .18215 .47614 L .19198 .47805 L p 0 .899 .539 r
F P
0 g
s
.08738 .42445 m .12974 .39217 L .14951 .39619 L p 0 .895 .537 r
F P
0 g
s
.14867 .42318 m .10594 .45486 L .10436 .50027 L p 0 .272 .325 r
F P
0 g
s
.08641 .45105 m .10594 .45486 L .14867 .42318 L p 0 .896 .538 r
F P
0 g
s
.10594 .45486 m .08641 .45105 L .08474 .49655 L p 0 .701 .369 r
F P
0 g
s
.08474 .49655 m .10436 .50027 L .10594 .45486 L p 0 .701 .369 r
F P
0 g
s
.05453 .37249 m .05273 .41757 L .06257 .41953 L p 0 .701 .369 r
F P
0 g
s
.09459 .38502 m .05273 .41757 L .05453 .37249 L p 0 .258 .321 r
F P
0 g
s
.10618 .34126 m .09625 .33918 L .05453 .37249 L p 0 .892 .535 r
F P
0 g
s
.05453 .37249 m .09625 .33918 L .09459 .38502 L p 0 .258 .321 r
F P
0 g
s
.1271 .39163 m .08478 .42393 L .06519 .42005 L p .701 0 .537 r
F P
0 g
s
.30255 .45397 m .30176 .4994 L .2826 .49568 L p .898 0 .368 r
F P
0 g
s
.2826 .49568 m .28347 .45015 L .30255 .45397 L p .898 0 .368 r
F P
0 g
s
.17363 .42817 m .17229 .47423 L .12907 .50496 L p 0 .278 .326 r
F P
0 g
s
.12907 .50496 m .17229 .47423 L .18215 .47614 L p 0 .899 .539 r
F P
0 g
s
.12648 .50446 m .16966 .47371 L .17101 .42765 L p .384 0 .326 r
F P
0 g
s
.16966 .47371 m .12648 .50446 L .10697 .50076 L p .692 0 .539 r
F P
0 g
s
.25975 .41862 m .24051 .4147 L .24155 .36955 L p .898 0 .368 r
F P
0 g
s
.21973 .36499 m .23899 .36902 L .23794 .41418 L p 0 .701 .368 r
F P
0 g
s
.14867 .42318 m .12885 .41921 L .08641 .45105 L p 0 .896 .538 r
F P
0 g
s
.08474 .49655 m .08641 .45105 L .12885 .41921 L p 0 .267 .323 r
F P
0 g
s
.06519 .42005 m .10723 .38759 L .1271 .39163 L p .701 0 .537 r
F P
0 g
s
.1262 .41868 m .0838 .45054 L .08212 .49605 L p .372 0 .323 r
F P
0 g
s
.06416 .4467 m .0838 .45054 L .1262 .41868 L p .698 0 .538 r
F P
0 g
s
.0838 .45054 m .06416 .4467 L .0624 .49231 L p .895 0 .369 r
F P
0 g
s
.0624 .49231 m .08212 .49605 L .0838 .45054 L p .895 0 .369 r
F P
0 g
s
.10457 .38705 m .06257 .41953 L .05273 .41757 L p 0 .895 .537 r
F P
0 g
s
.28092 .44964 m .28004 .49518 L .27042 .49331 L p 0 .701 .368 r
F P
0 g
s
.27042 .49331 m .27134 .44773 L .28092 .44964 L p 0 .701 .368 r
F P
0 g
s
.1513 .4237 m .14987 .46987 L .10697 .50076 L p .379 0 .325 r
F P
0 g
s
.10697 .50076 m .14987 .46987 L .16966 .47371 L p .692 0 .539 r
F P
0 g
s
.10436 .50027 m .14722 .46935 L .14867 .42318 L p 0 .272 .325 r
F P
0 g
s
.14722 .46935 m .10436 .50027 L .08474 .49655 L p 0 .899 .539 r
F P
0 g
s
.05273 .41757 m .09459 .38502 L .10457 .38705 L p 0 .895 .537 r
F P
0 g
s
.27134 .44773 m .27042 .49331 L .26078 .49143 L p 0 .701 .368 r
F P
0 g
s
.26078 .49143 m .26174 .4458 L .27134 .44773 L p 0 .701 .368 r
F P
0 g
s
.23794 .41418 m .21859 .41024 L .21973 .36499 L p 0 .701 .368 r
F P
0 g
s
.19779 .3604 m .21715 .36445 L .21601 .40972 L p .898 0 .368 r
F P
0 g
s
.1262 .41868 m .10628 .41469 L .06416 .4467 L p .698 0 .538 r
F P
0 g
s
.0624 .49231 m .06416 .4467 L .10628 .41469 L p .367 0 .322 r
F P
0 g
s
.10361 .41416 m .06153 .44619 L .05976 .49181 L p 0 .261 .322 r
F P
0 g
s
.05167 .44426 m .06153 .44619 L .10361 .41416 L p 0 .896 .538 r
F P
0 g
s
.06153 .44619 m .05167 .44426 L .04986 .48993 L p 0 .701 .369 r
F P
0 g
s
.04986 .48993 m .05976 .49181 L .06153 .44619 L p 0 .701 .369 r
F P
0 g
s
.25918 .44529 m .2582 .49093 L .23884 .48717 L p .898 0 .368 r
F P
0 g
s
.23884 .48717 m .23989 .44143 L .25918 .44529 L p .898 0 .368 r
F P
0 g
s
.12885 .41921 m .12732 .46548 L .08474 .49655 L p 0 .267 .323 r
F P
0 g
s
.08474 .49655 m .12732 .46548 L .14722 .46935 L p 0 .899 .539 r
F P
0 g
s
.10361 .41416 m .09361 .41216 L .05167 .44426 L p 0 .896 .538 r
F P
0 g
s
.04986 .48993 m .05167 .44426 L .09361 .41216 L p 0 .258 .321 r
F P
0 g
s
.08212 .49605 m .12466 .46496 L .1262 .41868 L p .372 0 .323 r
F P
0 g
s
.12466 .46496 m .08212 .49605 L .0624 .49231 L p .692 0 .539 r
F P
0 g
s
.21601 .40972 m .19656 .40576 L .19779 .3604 L p .898 0 .368 r
F P
0 g
s
.18547 .35783 m .1952 .35986 L .19396 .40523 L p 0 .701 .368 r
F P
0 g
s
.23731 .44092 m .23625 .48666 L .21677 .48288 L p 0 .701 .368 r
F P
0 g
s
.21677 .48288 m .21792 .43704 L .23731 .44092 L p 0 .701 .368 r
F P
0 g
s
.19396 .40523 m .1842 .40325 L .18547 .35783 L p 0 .701 .368 r
F P
0 g
s
.17573 .35579 m .18547 .35783 L .1842 .40325 L p 0 .701 .368 r
F P
0 g
s
.10628 .41469 m .10465 .46107 L .0624 .49231 L p .367 0 .322 r
F P
0 g
s
.0624 .49231 m .10465 .46107 L .12466 .46496 L p .692 0 .539 r
F P
0 g
s
.05976 .49181 m .10198 .46055 L .10361 .41416 L p 0 .261 .322 r
F P
0 g
s
.10198 .46055 m .05976 .49181 L .04986 .48993 L p 0 .899 .539 r
F P
0 g
s
.1842 .40325 m .17441 .40126 L .17573 .35579 L p 0 .701 .368 r
F P
0 g
s
.15355 .35116 m .17312 .35525 L .17179 .40072 L p .898 0 .368 r
F P
0 g
s
.09361 .41216 m .09193 .4586 L .04986 .48993 L p 0 .258 .321 r
F P
0 g
s
.04986 .48993 m .09193 .4586 L .10198 .46055 L p 0 .899 .539 r
F P
0 g
s
.21533 .43652 m .21417 .48237 L .19459 .47856 L p .898 0 .368 r
F P
0 g
s
.19459 .47856 m .19584 .43262 L .21533 .43652 L p .898 0 .368 r
F P
0 g
s
.17179 .40072 m .15214 .39673 L .15355 .35116 L p .898 0 .368 r
F P
0 g
s
.13125 .3465 m .15093 .35061 L .14951 .39619 L p 0 .701 .368 r
F P
0 g
s
.19323 .43209 m .19198 .47805 L .18215 .47614 L p 0 .701 .368 r
F P
0 g
s
.18215 .47614 m .18344 .43014 L .19323 .43209 L p 0 .701 .368 r
F P
0 g
s
.18344 .43014 m .18215 .47614 L .17229 .47423 L p 0 .701 .368 r
F P
0 g
s
.17229 .47423 m .17363 .42817 L .18344 .43014 L p 0 .701 .368 r
F P
0 g
s
.14951 .39619 m .12974 .39217 L .13125 .3465 L p 0 .701 .368 r
F P
0 g
s
.10883 .34181 m .12862 .34595 L .1271 .39163 L p .898 0 .368 r
F P
0 g
s
.17101 .42765 m .16966 .47371 L .14987 .46987 L p .898 0 .368 r
F P
0 g
s
.14987 .46987 m .1513 .4237 L .17101 .42765 L p .898 0 .368 r
F P
0 g
s
.1271 .39163 m .10723 .38759 L .10883 .34181 L p .898 0 .368 r
F P
0 g
s
.09625 .33918 m .10618 .34126 L .10457 .38705 L p 0 .701 .368 r
F P
0 g
s
.14867 .42318 m .14722 .46935 L .12732 .46548 L p 0 .701 .368 r
F P
0 g
s
.12732 .46548 m .12885 .41921 L .14867 .42318 L p 0 .701 .368 r
F P
0 g
s
.10457 .38705 m .09459 .38502 L .09625 .33918 L p 0 .701 .368 r
F P
0 g
s
.1262 .41868 m .12466 .46496 L .10465 .46107 L p .898 0 .368 r
F P
0 g
s
.10465 .46107 m .10628 .41469 L .1262 .41868 L p .898 0 .368 r
F P
0 g
s
.10361 .41416 m .10198 .46055 L .09193 .4586 L p 0 .701 .368 r
F P
0 g
s
.09193 .4586 m .09361 .41216 L .10361 .41416 L p 0 .701 .368 r
F P
0 g
s
[ .01 .01 ] 0 setdash
.0748 .33064 m
.92907 .5096 L
s
.92907 .5096 m
.93341 .62406 L
s
.93341 .62406 m
.07001 .45637 L
s
.07001 .45637 m
.0748 .33064 L
s
.03135 .36585 m
.02618 .4894 L
s
.02618 .4894 m
.07001 .45637 L
s
.07001 .45637 m
.0748 .33064 L
s
.0748 .33064 m
.03135 .36585 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 0.0625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X000000P10`0000010?ooo`3oooooZZ[oZSLg
=gIfM[Fe]OCdm03oZS/k>gYjN[Vi^CLg=gIfM[Fe]OCdm?clo5D005Gooj[ooc/k>gYjN[Vi^OShn03o
oclo?ginO[fm_C/k>gYjN[Vi^OShn000EED0EJX00?l003lo?ginO[fm_Oclo0<30d92@X61PL30`3lo
?ginO[fm_Ol0E@00ZUD0ZZX0E@<30d92@X61PL30`000E@L71dI6AXF5Q@<30d92@X61PL30`?l0ZP00
oeD0ojX0ZPL71dI6AXF5QLC4a000ZP/;2dY:BXV9R@L71dI6AXF5QLC4a?l0o`1E05EE0:X0o`/;2dY:
BXV9RLS8b000o`l?3di>CXf=S@/;2dY:BXV9RLS8b?mE001EEEEEEJYE00l?3di>CXf=SLc<c01E01<C
4e9BDY6AT@l?3di>CXf=SLc<c?mEE@1EZUEEZZYEEA<C4e9BDY6ATM3@d01EEALG5eIFEYFEUA<C4e9B
DY6ATM3@d?mEZP1EoeEEojYEZQLG5eIFEYFEUMCDe01EZQ/K6eYJFYVIVALG5eIFEYFEUMCDe?mEo`2Z
05FZ0:YEoa/K6eYJFYVIVMSHf01EoalO7eiNGYfMWA/K6eYJFYVIVMSHf?nZ002ZEEFZEJZZ01lO7eiN
GYfMWMcLg02Z02<S8f9RHZ6QXAlO7eiNGYfMWMcLg?nZE@2ZZUFZZZZZEB<S8f9RHZ6QXN3Ph02ZEBLW
9fIVIZFUYB<S8f9RHZ6QXN3Ph?nZZP2ZoeFZojZZZRLW9fIVIZFUYNCTi02ZZR/[:fYZJZVYZBLW9fIV
IZFUYNCTi?nZo`3o05Go0:ZZob/[:fYZJZVYZNSXj02Zobl_;fi^KZf][B/[:fYZJZVYZNSXj?oo003o
EEGoEJ[o02l_;fi^KZf][Nc/k03o03<c<g9bL[6a/Bl_;fi^KZf][Nc/k?ooE@3oZUGoZZ[oEC<c<g9b
L[6a/O3`l03oECLg=gIfM[Fe]C<c<g9bL[6a/O3`l000\
\>"],
  ImageRangeCache->{{{0, 359}, {-0.9375, 0}} -> {197.5, 
  0.05184, -1.33333, -1.33333}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computes the Trajectory ", "Section"],

Cell[TextData[{
  "The trajectory  on an electron inside the field of the previously defined \
undulator is  computed by mean of a 4th order Runge Kutta Integration. A plot \
of the horizontal and vertical angle and position of the electron as a \
function of the longitudinal coordinate s is performed. Note that the data \
resulting from the RungeKutta integration is kept in the ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "kernel  in a two dimensional List which holds the position and angle in \
both the horizonatal and vertical planes. The user interested in more \
information should look in the documentation the information concerning the \
\"radFldPtcTrj\" function. To increase (decrease) the precision increase \
(decrease) the number of points npt. Note that the computation time grows \
proportionnaly to the number of points npt and to the number of magnet blocks \
in the geometry. If one change the initial conditions x0,z0,xp0 and zp0, one \
will find that the  result of this computation can be interpreted (as \
expected)  as a focsusing (defocusing) in the vertical (horizontal) plane \
proportionnal to the square of the peak field over the square of the electron \
energy. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(energy = 0.08; 
    \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
     (*\ electron\ energy\ \ in\ GeV\ *) \nx0 = 1; 
    \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Initial\ Horiz . \ position\ [millimeters]\ *) \nz0\  = \(-1\)\ \ ; 
    \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \  (*\ Initial\ Vertic . \ position[millimeters]\ *) \n
    xp0 = 0; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Initial\ Horiz . \ angle\ [radians]\ *) \nzp0 = 0\ \ ; 
    \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \  (*\ Initial\ Vertic . \ angle\ [radians]\ *) \n
    npt = 20*NumberOfPeriod; 
    \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ Number\ of\ longitudinal\ Points\ *) \n\n
    ymax = Period*\((NumberOfPeriod/2 + 4)\); \nt0 = AbsoluteTime[]; \n
    t = Transpose[
        radFldPtcTrj[g, energy, {x0, xp0, z0, zp0}, {\(-ymax\), ymax}, npt]]; 
    \ndt = AbsoluteTime[] - t0; \n\t
    Print["\<Computation Time : \>", \ N[dt, 3], "\< sec  x = \>", 
      1000*t[\([2, npt]\)], "\< \[Mu]m,  z = \>", 1000*t[\([4, npt]\)], 
      "\< \[Mu]m  at Exit\>"]; \)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Computation Time : \"\>", "\[InvisibleSpace]", 
        StyleBox["3.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" sec  x = \"\>", 
        "\[InvisibleSpace]", "1011.97318085532672`", "\[InvisibleSpace]", 
        "\<\" \[Mu]m,  z = \"\>", "\[InvisibleSpace]", 
        \(-617.703787549299754`\), "\[InvisibleSpace]", 
        "\<\" \[Mu]m  at Exit\"\>"}],
      SequenceForm[ 
      "Computation Time : ", 3.0, " sec  x = ", 1011.9731808553267, 
        " \[Mu]m,  z = ", -617.70378754929982, " \[Mu]m  at Exit"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*\ Plot\ Horizontal\ Angle\ *) \n
    ListPlot[Transpose[{t[\([1]\)], 1000000*t[\([3]\)]}]\n\t, 
      PlotJoined -> True, \ PlotRange -> All\n\t\t\t, 
      AxesLabel -> {"\<s [mm]\>", "\<x' [\[Mu]r]\>"}]; \n
    \n (*\ Plot\ Horizontal\ Position\ *) \n
    ListPlot[Transpose[{t[\([1]\)], 1000*t[\([2]\)]}]\n\t, 
      PlotJoined -> True, \ PlotRange -> All\n\t\t\t, 
      AxesLabel -> {"\<s [mm]\>", "\<x [\[Mu]m]\>"}]; \n
    \n (*\ Plot\ Vertical\ Angle\ *) \n
    ListPlot[Transpose[{t[\([1]\)], 1000000*t[\([5]\)]}]\n\t, 
      PlotJoined -> True, \ PlotRange -> All\n\t\t\t, 
      AxesLabel -> {"\<s [mm]\>", "\<z' [\[Mu]r]\>"}]; \n
    \n (*\ Plot\ Vertical\ Position\ *) \n
    ListPlot[Transpose[{t[\([1]\)], 1000*t[\([4]\)]}], \n\t
      PlotJoined -> True, \ PlotRange -> All\n\t\t, 
      AxesLabel -> {"\<s [mm]\>", "\<z [\[Mu]m]\>"}]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.00155618 0.307962 1.68598e-05 [
[.03315 .29546 -15.125 -14 ]
[.03315 .29546 15.125 0 ]
[.18876 .29546 -15.125 -14 ]
[.18876 .29546 15.125 0 ]
[.34438 .29546 -15.125 -14 ]
[.34438 .29546 15.125 0 ]
[.65562 .29546 -11 -14 ]
[.65562 .29546 11 0 ]
[.81124 .29546 -11 -14 ]
[.81124 .29546 11 0 ]
[.96685 .29546 -11 -14 ]
[.96685 .29546 11 0 ]
[1.025 .30796 0 -7 ]
[1.025 .30796 38.125 7 ]
[.4875 .05507 -42.25 -7 ]
[.4875 .05507 0 7 ]
[.4875 .13936 -42.25 -7 ]
[.4875 .13936 0 7 ]
[.4875 .22366 -36.25 -7 ]
[.4875 .22366 0 7 ]
[.4875 .39226 -28 -7 ]
[.4875 .39226 0 7 ]
[.4875 .47656 -34 -7 ]
[.4875 .47656 0 7 ]
[.4875 .56086 -34 -7 ]
[.4875 .56086 0 7 ]
[.5 .64303 -17 0 ]
[.5 .64303 17 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03315 .30796 m
.03315 .31421 L
s
gsave
.03315 .29546 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18876 .30796 m
.18876 .31421 L
s
gsave
.18876 .29546 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.34438 .30796 m
.34438 .31421 L
s
gsave
.34438 .29546 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.65562 .30796 m
.65562 .31421 L
s
gsave
.65562 .29546 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81124 .30796 m
.81124 .31421 L
s
gsave
.81124 .29546 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96685 .30796 m
.96685 .31421 L
s
gsave
.96685 .29546 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06427 .30796 m
.06427 .31171 L
s
.09539 .30796 m
.09539 .31171 L
s
.12652 .30796 m
.12652 .31171 L
s
.15764 .30796 m
.15764 .31171 L
s
.21989 .30796 m
.21989 .31171 L
s
.25101 .30796 m
.25101 .31171 L
s
.28214 .30796 m
.28214 .31171 L
s
.31326 .30796 m
.31326 .31171 L
s
.37551 .30796 m
.37551 .31171 L
s
.40663 .30796 m
.40663 .31171 L
s
.43775 .30796 m
.43775 .31171 L
s
.46888 .30796 m
.46888 .31171 L
s
.53112 .30796 m
.53112 .31171 L
s
.56225 .30796 m
.56225 .31171 L
s
.59337 .30796 m
.59337 .31171 L
s
.62449 .30796 m
.62449 .31171 L
s
.68674 .30796 m
.68674 .31171 L
s
.71786 .30796 m
.71786 .31171 L
s
.74899 .30796 m
.74899 .31171 L
s
.78011 .30796 m
.78011 .31171 L
s
.84236 .30796 m
.84236 .31171 L
s
.87348 .30796 m
.87348 .31171 L
s
.90461 .30796 m
.90461 .31171 L
s
.93573 .30796 m
.93573 .31171 L
s
.00202 .30796 m
.00202 .31171 L
s
.99798 .30796 m
.99798 .31171 L
s
.25 Mabswid
0 .30796 m
1 .30796 L
s
gsave
1.025 .30796 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.625000 14.000000 moveto
(@) show
74.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.187500 14.000000 moveto
(D) show
97.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.5 .05507 m
.50625 .05507 L
s
gsave
.4875 .05507 -103.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15000) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .13936 m
.50625 .13936 L
s
gsave
.4875 .13936 -103.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10000) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .22366 m
.50625 .22366 L
s
gsave
.4875 .22366 -97.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5000) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .39226 m
.50625 .39226 L
s
gsave
.4875 .39226 -89 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5000) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .47656 m
.50625 .47656 L
s
gsave
.4875 .47656 -95 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10000) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .56086 m
.50625 .56086 L
s
gsave
.4875 .56086 -95 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15000) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.5 .07192 m
.50375 .07192 L
s
.5 .08878 m
.50375 .08878 L
s
.5 .10564 m
.50375 .10564 L
s
.5 .1225 m
.50375 .1225 L
s
.5 .15622 m
.50375 .15622 L
s
.5 .17308 m
.50375 .17308 L
s
.5 .18994 m
.50375 .18994 L
s
.5 .2068 m
.50375 .2068 L
s
.5 .24052 m
.50375 .24052 L
s
.5 .25738 m
.50375 .25738 L
s
.5 .27424 m
.50375 .27424 L
s
.5 .2911 m
.50375 .2911 L
s
.5 .32482 m
.50375 .32482 L
s
.5 .34168 m
.50375 .34168 L
s
.5 .35854 m
.50375 .35854 L
s
.5 .3754 m
.50375 .3754 L
s
.5 .40912 m
.50375 .40912 L
s
.5 .42598 m
.50375 .42598 L
s
.5 .44284 m
.50375 .44284 L
s
.5 .4597 m
.50375 .4597 L
s
.5 .49342 m
.50375 .49342 L
s
.5 .51028 m
.50375 .51028 L
s
.5 .52714 m
.50375 .52714 L
s
.5 .544 m
.50375 .544 L
s
.5 .03821 m
.50375 .03821 L
s
.5 .02135 m
.50375 .02135 L
s
.5 .00449 m
.50375 .00449 L
s
.5 .57772 m
.50375 .57772 L
s
.5 .59458 m
.50375 .59458 L
s
.5 .61144 m
.50375 .61144 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(') show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
74.125000 14.000000 moveto
(@) show
78.625000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(m) show
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(r) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
89.062500 14.000000 moveto
(D) show
93.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Math2
%%+ font Times-Roman
grestore
.5 Mabswid
.02381 .30796 m
.0286 .30797 L
.03338 .30797 L
.03817 .30798 L
.04295 .30799 L
.04774 .30799 L
.05252 .308 L
.05731 .30801 L
.0621 .30802 L
.06688 .30803 L
.07167 .30804 L
.07645 .30806 L
.08124 .30807 L
.08603 .30809 L
.09081 .30811 L
.0956 .30813 L
.10038 .30816 L
.10517 .30819 L
.10995 .30822 L
.11474 .30826 L
.11953 .3083 L
.12431 .30836 L
.1291 .30842 L
.13388 .30849 L
.13867 .30858 L
.14346 .30868 L
.14824 .30881 L
.15303 .30896 L
.15781 .30915 L
.1626 .30939 L
.16738 .30968 L
.17217 .31006 L
.17696 .31054 L
.18174 .31118 L
.18653 .31202 L
.19131 .31316 L
.1961 .31473 L
.20089 .31694 L
.20567 .32013 L
.21046 .32482 L
.21524 .33194 L
.22003 .34304 L
.22481 .36097 L
.2296 .39108 L
.23439 .44273 L
.23917 .51905 L
.24396 .58737 L
.24874 .60332 L
.25353 .54909 L
.25832 .43233 L
Mistroke
.2631 .28629 L
.26789 .15289 L
.27267 .07294 L
.27746 .07001 L
.28224 .14415 L
.28703 .27192 L
.29182 .4119 L
.2966 .52095 L
.30139 .56321 L
.30617 .52664 L
.31096 .42128 L
.31575 .28134 L
.32053 .14983 L
.32532 .06857 L
.3301 .06293 L
.33489 .13437 L
.33967 .26106 L
.34446 .40213 L
.34925 .51446 L
.35403 .56135 L
.35882 .5294 L
.3636 .42741 L
.36839 .28848 L
.37318 .15555 L
.37796 .07073 L
.38275 .06076 L
.38753 .12831 L
.39232 .25294 L
.3971 .39434 L
.40189 .50938 L
.40668 .5605 L
.41146 .53294 L
.41625 .43425 L
.42103 .29633 L
.42582 .16202 L
.43061 .07364 L
.43539 .05928 L
.44018 .12279 L
.44496 .24517 L
.44975 .38671 L
.45453 .50427 L
.45932 .55954 L
.46411 .53638 L
.46889 .44107 L
.47368 .3043 L
.47846 .16874 L
.48325 .0769 L
.48804 .05816 L
.49282 .11756 L
.49761 .23753 L
Mistroke
.50239 .37905 L
.50718 .49898 L
.51196 .55835 L
.51675 .53958 L
.52154 .44776 L
.52632 .31228 L
.53111 .17563 L
.53589 .08043 L
.54068 .05732 L
.54547 .11256 L
.55025 .22998 L
.55504 .37132 L
.55982 .49348 L
.56461 .55687 L
.56939 .5425 L
.57418 .45427 L
.57897 .32023 L
.58375 .18262 L
.58854 .08419 L
.59332 .05672 L
.59811 .10775 L
.6029 .22247 L
.60768 .36349 L
.61247 .48772 L
.61725 .55504 L
.62204 .54507 L
.62682 .46051 L
.63161 .32804 L
.6364 .1896 L
.64118 .08803 L
.64597 .05621 L
.65075 .10296 L
.65554 .21483 L
.66033 .35533 L
.66511 .48144 L
.6699 .55256 L
.67468 .54691 L
.67947 .466 L
.68425 .33512 L
.68904 .19585 L
.69383 .09106 L
.69861 .05467 L
.7034 .09677 L
.70818 .20521 L
.71297 .34446 L
.71776 .47147 L
.72254 .54516 L
.72733 .54221 L
.73211 .46268 L
.7369 .33006 L
Mistroke
.74168 .18484 L
.74647 .06877 L
.75126 .01472 L
.75604 .03035 L
.76083 .09774 L
.76561 .17335 L
.7704 .22509 L
.77519 .25539 L
.77997 .27341 L
.78476 .28457 L
.78954 .29171 L
.79433 .29642 L
.79911 .29962 L
.8039 .30184 L
.80869 .30341 L
.81347 .30455 L
.81826 .3054 L
.82304 .30603 L
.82783 .30652 L
.83262 .3069 L
.8374 .30719 L
.84219 .30743 L
.84697 .30762 L
.85176 .30777 L
.85654 .3079 L
.86133 .308 L
.86612 .30809 L
.8709 .30816 L
.87569 .30822 L
.88047 .30827 L
.88526 .30832 L
.89005 .30836 L
.89483 .30839 L
.89962 .30842 L
.9044 .30845 L
.90919 .30847 L
.91397 .30849 L
.91876 .30851 L
.92355 .30852 L
.92833 .30853 L
.93312 .30855 L
.9379 .30856 L
.94269 .30857 L
.94748 .30858 L
.95226 .30858 L
.95705 .30859 L
.96183 .3086 L
.96662 .3086 L
.9714 .30861 L
.97619 .30861 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo002LOol00`00Oomoo`39Ool0
09aoo`03001oogoo0<Uoo`00W7oo0P00bWoo002LOol00`00Oomoo`39Ool009aoo`03001oogoo0<Uo
o`00W7oo00<007ooOol0Agoo00<007ooOol0Ogoo002LOol00`00Oomoo`17Ool00`00Oomoo`1oOol0
09aoo`8004Qoo`80081oo`00W7oo00<007ooOol0Agoo0P00P7oo002LOol00`00Oomoo`17Ool00`00
Ool0001oOol009aoo`03001oogoo04Moo`03001oo`0007moo`00W7oo00<007ooOol0Agoo00<007oo
0000Ogoo002LOol20018Ool00`00Ool0001oOol009aoo`03001oogoo04Moo`03001oo`0007moo`00
LWoo0`000goo1@0017oo0`001Goo0`0017oo0`002Goo00<007ooOol0AWoo00@007ooOol007moo`00
Lgoo00<007ooOol01goo00@007ooOol000=oo`05001oogooOol00003Ool01000Oomoo`000goo00<0
07ooOol01Woo00<007ooOol0AWoo00@007ooOol007moo`00Lgoo00<007ooOol027oo0P001Goo00<0
07oo00001Goo0P001Goo00<007ooOol01Goo00<007ooOol0>7oo00<007ooOol02goo00@007ooOol0
07moo`00Igoo200017oo00<007ooOol027oo0P001Goo00<007oo00001Goo0P001Goo00<007ooOol0
0Woo00<007ooOol00`002Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007oo
Ool02goo00@007ooOol007moo`00Lgoo00<007ooOol00goo00<007ooOol00Woo0P001Goo00D007oo
001oo`0000=oo`8000Eoo`03001oogoo009oo`04001oogoo000;Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool01000Oomoo`00Ogoo001ZOol00`00Oomoo`06Ool0
0`00Oomoo`03Ool01`00Oomoogoo001oo`0000Eoo`05001oo`00Ool00003Ool20005Ool01000Oomo
ogoo0P000Woo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<0
07ooOol02goo00@007ooOol007moo`00JGoo0P0027oo00<007ooOol00Woo1@000Woo00<007ooOol0
0goo00D007oo001oo`0000=oo`8000Eoo`04001oogooOol20002Ool00`00Oomoo`09Ool00`00Oomo
o`0<Ool2000>Ool00`00Oomoo`0<Ool2000=Ool01@00Oomoogoo0000OWoo001JOol00`00Oomoo`0<
Ool20008Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`03Ool00`00Ool000020003Ool20005Ool0
1000Oomoogoo0P000Woo0P002Goo0P003Woo0P003Woo0P003Goo0P003Goo00D007ooOomoo`0007io
o`00FGoo0P003Woo0P001goo0P0017oo0`001Goo00D007ooOomoo`0000=oo`80009oo`04001oogoo
0003Ool01`00Oomoogoo001oo`00009oo`03001oogoo00Qoo`8000ioo`8000eoo`03001oo`0000eo
o`8000eoo`05001oogooOol0001nOol005Uoo`8000ioo`8000Qoo`03001oogoo009oo`L0009oo`<0
00Aoo`@000Aoo`<000Aoo`03001oo`00009oo`03001oogoo00Qoo`8000ioo`8000eoo`03001oo`00
00eoo`03001oo`0000aoo`05001oogooOol0001nOol005Uoo`8000ioo`8000eoo`03001oo`0000eo
o`8000eoo`03001oo`00009oo`03001oogoo00Qoo`8000eoo`03001oo`0000eoo`03001oo`0000eo
o`03001oo`0000aoo`05001oogooOol0001nOol005Uoo`8000ioo`8000eoo`03001oo`0000eoo`80
00eoo`03001oo`00009oo`03001oogoo00Qoo`8000eoo`04001oogoo000<Ool00`00Ool0000<Ool0
1000Oomoo`0037oo00D007ooOomoo`0007ioo`00FGoo0P003Woo0P003Goo00<007oo00003Goo0P00
3Goo00<007oo00000Woo0P002Goo00<007oo000037oo00@007ooOol000aoo`03001oo`0000aoo`04
001oogoo000<Ool01@00Oomoogoo0000OWoo001IOol00`00Ool0000<Ool00`00Ool0000=Ool00`00
Ool0000=Ool2000=Ool01P00Oomoo`00Ool000Yoo`03001oo`0000aoo`04001oogoo000<Ool00`00
Ool0000<Ool01000Oomoo`0037oo00D007ooOomoo`0007ioo`00FGoo00<007oo000037oo00<007oo
00003Goo00<007oo00003Goo00<007oo000037oo00H007ooOol007oo000:Ool00`00Ool0000<Ool0
1000Oomoo`0037oo00@007ooOol000]oo`04001oogoo000<Ool01@00Oomoogoo0000OWoo001IOol0
0`00Ool0000<Ool00`00Ool0000=Ool00`00Ool0000<Ool01000Oomoo`0037oo00H007ooOol007oo
000:Ool00`00Ool0000<Ool01000Oomoo`0037oo00@007ooOol000]oo`04001oogoo000<Ool01@00
Oomoogoo0000OWoo001IOol00`00Ool0000<Ool01000Oomoo`0037oo00<007oo000037oo00@007oo
Ool000aoo`06001oogoo001oo`002Woo00<007oo000037oo00@007ooOol000aoo`04001oogoo000;
Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0O7oo001IOol00`00Ool0000<Ool01000
Oomoo`0037oo00<007oo000037oo00@007ooOol000aoo`05001oogoo001oo`020009Ool00`00Ool0
000<Ool01000Oomoo`0037oo00@007ooOol000]oo`04001oogoo000;Ool00`00Oomoo`02Ool00`00
Oomoo`1lOol005Uoo`03001oo`0000aoo`04001oogoo000<Ool00`00Ool0000<Ool01000Oomoo`00
37oo00H007ooOol007oo0009Ool01000Oomoo`0037oo00@007ooOol000aoo`04001oogoo000;Ool0
1000Oomoo`002goo00<007ooOol00Woo00<007ooOol0O7oo001IOol00`00Ool0000<Ool01000Oomo
o`0037oo00<007oo000037oo00@007ooOol000aoo`06001oogoo001oo`002Goo00@007ooOol000ao
o`04001oogoo000<Ool01000Oomoo`002goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo
07aoo`00F7oo00@007ooOol000aoo`04001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol0
00aoo`06001oogoo001oo`002Goo00@007ooOol000aoo`04001oogoo000;Ool01@00Oomoogoo0000
2goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo07aoo`00F7oo00@007ooOol000aoo`04
001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000aoo`06001oogoo001oo`002Goo00@0
07ooOol000aoo`04001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000]oo`03001oogoo
009oo`03001oogoo07aoo`00F7oo00@007ooOol000aoo`04001oogoo000;Ool01@00Oomoogoo0000
2goo00@007ooOol000aoo`05001oogoo001oo`020008Ool01000Oomoo`0037oo00@007ooOol000]o
o`05001oogooOol0000;Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0O7oo001HOol0
1000Oomoo`0037oo00@007ooOol000]oo`05001oogooOol0000;Ool01000Oomoo`002goo00L007oo
Oomoo`00Ool00009Ool01000Oomoo`0037oo00@007ooOol000]oo`05001oogooOol0000;Ool01000
Oomoo`002goo00<007ooOol00Woo00<007ooOol0O7oo001HOol01@00Oomoogoo00002goo00@007oo
Ool000]oo`05001oogooOol0000;Ool01000Oomoo`002goo00L007ooOomoo`00Ool00009Ool01000
Oomoo`0037oo00@007ooOol000]oo`05001oogooOol0000;Ool01000Oomoo`002goo00<007ooOol0
0Woo00<007ooOol0O7oo001HOol01@00Oomoogoo00002Woo00D007ooOomoo`0000Ioo`<0009oo`03
001oogoo00<000Aoo`<000=oo`03001oo`00008000Aoo`<000=oo`07001oogooOol007oo00002Goo
00@007ooOol000aoo`04001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000]oo`03001o
ogoo009oo`03001oogoo07aoo`00F7oo00D007ooOomoo`0000Yoo`05001oogooOol00007Ool02`00
Oomoogoo001oo`00Ool007oo00000Woo00D007ooOomoo`00009oo`800004Ool007oo0002Ool01@00
Oomoogoo00000Woo00L007ooOomoo`00Ool00009Ool01000Oomoo`002goo00D007ooOomoo`0000]o
o`05001oogooOol0000;Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0O7oo001HOol0
1@00Oomoogoo00002Woo00D007ooOomoo`0000Moo`04001oogooOol20002Ool00`00Oomoo`020005
Ool00`00Ool00002Ool00`00Oomoo`020005Ool00`00Ool00003Ool00`00Ool000020007Ool01000
Oomoo`002goo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool01000Oomoo`002goo00<007oo
Ool00goo00<007ooOol0Ngoo001HOol01@00Oomoogoo00002Woo200017oo00@007ooOomoo`80009o
o`03001oogoo008000Eoo`<0009oo`03001oogoo008000Eoo`03001oo`0000=oo`03001oo`0000Uo
o`04001oogoo000;Ool01@00Oomoogoo00002goo00D007ooOomoo`0000]oo`04001oogoo000;Ool0
0`00Oomoo`03Ool00`00Oomoo`1kOol005Qoo`05001oogooOol0000:Ool01@00Oomoogoo00001goo
00@007ooOomoo`80009oo`03001oogoo008000Eoo`<0009oo`03001oogoo008000Eoo`03001oo`00
00=oo`03001oo`0000Uoo`05001oogooOol0000:Ool01@00Oomoogoo00002goo00D007ooOomoo`00
00Yoo`05001oogooOol0000;Ool00`00Oomoo`03Ool00`00Oomoo`1kOol005Qoo`05001oogooOol0
000:Ool01@00Oomoogoo00001goo00@007ooOomoo`80009oo`03001oogoo008000Eoo`<0009oo`03
001oogoo008000Eoo`03001oo`0000=oo`03001oo`0000Uoo`05001oogooOol0000:Ool01@00Oomo
ogoo00002goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool00`00Oomoo`03Ool00`00Oomo
o`1kOol005Qoo`05001oogooOol0000:Ool01@00Oomoogoo00001goo00@007ooOomoo`80009oo`03
001oogoo008000Eoo`<0009oo`03001oogoo008000Eoo`03001oo`0000=oo`03001oo`0000Uoo`05
001oogooOol0000:Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`05001oogooOol0000;
Ool00`00Oomoo`03Ool00`00Oomoo`1kOol005Qoo`05001oogooOol0000:Ool01@00Oomoogoo0000
1goo00@007ooOomoo`80009oo`03001oogoo008000Eoo`<000=oo`04001oo`000005Ool00`00Ool0
0003Ool01000Ool000001goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000]oo`05
001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`1k
Ool005Qoo`05001oogooOol0000:Ool01@00Oomoogoo00001Woo0P000goo00L007oo001oo`00Ool0
0002Ool02@00Oomoogoo001oo`00Ool00002Ool20002Ool01@00Oomoogoo00000Woo00L007ooOomo
o`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002goo00D007ooOomo
o`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo07]oo`00F7oo
00D007ooOomoo`0000Yoo`05001oogooOol00007Ool01@00Oomoogoo00000Woo0`0017oo0`000Woo
00<007ooOol00`0017oo0`000goo00L007ooOomoo`00Ool00008Ool00`00Oomoo`02Ool00`00Oomo
o`08Ool01@00Oomoogoo00002goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol017oo00<007ooOol0Ngoo001HOol01@00Oomoogoo00002Woo00D007oo
Oomoo`0000]oo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01`00Oomoogoo
001oo`0000Qoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`1k
Ool005Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo0000
2Woo00<007ooOol00Woo00<007ooOol027oo00L007ooOomoo`00Ool00008Ool00`00Oomoo`02Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`1kOol005Qoo`05001oogoo
Ool0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo
00<007ooOol027oo00H007ooOomoo`00Ool20007Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`1kOol005Qoo`05001oogooOol0000:Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00L0
07ooOomoo`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`04Ool00`00Oomoo`1kOol005Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08
Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo0P0027oo
00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo00<007ooOol0Ngoo
001HOol01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yo
o`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`8000Qoo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo07]oo`00F7oo00D007ooOomoo`00
00Yoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`1kOol005Moo`03001oogoo009oo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool0
0`00Oomoo`02Ool30007Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`05Ool00`00Oomoo`1jOol005Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03
001oogoo009oo`8000Qoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo07Yoo`00Egoo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<0
07ooOol00Woo0P0027oo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0
1Goo00<007ooOol0NWoo001GOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool20008Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00Oomoo`1jOol005Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001o
ogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001o
ogoo009oo`8000Qoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Mo
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo07Yoo`00Egoo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool00goo0`001goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Goo
00<007ooOol0NWoo001GOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool20008Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`05Ool0
0`00Oomoo`1jOol005Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
00Moo`03001oo`0000@000Eoo`<00004Ool007ooOol30005Ool300000goo001oo`04Ool20008Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`1jOol0
05Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo
00=oo`8000=oo`04001oogooOol2000017oo001oogoo0P000goo00@007ooOomoo`8000Eoo`8000Qo
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo07Uo
o`00Egoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool00goo00D007oo001oo`0000Eoo`8000Aoo`800003Ool007oo00Aoo`03001oogoo00=oo`8000Qo
o`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo07Uo
o`00Egoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol020001Goo00D0
07oo001oo`0000Eoo`8000Aoo`800003Ool007oo00Aoo`03001oogoo00=oo`@000Ioo`03001oogoo
00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo07Uoo`00Egoo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00D0
07oo001oo`0000Eoo`8000Aoo`800003Ool007oo00Aoo`03001oogoo00=oo`8000Qoo`03001oogoo
00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo07Uoo`00Egoo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo0P00
0Woo00<007ooOol00goo0P0017oo0P0000=oo`00Ool017oo00<007ooOol00goo0P0027oo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0NGoo001GOol0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`040003
Ool00`00Oomoo`02Ool30004Ool200000goo001oo`04Ool00`00Oomoo`03Ool20008Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`1iOol005Moo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`04001oogoo0002Ool0
1@00Oomoogoo000017oo0`0017oo0P0000=oo`00Ool017oo00<007ooOol00goo0P0027oo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0NGoo001GOol0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool01`00Oomoogoo001o
o`0000Aoo`05001oogooOol00002Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Eoo`<000Mo
o`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo07Uo
o`00Egoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00@007oo
Oomoo`D000=oo`@000=oo`@000Aoo`<00003Ool007oo00Aoo`8000Qoo`03001oogoo00=oo`03001o
ogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo07Qoo`00Egoo00<007ooOol00goo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo0P001goo00<007ooOol017oo00<007oo
Ool01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<007oo
Ool017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0N7oo001GOol00`00Oomoo`03Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`04Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`1hOol005Moo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`8000Moo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo07Qoo`0037oo10001Woo0`0017oo0`00
6Woo1P0017oo0`0017oo0`0027oo00<007ooOol017oo00<007ooOol01Woo00@007ooOomoo`@000Ao
o`@000=oo`@000Qoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`<000Ioo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Aoo`@000Aoo`<000Aoo`@000Io
o`03001oogoo00Ioo`03001oogoo00Moo`H000Aoo`<000Aoo`<001Uoo`@000Ioo`<000Aoo`<003Yo
o`0047oo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogooOol0000IOol00`00Oomoo`03
Ool01000Oomoo`000goo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo009oo`03001oo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo000027oo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo0P001goo00<007ooOol017oo00<007oo
Ool01Woo00<007ooOol017oo00<007ooOol017oo0P0017oo00D007oo001oo`00009oo`05001oogoo
Ool00006Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`03Ool01000Oomoo`000goo00@0
07ooOol000=oo`03001oogoo01Yoo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo
0000>Goo000AOol01000Oomoo`001Goo0P001Goo00<007ooOol05goo00<007ooOol017oo00<007oo
Ool00goo0P001Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00Woo
00<007oo00000Woo00<007ooOol00Woo0`0017oo0P001goo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol00goo0P001goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007oo
Ool017oo0P000goo00@007ooOol0009oo`8000Aoo`8000Eoo`03001oogoo00Eoo`03001oogoo00Uo
o`03001oogoo00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo01Yoo`04001oogoo0005Ool20005
Ool00`00Oomoo`0fOol000=oo`P000Ioo`04001oogoo0005Ool20005Ool00`00Oomoo`0=Ool80003
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Ool000070004Ool00`00Ool00002Ool00`00Oomoo`02Ool30004Ool20007Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool20003Ool01000Oomoo`000Woo0P0017oo0P001Goo00<007ooOol01Goo
00<007ooOol02Goo0P001Goo00<007ooOol00goo0P001Goo00<007ooOol06Woo00@007ooOol000Eo
o`8000Eoo`03001oogoo03Ioo`004Goo00@007ooOol000Eoo`8000Eoo`03001oogoo01Uoo`03001o
ogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Io
o`03001oogoo009oo`03001oo`00009oo`03001oogoo009oo`<000Aoo`8000Moo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo00=oo`8000Moo`03001oogoo00Aoo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00Aoo`8000=oo`04001oogoo0002Ool20004Ool20005Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool00`00Ool00004Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0JOol01000
Oomoo`001Goo0P001Goo00<007ooOol0=Woo000>Ool30003Ool00`00Oomoo`03Ool20005Ool00`00
Oomoo`0JOol01@00Oomoogoo00001Goo0P001Goo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool01Woo00<007ooOol00Woo00<007oo00000Woo00<007ooOol00Woo0`0017oo0P001goo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol01Goo0P001Woo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol017oo0P000goo00@007ooOol0009oo`8000Aoo`8000Eoo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oo`0000=oo`03001oogoo00=oo`8000Eoo`03001oogoo01Mo
o`<000=oo`03001oogoo00=oo`8000Eoo`03001oogoo03Ioo`003goo00<007ooOol00Woo00<007oo
Ool00goo0P001Goo00<007ooOol06goo00@007ooOol000Eoo`8000Eoo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo009oo`03001oo`00009oo`03001oogoo009oo`<000Ao
o`8000Moo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Aoo`8000=oo`04001oogoo0002
Ool20004Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool01000Oomoo`000Woo00<007ooOol0
0goo0P001Goo00<007ooOol067oo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol0
=Woo000@Ool01@00Oomoogoo00001Goo0P001Goo00<007ooOol05Woo00<007ooOol00Woo00@007oo
Ool000Eoo`8000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo009o
o`03001oo`00009oo`03001oogoo009oo`<000Aoo`8000Moo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Ao
o`03001oogoo00Aoo`8000=oo`04001oogoo0002Ool20004Ool20005Ool00`00Oomoo`05Ool00`00
Oomoo`08Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`8000Eoo`03001oogoo01Uoo`05001o
ogooOol00005Ool20005Ool00`00Oomoo`0fOol000aoo`05001oogooOol00004Ool01@00Oomoogoo
00000Woo00D007ooOomoo`0001Yoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00D007ooOomo
o`0000Moo`03001oogoo00Aoo`03001oogoo00Ioo`04001oogooOol200000goo001oo`02Ool01@00
Oomoogoo00000Woo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo
00=oo`<000Aoo`05001oo`00Ool00002Ool01@00Oomoogoo00001Woo00<007ooOol01Goo00<007oo
Ool02Goo00@007oo000000Aoo`05001oogooOol00002Ool01@00Oomoogoo000067oo00D007ooOomo
o`0000Aoo`05001oogooOol00002Ool01@00Oomoogoo0000>Goo000=Ool30006Ool30004Ool3000L
Ool20006Ool30004Ool30008Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00
Ool00004Ool40003Ool40008Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`04Ool20005
Ool30004Ool40006Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool20006Ool30004Ool3000JOol30006
Ool30004Ool3000jOol005Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Eoo`8000Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00ao
o`03001oogoo04moo`<001]oo`<000Aoo`00EWoo00<007ooOol017oo00<007ooOol01Woo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol03Goo00<007ooOol0CWoo00<007ooOol07Goo00<007ooOol00Woo001FOol0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomoo`14Ool3
0006Ool00`00Oomoo`02Ool300001Goo00000000Ool00`0000Eoo`00000007oo00<00004Ool00000
0004Ool00`00Oomoo`02Ool005Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00moo`<004=oo`04001oogoo0005Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool005Ioo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo019oo`H0041oo`03001oogoo00=oo`03001oogoo
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`03001oogoo
009oo`002Gooo`00:0002goo0P001Woo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo0009Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`070008Ool00`00
Oomoo`07Ool01000Oomoo`001Goo00<007oo00001Woo0P001Woo0P001Woo00<007oo00001Goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`03001oo`0000Ioo`8000Moo`03001oogoo00Eoo`8000Io
o`03001oo`0000Aoo`03001oogoo009oo`04001oogoo0005Ool00`00Ool00006Ool20006Ool20006
Ool00`00Ool00005Ool01000Oomoo`002Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo000BOol00`00Oomoo`0[Ool4000BOol00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`0COol00`00Oomoo`0[Ool00`00Oomoo`0AOol01000Oomoo`00
1Goo00<007ooOol00Woo0`000Woo0P000Woo00<007ooOol00`000Woo0P000Woo00<007ooOol00goo
00<007ooOol00Woo0014Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`00Oomoo`1FOol30005Ool00`00Oomoo`03Ool01000Ool000000Woo0P0017oo00@007oo
0000009oo`8000Ioo`03001oogoo009oo`00AGoo0P003goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol0GWoo00<007ooOol07Goo00<007ooOol00Woo0017Ool00`00Oomo
o`0<Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool20006Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`1NOol00`00Oomoo`0MOol0
0`00Oomoo`02Ool004Moo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo05ioo`<001]oo`<000Aoo`00B7oo00<007ooOol02goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol017oo00<007ooOol0Pgoo0018Ool00`00Oomoo`0;Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`23Ool004Uoo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo08=oo`00BWoo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo0P001Woo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0Pgoo001:Ool00`00Oomoo`09Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool20006Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`23Ool004Yoo`03001oogoo00Uoo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`8000Eoo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo08=oo`00BWoo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo0P001Goo00<007ooOol0
1Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0Pgoo001;Ool00`00Oomoo`08Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool20005Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`23Ool004]oo`03001oogoo00Qoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`8000Eoo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo08=oo`00Bgoo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo0P001Goo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol0Pgoo001;Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool20005Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`23Ool004]oo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo
00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`8000Eoo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00=oo`03001oogoo08Aoo`00Bgoo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo0P001Goo00<007ooOol01Woo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol0Q7oo001;Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`06Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`24Ool004aoo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`8000Eoo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oogoo00=oo`03001oogoo08Aoo`00C7oo00<007ooOol01Woo00<007ooOol01goo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00@007ooOomoo`D00003Ool007oo009o
o`<000Aoo`<00003Ool007oo009oo`<000Qoo`8000Eoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo00=oo`03001oogoo08Aoo`00C7oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo0P000Woo00<007ooOol00P000Woo
00@007ooOomoo`80009oo`03001oogoo008000Moo`8000Eoo`03001oogoo00Ioo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo08Aoo`00C7oo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007oo00000goo00@007oo
000000Eoo`03001oo`0000=oo`03001oo`0000Ioo`8000Eoo`03001oogoo00Ioo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo08Aoo`00C7oo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007oo00000goo00@007oo
000000Eoo`03001oo`0000=oo`03001oo`0000Ioo`<000Aoo`03001oogoo00Ioo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo08Aoo`00C7oo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<007oo00000goo00@007oo
000000Eoo`03001oo`0000=oo`03001oo`0000Ioo`8000Eoo`03001oogoo00Ioo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo08Aoo`00C7oo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo0P0000=oo`00Ool00Woo00@0
07oo000000Eoo`03001oo`0000=oo`03001oo`0000Ioo`8000Eoo`03001oogoo00Ioo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00Ioo`03001oogoo00=oo`03001oogoo08Aoo`00C7oo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol00Woo100000Aoo`00Ool0009o
o`03001oogoo008000Eoo`03001oo`0000=oo`03001oo`0000Ioo`8000Eoo`03001oogoo00Ioo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo08Aoo`00C7oo00<007ooOol01Woo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
0Woo00<007oo00000Woo00<007ooOol00P001Goo00<007oo00000goo00<007oo00001Woo0P001Goo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol0Q7oo001=Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool01@00Oomoogoo00000Woo00D007oo001oo`00009oo`04001oogooOol20002Ool00`00Oomo
o`020007Ool20005Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`24
Ool004eoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo00=oo`D000=oo`<000Aoo`<00003Ool007oo009oo`<000Qoo`8000Eoo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo08Aoo`00CGoo00<007ooOol0
1Goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo0P0017oo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Q7oo001=Ool00`00Oomoo`05
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20004Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`24Ool004eoo`03001oogoo00Eo
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Mo
o`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Ioo`8000Aoo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo08Aoo`00CGoo00<007ooOol01Goo
00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01Woo0P0017oo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0Q7oo001=Ool00`00Oomoo`05Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20004Ool00`00Oomo
o`08Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol0Q7oo001>Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo
00D007ooOomoo`0008Moo`00CWoo00<007ooOol017oo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol01Woo0P0017oo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0
27oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol00027Ool0
04ioo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo
00Ioo`03001oo`0000=oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Qoo`05001oogoo
Ool0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo0000Qgoo001>Ool00`00Oomo
o`04Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`06Ool30003Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol0
0Woo00<007ooOol027oo00D007ooOomoo`0008Moo`00CWoo00<007ooOol017oo00<007ooOol01goo
00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol027oo00<007ooOol00Woo00<007ooOol01Woo00<007oo00000goo00<007ooOol027oo
00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo
00Qoo`05001oogooOol00027Ool004ioo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo00Qoo`03001oogoo009o
o`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomo
ogoo0000Qgoo001>Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Ioo`03
001oo`0000=oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000;
Ool01@00Oomoogoo00002Woo00D007ooOomoo`0008Moo`00CWoo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00003Ool00`00Oomoo`08Ool00`00Oomoo`02Ool0
0`00Oomoo`08Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`05001oogooOol00027Ool0
04ioo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`05001oogoo
Ool0000;Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol01Woo0`000goo00<007oo
Ool027oo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000]oo`05001oogooOol0000:
Ool01@00Oomoogoo0000Qgoo001>Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`02Ool0
0`00Oomoo`08Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001o
ogoo00Ioo`03001oo`0000=oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Qoo`05001o
ogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0008Moo`00CWoo00<007ooOol00goo
00<007ooOol027oo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00`001Goo0`000Woo00<0
07oo00000P001Goo0`000Woo00<007oo00000P002Goo00<007oo00000goo00<007ooOol02Goo00D0
07ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0008Mo
o`00CWoo00<007ooOol00goo00<007ooOol02Goo00D007ooOomoo`0000Yoo`05001oogooOol00005
Ool01P00Oomoogoo001oo`80009oo`8000=oo`06001oogooOol007oo0P000Woo0P0027oo00<007oo
00000goo00<007ooOol02Goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo
00002Woo00D007ooOomoo`0008Moo`00CWoo00<007ooOol00goo00<007ooOol02Goo00D007ooOomo
o`0000Yoo`05001oogooOol00004Ool00`00Oomoo`03Ool20003Ool01@00Ool007oo00001Goo0P00
0goo00<007oo00001goo00<007oo00000goo00<007ooOol02Goo00D007ooOomoo`0000Yoo`05001o
ogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0008Moo`00CWoo00<007ooOol00goo
00<007ooOol02Goo00@007ooOol000]oo`05001oogooOol00004Ool00`00Oomoo`03Ool20003Ool0
1@00Ool007oo00001Goo0`000Woo00<007oo00001goo0`000goo00<007ooOol02Goo00D007ooOomo
o`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0008Moo`00CWoo
00<007ooOol00goo00<007ooOol02Goo00@007ooOol000]oo`05001oogooOol00004Ool00`00Oomo
o`03Ool20003Ool01@00Ool007oo00001Goo0`000Woo00<007oo00001goo00<007oo00000goo00<0
07ooOol02Goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D0
07ooOomoo`0008Moo`00Cgoo00<007ooOol00Woo00<007ooOol02Goo00@007ooOol000]oo`05001o
ogooOol00004Ool00`00Oomoo`03Ool20002Ool01P00Oomoo`00Ool000Eoo`<0009oo`03001oo`00
00Moo`03001oo`0000=oo`03001oogoo00Uoo`05001oogooOol0000:Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Yoo`05001oogooOol00027Ool004moo`03001oogoo009oo`03001oogoo00Uo
o`04001oogoo000;Ool01@00Oomoogoo000017oo00<007ooOol00goo0P000Woo00H007ooOol007oo
0005Ool30002Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`09Ool01@00Oomoogoo0000
2Woo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool01@00Oomoogoo0000Qgoo001?Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool01000Oomoo`0037oo00@007ooOol000Aoo`03001oogoo00=oo`80
009oo`06001oogoo001oo`001Goo0`000Woo00<007oo00001goo00<007oo00000goo00<007ooOol0
2Goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002goo00@007ooOol0
08Moo`00Cgoo00<007ooOol00Woo00<007ooOol02Goo00@007ooOol000aoo`04001oo`000005Ool0
1P00Oomoogoo001oo`800004Ool007oo0003Ool01@00Oomoogoo00000Woo00<007ooOol00P0027oo
0`000Woo00<007ooOol02Woo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo
00002goo00@007ooOol008Moo`00Cgoo00<007ooOol00Woo00<007ooOol02Goo00@007ooOol000ao
o`04001oogoo0006Ool30002Ool00`00Ool000020005Ool30003Ool40009Ool00`00Ool00002Ool0
0`00Oomoo`0:Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000;Ool0
1000Oomoo`00Qgoo001?Ool00`00Oomoo`02Ool00`00Oomoo`09Ool01000Oomoo`0037oo00@007oo
Ool000]oo`04001oogoo000<Ool01000Oomoo`002Goo00<007oo00000Woo00<007ooOol02Woo00@0
07ooOol000]oo`05001oogooOol0000;Ool01@00Oomoogoo00002goo00@007ooOol008Moo`00Cgoo
00<007ooOol00Woo00<007ooOol02Goo00@007ooOol000aoo`03001oo`0000aoo`04001oogoo000<
Ool01000Oomoo`002Goo00<007oo00000Woo00<007ooOol02Woo00@007ooOol000]oo`04001oogoo
000<Ool01@00Oomoogoo00002goo00<007oo0000R7oo001?Ool00`00Oomoo`02Ool00`00Oomoo`09
Ool01000Oomoo`0037oo00<007oo000037oo00@007ooOol000aoo`04001oogoo0009Ool00`00Ool0
0002Ool00`00Oomoo`0:Ool01000Oomoo`0037oo00<007oo000037oo00D007ooOomoo`0000]oo`03
001oo`0008Qoo`00Cgoo00<007ooOol00Woo00<007ooOol02Goo00@007ooOol000aoo`03001oo`00
00aoo`04001oogoo000<Ool01000Oomoo`002Goo0`000Woo00<007ooOol02Woo00@007ooOol000ao
o`03001oo`0000aoo`04001oogoo000<Ool00`00Ool00028Ool004moo`03001oogoo009oo`03001o
ogoo00Uoo`04001oogoo000<Ool00`00Ool0000<Ool01000Oomoo`0037oo00<007oo00002Woo00H0
07ooOol007oo000<Ool01000Oomoo`0037oo00<007oo000037oo00@007ooOol000aoo`03001oo`00
08Qoo`00Cgoo00<007ooOol00Woo00<007ooOol02Goo00@007ooOol000aoo`03001oo`0000aoo`04
001oogoo000<Ool00`00Ool0000:Ool01P00Oomoo`00Ool000aoo`04001oogoo000<Ool00`00Ool0
000=Ool00`00Ool0000<Ool00`00Ool00028Ool004moo`05001oogooOol0000<Ool01000Oomoo`00
37oo00<007oo000037oo00@007ooOol000aoo`03001oo`0000Yoo`06001oogoo001oo`0037oo00@0
07ooOol000aoo`03001oo`0000eoo`03001oo`0000aoo`03001oo`0008Qoo`00Cgoo00D007ooOomo
o`0000aoo`04001oogoo000<Ool00`00Ool0000=Ool00`00Ool0000<Ool00`00Ool0000:Ool01P00
Oomoo`00Ool000aoo`04001oogoo000<Ool00`00Ool0000=Ool00`00Ool0000<Ool00`00Ool00028
Ool004moo`05001oogooOol0000<Ool01000Oomoo`0037oo00<007oo00003Goo00<007oo000037oo
00<007oo00002Woo0P0000Aoo`00Ool000eoo`03001oo`0000aoo`03001oo`0000eoo`03001oo`00
00eoo`8008Qoo`00Cgoo00D007ooOomoo`0000aoo`04001oogoo000<Ool00`00Ool0000=Ool00`00
Ool0000<Ool00`00Ool0000:Ool01P00Oomoo`00Ool000eoo`03001oo`0000aoo`03001oo`0000eo
o`03001oo`0000eoo`8008Qoo`00Cgoo00D007ooOomoo`0000aoo`04001oogoo000<Ool00`00Ool0
000=Ool00`00Ool0000=Ool2000:Ool01P00Oomoo`00Ool000eoo`03001oo`0000aoo`03001oo`00
00eoo`03001oo`0000eoo`8008Qoo`00D7oo00@007ooOol000aoo`03001oo`0000eoo`03001oo`00
00eoo`03001oo`0000eoo`8000Yoo`06001oogoo001oo`003Goo00<007oo000037oo00<007oo0000
3Goo00<007oo00003Goo0P00R7oo001@Ool01000Oomoo`0037oo00<007oo00003Woo0P003Goo00<0
07oo00003Goo0P002Woo00H007ooOol007oo000=Ool00`00Ool0000=Ool2000=Ool00`00Ool0000=
Ool20028Ool0051oo`04001oogoo000=Ool2000>Ool2000=Ool00`00Ool0000=Ool2000:Ool20002
Ool2000=Ool00`00Ool0000=Ool2000=Ool00`00Ool0000=Ool00`00Oomoo`27Ool0051oo`04001o
ogoo000=Ool2000>Ool00`00Oomoo`0<Ool2000>Ool00`00Oomoo`09Ool01000Oomoogoo0P003Goo
0P003Woo0P003Goo0`00Ugoo001@Ool01000Oomoo`003Goo0P003Woo10000goo1@0017oo0`001Goo
0`0017oo0`002Goo00D007ooOomoo`0000ioo`8000ioo`03001oogoo00aoo`03001oogoo09Moo`00
D7oo00@007ooOol000eoo`03001oogoo00eoo`03001oo`0000Uoo`03001oogoo0080009oo`05001o
ogooOol00003Ool00`00Oomoo`020002Ool00`00Oomoo`06Ool01@00Oomoogoo00003Woo00<007oo
Ool03Goo00<007ooOol0YWoo001@Ool01000Oomoo`003Goo00<007ooOol03Goo00<007oo00002Woo
0P0000=oo`00Ool00Woo00<007oo00001Goo0P0000=oo`00Ool00Woo00<007ooOol01Goo00D007oo
Oomoo`000<Moo`00D7oo00@007ooOol000eoo`03001oogoo00eoo`03001oo`0000Yoo`800003Ool0
07oo009oo`03001oo`0000Eoo`8000Eoo`03001oogoo00Eoo`<00<Uoo`00D7oo00@007ooOol001mo
o`03001oogoo00Qoo`8000Eoo`03001oo`0000Eoo`8000Eoo`03001oogoo00Eoo`03001oogoo0<Uo
o`00D7oo00@007ooOol001moo`03001oogoo00Moo`03001oo`0000Eoo`03001oo`0000Eoo`8000Eo
o`03001oogoo00Eoo`03001oogoo0<Uoo`00DGoo00<007oo00007goo00<007ooOol00goo10000Woo
00<007ooOol00goo00<007oo00001Goo0P001Goo00<007ooOol01Goo00<007ooOol0bGoo001AOol0
0`00Ool0000OOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00005Ool2
0005Ool00`00Oomoo`05Ool00`00Oomoo`39Ool0055oo`8001moo`8000Ioo`03001oogoo00=oo`05
001oogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Qoo`800<Yoo`00DGoo0P00
87oo00<007ooOol017oo1@000Woo0`001Goo0`0017oo0`002Goo00<007ooOol0bGoo001AOol20019
Ool00`00Oomoo`39Ool0055oo`8004Uoo`03001oogoo0<Uoo`00DGoo0P00BGoo00<007ooOol0bGoo
001BOol00`00Oomoo`17Ool2003:Ool0059oo`03001oogoo04Moo`03001oogoo0<Uoo`00DWoo00<0
07ooOol0Agoo00<007ooOol0bGoo002LOol00`00Oomoo`39Ool009aoo`03001oogoo0<Uoo`00W7oo
0P00bWoo002LOol00`00Oomoo`39Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00W7oo0P00bWoo002GOol3
0003Ool00`00Oomoo`0<Ool3002iOol009Moo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo
0;Moo`00RGoo0`000Woo0`001Woo00<007ooOol00goo00D007oo000007oo008000Aoo`<000=oo`03
001oogoo0;Moo`00RWoo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`03001oogoo00800003Ool0
07oo00=oo`03001oogoo009oo`03001oogoo0;Moo`00Rgoo00<007oo00002Goo00<007ooOol017oo
00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo0;Moo`00S7oo00<007ooOol027oo00<0
07ooOol017oo00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo0;Moo`00Rgoo00<007oo
00002Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool0]goo002:Ool01@00Oomoogoo000027oo00<007ooOol01Goo00D007ooOomoo`0000Aoo`<000=o
o`03001oogoo0;Moo`00RGoo0`0000Aoo`000000009oo`03001oogoo009oo`03001oogoo00Eoo`05
001oogooOol00005Ool01P00Ool00000Ool00;Uoo`00TWoo00<007ooOol00Woo00<007ooOol057oo
00<007ooOol0]goo002BOol00`00Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`2gOol0099oo`03
001oogoo009oo`<0019oo`<00;Uoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-341.207, -19703, 2.72438, 
  251.463}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.00155618 -1.96131 0.00197603 [
[.03315 .00222 -15.125 -14 ]
[.03315 .00222 15.125 0 ]
[.18876 .00222 -15.125 -14 ]
[.18876 .00222 15.125 0 ]
[.34438 .00222 -15.125 -14 ]
[.34438 .00222 15.125 0 ]
[.65562 .00222 -11 -14 ]
[.65562 .00222 11 0 ]
[.81124 .00222 -11 -14 ]
[.81124 .00222 11 0 ]
[.96685 .00222 -11 -14 ]
[.96685 .00222 11 0 ]
[1.025 .01472 0 -7 ]
[1.025 .01472 38.125 7 ]
[.4875 .11352 -28 -7 ]
[.4875 .11352 0 7 ]
[.4875 .21232 -28 -7 ]
[.4875 .21232 0 7 ]
[.4875 .31112 -28 -7 ]
[.4875 .31112 0 7 ]
[.4875 .40992 -28 -7 ]
[.4875 .40992 0 7 ]
[.4875 .50872 -28 -7 ]
[.4875 .50872 0 7 ]
[.4875 .60752 -28 -7 ]
[.4875 .60752 0 7 ]
[.5 .64303 -18.5625 0 ]
[.5 .64303 18.5625 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03315 .01472 m
.03315 .02097 L
s
gsave
.03315 .00222 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18876 .01472 m
.18876 .02097 L
s
gsave
.18876 .00222 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.34438 .01472 m
.34438 .02097 L
s
gsave
.34438 .00222 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.65562 .01472 m
.65562 .02097 L
s
gsave
.65562 .00222 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81124 .01472 m
.81124 .02097 L
s
gsave
.81124 .00222 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96685 .01472 m
.96685 .02097 L
s
gsave
.96685 .00222 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06427 .01472 m
.06427 .01847 L
s
.09539 .01472 m
.09539 .01847 L
s
.12652 .01472 m
.12652 .01847 L
s
.15764 .01472 m
.15764 .01847 L
s
.21989 .01472 m
.21989 .01847 L
s
.25101 .01472 m
.25101 .01847 L
s
.28214 .01472 m
.28214 .01847 L
s
.31326 .01472 m
.31326 .01847 L
s
.37551 .01472 m
.37551 .01847 L
s
.40663 .01472 m
.40663 .01847 L
s
.43775 .01472 m
.43775 .01847 L
s
.46888 .01472 m
.46888 .01847 L
s
.53112 .01472 m
.53112 .01847 L
s
.56225 .01472 m
.56225 .01847 L
s
.59337 .01472 m
.59337 .01847 L
s
.62449 .01472 m
.62449 .01847 L
s
.68674 .01472 m
.68674 .01847 L
s
.71786 .01472 m
.71786 .01847 L
s
.74899 .01472 m
.74899 .01847 L
s
.78011 .01472 m
.78011 .01847 L
s
.84236 .01472 m
.84236 .01847 L
s
.87348 .01472 m
.87348 .01847 L
s
.90461 .01472 m
.90461 .01847 L
s
.93573 .01472 m
.93573 .01847 L
s
.00202 .01472 m
.00202 .01847 L
s
.99798 .01472 m
.99798 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.625000 14.000000 moveto
(@) show
74.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.187500 14.000000 moveto
(D) show
97.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.5 .11352 m
.50625 .11352 L
s
gsave
.4875 .11352 -89 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1050) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .21232 m
.50625 .21232 L
s
gsave
.4875 .21232 -89 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .31112 m
.50625 .31112 L
s
gsave
.4875 .31112 -89 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1150) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .40992 m
.50625 .40992 L
s
gsave
.4875 .40992 -89 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .50872 m
.50625 .50872 L
s
gsave
.4875 .50872 -89 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1250) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .60752 m
.50625 .60752 L
s
gsave
.4875 .60752 -89 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1300) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.5 .03448 m
.50375 .03448 L
s
.5 .05424 m
.50375 .05424 L
s
.5 .074 m
.50375 .074 L
s
.5 .09376 m
.50375 .09376 L
s
.5 .13328 m
.50375 .13328 L
s
.5 .15304 m
.50375 .15304 L
s
.5 .1728 m
.50375 .1728 L
s
.5 .19256 m
.50375 .19256 L
s
.5 .23208 m
.50375 .23208 L
s
.5 .25184 m
.50375 .25184 L
s
.5 .2716 m
.50375 .2716 L
s
.5 .29136 m
.50375 .29136 L
s
.5 .33088 m
.50375 .33088 L
s
.5 .35064 m
.50375 .35064 L
s
.5 .3704 m
.50375 .3704 L
s
.5 .39016 m
.50375 .39016 L
s
.5 .42968 m
.50375 .42968 L
s
.5 .44944 m
.50375 .44944 L
s
.5 .4692 m
.50375 .4692 L
s
.5 .48896 m
.50375 .48896 L
s
.5 .52848 m
.50375 .52848 L
s
.5 .54824 m
.50375 .54824 L
s
.5 .568 m
.50375 .568 L
s
.5 .58776 m
.50375 .58776 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -79.5625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
72.000000 14.000000 moveto
(@) show
76.500000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(m) show
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(m) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
92.187500 14.000000 moveto
(D) show
96.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Math2
%%+ font Times-Roman
grestore
.5 Mabswid
.02381 .01472 m
.0286 .01472 L
.03338 .01472 L
.03817 .01472 L
.04295 .01473 L
.04774 .01474 L
.05252 .01475 L
.05731 .01477 L
.0621 .01479 L
.06688 .01481 L
.07167 .01484 L
.07645 .01487 L
.08124 .0149 L
.08603 .01495 L
.09081 .015 L
.0956 .01505 L
.10038 .01512 L
.10517 .01519 L
.10995 .01528 L
.11474 .01538 L
.11953 .01549 L
.12431 .01562 L
.1291 .01578 L
.13388 .01595 L
.13867 .01616 L
.14346 .0164 L
.14824 .01668 L
.15303 .01701 L
.15781 .0174 L
.1626 .01787 L
.16738 .01844 L
.17217 .01912 L
.17696 .01996 L
.18174 .021 L
.18653 .0223 L
.19131 .02396 L
.1961 .0261 L
.20089 .02891 L
.20567 .03269 L
.21046 .03786 L
.21524 .04513 L
.22003 .05562 L
.22481 .07122 L
.2296 .09527 L
.23439 .13374 L
.23917 .19562 L
.24396 .28501 L
.24874 .39058 L
.25353 .48939 L
.25832 .55674 L
Mistroke
.2631 .5755 L
.26789 .54263 L
.27267 .47023 L
.27746 .38258 L
.28224 .30808 L
.28703 .27104 L
.29182 .28356 L
.2966 .34223 L
.30139 .42893 L
.30617 .51667 L
.31096 .57816 L
.31575 .59418 L
.32053 .55998 L
.32532 .48631 L
.3301 .39661 L
.33489 .31904 L
.33967 .27822 L
.34446 .28695 L
.34925 .34264 L
.35403 .42781 L
.35882 .51573 L
.3636 .57888 L
.36839 .59736 L
.37318 .56555 L
.37796 .49335 L
.38275 .40366 L
.38753 .32457 L
.39232 .28112 L
.3971 .28692 L
.40189 .34022 L
.40668 .4243 L
.41146 .51272 L
.41625 .57779 L
.42103 .59899 L
.42582 .56984 L
.43061 .49938 L
.43539 .40994 L
.44018 .32957 L
.44496 .28365 L
.44975 .2866 L
.45453 .33753 L
.45932 .4205 L
.46411 .50937 L
.46889 .57635 L
.47368 .60029 L
.47846 .57386 L
.48325 .50525 L
.48804 .41621 L
.49282 .33465 L
.49761 .28635 L
Mistroke
.50239 .28647 L
.50718 .335 L
.51196 .41677 L
.51675 .50601 L
.52154 .57482 L
.52632 .60148 L
.53111 .5778 L
.53589 .51112 L
.54068 .42257 L
.54547 .33994 L
.55025 .28931 L
.55504 .28661 L
.55982 .33268 L
.56461 .41316 L
.56939 .50267 L
.57418 .57323 L
.57897 .60256 L
.58375 .58165 L
.58854 .51696 L
.59332 .42899 L
.59811 .34537 L
.6029 .29245 L
.60768 .28691 L
.61247 .33047 L
.61725 .40954 L
.62204 .49919 L
.62682 .57138 L
.63161 .60332 L
.6364 .58514 L
.64118 .52246 L
.64597 .43511 L
.65075 .35052 L
.65554 .29529 L
.66033 .28683 L
.66511 .32772 L
.6699 .40517 L
.67468 .4947 L
.67947 .56826 L
.68425 .60254 L
.68904 .58683 L
.69383 .52589 L
.69861 .43883 L
.7034 .35282 L
.70818 .29469 L
.71297 .28247 L
.71776 .31953 L
.72254 .39383 L
.72733 .4812 L
.73211 .55337 L
.7369 .58625 L
Mistroke
.74168 .56779 L
.74647 .50103 L
.75126 .40296 L
.75604 .29812 L
.76083 .20921 L
.76561 .14749 L
.7704 .10908 L
.77519 .08516 L
.77997 .06973 L
.78476 .05944 L
.78954 .05239 L
.79433 .04744 L
.79911 .04389 L
.8039 .04131 L
.80869 .0394 L
.81347 .03797 L
.81826 .0369 L
.82304 .0361 L
.82783 .03549 L
.83262 .03504 L
.8374 .03472 L
.84219 .03448 L
.84697 .03432 L
.85176 .03423 L
.85654 .03418 L
.86133 .03418 L
.86612 .03421 L
.8709 .03426 L
.87569 .03435 L
.88047 .03445 L
.88526 .03457 L
.89005 .03471 L
.89483 .03485 L
.89962 .03501 L
.9044 .03518 L
.90919 .03536 L
.91397 .03555 L
.91876 .03574 L
.92355 .03594 L
.92833 .03614 L
.93312 .03635 L
.9379 .03656 L
.94269 .03678 L
.94748 .037 L
.95226 .03722 L
.95705 .03745 L
.96183 .03768 L
.96662 .03791 L
.9714 .03814 L
.97619 .03837 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`003Woo10001Woo0`0017oo0`006Woo1P00
17oo0`0017oo0`006goo0`001Goo0`0017oo0`00@goo0`001Goo0`0017oo0`006Goo1P0017oo0`00
17oo0`006Woo10001Woo0`0017oo0`00>goo000BOol00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00D007ooOomoo`0001Uoo`03001oogoo00=oo`04001oogoo0003Ool01000Oomoo`000goo00<007oo
Ool06Goo00<007ooOol00goo00D007ooOomoo`00009oo`05001oogooOol00013Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00D007ooOomoo`0001Qoo`03001oogoo00=oo`04001oogoo0003Ool0
1000Oomoo`000goo00<007ooOol06goo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogoo
Ool0000jOol001=oo`04001oogoo0005Ool20005Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00
Oomoo`03Ool20005Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00
Oomoo`10Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0FOol00`00Oomoo`04
Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0KOol01000Oomoo`001Goo0P001Goo00<007ooOol0
=goo0005Ool80006Ool01000Oomoo`001Goo0P001Goo00<007ooOol037oo200017oo00<007ooOol0
0goo00<007ooOol00goo0P001Goo00<007ooOol037oo200017oo00<007ooOol00Woo00<007ooOol0
0goo0P001Goo00<007ooOol0@7oo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol0
5goo00<007ooOol00goo00<007ooOol00goo0P001Goo00<007ooOol06goo00@007ooOol000Eoo`80
00Eoo`03001oogoo03Moo`004goo00@007ooOol000Eoo`8000Eoo`03001oogoo01Uoo`03001oogoo
009oo`03001oogoo00=oo`8000Eoo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo00=oo`80
00Eoo`03001oogoo041oo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo01Qoo`03
001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo01]oo`04001oogoo0005Ool20005Ool0
0`00Oomoo`0gOol0011oo`<000=oo`03001oogoo00=oo`8000Eoo`03001oogoo01Yoo`05001oogoo
Ool00005Ool20005Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00
Oomoo`10Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0IOol01@00Oomoogoo
00001Goo0P001Goo00<007ooOol067oo0`000goo00<007ooOol00goo0P001Goo00<007ooOol0=goo
000AOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0KOol01000Oomoo`001Goo
0P001Goo00<007ooOol067oo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol0@7oo
00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol06Woo00@007ooOol000Eoo`8000Eo
o`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo03Moo`004Woo
00D007ooOomoo`0000Eoo`8000Eoo`03001oogoo01Ioo`03001oogoo009oo`04001oogoo0005Ool2
0005Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`10Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0EOol00`00Oomoo`02Ool01000Oomo
o`001Goo0P001Goo00<007ooOol06Woo00D007ooOomoo`0000Eoo`8000Eoo`03001oogoo03Moo`00
3Woo00D007ooOomoo`0000Aoo`05001oogooOol00002Ool01@00Oomoogoo00006Woo00@007ooOol0
00Aoo`05001oogooOol00002Ool01@00Oomoogoo00006Woo0P001Goo00D007ooOomoo`00009oo`05
001oogooOol00012Ool20005Ool01@00Oomoogoo00000Woo00D007ooOomoo`0001Uoo`04001oogoo
0004Ool01@00Oomoogoo00000Woo00D007ooOomoo`0001Uoo`05001oogooOol00004Ool01@00Oomo
ogoo00000Woo00D007ooOomoo`0003Yoo`003goo0`001Woo0`0017oo0`0077oo0P001Woo0`0017oo
0`0077oo00<007ooOol017oo0`0017oo0`00A7oo00<007ooOol017oo0`0017oo0`006goo0P001Woo
0`0017oo0`006goo0`001Woo0`0017oo0`00>goo003oOomYOol009aoo`03001oogoo0:9oo`<001]o
o`<000Ioo`00W7oo00<007ooOol0XWoo00<007ooOol07Goo00<007ooOol017oo002LOol00`00Oomo
o`2IOol30006Ool00`00Oomoo`02Ool300001Goo00000000Ool00`0000Eoo`00000007oo00<00004
Ool000000004Ool00`00Oomoo`04Ool009aoo`03001oogoo09Uoo`04001oogoo0005Ool00`00Oomo
o`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomo
o`04Ool000]oool002D000aoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`002goo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo3P001Goo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool02Goo0P001Woo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00001Goo00<007ooOol017oo000DOol00`00Oomoo`0VOol6000/Ool00`00Oomoo`0ZOol0
0`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0AOol00`00Oomoo`06Ool0
0`00Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool0
0`00Oomoo`04Ool0049oo`8005Qoo`03001oogoo09Uoo`04001oogoo0005Ool00`00Oomoo`02Ool3
0002Ool20002Ool00`00Oomoo`030002Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool004Ao
o`<005Eoo`03001oogoo09Yoo`<000Eoo`03001oogoo00=oo`04001oo`000002Ool20004Ool01000
Ool000000Woo0P001Woo00<007ooOol017oo0017Ool00`00Oomoo`1BOol00`00Oomoo`2ROol00`00
Oomoo`0MOol00`00Oomoo`04Ool004Moo`03001oogoo059oo`8005aoob0002Moo`03001oogoo01eo
o`03001oogoo00Aoo`00B7oo00<007ooOol0DGoo00<007ooOol0Egoo100087oo3P006Goo0`006goo
0`001Woo0018Ool00`00Oomoo`1AOol00`00Oomoo`1EOol2001bOol004Uoo`03001oogoo051oo`03
001oogoo05Aoo`03001oogoo079oo`00BGoo00<007ooOol0D7oo00<007ooOol0DWoo0P00MGoo001:
Ool00`00Oomoo`1?Ool00`00Oomoo`1AOol00`00Oomoo`1eOol004]oo`03001oogoo04ioo`80059o
o`03001oogoo07Eoo`00Bgoo00<007ooOol0CWoo00<007ooOol0D7oo00<007ooOol0MWoo001;Ool0
0`00Oomoo`1>Ool00`00Oomoo`1@Ool00`00Oomoo`1fOol004aoo`03001oogoo04eoo`03001oogoo
04moo`03001oogoo07Moo`00C7oo00<007ooOol0CGoo00<007ooOol0Cgoo00<007ooOol0Mgoo001<
Ool00`00Oomoo`1=Ool00`00Oomoo`1?Ool00`00Oomoo`1gOol004aoo`03001oogoo04eoo`8004mo
o`03001oogoo07Qoo`00C7oo00<007ooOol0CGoo00<007ooOol0CWoo00<007ooOol0N7oo001=Ool0
0`00Oomoo`1<Ool00`00Oomoo`1>Ool00`00Oomoo`1hOol004eoo`03001oogoo04aoo`03001oogoo
04eoo`03001oogoo07Uoo`00CGoo00<007ooOol0C7oo00<007ooOol0CGoo00<007ooOol0NGoo001>
Ool00`00Oomoo`1;Ool2001>Ool00`00Oomoo`1iOol004ioo`03001oogoo04]oo`03001oogoo04eo
o`03001oogoo07Uoo`00CWoo00<007ooOol0Bgoo00<007ooOol0C7oo00<007ooOol0NWoo001>Ool0
0`00Oomoo`0YOol30005Ool30002Ool50005Ool30008Ool00`00Oomoo`1<Ool00`00Oomoo`1jOol0
04ioo`03001oogoo02Yoo`03001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00000goo
00<007ooOol01Goo00<007ooOol0C7oo00<007ooOol0NWoo001>Ool00`00Oomoo`0ZOol00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomo
o`1<Ool00`00Oomoo`1jOol004ioo`03001oogoo02Yoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00Aoo`03001oo`0000Eoo`03001oogoo00Aoo`<004aoo`03001oogoo07Yoo`00Cgoo00<0
07ooOol0:Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007oo00001Goo00<0
07ooOol017oo00<007ooOol0C7oo00<007ooOol0NWoo001?Ool00`00Oomoo`0YOol00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol017oo00<007ooOol0
C7oo00<007ooOol0NWoo001?Ool00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Ool000030003Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`1;Ool00`00Oomoo`1kOol0
04moo`03001oogoo02Uoo`03001oogoo009oo`03001oogoo00=oo`03001oo`0000Ioo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo04]oo`03001oogoo07]oo`00Cgoo00<007ooOol0:7oo0P00
1Goo00D007ooOomoo`0000=oo`03001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`1;Ool0
0`00Oomoo`1kOol004moo`03001oogoo02Uoo`03001oogoo00Aoo`<000Aoo`D000=oo`<000Qoo`80
04aoo`03001oogoo07]oo`00Cgoo00<007ooOol0BWoo00<007ooOol0Bgoo00<007ooOol0Ngoo001?
Ool00`00Oomoo`1:Ool00`00Oomoo`1:Ool00`00Oomoo`1lOol004moo`03001oogoo04Yoo`03001o
ogoo04Yoo`03001oogoo07aoo`00Cgoo00<007ooOol0BWoo00<007ooOol0BWoo00<007ooOol0O7oo
001?Ool00`00Oomoo`1:Ool2001;Ool00`00Oomoo`1lOol004moo`03001oogoo04Yoo`03001oogoo
04Yoo`03001oogoo07aoo`00Cgoo00<007ooOol0BWoo00<007ooOol0BWoo00<007ooOol0O7oo001?
Ool00`00Oomoo`1:Ool00`00Oomoo`1:Ool00`00Oomoo`1lOol004moo`03001oogoo04Yoo`03001o
ogoo04Yoo`03001oogoo07aoo`00D7oo00<007ooOol0BGoo00<007ooOol0BWoo00<007ooOol0O7oo
001@Ool00`00Oomoo`19Ool2001;Ool00`00Oomoo`1lOol0051oo`03001oogoo04Uoo`03001oogoo
04Yoo`03001oogoo07aoo`00D7oo00<007ooOol0BGoo00<007ooOol0BWoo00<007ooOol0O7oo001@
Ool00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomoo`1mOol0051oo`03001oogoo04Uoo`03001o
ogoo04Uoo`03001oogoo07eoo`00D7oo00<007ooOol0BGoo00<007ooOol0BGoo00<007ooOol0OGoo
001@Ool00`00Oomoo`19Ool2001:Ool00`00Oomoo`1mOol0051oo`03001oogoo04Uoo`03001oogoo
04Uoo`03001oogoo07eoo`00D7oo00<007ooOol0BGoo00<007ooOol0BGoo00<007ooOol0OGoo001@
Ool00`00Oomoo`0WOol30005Ool30004Ool30005Ool30008Ool00`00Oomoo`19Ool00`00Oomoo`1m
Ool0051oo`03001oogoo02Qoo`03001oogoo00Eoo`03001oogoo009oo`05001oogooOol00003Ool0
1@00Oomoogoo00001goo00<007ooOol0BGoo00<007ooOol0OGoo001@Ool00`00Oomoo`0XOol00`00
Oomoo`05Ool01@00Oomoogoo00001Goo00<007oo00001Goo00<007ooOol017oo00<007ooOol0BGoo
00<007ooOol0OGoo001@Ool00`00Oomoo`0XOol00`00Oomoo`05Ool01@00Oomoogoo00001Goo00<0
07oo00001Goo00<007ooOol017oo0`00BGoo00<007ooOol0OGoo001@Ool00`00Oomoo`0XOol00`00
Oomoo`05Ool01@00Oomoogoo00001Goo00<007oo00001Goo00<007ooOol017oo00<007ooOol0BGoo
00<007ooOol0OGoo001AOol00`00Oomoo`0WOol00`00Oomoo`05Ool01@00Oomoogoo00001Goo00<0
07oo00001Goo00<007ooOol017oo00<007ooOol0BGoo00<007ooOol0OGoo001AOol00`00Oomoo`0W
Ool00`00Oomoo`05Ool01@00Oomoogoo00001Goo00<007oo00001Goo00<007ooOol017oo00<007oo
Ool0BGoo00<007ooOol0OGoo001AOol00`00Oomoo`0WOol00`00Oomoo`05Ool01@00Oomoogoo0000
1Goo00<007oo00001Goo00<007ooOol017oo00<007ooOol0BGoo00<007ooOol0OGoo001AOol00`00
Oomoo`0VOol20006Ool20004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Moo`8004Yoo`03
001oogoo07eoo`00DGoo00<007ooOol09goo00<007ooOol01Goo00<007ooOol00goo0`001Goo0`00
27oo00<007ooOol0BGoo00<007ooOol0OGoo001AOol00`00Oomoo`18Ool00`00Oomoo`19Ool00`00
Oomoo`1mOol0055oo`03001oogoo04Qoo`03001oogoo04Uoo`03001oogoo07eoo`00DGoo00<007oo
Ool0B7oo00<007ooOol0BGoo00<007ooOol0OGoo001AOol00`00Oomoo`18Ool00`00Oomoo`19Ool0
0`00Oomoo`1mOol0055oo`03001oogoo04Qoo`8004Yoo`03001oogoo07eoo`00DGoo00<007ooOol0
B7oo00<007ooOol0BGoo00<007ooOol0OGoo001AOol00`00Oomoo`18Ool00`00Oomoo`18Ool00`00
Oomoo`1nOol0055oo`03001oogoo04Qoo`03001oogoo04Qoo`03001oogoo07ioo`00DWoo00<007oo
Ool0Agoo00<007ooOol0B7oo00<007ooOol0OWoo001BOol00`00Oomoo`17Ool00`00Oomoo`18Ool0
0`00Oomoo`1nOol0059oo`03001oogoo00Uoo`03001oogoo03]oo`8004Uoo`03001oogoo07ioo`00
DWoo00<007ooOol02Goo00<007ooOol0>goo00<007ooOol0B7oo00<007ooOol0OWoo001BOol00`00
Oomoo`09Ool2000>Ool00`00Oomoo`0[Ool00`00Oomoo`18Ool00`00Oomoo`1nOol0059oo`03001o
ogoo00Uoo`03001oo`0000eoo`03001oogoo00aoo`03001oogoo00aoo`8000ioo`03001oogoo03]o
o`03001oogoo00Yoo`03001oogoo07ioo`00DWoo00<007ooOol02Goo00<007oo00003Goo0P003Goo
0P003Goo00<007oo000037oo0`003Woo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo
00<007ooOol02Woo00<007ooOol0OWoo001BOol00`00Oomoo`09Ool00`00Ool0000=Ool2000=Ool2
000=Ool00`00Ool0000<Ool3000=Ool2000>Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`1nOol0059oo`03001oogoo00Qoo`04001oogoo000<Ool00`00Ool0000=Ool2
000=Ool00`00Ool0000<Ool3000=Ool2000=Ool2000>Ool2000=Ool2000<Ool00`00Oomoo`1nOol0
059oo`03001oogoo00Qoo`04001oogoo000<Ool00`00Ool0000<Ool00`00Ool0000=Ool00`00Ool0
000<Ool3000=Ool2000=Ool2000=Ool00`00Ool0000=Ool00`00Ool0000;Ool00`00Oomoo`1nOol0
059oo`03001oogoo00Qoo`04001oogoo000<Ool00`00Ool0000<Ool00`00Ool0000=Ool00`00Ool0
000<Ool3000=Ool00`00Ool0000<Ool00`00Ool0000<Ool00`00Ool0000=Ool00`00Ool0000;Ool0
0`00Oomoo`1nOol0059oo`03001oogoo00Qoo`04001oogoo000<Ool00`00Ool0000:Ool30002Ool0
0`00Oomoo`030002Ool6000017oo001oogoo0`001goo0`003Goo00<007oo000037oo00<007oo0000
37oo00<007oo00003Goo00<007oo00002goo00<007ooOol0OWoo001BOol00`00Oomoo`08Ool01000
Oomoo`0037oo00<007oo00002goo0P000Woo00D007ooOomoo`0000Qoo`05001oo`00Ool00003Ool0
0`00Oomoo`04Ool3000<Ool01000Oomoo`0037oo00<007oo000037oo00<007oo00003Goo00<007oo
00002goo00<007ooOol0OWoo001BOol00`00Oomoo`08Ool01000Oomoo`0037oo00<007oo00002goo
0P000Woo00D007ooOomoo`0000Moo`03001oo`00008000Eoo`03001oogoo00=oo`@000]oo`04001o
ogoo000<Ool00`00Ool0000<Ool01000Oomoo`0037oo00<007oo00002goo00<007ooOol0OWoo001B
Ool00`00Oomoo`08Ool01000Oomoo`002goo00@007ooOol000]oo`80009oo`05001oogooOol00007
Ool01@00Ool007oo00001Goo00<007ooOol00Woo00D007oo001oo`0000]oo`04001oogoo000<Ool0
0`00Ool0000<Ool01000Oomoo`002goo00D007ooOomoo`0000Yoo`03001oogoo07ioo`00DWoo00<0
07ooOol027oo00D007ooOomoo`0000Yoo`05001oogooOol0000:Ool01@00Oomoogoo00000goo00<0
07ooOol01Goo00D007oo001oo`0000Eoo`03001oogoo009oo`05001oo`00Ool0000;Ool01000Oomo
o`0037oo00<007oo000037oo00@007ooOol000]oo`05001oogooOol0000:Ool00`00Oomoo`1nOol0
059oo`03001oogoo00Qoo`05001oogooOol0000:Ool01@00Oomoogoo00002Woo00D007ooOomoo`00
00=oo`03001oogoo00Eoo`80009oo`03001oogoo00=oo`03001oogoo009oo`05001oo`00Ool0000;
Ool01000Oomoo`002goo00@007ooOol000aoo`04001oogoo000;Ool01@00Oomoogoo00002Woo00<0
07ooOol0OWoo001BOol00`00Oomoo`08Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000Yoo`05
001oogooOol00003Ool00`00Oomoo`02Ool40003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00
Ool007oo00002goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01000Oomoo`002goo00D0
07ooOomoo`0000Yoo`03001oogoo07ioo`00DWoo00<007ooOol027oo00D007ooOomoo`0000Yoo`05
001oogooOol0000:Ool01@00Oomoogoo00000goo00<007ooOol00Woo00@007ooOol000=oo`03001o
ogoo00=oo`03001oogoo009oo`05001oo`00Ool0000;Ool01@00Oomoogoo00002Woo00D007ooOomo
o`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Goo00<007ooOol0Ogoo001BOol00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Goo0P0017oo00@007oo
000000Eoo`03001oo`0000=oo`8000=oo`03001oogoo00=oo`03001oo`00008000Yoo`03001oogoo
009oo`03001oogoo00Qoo`05001oogooOol0000:Ool01@00Oomoogoo00002goo00D007ooOomoo`00
00Uoo`03001oogoo07moo`00DWoo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00D0
07ooOomoo`0000Yoo`03001oogoo009oo`04001oogoo0005Ool500000goo001oo`030006Ool01@00
Ool007oo00002Woo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`05001oogoo
Ool0000;Ool01@00Oomoogoo00002Goo00<007ooOol0Ogoo001BOol00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00D0
07ooOomoo`0000Yoo`05001oo`00Ool0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomo
ogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol00009Ool00`00Oomoo`1oOol005=oo`03
001oogoo00Ioo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02
Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00D007oo001oo`0000Yoo`03001oogoo009oo`03
001oogoo00Qoo`05001oogooOol0000:Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Uoo`03
001oogoo07moo`00Dgoo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol027oo00D007ooOomo
o`0000Yoo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool01@00Ool007oo0000
2Woo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`05001oogooOol0000:Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1oOol005=oo`03001oogoo00Ioo`03001oogoo
009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00
Oomoogoo00002Woo00D007oo001oo`0000Yoo`03001oogoo009oo`03001oogoo00Qoo`05001oogoo
Ool0000:Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0Ogoo
001COol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo00002Woo00<0
07ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oo`00008000Yoo`03001oogoo
009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1oOol005=oo`03001oogoo00Ioo`03001oogoo009o
o`03001oogoo00Qoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool01@00Ool007oo00002Woo00<007ooOol00Woo00<007ooOol027oo00D0
07ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Mo
o`03001oogoo07moo`00Dgoo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol027oo00D007oo
Oomoo`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03
001oo`00009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1o
Ool005=oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001o
o`00009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1oOol0
05=oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oo`00
009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`05001oogooOol0000:Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1oOol005=o
o`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oo`00009o
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qo
o`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo07mo
o`00Dgoo00<007ooOol01Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol027oo00H007oo
000007oo0009Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1oOol0
05=oo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oo`00
009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo
07moo`00Dgoo00<007ooOol01Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo081oo`00Dgoo00<007ooOol01Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0
1Woo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo081oo`00Dgoo00<007ooOol01Goo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00goo00<0
07ooOol01Woo00@007ooOol0009oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00Eoo`03001oogoo081oo`00Dgoo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol00P0000=oo`00Ool01goo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol01Goo00<007ooOol0P7oo001COol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol0P7oo001COol00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol0
17oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol0P7oo001COol00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool30003Ool60003Ool30004
Ool40005Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol0P7oo001COol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool20004Ool20004Ool01000Ool000000Woo00D007ooOomo
o`0000=oo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`20Ool005=oo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`8000Eoo`03001oogoo00=oo`03001o
o`0000=oo`04001oo`000004Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Moo`03001oogoo
00Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo081oo`00Dgoo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo0P001Goo0P0017oo00<0
07oo00000goo00@007oo000000Aoo`05001oogooOol00002Ool300000goo001oo`06Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`20Ool005=oo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`8000Eoo`03001oo`00
00=oo`03001oo`0000=oo`04001oo`000004Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Mo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo081oo`00Dgoo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo0P001Goo
00@007ooOol0009oo`03001oo`0000=oo`04001oo`000004Ool01@00Oomoogoo00000Woo00D007oo
Oomoo`0000Moo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo081oo`00
Dgoo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
1Goo0P001Goo00T007ooOomoo`00Ool007oo00000goo00@007oo000000Aoo`05001oogooOol00002
Ool01@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool0P7oo001COol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool20004Ool20003Ool01@00Ool007oo00000goo00@007oo000000Aoo`05001oogoo
Ool00002Ool01@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol0P7oo001COol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool20005Ool01000Oomoo`000goo0P000Woo00D007ooOomoo`0000=oo`03
001oogoo009oo`04001oogoo0003Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`20Ool005=oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`8000Eoo`<000Eoo`<000Aoo`@000Eoo`03001oogoo
0080009oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo081oo`00Dgoo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo
00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo081oo`00Dgoo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Woo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo081oo`00Dgoo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo081oo`00E7oo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo081oo`00E7oo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo081oo`00E7oo00<007ooOol0
0goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00@007ooOomoo`80009oo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo081oo`00E7oo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00D007ooOomoo`00
00=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo
085oo`00E7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol017oo00D0
07ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=o
o`03001oogoo085oo`00E7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo00<007oo
Ool017oo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00=oo`03001oogoo085oo`00E7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo085oo`00E7oo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Woo00<007ooOol017oo00@007ooOomoo`8000=oo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo085oo`00E7oo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol017oo00D007ooOomoo`0000Aoo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo085oo`00E7oo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00D007ooOomoo`0000Aoo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo085oo`00
E7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo00D007ooOomo
o`0000Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=oo`03001o
ogoo085oo`00E7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol017oo
00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00=oo`03001oogoo085oo`00E7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<0
07ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol0PGoo001DOol00`00Oomoo`03Ool00`00Oomoo`06
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`21Ool005Aoo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo085o
o`00E7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007oo
Ool01goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007oo
Ool00goo00<007ooOol0PGoo001DOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool40003Ool600000goo000000030005Ool30003Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomo
o`03Ool00`00Oomoo`21Ool005Aoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo00=oo`03001oo`0000Aoo`03001oo`0000=oo`03001oo`0000=oo`09
001oogooOol007oo001oo`00009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo085oo`00E7oo00<007ooOol0
0goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007oo0000
1Goo0P001Goo00<007ooOol00Woo00<007oo00000Woo00H007ooOol007oo0004Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`21
Ool005Eoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool0
0`00Ool00006Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Ool00002Ool01P00Oomoo`00Ool0
00Aoo`<0009oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03
001oogoo085oo`00EGoo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo009oo`04001oogoo0006Ool20004Ool00`00Oomoo`02Ool00`00Ool00002Ool01P00Oomoo`00
Ool000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00=oo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo009oo`03001oogoo085oo`00EGoo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo009oo`04001oogoo0006Ool00`00Ool00003Ool01@00Oomoogoo00000Woo00@0
07ooOol0009oo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo085oo`00EGoo00D007ooOomoo`0000Yoo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0006Ool01000Oomoo`000Woo1000
0goo00@007ooOol0009oo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00Ioo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo085oo`00EGoo00D007ooOomoo`0000Yo
o`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`04001oogoo0004Ool00`00Ool00002
Ool01000Oomoo`001Woo00@007ooOol0009oo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo00=oo`03001oogoo00Moo`05001oogooOol00024Ool005Eoo`05001oogooOol0
000:Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00@007oo000000Eoo`800003Ool007oo009o
o`8000Ioo`05001oo`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool01@00Oomoogoo0000Q7oo001EOol01@00Oomoogoo00002Woo
00D007ooOomoo`0000Yoo`03001oogoo009oo`04001oogoo0006Ool20004Ool60003Ool30003Ool0
0`00Oomoo`02Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`07Ool01@00Oomo
ogoo0000Q7oo001EOol01@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000:
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01@00Oomoogoo0000Q7oo001EOol0
1@00Oomoogoo00002Woo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool01@00Oomoogoo0000
2Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
27oo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001o
ogoo00Moo`05001oogooOol00024Ool005Eoo`05001oogooOol0000:Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Yoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00
Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol027oo00@007ooOol008Aoo`00EWoo00@007oo
Ool000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000Yoo`05001o
ogooOol00005Ool00`00Oomoo`03Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol0
27oo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01000Oomoo`00Q7oo001FOol01000Oomo
o`002Woo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool01@00Oomoogoo00002goo00@007oo
Ool000Eoo`8000Aoo`05001oogooOol0000:Ool00`00Oomoo`02Ool00`00Oomoo`08Ool01@00Oomo
ogoo00002Woo00D007ooOomoo`0000]oo`04001oogoo0024Ool005Ioo`04001oogoo000;Ool01000
Oomoo`002goo00@007ooOol000]oo`05001oogooOol0000;Ool01000Oomoo`001Goo00<007ooOol0
0goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01@00Oomoogoo00002Woo00D007ooOomo
o`0000]oo`04001oogoo0024Ool005Ioo`03001oo`0000aoo`04001oogoo000;Ool01000Oomoo`00
2goo00D007ooOomoo`0000]oo`04001oogoo0005Ool00`00Oomoo`03Ool01@00Oomoogoo00002Woo
00D007ooOomoo`0000]oo`05001oogooOol0000:Ool01@00Oomoogoo00002goo00<007oo0000QGoo
001FOol00`00Ool0000<Ool01000Oomoo`002goo00@007ooOol000]oo`05001oogooOol0000;Ool0
1000Oomoo`001Goo00<007ooOol00goo00D007ooOomoo`0000Yoo`05001oogooOol0000;Ool01000
Oomoo`002goo00D007ooOomoo`0000]oo`03001oo`0008Eoo`00EWoo00<007oo000037oo00@007oo
Ool000]oo`04001oogoo000;Ool01@00Oomoogoo00002goo00@007ooOol000Eoo`03001oogoo00=o
o`05001oogooOol0000;Ool01000Oomoo`002goo00@007ooOol000]oo`05001oogooOol0000;Ool0
0`00Ool00025Ool005Ioo`03001oo`0000aoo`04001oogoo000<Ool00`00Ool0000<Ool01000Oomo
o`002goo00@007ooOol000Eoo`03001oogoo00=oo`04001oogoo000<Ool01000Oomoo`002goo00@0
07ooOol000]oo`05001oogooOol0000;Ool00`00Ool00025Ool005Moo`8000aoo`04001oogoo000<
Ool00`00Ool0000<Ool01000Oomoo`002goo00@007ooOol000Eoo`8000Aoo`04001oogoo000<Ool0
1000Oomoo`002goo00@007ooOol000]oo`05001oogooOol0000;Ool00`00Ool00025Ool005Moo`03
001oogoo00]oo`04001oogoo000<Ool00`00Ool0000<Ool01000Oomoo`002goo00@007ooOol000Eo
o`03001oogoo00=oo`04001oogoo000<Ool01000Oomoo`002goo00@007ooOol000]oo`05001oogoo
Ool0000<Ool20025Ool005Moo`03001oogoo00]oo`04001oogoo000<Ool00`00Ool0000<Ool01000
Oomoo`002goo00@007ooOol000Eoo`03001oogoo00=oo`04001oogoo000<Ool01000Oomoo`002goo
00@007ooOol000]oo`04001oogoo000=Ool20025Ool006Eoo`04001oogoo000<Ool00`00Ool0000<
Ool01000Oomoo`002goo00@007ooOol000Eoo`03001oogoo00=oo`04001oogoo000<Ool01000Oomo
o`002goo00@007ooOol000aoo`03001oo`0000eoo`03001oogoo08Aoo`00IGoo00<007oo00003Goo
00<007oo000037oo00<007oo000037oo00@007ooOol000Eoo`03001oogoo00=oo`04001oogoo000<
Ool01000Oomoo`002goo00@007ooOol000aoo`03001oo`0000eoo`03001oogoo08Aoo`00IWoo0P00
3Goo0P003Goo00<007oo000037oo00@007ooOol000Eoo`03001oogoo00Aoo`03001oo`0000aoo`04
001oogoo000;Ool01000Oomoo`0037oo00<007oo00003Goo00<007ooOol0Q7oo001VOol2000=Ool2
000=Ool00`00Ool0000=Ool00`00Ool00005Ool20005Ool00`00Ool0000<Ool00`00Ool0000=Ool0
0`00Ool0000<Ool00`00Ool0002DOol006Ioo`8000ioo`03001oogoo00aoo`8000eoo`8000Ioo`03
001oogoo00Aoo`8000ioo`8000eoo`8000eoo`03001oo`0009Aoo`00Igoo00<007ooOol037oo00<0
07ooOol037oo00<007ooOol037oo0P001Woo00<007ooOol017oo0P003Woo0P003Goo0P003Woo0P00
U7oo001fOol01000Oomoogoo0`000goo100000=oo`00Ool00Woo0`001Goo0`0000=oo`00Ool01Goo
00<007ooOol01Goo00<007ooOol037oo00<007ooOol037oo0P003Woo00<007ooOol0Tgoo001kOol0
0`00Oomoo`06Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`8000Ioo`03001oogoo00Eo
o`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo09=oo`00Ngoo00<007oo
Ool01goo00<007oo00001Goo00<007oo00001Goo00<007ooOol017oo00<007ooOol0bGoo001kOol0
0`00Oomoo`07Ool00`00Ool00005Ool00`00Ool00005Ool00`00Oomoo`04Ool30039Ool007]oo`03
001oogoo00Moo`03001oo`0000Eoo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo0<Uoo`00
Ngoo00<007ooOol017oo0`000Woo00<007ooOol00goo00<007oo00001Goo00<007ooOol017oo00<0
07ooOol0bGoo001kOol00`00Oomoo`05Ool01@00Oomoogoo00001Goo00<007oo00001Goo00<007oo
Ool017oo00<007ooOol0bGoo001kOol00`00Oomoo`06Ool01000Oomoo`001Goo00<007oo00001Goo
00<007ooOol0d7oo001jOol20004Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol0003COol007]oo`03001oogoo00=oo`<000Eoo`<000Eoo`<00=Aoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00Ugoo0P00cgoo002COol30002Ool00`00
Oomoo`0COol3002gOol009=oo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo0;Eoo`00Qgoo
0`000Woo0`0017oo00<007ooOol00Woo00D007oo000007oo008000Eoo`<00005Ool00000001oo`03
00000goo001oo`2fOol008Qoo`05001oogooOol00006Ool00`00Oomoo`03Ool00`00Oomoo`020000
0goo001oo`04Ool01@00Oomoogoo00000goo00@007ooOol00;Moo`00RGoo00<007oo00001goo00<0
07ooOol00goo00D007ooOomoo`0000Moo`05001oogooOol00003Ool01000Oomoo`00]goo002:Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo00D007ooOomoo`0000=oo`04001o
ogoo002gOol008Uoo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Ao
o`05001oogooOol00003Ool01000Oomoo`00]goo0028Ool01@00Oomoogoo00001Woo00<007ooOol0
17oo00D007ooOomoo`0000Eoo`<0009oo`80009oo`04001oogoo002gOol008Moo`<00004Ool00000
0005Ool00`00Oomoo`04Ool01@00Oomoogoo00001Woo00@007oo0000009oo`8000=oo`03001oogoo
0;Eoo`00Tgoo00<007ooOol06Woo00<007ooOol0]Goo002COol00`00Oomoo`0JOol00`00Oomoo`2e
Ool009=oo`<001Qoo`<00;Moo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-346.154, 963.222, 2.76183, 
  2.17502}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.00155618 0.0271541 0.000463205 [
[.03315 .01465 -15.125 -14 ]
[.03315 .01465 15.125 0 ]
[.18876 .01465 -15.125 -14 ]
[.18876 .01465 15.125 0 ]
[.34438 .01465 -15.125 -14 ]
[.34438 .01465 15.125 0 ]
[.65562 .01465 -11 -14 ]
[.65562 .01465 11 0 ]
[.81124 .01465 -11 -14 ]
[.81124 .01465 11 0 ]
[.96685 .01465 -11 -14 ]
[.96685 .01465 11 0 ]
[1.025 .02715 0 -7 ]
[1.025 .02715 38.125 7 ]
[.4875 .1198 -22 -7 ]
[.4875 .1198 0 7 ]
[.4875 .21244 -22 -7 ]
[.4875 .21244 0 7 ]
[.4875 .30508 -22 -7 ]
[.4875 .30508 0 7 ]
[.4875 .39772 -22 -7 ]
[.4875 .39772 0 7 ]
[.4875 .49036 -28 -7 ]
[.4875 .49036 0 7 ]
[.4875 .583 -28 -7 ]
[.4875 .583 0 7 ]
[.5 .64303 -16.6562 0 ]
[.5 .64303 16.6562 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03315 .02715 m
.03315 .0334 L
s
gsave
.03315 .01465 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18876 .02715 m
.18876 .0334 L
s
gsave
.18876 .01465 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.34438 .02715 m
.34438 .0334 L
s
gsave
.34438 .01465 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.65562 .02715 m
.65562 .0334 L
s
gsave
.65562 .01465 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81124 .02715 m
.81124 .0334 L
s
gsave
.81124 .01465 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96685 .02715 m
.96685 .0334 L
s
gsave
.96685 .01465 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06427 .02715 m
.06427 .0309 L
s
.09539 .02715 m
.09539 .0309 L
s
.12652 .02715 m
.12652 .0309 L
s
.15764 .02715 m
.15764 .0309 L
s
.21989 .02715 m
.21989 .0309 L
s
.25101 .02715 m
.25101 .0309 L
s
.28214 .02715 m
.28214 .0309 L
s
.31326 .02715 m
.31326 .0309 L
s
.37551 .02715 m
.37551 .0309 L
s
.40663 .02715 m
.40663 .0309 L
s
.43775 .02715 m
.43775 .0309 L
s
.46888 .02715 m
.46888 .0309 L
s
.53112 .02715 m
.53112 .0309 L
s
.56225 .02715 m
.56225 .0309 L
s
.59337 .02715 m
.59337 .0309 L
s
.62449 .02715 m
.62449 .0309 L
s
.68674 .02715 m
.68674 .0309 L
s
.71786 .02715 m
.71786 .0309 L
s
.74899 .02715 m
.74899 .0309 L
s
.78011 .02715 m
.78011 .0309 L
s
.84236 .02715 m
.84236 .0309 L
s
.87348 .02715 m
.87348 .0309 L
s
.90461 .02715 m
.90461 .0309 L
s
.93573 .02715 m
.93573 .0309 L
s
.00202 .02715 m
.00202 .0309 L
s
.99798 .02715 m
.99798 .0309 L
s
.25 Mabswid
0 .02715 m
1 .02715 L
s
gsave
1.025 .02715 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.625000 14.000000 moveto
(@) show
74.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.187500 14.000000 moveto
(D) show
97.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.5 .1198 m
.50625 .1198 L
s
gsave
.4875 .1198 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .21244 m
.50625 .21244 L
s
gsave
.4875 .21244 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(400) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .30508 m
.50625 .30508 L
s
gsave
.4875 .30508 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(600) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .39772 m
.50625 .39772 L
s
gsave
.4875 .39772 -83 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(800) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .49036 m
.50625 .49036 L
s
gsave
.4875 .49036 -89 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .583 m
.50625 .583 L
s
gsave
.4875 .583 -89 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.5 .05031 m
.50375 .05031 L
s
.5 .07347 m
.50375 .07347 L
s
.5 .09663 m
.50375 .09663 L
s
.5 .14296 m
.50375 .14296 L
s
.5 .16612 m
.50375 .16612 L
s
.5 .18928 m
.50375 .18928 L
s
.5 .2356 m
.50375 .2356 L
s
.5 .25876 m
.50375 .25876 L
s
.5 .28192 m
.50375 .28192 L
s
.5 .32824 m
.50375 .32824 L
s
.5 .3514 m
.50375 .3514 L
s
.5 .37456 m
.50375 .37456 L
s
.5 .42088 m
.50375 .42088 L
s
.5 .44404 m
.50375 .44404 L
s
.5 .4672 m
.50375 .4672 L
s
.5 .51352 m
.50375 .51352 L
s
.5 .53668 m
.50375 .53668 L
s
.5 .55984 m
.50375 .55984 L
s
.5 .00399 m
.50375 .00399 L
s
.5 .60616 m
.50375 .60616 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -77.6562 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
68.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(') show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
73.437500 14.000000 moveto
(@) show
77.937500 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(m) show
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(r) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
88.375000 14.000000 moveto
(D) show
92.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Math2
%%+ font Times-Roman
grestore
.5 Mabswid
.02381 .02715 m
.0286 .02715 L
.03338 .02715 L
.03817 .02715 L
.04295 .02715 L
.04774 .02715 L
.05252 .02715 L
.05731 .02715 L
.0621 .02715 L
.06688 .02715 L
.07167 .02715 L
.07645 .02715 L
.08124 .02715 L
.08603 .02715 L
.09081 .02715 L
.0956 .02715 L
.10038 .02715 L
.10517 .02715 L
.10995 .02715 L
.11474 .02715 L
.11953 .02715 L
.12431 .02715 L
.1291 .02715 L
.13388 .02715 L
.13867 .02714 L
.14346 .02714 L
.14824 .02714 L
.15303 .02713 L
.15781 .02713 L
.1626 .02712 L
.16738 .0271 L
.17217 .02709 L
.17696 .02706 L
.18174 .02703 L
.18653 .02698 L
.19131 .02691 L
.1961 .02681 L
.20089 .02665 L
.20567 .02641 L
.21046 .02603 L
.21524 .02544 L
.22003 .02454 L
.22481 .02314 L
.2296 .02097 L
.23439 .01763 L
.23917 .01472 L
.24396 .01808 L
.24874 .0286 L
.25353 .04116 L
.25832 .05034 L
Mistroke
.2631 .05587 L
.26789 .06221 L
.27267 .07225 L
.27746 .0827 L
.28224 .08823 L
.28703 .08677 L
.29182 .08333 L
.2966 .08487 L
.30139 .09331 L
.30617 .10436 L
.31096 .11273 L
.31575 .11777 L
.32053 .12369 L
.32532 .13348 L
.3301 .14402 L
.33489 .14992 L
.33967 .14875 L
.34446 .14519 L
.34925 .14623 L
.35403 .15424 L
.35882 .16513 L
.3636 .17363 L
.36839 .1787 L
.37318 .18441 L
.37796 .19394 L
.38275 .20449 L
.38753 .2107 L
.39232 .20986 L
.3971 .20628 L
.40189 .20692 L
.40668 .21451 L
.41146 .22523 L
.41625 .23383 L
.42103 .23894 L
.42582 .24443 L
.43061 .25363 L
.43539 .2641 L
.44018 .27058 L
.44496 .27008 L
.44975 .26652 L
.45453 .26677 L
.45932 .27391 L
.46411 .28441 L
.46889 .29307 L
.47368 .2982 L
.47846 .30345 L
.48325 .31228 L
.48804 .32261 L
.49282 .32928 L
.49761 .32913 L
Mistroke
.50239 .32562 L
.50718 .32551 L
.51196 .33217 L
.51675 .34239 L
.52154 .35105 L
.52632 .35619 L
.53111 .3612 L
.53589 .36962 L
.54068 .37974 L
.54547 .38656 L
.55025 .38674 L
.55504 .38333 L
.55982 .38289 L
.56461 .38904 L
.56939 .39891 L
.57418 .40752 L
.57897 .41264 L
.58375 .41741 L
.58854 .42538 L
.59332 .43524 L
.59811 .44214 L
.6029 .44265 L
.60768 .43937 L
.61247 .43863 L
.61725 .44425 L
.62204 .45371 L
.62682 .46221 L
.63161 .4673 L
.6364 .47182 L
.64118 .47933 L
.64597 .48886 L
.65075 .49578 L
.65554 .49661 L
.66033 .4935 L
.66511 .4925 L
.6699 .49757 L
.67468 .50657 L
.67947 .51487 L
.68425 .5199 L
.68904 .52418 L
.69383 .53123 L
.69861 .54042 L
.7034 .54737 L
.70818 .54855 L
.71297 .54567 L
.71776 .54447 L
.72254 .54899 L
.72733 .55746 L
.73211 .56556 L
.7369 .57068 L
Mistroke
.74168 .57515 L
.74647 .58251 L
.75126 .59248 L
.75604 .60074 L
.76083 .60332 L
.76561 .60101 L
.7704 .59839 L
.77519 .59669 L
.77997 .5956 L
.78476 .5949 L
.78954 .59444 L
.79433 .59416 L
.79911 .59397 L
.8039 .59385 L
.80869 .59377 L
.81347 .59372 L
.81826 .59368 L
.82304 .59365 L
.82783 .59364 L
.83262 .59363 L
.8374 .59362 L
.84219 .59361 L
.84697 .59361 L
.85176 .5936 L
.85654 .5936 L
.86133 .5936 L
.86612 .5936 L
.8709 .59359 L
.87569 .59359 L
.88047 .59359 L
.88526 .59359 L
.89005 .59359 L
.89483 .59359 L
.89962 .59359 L
.9044 .59359 L
.90919 .59359 L
.91397 .59359 L
.91876 .59359 L
.92355 .59359 L
.92833 .59359 L
.93312 .59359 L
.9379 .59359 L
.94269 .59359 L
.94748 .59359 L
.95226 .59359 L
.95705 .59359 L
.96183 .59359 L
.96662 .59359 L
.9714 .59359 L
.97619 .59359 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo000<Ool40006Ool30004Ool3
000JOol60004Ool30004Ool3000LOol30005Ool30004Ool30015Ool30005Ool30004Ool3000JOol6
0004Ool30004Ool3000IOol40006Ool30004Ool3000jOol0011oo`03001oogoo009oo`05001oogoo
Ool00002Ool01@00Oomoogoo00006Goo00<007ooOol00goo00@007ooOol000=oo`04001oogoo0003
Ool00`00Oomoo`0JOol00`00Oomoo`03Ool01@00Oomoogoo00000Woo00D007ooOomoo`0004Eoo`03
001oogoo00=oo`05001oogooOol00002Ool01@00Oomoogoo00006Goo00<007ooOol00goo00@007oo
Ool000=oo`04001oogoo0003Ool00`00Oomoo`0JOol00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00D007ooOomoo`0003Uoo`004Goo00@007ooOol000Eoo`8000Eoo`03001oogoo01Moo`03001oogoo
00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00=oo`80
00Eoo`03001oogoo049oo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo01Moo`03
001oogoo00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo01Yoo`04001oogoo0005Ool20005Ool0
0`00Oomoo`0fOol000=oo`P000Ioo`04001oogoo0005Ool20005Ool00`00Oomoo`0=Ool80003Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0=Ool80004Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool20005Ool00`00Oomoo`12Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool0
0`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0JOol01000Oomo
o`001Goo0P001Goo00<007ooOol0=Woo000AOol01000Oomoo`001Goo0P001Goo00<007ooOol06Goo
00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol06Goo00<007ooOol00Woo00<007oo
Ool00goo0P001Goo00<007ooOol0@Woo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007oo
Ool06Goo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol06Woo00@007ooOol000Eo
o`8000Eoo`03001oogoo03Ioo`003Woo0`000goo00<007ooOol00goo0P001Goo00<007ooOol06Woo
00D007ooOomoo`0000Eoo`8000Eoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00=oo`80
00Eoo`03001oogoo049oo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo01Yoo`05
001oogooOol00005Ool20005Ool00`00Oomoo`0GOol30003Ool00`00Oomoo`03Ool20005Ool00`00
Oomoo`0fOol000moo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo01]oo`04001o
ogoo0005Ool20005Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00
Oomoo`12Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0KOol01000Oomoo`00
1Goo0P001Goo00<007ooOol067oo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol0
=Woo000@Ool01@00Oomoogoo00001Goo0P001Goo00<007ooOol05Woo00<007ooOol00Woo00@007oo
Ool000Eoo`8000Eoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001o
ogoo01aoo`03001oogoo02=oo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo01Io
o`03001oogoo009oo`04001oogoo0005Ool20005Ool00`00Oomoo`0IOol01@00Oomoogoo00001Goo
0P001Goo00<007ooOol0=Woo000<Ool01@00Oomoogoo000017oo00D007ooOomoo`00009oo`05001o
ogooOol0000JOol01000Oomoo`0017oo00D007ooOomoo`00009oo`05001oogooOol0000KOol20005
Ool01@00Oomoogoo00000Woo00D007ooOomoo`0001moo`8002=oo`8000Eoo`05001oogooOol00002
Ool01@00Oomoogoo00006Woo00@007ooOol000Aoo`05001oogooOol00002Ool01@00Oomoogoo0000
67oo00D007ooOomoo`0000Aoo`05001oogooOol00002Ool01@00Oomoogoo0000>Goo000=Ool30006
Ool30004Ool3000LOol20006Ool30004Ool3000MOol00`00Oomoo`04Ool30004Ool3000POol00`00
Oomoo`0SOol00`00Oomoo`04Ool30004Ool3000LOol20006Ool30004Ool3000JOol30006Ool30004
Ool3000jOol009aoo`03001oogoo0:Aoo`<001]oo`<000Aoo`00Cgoo0P00Bgoo00<007ooOol0Y7oo
00<007ooOol07Goo00<007ooOol00Woo001=Ool20002Ool00`00Oomoo`18Ool00`00Oomoo`2KOol3
0006Ool00`00Oomoo`02Ool300001Goo00000000Ool00`0000Eoo`00000007oo00<00004Ool00000
0004Ool00`00Oomoo`02Ool004aoo`03001oogoo009oo`03001oogoo04Qoo`03001oogoo09]oo`04
001oogoo0005Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00005Ool00`00Oomoo`02Ool004Qoo`@000Ioo`03001oogoo04Moo`03001oogoo09ioo`03
001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Eoo`03001oogoo009oo`002Gooo`00:0002goo0P001Woo00<007ooOol00goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo0009Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool20008Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool0019oo`03
001oogoo02]oo`03001oogoo00moo`03001oogoo01Uoo`03001oogoo02]oo`03001oogoo02]oo`03
001oogoo02]oo`03001oogoo02]oo`03001oogoo015oo`04001oogoo0005Ool00`00Oomoo`02Ool3
0002Ool20002Ool00`00Oomoo`030002Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool005=o
o`03001oogoo04Ioo`03001oogoo09aoo`<000Eoo`03001oogoo00=oo`04001oo`000002Ool20004
Ool01000Ool000000Woo0P001Woo00<007ooOol00Woo001COol00`00Oomoo`16Ool00`00Oomoo`2T
Ool00`00Oomoo`0MOol00`00Oomoo`02Ool005=oo`03001oogoo04Ioo`03001oogoo0:Aoo`03001o
ogoo01eoo`03001oogoo009oo`00E7oo00<007ooOol0AGoo00<007ooOol0Y7oo0`006goo0`0017oo
001EOol00`00Oomoo`14Ool2003:Ool005Ioo`03001oogoo04=oo`03001oogoo0<Uoo`00Egoo00<0
07ooOol0@Woo00<007ooOol0bGoo001HOol00`00Oomoo`11Ool00`00Oomoo`39Ool005Qoo`03001o
ogoo045oo`03001oogoo0<Uoo`00FGoo00<007ooOol0@7oo00<007ooOol0bGoo001IOol00`00Oomo
o`10Ool00`00Oomoo`39Ool005Uoo`03001oogoo041oo`800<Yoo`00FWoo00<007ooOol0?goo00<0
07ooOol0bGoo001JOol01000Oomoogoo0P00?7oo00<007ooOol0bGoo001KOol00`00Ool00002Ool0
0`00Oomoo`0iOol00`00Oomoo`39Ool005aoo`05001oogooOol0000kOol00`00Oomoo`39Ool0065o
o`03001oogoo03Qoo`03001oogoo0<Uoo`00HGoo00<007ooOol0>7oo0P00bWoo001ROol00`00Oomo
o`0gOol00`00Oomoo`39Ool0069oo`03001oogoo03Moo`03001oogoo0<Uoo`00Hgoo00<007ooOol0
=Woo00<007ooOol0bGoo001SOol00`00Oomoo`0IOol60004Ool30004Ool30009Ool00`00Oomoo`39
Ool006Aoo`03001oogoo01Qoo`03001oogoo00=oo`04001oogoo0003Ool01000Oomoo`000goo00<0
07ooOol01Woo00<007ooOol0bGoo001UOol00`00Oomoo`0HOol00`00Oomoo`04Ool00`00Oomoo`03
Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`39Ool006Ioo`03001oogoo01Qoo`03001oogoo00=o
o`03001oogoo00=oo`8000Eoo`03001oogoo00Eoo`<00<Uoo`00Igoo00<007ooOol067oo00<007oo
Ool00Woo00<007ooOol00goo0P001Goo00<007ooOol01Goo00<007ooOol0bGoo001WOol00`00Oomo
o`0IOol01@00Oomoogoo00001Goo0P001Goo00<007ooOol01Goo00<007ooOol0bGoo001XOol00`00
Oomoo`0IOol01000Oomoo`001Goo0P001Goo00<007ooOol01Goo00<007ooOol0bGoo001YOol00`00
Oomoo`0COol00`00Oomoo`02Ool01000Oomoo`001Goo0P001Goo00<007ooOol01Goo00<007ooOol0
bGoo001YOol00`00Oomoo`0DOol01000Oomoo`0017oo00D007ooOomoo`00009oo`05001oogooOol0
0008Ool00`00Oomoo`39Ool006Yoo`03001oogoo01Aoo`8000Ioo`<000Aoo`<000Uoo`03001oogoo
0<Uoo`00JWoo00<007ooOol0;goo0P00bWoo001ZOol01000Oomoogoo0`00:goo00<007ooOol0bGoo
001[Ool30002Ool00`00Oomoo`0YOol00`00Oomoo`39Ool0075oo`03001oogoo02Qoo`03001oogoo
0<Uoo`00LGoo00<007ooOol0:7oo00<007ooOol0bGoo001aOol00`00Oomoo`0XOol00`00Oomoo`39
Ool0079oo`03001oogoo02Moo`03001oogoo0<Uoo`00LWoo00<007ooOol09goo0P00bWoo001cOol0
0`00Oomoo`0VOol00`00Oomoo`39Ool007Aoo`03001oogoo02Eoo`03001oogoo0<Uoo`00M7oo00<0
07ooOol09Goo00<007ooOol0bGoo001eOol2000UOol00`00Oomoo`39Ool007Moo`03001oogoo029o
o`03001oogoo0<Uoo`00Mgoo00<007ooOol08Woo00<007ooOol0bGoo001hOol00`00Oomoo`0QOol2
003:Ool007Qoo`03001oogoo025oo`03001oogoo0<Uoo`00N7oo00<007ooOol08Goo00<007ooOol0
bGoo001iOol00`00Oomoo`0POol00`00Oomoo`39Ool007Uoo`03001oogoo00Qoo`03001oogoo009o
o`<000Aoo`<000Uoo`03001oogoo0<Uoo`00NWoo00<007ooOol00`0017oo00D007ooOomoo`0000=o
o`04001oogoo0003Ool00`00Oomoo`06Ool00`00Oomoo`39Ool007]oo`8000=oo`05001oogooOol0
0002Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`05Ool30039Ool007moo`T000Eoo`8000Eoo`03
001oogoo00Eoo`03001oogoo0<Uoo`00Ogoo00<007oo00000Woo00@007ooOol000Eoo`8000Eoo`03
001oogoo00Eoo`03001oogoo0<Uoo`00P7oo00D007oo001oo`00009oo`03001oogoo00=oo`8000Eo
o`03001oogoo00Eoo`03001oogoo0<Uoo`00PGoo0P0000Eoo`00Oomoo`0000Eoo`8000Eoo`03001o
ogoo00Eoo`03001oogoo0<Uoo`00PWoo00<007oo00000Woo00<007ooOol00goo0P001Goo00<007oo
Ool01Goo00<007ooOol0bGoo0023Ool20003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Qo
o`03001oogoo0<Uoo`00Pgoo0P0017oo0`0017oo0`002Goo0P00bWoo0025Ool00`00Oomoo`0DOol0
0`00Oomoo`39Ool008Eoo`03001oogoo01Aoo`03001oogoo0<Uoo`00QWoo00<007ooOol04goo00<0
07ooOol0bGoo0026Ool00`00Oomoo`0COol00`00Oomoo`39Ool008Moo`03001oogoo019oo`03001o
ogoo0<Uoo`00R7oo00<007ooOol04Goo00<007ooOol0bGoo0028Ool00`00Oomoo`0AOol2003:Ool0
08Uoo`03001oogoo011oo`03001oogoo0<Uoo`00RGoo00@007ooOomoo`8000eoo`03001oogoo0<Uo
o`00RGoo00@007oo0000009oo`03001oogoo00Yoo`03001oogoo0<Uoo`00RWoo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol0bGoo002@Ool00`00Oomoo`09Ool00`00Oomoo`39Ool0091oo`03
001oogoo00Uoo`03001oogoo0<Uoo`00TGoo00<007ooOol027oo0P00bWoo002AOol00`00Oomoo`08
Ool00`00Oomoo`39Ool0099oo`03001oogoo00Moo`03001oogoo0<Uoo`00Tgoo00<007ooOol01Woo
00<007ooOol0bGoo0021Ool30005Ool30004Ool40008Ool00`00Oomoo`39Ool0081oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000Woo00@007ooOomoo`<000Ioo`03001oogoo0<Uoo`00Ogoo00<0
07ooOol00goo00<007oo00001Goo0P001Goo00<007oo00001Goo00<007ooOol0bGoo001oOol00`00
Oomoo`03Ool00`00Ool00005Ool20005Ool00`00Ool00005Ool30039Ool007moo`03001oogoo00=o
o`03001oo`0000Eoo`8000Eoo`04001oogoo0004Ool00`00Oomoo`39Ool007moo`8000=oo`04001o
ogoo0005Ool20005Ool01000Oomoo`0017oo00<007ooOol0bGoo001oOol00`00Ool000020003Ool0
0`00Oomoo`03Ool20005Ool01000Oomoo`0017oo00<007ooOol0bGoo0020Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool20005Ool01@00Oomoogoo00000goo00<007ooOol0bGoo0021Ool20005Ool01@00
Oomoogoo00000Woo00D007ooOomoo`0000Eoo`04001oogoo003;Ool008=oo`<000=oo`<000Aoo`<0
00Ioo`03001oogoo00<00<Uoo`00VWoo100000=oo`00Ool0agoo002LOol01@00Oomoogoo0000agoo
002LOol01@00Oomoogoo0000agoo002LOol00`00Oomoo`02Ool00`00Oomoo`34Ool009aoo`03001o
ogoo009oo`03001oogoo0<Aoo`00W7oo00<007ooOol00Woo00<007ooOol0a7oo002LOol20004Ool0
0`00Oomoo`33Ool009aoo`03001oogoo00Aoo`03001oogoo0<9oo`00W7oo00<007ooOol01Goo00<0
07ooOol0`Goo002LOol00`00Oomoo`06Ool00`00Oomoo`30Ool009aoo`03001oogoo00Ioo`03001o
ogoo0<1oo`00W7oo00<007ooOol01goo00<007ooOol0_goo002LOol00`00Oomoo`08Ool00`00Oomo
o`2nOol009aoo`8000Uoo`03001oogoo0;ioo`00W7oo00<007ooOol02Goo00<007ooOol0_Goo002L
Ool00`00Oomoo`09Ool00`00Oomoo`2mOol009aoo`03001oogoo00Uoo`04001oogooOol3002iOol0
085oo`<000Eoo`<000Aoo`<000Uoo`03001oogoo00Yoo`<0009oo`03001oogoo0;Moo`00P7oo00D0
07ooOomoo`0000=oo`05001oogooOol00002Ool01@00Oomoogoo000027oo00<007ooOol047oo00<0
07ooOol0]Woo001oOol00`00Oomoo`03Ool00`00Ool00005Ool20005Ool00`00Oomoo`05Ool00`00
Oomoo`0AOol00`00Oomoo`2eOol007moo`03001oogoo00=oo`03001oo`0000Eoo`8000Eoo`03001o
ogoo00Eoo`<0019oo`03001oogoo0;Aoo`00P7oo00D007ooOomoo`00009oo`03001oogoo00=oo`80
00Eoo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo0;Aoo`00PGoo0`000goo00<007ooOol0
0goo0P001Goo00<007ooOol01Goo00<007ooOol04goo00<007ooOol0/goo0020Ool01@00Oomoogoo
00000Woo00<007ooOol00goo0P001Goo00<007ooOol01Goo00<007ooOol04goo00<007ooOol0/goo
001oOol00`00Oomoo`03Ool00`00Ool00005Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`0COol0
0`00Oomoo`2cOol0081oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomoo`00
00Qoo`03001oogoo01Aoo`800;=oo`00PGoo0`001Goo0`0017oo0`002Goo00<007ooOol05Woo00<0
07ooOol0/7oo002LOol2000GOol00`00Oomoo`2`Ool009aoo`03001oogoo01Moo`03001oogoo0:mo
o`00W7oo00<007ooOol05goo00<007ooOol0[goo002LOol00`00Oomoo`0HOol00`00Oomoo`2^Ool0
09aoo`03001oogoo01Uoo`03001oogoo0:eoo`00W7oo00<007ooOol06Goo00<007ooOol00`00ZWoo
002LOol00`00Oomoo`0JOol20003Ool00`00Oomoo`2WOol009aoo`80025oo`03001oogoo0:Ioo`00
W7oo00<007ooOol087oo00<007ooOol0YWoo002LOol00`00Oomoo`0QOol00`00Oomoo`2UOol009ao
o`03001oogoo025oo`03001oogoo0:Eoo`00W7oo00<007ooOol08Goo00<007ooOol0YGoo002LOol0
0`00Oomoo`0ROol00`00Oomoo`2TOol009aoo`03001oogoo02=oo`03001oogoo0:=oo`00W7oo0P00
9Goo00<007ooOol0XWoo002LOol00`00Oomoo`0UOol00`00Oomoo`2QOol009aoo`03001oogoo02Io
o`03001oogoo0:1oo`00W7oo00<007ooOol09goo00<007ooOol0Wgoo001jOol30005Ool30004Ool3
0005Ool30008Ool00`00Oomoo`0WOol00`00Oomoo`2OOol007]oo`03001oogoo00=oo`05001oogoo
Ool00002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Moo`03001oogoo02Qoo`03001oogoo
09ioo`00Ngoo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007oo00001Goo00<007ooOol0
17oo0`00:7oo00<007ooOol0WWoo001kOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00
Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`0YOol00`00Oomoo`03002JOol007]oo`03001oogoo
009oo`03001oogoo00=oo`8000Eoo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo02Yoo`80
009oo`03001oogoo09Qoo`00Ngoo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007oo0000
1Goo00<007ooOol017oo00<007ooOol0;goo00<007ooOol0Ugoo001kOol00`00Oomoo`02Ool00`00
Oomoo`03Ool20005Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`0`Ool00`00Oomoo`2F
Ool007]oo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oo`0000Eoo`03001oogoo00Ao
o`03001oogoo035oo`03001oogoo09Eoo`00NWoo0P001Goo00D007ooOomoo`00009oo`05001oogoo
Ool00003Ool01@00Oomoogoo00001goo00<007ooOol0<Goo00<007ooOol0UGoo001kOol00`00Oomo
o`04Ool30004Ool30005Ool30008Ool2000cOol00`00Oomoo`2DOol009aoo`03001oogoo039oo`03
001oogoo09Aoo`00W7oo00<007ooOol0<goo0P00U7oo002LOol00`00Oomoo`0eOol00`00Oomoo`2A
Ool009aoo`03001oogoo03Eoo`03001oogoo095oo`00W7oo00<007ooOol0=Woo00<007ooOol0T7oo
002LOol00`00Oomoo`0fOol00`00Oomoo`2@Ool009aoo`8003Qoo`03001oogoo08moo`00W7oo00<0
07ooOol0>7oo00<007ooOol0SWoo002LOol00`00Oomoo`0hOol00`00Oomoo`02Ool00`00Oomoo`29
Ool009aoo`03001oogoo03Uoo`06001oo`00001oo`00RWoo002LOol00`00Oomoo`0jOol00`00Oomo
o`02Ool00`00Oomoo`27Ool009aoo`03001oogoo03moo`03001oogoo08Moo`00W7oo00<007ooOol0
@7oo00<007ooOol0QWoo002LOol20011Ool00`00Oomoo`26Ool009aoo`03001oogoo045oo`03001o
ogoo08Eoo`00W7oo00<007ooOol0@Goo0P00QWoo002LOol00`00Oomoo`13Ool00`00Oomoo`23Ool0
07Yoo`<000=oo`H000=oo`<000Eoo`<000Qoo`03001oogoo04Aoo`03001oogoo089oo`00Ngoo00<0
07ooOol00Woo00<007ooOol00goo00<007oo00000goo00D007ooOomoo`0000=oo`03001oogoo00Eo
o`03001oogoo04Aoo`03001oogoo089oo`00Ngoo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007oo00001Goo00<007ooOol017oo00<007ooOol0AGoo00<007ooOol0PGoo001kOol0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`04Ool3
0016Ool00`00Oomoo`20Ool007]oo`03001oogoo00Eoo`05001oogooOol00005Ool00`00Ool00005
Ool00`00Oomoo`04Ool00`00Oomoo`16Ool00`00Oomoo`20Ool007]oo`03001oogoo00Ioo`04001o
ogoo0005Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`17Ool00`00Oomoo`1oOol007]o
o`03001oogoo00Moo`03001oo`0000Eoo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo04Mo
o`03001oogoo00Eooc/003moo`00Ngoo00<007ooOol00Woo00<007ooOol00Woo00<007oo00001Goo
00<007oo00001Goo00<007ooOol017oo00<007ooOol0B7oo00@007ooOomoo`<007Yoo`00NWoo0P00
1Goo00@007ooOol000=oo`05001oogooOol00003Ool01@00Oomoogoo00001goo00<007ooOol0BGoo
00<007oo0000OGoo001kOol00`00Oomoo`04Ool20005Ool30005Ool30008Ool00`00Oomoo`1:Ool0
0`00Oomoo`1lOol009aoo`800<Yoo`00W7oo00<007ooOol0bGoo002LOol00`00Oomoo`39Ool009ao
o`03001oogoo0<Uoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUo
o`00ogooJGoo003oOomYOol00?moofUoo`00Vgoo0P00bgoo002GOol30002Ool00`00Oomoo`0<Ool3
002jOol009Moo`03001oogoo009oo`03001oogoo00ioo`03001oogoo0;Qoo`00RWoo1P001goo00<0
07ooOol00Woo00D007oo000007oo008000Eoo`<0009oo`03001oogoo0;Qoo`00Rgoo00D007ooOomo
o`0000Moo`03001oogoo00=oo`03001oogoo00800003Ool007oo00Aoo`05001oogooOol0002jOol0
08aoo`03001oogoo00Qoo`03001oogoo00=oo`05001oogooOol00007Ool01@00Oomoogoo0000^Woo
002<Ool00`00Oomoo`08Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo00D007ooOomoo`000;Yo
o`00SGoo00<007ooOol01goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00D007oo
Oomoo`000;Yoo`00RWoo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`05001oogooOol00005Ool3
0002Ool00`00Oomoo`2hOol008Yoo`H00003Ool007oo00Aoo`03001oogoo00Aoo`05001oogooOol0
0006Ool00`00Ool00002002jOol0095oo`03001oogoo00=oo`03001oogoo01=oo`03001oogoo0;Qo
o`00TGoo00<007ooOol00goo00<007ooOol04goo00<007ooOol0^7oo002AOol00`00Oomoo`03Ool3
000AOol3002jOol00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-341.207, -159.18, 2.72438, 
  9.1528}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.00155618 1.55355 0.00153833 [
[.03315 .15655 -15.125 -14 ]
[.03315 .15655 15.125 0 ]
[.18876 .15655 -15.125 -14 ]
[.18876 .15655 15.125 0 ]
[.34438 .15655 -15.125 -14 ]
[.34438 .15655 15.125 0 ]
[.65562 .15655 -11 -14 ]
[.65562 .15655 11 0 ]
[.81124 .15655 -11 -14 ]
[.81124 .15655 11 0 ]
[.96685 .15655 -11 -14 ]
[.96685 .15655 11 0 ]
[1.025 .16905 0 -7 ]
[1.025 .16905 38.125 7 ]
[.4875 .01522 -36.25 -7 ]
[.4875 .01522 0 7 ]
[.4875 .32289 -30.25 -7 ]
[.4875 .32289 0 7 ]
[.4875 .47672 -30.25 -7 ]
[.4875 .47672 0 7 ]
[.5 .64303 -18.2188 0 ]
[.5 .64303 18.2188 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03315 .16905 m
.03315 .1753 L
s
gsave
.03315 .15655 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18876 .16905 m
.18876 .1753 L
s
gsave
.18876 .15655 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.34438 .16905 m
.34438 .1753 L
s
gsave
.34438 .15655 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.65562 .16905 m
.65562 .1753 L
s
gsave
.65562 .15655 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81124 .16905 m
.81124 .1753 L
s
gsave
.81124 .15655 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.96685 .16905 m
.96685 .1753 L
s
gsave
.96685 .15655 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(300) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.06427 .16905 m
.06427 .1728 L
s
.09539 .16905 m
.09539 .1728 L
s
.12652 .16905 m
.12652 .1728 L
s
.15764 .16905 m
.15764 .1728 L
s
.21989 .16905 m
.21989 .1728 L
s
.25101 .16905 m
.25101 .1728 L
s
.28214 .16905 m
.28214 .1728 L
s
.31326 .16905 m
.31326 .1728 L
s
.37551 .16905 m
.37551 .1728 L
s
.40663 .16905 m
.40663 .1728 L
s
.43775 .16905 m
.43775 .1728 L
s
.46888 .16905 m
.46888 .1728 L
s
.53112 .16905 m
.53112 .1728 L
s
.56225 .16905 m
.56225 .1728 L
s
.59337 .16905 m
.59337 .1728 L
s
.62449 .16905 m
.62449 .1728 L
s
.68674 .16905 m
.68674 .1728 L
s
.71786 .16905 m
.71786 .1728 L
s
.74899 .16905 m
.74899 .1728 L
s
.78011 .16905 m
.78011 .1728 L
s
.84236 .16905 m
.84236 .1728 L
s
.87348 .16905 m
.87348 .1728 L
s
.90461 .16905 m
.90461 .1728 L
s
.93573 .16905 m
.93573 .1728 L
s
.00202 .16905 m
.00202 .1728 L
s
.99798 .16905 m
.99798 .1728 L
s
.25 Mabswid
0 .16905 m
1 .16905 L
s
gsave
1.025 .16905 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.625000 14.000000 moveto
(@) show
74.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.187500 14.000000 moveto
(D) show
97.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.5 .01522 m
.50625 .01522 L
s
gsave
.4875 .01522 -97.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .32289 m
.50625 .32289 L
s
gsave
.4875 .32289 -91.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(800) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .47672 m
.50625 .47672 L
s
gsave
.4875 .47672 -91.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(700) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.125 Mabswid
.5 .04599 m
.50375 .04599 L
s
.5 .07675 m
.50375 .07675 L
s
.5 .10752 m
.50375 .10752 L
s
.5 .13829 m
.50375 .13829 L
s
.5 .19982 m
.50375 .19982 L
s
.5 .23059 m
.50375 .23059 L
s
.5 .26135 m
.50375 .26135 L
s
.5 .29212 m
.50375 .29212 L
s
.5 .35365 m
.50375 .35365 L
s
.5 .38442 m
.50375 .38442 L
s
.5 .41519 m
.50375 .41519 L
s
.5 .44595 m
.50375 .44595 L
s
.5 .50749 m
.50375 .50749 L
s
.5 .53825 m
.50375 .53825 L
s
.5 .56902 m
.50375 .56902 L
s
.5 .59979 m
.50375 .59979 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -79.2188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
71.312500 14.000000 moveto
(@) show
75.812500 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(m) show
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(m) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
91.500000 14.000000 moveto
(D) show
95.437500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Math2
%%+ font Times-Roman
grestore
.5 Mabswid
.02381 .01522 m
.0286 .01522 L
.03338 .01522 L
.03817 .01522 L
.04295 .01522 L
.04774 .01522 L
.05252 .01522 L
.05731 .01522 L
.0621 .01522 L
.06688 .01522 L
.07167 .01522 L
.07645 .01522 L
.08124 .01522 L
.08603 .01522 L
.09081 .01522 L
.0956 .01522 L
.10038 .01522 L
.10517 .01522 L
.10995 .01522 L
.11474 .01522 L
.11953 .01522 L
.12431 .01522 L
.1291 .01522 L
.13388 .01522 L
.13867 .01522 L
.14346 .01522 L
.14824 .01522 L
.15303 .01522 L
.15781 .01522 L
.1626 .01522 L
.16738 .01522 L
.17217 .01522 L
.17696 .01522 L
.18174 .01522 L
.18653 .01521 L
.19131 .01521 L
.1961 .01521 L
.20089 .01521 L
.20567 .0152 L
.21046 .01519 L
.21524 .01518 L
.22003 .01515 L
.22481 .01512 L
.2296 .01507 L
.23439 .01499 L
.23917 .01488 L
.24396 .01476 L
.24874 .01472 L
.25353 .01479 L
.25832 .01499 L
Mistroke
.2631 .01526 L
.26789 .01558 L
.27267 .01599 L
.27746 .0165 L
.28224 .0171 L
.28703 .01772 L
.29182 .01831 L
.2966 .01889 L
.30139 .01952 L
.30617 .02025 L
.31096 .02108 L
.31575 .02199 L
.32053 .02294 L
.32532 .02397 L
.3301 .02511 L
.33489 .02634 L
.33967 .0276 L
.34446 .02882 L
.34925 .03002 L
.35403 .03127 L
.35882 .03263 L
.3636 .03408 L
.36839 .03561 L
.37318 .03718 L
.37796 .03883 L
.38275 .04059 L
.38753 .04244 L
.39232 .04432 L
.3971 .04616 L
.40189 .04799 L
.40668 .04986 L
.41146 .05183 L
.41625 .0539 L
.42103 .05604 L
.42582 .05823 L
.43061 .06049 L
.43539 .06286 L
.44018 .06532 L
.44496 .06781 L
.44975 .07027 L
.45453 .07271 L
.45932 .07519 L
.46411 .07776 L
.46889 .08044 L
.47368 .08318 L
.47846 .08597 L
.48325 .08884 L
.48804 .0918 L
.49282 .09486 L
.49761 .09795 L
Mistroke
.50239 .10102 L
.50718 .10406 L
.51196 .10713 L
.51675 .1103 L
.52154 .11357 L
.52632 .1169 L
.53111 .12029 L
.53589 .12374 L
.54068 .12729 L
.54547 .13093 L
.55025 .13461 L
.55504 .13826 L
.55982 .14189 L
.56461 .14555 L
.56939 .1493 L
.57418 .15314 L
.57897 .15706 L
.58375 .16102 L
.58854 .16504 L
.59332 .16916 L
.59811 .17337 L
.6029 .17761 L
.60768 .18184 L
.61247 .18604 L
.61725 .19027 L
.62204 .19457 L
.62682 .19898 L
.63161 .20345 L
.6364 .20797 L
.64118 .21254 L
.64597 .21721 L
.65075 .22196 L
.65554 .22676 L
.66033 .23154 L
.66511 .23629 L
.6699 .24107 L
.67468 .24592 L
.67947 .25086 L
.68425 .25587 L
.68904 .26092 L
.69383 .26603 L
.69861 .27123 L
.7034 .27651 L
.70818 .28183 L
.71297 .28714 L
.71776 .29243 L
.72254 .29773 L
.72733 .3031 L
.73211 .30856 L
.7369 .31409 L
Mistroke
.74168 .31966 L
.74647 .32529 L
.75126 .33102 L
.75604 .33684 L
.76083 .34271 L
.76561 .34859 L
.7704 .35444 L
.77519 .36026 L
.77997 .36607 L
.78476 .37187 L
.78954 .37767 L
.79433 .38346 L
.79911 .38925 L
.8039 .39504 L
.80869 .40083 L
.81347 .40661 L
.81826 .4124 L
.82304 .41819 L
.82783 .42397 L
.83262 .42976 L
.8374 .43554 L
.84219 .44133 L
.84697 .44712 L
.85176 .4529 L
.85654 .45869 L
.86133 .46447 L
.86612 .47026 L
.8709 .47604 L
.87569 .48183 L
.88047 .48761 L
.88526 .4934 L
.89005 .49918 L
.89483 .50497 L
.89962 .51075 L
.9044 .51654 L
.90919 .52232 L
.91397 .52811 L
.91876 .5339 L
.92355 .53968 L
.92833 .54547 L
.93312 .55125 L
.9379 .55704 L
.94269 .56282 L
.94748 .56861 L
.95226 .57439 L
.95705 .58018 L
.96183 .58596 L
.96662 .59175 L
.9714 .59753 L
.97619 .60332 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
W7oo00<007ooOol0bGoo002LOol00`00Oomoo`39Ool007Yoo`<000Eoo`<000Aoo`<000Eoo`<000Qo
o`03001oogoo0<Uoo`00Ngoo00<007ooOol00goo00D007ooOomoo`00009oo`05001oogooOol00003
Ool01@00Oomoogoo00001goo00<007ooOol0bGoo001kOol00`00Oomoo`02Ool00`00Oomoo`03Ool2
0005Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`39Ool0011oodd0019oo`P000Aoo`03
001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oo`0000Eoo`03001oogoo00Aoo`<00<Uoo`00
GGoo1`005goo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007oo00001Goo00<007ooOol0
17oo00<007ooOol0bGoo001TOol6000AOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00
Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`39Ool006Yoo`<000ioo`03001oogoo009oo`03001o
ogoo00=oo`8000Eoo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo0<Uoo`00KGoo10002Woo
00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007oo00001Goo00<007ooOol017oo00<007oo
Ool0bGoo001aOol40005Ool20005Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000=oo`05001o
ogooOol00007Ool00`00Oomoo`39Ool007Eoo`<000=oo`03001oogoo00Aoo`<000Aoo`<000Eoo`<0
00Qoo`03001oogoo0<Uoo`00N7oo0`008Goo00<007ooOol0bGoo001kOol3000NOol00`00Oomoo`39
Ool007ioo`03001oogoo01]oo`800<Yoo`00Ogoo0`006Woo00<007ooOol0bGoo0022Ool3000GOol0
0`00Oomoo`39Ool008Eoo`03001oogoo01Aoo`03001oogoo0<Uoo`00QWoo0`004goo00<007ooOol0
bGoo0029Ool00`00Oomoo`0@Ool00`00Oomoo`39Ool008Yoo`<000moo`03001oogoo0<Uoo`00SGoo
0P003Goo00<007ooOol0bGoo002?Ool00`00Oomoo`0:Ool00`00Oomoo`39Ool0091oo`<000Uoo`80
0<Yoo`00Tgoo00<007ooOol01Woo00<007ooOol0bGoo002DOol20006Ool00`00Oomoo`39Ool009Io
o`03001oogoo00=oo`03001oogoo0<Uoo`00Ugoo0`000Woo00<007ooOol0bGoo002JOol00`00Ool0
003;Ool009]oo`800<]oo`00W7oo0P00bWoo002LOol01000Ool00000b7oo002LOol20002Ool00`00
Oomoo`35Ool009aoo`03001oogoo009oo`03001oogoo0<Aoo`00W7oo00<007ooOol00goo0P00a7oo
000<Ool40006Ool30004Ool3000JOol60004Ool30004Ool3000LOol30005Ool30004Ool3000POol0
0`00Oomoo`05Ool00`00Oomoo`0JOol30005Ool30004Ool3000JOol60004Ool30004Ool3000IOol4
0006Ool30004Ool3000jOol0011oo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomoogoo
00006Goo00<007ooOol00goo00@007ooOol000=oo`04001oogoo0003Ool00`00Oomoo`0JOol00`00
Oomoo`03Ool01@00Oomoogoo00000Woo00D007ooOomoo`0001moo`03001oogoo00Ioo`8001]oo`03
001oogoo00=oo`05001oogooOol00002Ool01@00Oomoogoo00006Goo00<007ooOol00goo00@007oo
Ool000=oo`04001oogoo0003Ool00`00Oomoo`0JOol00`00Oomoo`02Ool01@00Oomoogoo00000Woo
00D007ooOomoo`0003Uoo`004Goo00@007ooOol000Eoo`8000Eoo`03001oogoo01Moo`03001oogoo
00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00=oo`80
00Eoo`03001oogoo01aoo`03001oogoo00Qoo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo
00=oo`8000Eoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo
01Yoo`04001oogoo0005Ool20005Ool00`00Oomoo`0fOol000=oo`P000Ioo`04001oogoo0005Ool2
0005Ool00`00Oomoo`0=Ool80003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20005Ool00`00Oomo
o`0=Ool80004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0LOol00`00Oomo
o`09Ool00`00Oomoo`0GOol00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0HOol0
0`00Oomoo`03Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0JOol01000Oomoo`001Goo0P001Goo
00<007ooOol0=Woo000AOol01000Oomoo`001Goo0P001Goo00<007ooOol06Goo00<007ooOol00Woo
00<007ooOol00goo0P001Goo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol00goo0P001Goo
00<007ooOol077oo00<007ooOol02Woo0P005goo00<007ooOol00Woo00<007ooOol00goo0P001Goo
00<007ooOol06Goo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol06Woo00@007oo
Ool000Eoo`8000Eoo`03001oogoo03Ioo`003Woo0`000goo00<007ooOol00goo0P001Goo00<007oo
Ool06Woo00D007ooOomoo`0000Eoo`8000Eoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo
00=oo`8000Eoo`03001oogoo01aoo`03001oogoo00aoo`03001oogoo01Aoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo01Yoo`05001oogooOol00005Ool20005Ool00`00Oomoo`0G
Ool30003Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0fOol000moo`03001oogoo009oo`03001o
ogoo00=oo`8000Eoo`03001oogoo01]oo`04001oogoo0005Ool20005Ool00`00Oomoo`0IOol00`00
Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0LOol2000>Ool2000DOol00`00Oomoo`02
Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0KOol01000Oomoo`001Goo0P001Goo00<007ooOol0
67oo00<007ooOol00Woo00<007ooOol00goo0P001Goo00<007ooOol0=Woo000@Ool01@00Oomoogoo
00001Goo0P001Goo00<007ooOol05Woo00<007ooOol00Woo00@007ooOol000Eoo`8000Eoo`03001o
ogoo01Uoo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo01aoo`03001oogoo00mo
o`03001oogoo015oo`03001oogoo009oo`03001oogoo00=oo`8000Eoo`03001oogoo01Ioo`03001o
ogoo009oo`04001oogoo0005Ool20005Ool00`00Oomoo`0IOol01@00Oomoogoo00001Goo0P001Goo
00<007ooOol0=Woo000<Ool01@00Oomoogoo000017oo00D007ooOomoo`00009oo`05001oogooOol0
000JOol01000Oomoo`0017oo00D007ooOomoo`00009oo`05001oogooOol0000KOol20005Ool01@00
Oomoogoo00000Woo00D007ooOomoo`0001moo`03001oogoo011oo`80011oo`8000Eoo`05001oogoo
Ool00002Ool01@00Oomoogoo00006Woo00@007ooOol000Aoo`05001oogooOol00002Ool01@00Oomo
ogoo000067oo00D007ooOomoo`0000Aoo`05001oogooOol00002Ool01@00Oomoogoo0000>Goo000=
Ool30006Ool30004Ool3000LOol20006Ool30004Ool3000MOol00`00Oomoo`04Ool30004Ool3000P
Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`04Ool30004Ool3000LOol20006Ool30004
Ool3000JOol30006Ool30004Ool3000jOol009aoo`03001oogoo019oo`03001oogoo08moo`<001]o
o`<000Aoo`00W7oo00<007ooOol04goo00<007ooOol0SWoo00<007ooOol07Goo00<007ooOol00Woo
002LOol00`00Oomoo`0DOol20025Ool30006Ool00`00Oomoo`02Ool300001Goo00000000Ool00`00
00Eoo`00000007oo00<00004Ool000000004Ool00`00Oomoo`02Ool009aoo`03001oogoo01Ioo`03
001oogoo089oo`04001oogoo0005Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool009aoo`03001oogoo01Moo`8008Eoo`03
001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Eoo`03001oogoo009oo`002Gooo`00:0002goo0P001Woo00<007ooOol00goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo0009Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool0
019oo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo01Yoo`03001oogoo
00ioo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo015oo`04001oogoo0005Ool00`00Oomo
o`02Ool30002Ool20002Ool00`00Oomoo`030002Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool009aoo`03001oogoo01]oo`8007moo`<000Eoo`03001oogoo00=oo`04001oo`000002Ool20004
Ool01000Ool000000Woo0P001Woo00<007ooOol00Woo002LOol00`00Oomoo`0MOol00`00Oomoo`24
Ool00`00Oomoo`0MOol00`00Oomoo`02Ool009aoo`03001oogoo01ioo`8008Aoo`03001oogoo01eo
o`03001oogoo009oo`00W7oo00<007ooOol087oo00<007ooOol0PGoo0`006goo0`0017oo002LOol0
0`00Oomoo`0POol00`00Oomoo`2VOol009aoo`03001oogoo025oo`03001oogoo0:Eoo`00W7oo0P00
8goo0P00YGoo002LOol00`00Oomoo`0TOol00`00Oomoo`2ROol009aoo`03001oogoo02Aoo`03001o
ogoo0:9oo`00W7oo00<007ooOol09Goo0P00XWoo002LOol00`00Oomoo`0WOol00`00Oomoo`2OOol0
09aoo`03001oogoo02Qoo`03001oogoo09ioo`00W7oo00<007ooOol0:Goo00<007ooOol0WGoo002L
Ool00`00Oomoo`0ZOol00`00Oomoo`2LOol009aoo`03001oogoo02]oo`03001oogoo09]oo`00W7oo
0P00;7oo00<007ooOol0Vgoo002LOol00`00Oomoo`0/Ool2002KOol009aoo`03001oogoo02ioo`03
001oogoo09Qoo`00W7oo00<007ooOol0;goo00<007ooOol0Ugoo002LOol00`00Oomoo`0`Ool00`00
Oomoo`2FOol009aoo`03001oogoo035oo`03001oogoo09Eoo`00W7oo00<007ooOol0<Woo00<007oo
Ool0U7oo002LOol00`00Oomoo`0bOol00`00Oomoo`2DOol009aoo`03001oogoo03=oo`8009Aoo`00
W7oo0P00=Woo00<007ooOol0TGoo002LOol00`00Oomoo`0eOol00`00Oomoo`2AOol009aoo`03001o
ogoo03Ioo`80095oo`00W7oo00<007ooOol0>7oo00<007ooOol0SWoo002LOol00`00Oomoo`0hOol0
0`00Oomoo`2>Ool009aoo`03001oogoo03Uoo`03001oogoo08eoo`00W7oo00<007ooOol0>Woo00<0
07ooOol0S7oo002LOol00`00Oomoo`0kOol00`00Oomoo`2;Ool009aoo`03001oogoo03aoo`03001o
ogoo08Yoo`00W7oo00<007ooOol0?7oo00<007ooOol0RWoo002LOol2000nOol2002:Ool009aoo`03
001oogoo03moo`03001oogoo08Moo`00W7oo00<007ooOol0?goo00<007ooOol0Qgoo002LOol00`00
Oomoo`10Ool00`00Oomoo`26Ool009aoo`03001oogoo045oo`03001oogoo08Eoo`00W7oo00<007oo
Ool0@Woo00<007ooOol0Q7oo0021Ool30005Ool30004Ool30009Ool00`00Oomoo`13Ool00`00Oomo
o`23Ool0081oo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Qoo`03
001oogoo04=oo`03001oogoo08=oo`00Ogoo00<007ooOol00goo00<007oo00001Goo0P001Goo00<0
07ooOol01Goo00<007ooOol0A7oo0P00Pgoo001fOol800000goo001oo`04Ool00`00Ool00005Ool2
0005Ool00`00Oomoo`05Ool30016Ool00`00Oomoo`20Ool0081oo`05001oogooOol00002Ool00`00
Oomoo`03Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`16Ool00`00Oomoo`20Ool0085oo`<000=o
o`03001oogoo00=oo`8000Eoo`03001oogoo00Eoo`03001oogoo04Moo`03001oogoo07moo`00P7oo
00D007ooOomoo`00009oo`03001oogoo00=oo`8000Eoo`03001oogoo00Eoo`03001oogoo04Qoo`03
001oogoo07ioo`00Ogoo00<007ooOol00goo00<007oo00001Goo0P001Goo00<007ooOol01Goo00<0
07ooOol0BGoo00<007ooOol0OGoo0020Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`05
001oogooOol00008Ool00`00Oomoo`1:Ool00`00Oomoo`1lOol0085oo`<000Eoo`<000Aoo`<000Uo
o`03001oogoo04Yoo`03001oogoo07aoo`00W7oo00<007ooOol0Bgoo00<007ooOol0Ngoo002LOol0
0`00Oomoo`1<Ool00`00Oomoo`1jOol009aoo`8004ioo`03001oogoo07Uoo`00W7oo00<007ooOol0
CGoo00<007ooOol0NGoo002LOol00`00Oomoo`1>Ool2001iOol009aoo`03001oogoo051oo`03001o
ogoo07Ioo`00W7oo00<007ooOol0D7oo00<007ooOol0MWoo002LOol00`00Oomoo`1AOol00`00Oomo
o`1eOol009aoo`03001oogoo055oo`03001oogoo07Eoo`00W7oo00<007ooOol0DWoo0P00MGoo002L
Ool00`00Oomoo`1DOol00`00Oomoo`1bOol009aoo`8005Eoo`03001oogoo079oo`00W7oo00<007oo
Ool0EGoo00<007ooOol0LGoo002LOol00`00Oomoo`1FOol00`00Oomoo`1`Ool009aoo`03001oogoo
05Moo`03001oogoo06moo`00W7oo00<007ooOol0Egoo00<007ooOol0Kgoo002LOol00`00Oomoo`1H
Ool00`00Oomoo`1^Ool009aoo`03001oogoo05Uoo`03001oogoo06eoo`00W7oo00<007ooOol0FWoo
00<007ooOol0K7oo002LOol00`00Oomoo`1KOol00`00Oomoo`1[Ool009aoo`8005aoo`03001oogoo
06]oo`00W7oo00<007ooOol0G7oo0P00Jgoo002LOol00`00Oomoo`1NOol00`00Oomoo`1XOol009ao
o`03001oogoo05ioo`03001oogoo06Qoo`00W7oo00<007ooOol0Ggoo00<007ooOol0Igoo002LOol0
0`00Oomoo`1POol00`00Oomoo`1VOol009aoo`03001oogoo065oo`03001oogoo06Eoo`00W7oo00<0
07ooOol0HGoo00<007ooOol0IGoo002LOol00`00Oomoo`1ROol00`00Oomoo`1TOol009aoo`8006Ao
o`03001oogoo06=oo`00W7oo00<007ooOol0I7oo00<007ooOol0HWoo002LOol00`00Oomoo`1UOol0
0`00Oomoo`1QOol009aoo`03001oogoo06Eoo`03001oogoo065oo`00W7oo00<007ooOol0IWoo0P00
HGoo002LOol00`00Oomoo`1XOol00`00Oomoo`1NOol0089oo`03001oogoo00Aoo`<000Aoo`<000Uo
o`03001oogoo06Qoo`03001oogoo05ioo`00PWoo00<007ooOol00goo00D007ooOomoo`00009oo`05
001oogooOol00008Ool00`00Oomoo`1YOol00`00Oomoo`1MOol0089oo`03001oogoo009oo`03001o
ogoo00=oo`8000Eoo`03001oogoo00Eoo`03001oogoo06Uoo`03001oogoo05eoo`00MWoo20001Goo
00D007ooOomoo`0000Eoo`8000Eoo`03001oogoo00Eoo`<006Yoo`8005eoo`00Pgoo00D007ooOomo
o`0000Eoo`8000Eoo`03001oogoo00Eoo`03001oogoo06aoo`03001oogoo05Yoo`00Pgoo00D007oo
Oomoo`0000Eoo`8000Eoo`03001oogoo00Eoo`03001oogoo06aoo`03001oogoo05Yoo`00Q7oo00@0
07ooOol000Eoo`8000Eoo`03001oogoo00Eoo`03001oogoo06eoo`03001oogoo05Uoo`00Q7oo00@0
07ooOol000Eoo`8000Eoo`03001oogoo00Eoo`03001oogoo06ioo`03001oogoo05Qoo`00Ogoo00<0
07ooOol00goo00@007ooOol000=oo`04001oogoo0003Ool00`00Oomoo`06Ool00`00Oomoo`1_Ool0
0`00Oomoo`1GOol0081oo`H000=oo`<000Aoo`<000Uoo`03001oogoo06moo`03001oogoo05Moo`00
W7oo00<007ooOol0L7oo00<007ooOol0EWoo002LOol00`00Oomoo`1aOol00`00Oomoo`1EOol009ao
o`8007=oo`03001oogoo05Aoo`00W7oo00<007ooOol0Lgoo00<007ooOol0Dgoo002LOol00`00Oomo
o`1cOol00`00Oomoo`1COol009aoo`03001oogoo07Aoo`8005=oo`00W7oo00<007ooOol0MWoo00<0
07ooOol0D7oo002LOol00`00Oomoo`1fOol00`00Oomoo`1@Ool009aoo`03001oogoo07Moo`03001o
ogoo04moo`00W7oo00<007ooOol0N7oo00<007ooOol0CWoo002LOol00`00Oomoo`1iOol00`00Oomo
o`1=Ool009aoo`8007Yoo`03001oogoo04eoo`00W7oo00<007ooOol0NWoo00<007ooOol0C7oo002L
Ool00`00Oomoo`1kOol00`00Oomoo`1;Ool009aoo`03001oogoo07aoo`03001oogoo04Yoo`00W7oo
00<007ooOol0OGoo00<007ooOol0BGoo002LOol00`00Oomoo`1mOol00`00Oomoo`19Ool009aoo`03
001oogoo07ioo`8004Uoo`00W7oo00<007ooOol0P7oo00<007ooOol0AWoo002LOol00`00Oomoo`20
Ool00`00Oomoo`16Ool009aoo`80089oo`03001oogoo04Eoo`00W7oo00<007ooOol0PGoo00<007oo
Ool0AGoo002LOol00`00Oomoo`22Ool20015Ool009aoo`03001oogoo08Aoo`03001oogoo049oo`00
W7oo00<007ooOol0Q7oo00<007ooOol0@Woo002LOol00`00Oomoo`25Ool00`00Oomoo`11Ool009ao
o`03001oogoo08Ioo`03001oogoo041oo`00W7oo00<007ooOol0Qgoo00<007ooOol0?goo002LOol0
0`00Oomoo`27Ool00`00Oomoo`0oOol009aoo`8008Uoo`03001oogoo03ioo`00W7oo00<007ooOol0
RGoo00<007ooOol0?Goo002LOol00`00Oomoo`39Ool009aoo`03001oogoo0<Uoo`00W7oo00<007oo
Ool0bGoo002LOol00`00Oomoo`39Ool009aoo`03001oogoo0<Uoo`00ogooJGoo003oOomYOol00?mo
ofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00Ugoo0P00
cgoo002BOol30003Ool00`00Oomoo`0BOol3002hOol0099oo`03001oogoo00=oo`03001oogoo01Ao
o`03001oogoo0;Ioo`00R7oo1P0017oo00<007ooOol00goo00D007oo000007oo008000Aoo`<00005
Ool00000001oo`0300000goo001oo`2gOol008Uoo`05001oogooOol00004Ool00`00Oomoo`04Ool0
0`00Oomoo`0200000goo001oo`03Ool01@00Oomoogoo00000goo00@007ooOol00;Qoo`00RWoo00<0
07ooOol01Goo00<007ooOol017oo00D007ooOomoo`0000Ioo`05001oogooOol00003Ool01000Oomo
o`00^7oo002:Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01@00Oomoogoo00001Woo00D007ooOomo
o`0000=oo`04001oogoo002hOol008]oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo00=oo`05001oogooOol00003Ool01000Oomoo`00^7oo0028Ool01@00Oomoogoo0000
1Goo00<007ooOol01Goo00D007ooOomoo`0000Aoo`<0009oo`80009oo`04001oogoo002hOol008Qo
o`H000Aoo`03001oogoo00Eoo`05001oogooOol00005Ool01000Ool000000Woo0P000goo00<007oo
Ool0]Woo002BOol00`00Oomoo`0JOol00`00Oomoo`2fOol0099oo`03001oogoo01Yoo`03001oogoo
0;Ioo`00TWoo0`0067oo0`00^7oo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUo
o`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-341.207, -1030.34, 2.72438, 
  2.75599}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computes the Magnetic Field and its  Integrals", "Section"],

Cell["\<\
For comparison, we plot here the vertical field, field integral and \
double field integral as a fiuunction of the longitudinal coordinate. \
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ymax = Period*\((NumberOfPeriod/2 + 6/2)\); \n
    npt = 20*NumberOfPeriod; \nt0 = AbsoluteTime[]; \n
    bz = radFldLst[g, "\<bz\>", {0, \(-ymax\), 0}, {0, ymax, 0}, npt, 
        "\<arg\>", \(-ymax\)]; \n\n (*\ Plot\ the\ Field\ \ *) \n\t
    ListPlot[bz, PlotJoined -> True, \ PlotRange -> All\n\t\t, 
      AxesLabel -> {"\<s [mm]\>", "\<Bz [T]\>"}]; \n
    \n (*\ Plot\ the\ Field\ Integral\ *) \n\t
    ListPlot[\((2*ymax/npt)\)*integ[\(Transpose[bz]\)[\([2]\)]]\n\t, 
      PlotJoined -> True\t, 
      AxesLabel -> {"\<s [mm]\>", "\<\[Integral]Bzds [Tmm]\>"}]; \n
    \n (*\ Plot\ the\ Double\ Field\ Integral\ *) \n\t
    ListPlot[\((2*ymax/npt)\)^2*integ[integ[\(Transpose[bz]\)[\([2]\)]]]\n\t, 
      PlotJoined -> True\t, 
      AxesLabel -> {"\<s [mm]\>", "\<\[Integral]\[Integral]Bzds [Tmm2]\>"}]; 
    \n\t\t\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.0017507 0.307484 0.402788 [
[.14986 .29498 -15.125 -14 ]
[.14986 .29498 15.125 0 ]
[.32493 .29498 -15.125 -14 ]
[.32493 .29498 15.125 0 ]
[.67507 .29498 -11 -14 ]
[.67507 .29498 11 0 ]
[.85014 .29498 -11 -14 ]
[.85014 .29498 11 0 ]
[1.025 .30748 0 -7 ]
[1.025 .30748 38.125 7 ]
[.4875 .06581 -27.25 -7 ]
[.4875 .06581 0 7 ]
[.4875 .14637 -27.25 -7 ]
[.4875 .14637 0 7 ]
[.4875 .22693 -27.25 -7 ]
[.4875 .22693 0 7 ]
[.4875 .38804 -19 -7 ]
[.4875 .38804 0 7 ]
[.4875 .4686 -19 -7 ]
[.4875 .4686 0 7 ]
[.4875 .54916 -19 -7 ]
[.4875 .54916 0 7 ]
[.5 .64303 -17.75 0 ]
[.5 .64303 17.75 14 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14986 .30748 m
.14986 .31373 L
s
gsave
.14986 .29498 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.32493 .30748 m
.32493 .31373 L
s
gsave
.32493 .29498 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.67507 .30748 m
.67507 .31373 L
s
gsave
.67507 .29498 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.85014 .30748 m
.85014 .31373 L
s
gsave
.85014 .29498 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.18487 .30748 m
.18487 .31123 L
s
.21989 .30748 m
.21989 .31123 L
s
.2549 .30748 m
.2549 .31123 L
s
.28992 .30748 m
.28992 .31123 L
s
.35994 .30748 m
.35994 .31123 L
s
.39496 .30748 m
.39496 .31123 L
s
.42997 .30748 m
.42997 .31123 L
s
.46499 .30748 m
.46499 .31123 L
s
.53501 .30748 m
.53501 .31123 L
s
.57003 .30748 m
.57003 .31123 L
s
.60504 .30748 m
.60504 .31123 L
s
.64006 .30748 m
.64006 .31123 L
s
.71008 .30748 m
.71008 .31123 L
s
.7451 .30748 m
.7451 .31123 L
s
.78011 .30748 m
.78011 .31123 L
s
.81513 .30748 m
.81513 .31123 L
s
.11485 .30748 m
.11485 .31123 L
s
.07983 .30748 m
.07983 .31123 L
s
.04482 .30748 m
.04482 .31123 L
s
.0098 .30748 m
.0098 .31123 L
s
.88515 .30748 m
.88515 .31123 L
s
.92017 .30748 m
.92017 .31123 L
s
.95518 .30748 m
.95518 .31123 L
s
.9902 .30748 m
.9902 .31123 L
s
.25 Mabswid
0 .30748 m
1 .30748 L
s
gsave
1.025 .30748 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.625000 14.000000 moveto
(@) show
74.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.187500 14.000000 moveto
(D) show
97.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.5 .06581 m
.50625 .06581 L
s
gsave
.4875 .06581 -88.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .14637 m
.50625 .14637 L
s
gsave
.4875 .14637 -88.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .22693 m
.50625 .22693 L
s
gsave
.4875 .22693 -88.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 .38804 m
.50625 .38804 L
s
gsave
.4875 .38804 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .4686 m
.50625 .4686 L
s
gsave
.4875 .4686 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .54916 m
.50625 .54916 L
s
gsave
.4875 .54916 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.6) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.5 .08595 m
.50375 .08595 L
s
.5 .10609 m
.50375 .10609 L
s
.5 .12623 m
.50375 .12623 L
s
.5 .16651 m
.50375 .16651 L
s
.5 .18665 m
.50375 .18665 L
s
.5 .20679 m
.50375 .20679 L
s
.5 .24707 m
.50375 .24707 L
s
.5 .2672 m
.50375 .2672 L
s
.5 .28734 m
.50375 .28734 L
s
.5 .32762 m
.50375 .32762 L
s
.5 .34776 m
.50375 .34776 L
s
.5 .3679 m
.50375 .3679 L
s
.5 .40818 m
.50375 .40818 L
s
.5 .42832 m
.50375 .42832 L
s
.5 .44846 m
.50375 .44846 L
s
.5 .48874 m
.50375 .48874 L
s
.5 .50888 m
.50375 .50888 L
s
.5 .52902 m
.50375 .52902 L
s
.5 .04567 m
.50375 .04567 L
s
.5 .02553 m
.50375 .02553 L
s
.5 .00539 m
.50375 .00539 L
s
.5 .5693 m
.50375 .5693 L
s
.5 .58944 m
.50375 .58944 L
s
.5 .60957 m
.50375 .60957 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -78.75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bz) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
79.312500 14.000000 moveto
(@) show
83.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(T) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 14.000000 moveto
(D) show
94.500000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.5 Mabswid
.02381 .30745 m
.0286 .30745 L
.03338 .30745 L
.03817 .30744 L
.04295 .30744 L
.04774 .30743 L
.05252 .30742 L
.05731 .30742 L
.0621 .30741 L
.06688 .3074 L
.07167 .30738 L
.07645 .30737 L
.08124 .30735 L
.08603 .30733 L
.09081 .3073 L
.0956 .30727 L
.10038 .30723 L
.10517 .30719 L
.10995 .30713 L
.11474 .30705 L
.11953 .30696 L
.12431 .30684 L
.1291 .30668 L
.13388 .30648 L
.13867 .30621 L
.14346 .30584 L
.14824 .30535 L
.15303 .30466 L
.15781 .3037 L
.1626 .30231 L
.16738 .30029 L
.17217 .29728 L
.17696 .2927 L
.18174 .28555 L
.18653 .27408 L
.19131 .25501 L
.1961 .22282 L
.20089 .17542 L
.20567 .1445 L
.21046 .18451 L
.21524 .29017 L
.22003 .41971 L
.22481 .53703 L
.2296 .60332 L
.23439 .60162 L
.23917 .53096 L
.24396 .4047 L
.24874 .25845 L
.25353 .1236 L
.25832 .03631 L
Mistroke
.2631 .01825 L
.26789 .07083 L
.27267 .18551 L
.27746 .3288 L
.28224 .4679 L
.28703 .56778 L
.29182 .60077 L
.2966 .56321 L
.30139 .45962 L
.30617 .31916 L
.31096 .17636 L
.31575 .06449 L
.32053 .01594 L
.32532 .03796 L
.3301 .12855 L
.33489 .26423 L
.33967 .40895 L
.34446 .5309 L
.34925 .59468 L
.35403 .58806 L
.35882 .51155 L
.3636 .38242 L
.36839 .2371 L
.37318 .10692 L
.37796 .02834 L
.38275 .01953 L
.38753 .08115 L
.39232 .20178 L
.3971 .34632 L
.40189 .48279 L
.40668 .57532 L
.41146 .59956 L
.41625 .55325 L
.42103 .44299 L
.42582 .30064 L
.43061 .15968 L
.43539 .05442 L
.44018 .01472 L
.44496 .04558 L
.44975 .14375 L
.45453 .28235 L
.45932 .42614 L
.46411 .54254 L
.46889 .59764 L
.47368 .58222 L
.47846 .49753 L
.48325 .36443 L
.48804 .21928 L
.49282 .09355 L
.49761 .02335 L
Mistroke
.50239 .02335 L
.50718 .09355 L
.51196 .21928 L
.51675 .36443 L
.52154 .49753 L
.52632 .58222 L
.53111 .59764 L
.53589 .54254 L
.54068 .42614 L
.54547 .28235 L
.55025 .14375 L
.55504 .04558 L
.55982 .01472 L
.56461 .05442 L
.56939 .15968 L
.57418 .30064 L
.57897 .44299 L
.58375 .55325 L
.58854 .59956 L
.59332 .57532 L
.59811 .48279 L
.6029 .34632 L
.60768 .20178 L
.61247 .08115 L
.61725 .01953 L
.62204 .02834 L
.62682 .10692 L
.63161 .2371 L
.6364 .38242 L
.64118 .51155 L
.64597 .58806 L
.65075 .59468 L
.65554 .5309 L
.66033 .40895 L
.66511 .26423 L
.6699 .12855 L
.67468 .03796 L
.67947 .01594 L
.68425 .06449 L
.68904 .17636 L
.69383 .31916 L
.69861 .45962 L
.7034 .56321 L
.70818 .60077 L
.71297 .56778 L
.71776 .4679 L
.72254 .3288 L
.72733 .18551 L
.73211 .07083 L
.7369 .01825 L
Mistroke
.74168 .03631 L
.74647 .1236 L
.75126 .25845 L
.75604 .4047 L
.76083 .53096 L
.76561 .60162 L
.7704 .60332 L
.77519 .53703 L
.77997 .41971 L
.78476 .29017 L
.78954 .18451 L
.79433 .1445 L
.79911 .17542 L
.8039 .22282 L
.80869 .25501 L
.81347 .27408 L
.81826 .28555 L
.82304 .2927 L
.82783 .29728 L
.83262 .30029 L
.8374 .30231 L
.84219 .3037 L
.84697 .30466 L
.85176 .30535 L
.85654 .30584 L
.86133 .30621 L
.86612 .30648 L
.8709 .30668 L
.87569 .30684 L
.88047 .30696 L
.88526 .30705 L
.89005 .30713 L
.89483 .30719 L
.89962 .30723 L
.9044 .30727 L
.90919 .3073 L
.91397 .30733 L
.91876 .30735 L
.92355 .30737 L
.92833 .30738 L
.93312 .3074 L
.9379 .30741 L
.94269 .30742 L
.94748 .30742 L
.95226 .30743 L
.95705 .30744 L
.96183 .30744 L
.96662 .30745 L
.9714 .30745 L
.97619 .30745 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{353.562, 218.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006i000141000`40O003h00Oogoo^Woo003oOonj
Ool00?mookYoo`00_goo00<007ooOol0mgoo002oOol00`00Oomoo`3gOol00;moo`<00?Moo`00_goo
00<007ooOol0mgoo002oOol00`00Oomoo`3gOol00;moo`03001oogoo0?Moo`00Z7oo00<007ooOol0
57oo00<007ooOol057oo00<007ooOol0h7oo001TOol00`00Oomoo`0COol00`00Oomoo`0[Ool00`00
Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0[Ool00`00Oomoo`0COol00`00Oomoo`2LOol006Ao
o`03001oogoo01=oo`03001oogoo01Eoo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo01Ao
o`03001oogoo01=oo`03001oogoo01Eoo`03001oogoo01=oo`03001oogoo09aoo`00I7oo00<007oo
Ool04goo00<007ooOol05Goo00<007ooOol04goo00<007ooOol04goo0`005Goo00<007ooOol04goo
00<007ooOol05Goo00<007ooOol04goo00<007ooOol0W7oo001TOol00`00Oomoo`0COol2000EOol2
000EOol2000DOol4000COol2000EOol2000EOol2000EOol2002MOol006=oo`8001Eoo`8001Eoo`80
01Eoo`8001Aoo`<001Aoo`03001oo`0001Aoo`03001oo`0001Aoo`8001Eoo`8009eoo`00Hgoo0P00
5Goo0P005Goo0P005Goo0P0057oo0`0057oo00<007oo000057oo00<007oo000057oo00<007oo0000
57oo0P00WGoo001SOol00`00Ool0000DOol2000EOol2000EOol2000DOol3000DOol00`00Ool0000D
Ool00`00Ool0000DOol00`00Ool0000COol01000Oomoo`00W7oo001SOol00`00Ool0000DOol00`00
Ool0000DOol2000DOol00`00Ool0000DOol3000DOol00`00Ool0000DOol00`00Ool0000COol01000
Oomoo`004goo00@007ooOol009aoo`00Hgoo00<007oo000057oo00<007oo000057oo00<007oo0000
4goo00<007oo000057oo0`0057oo00<007oo00004goo00@007ooOol001=oo`04001oogoo000COol0
1000Oomoo`00W7oo001SOol00`00Ool0000DOol00`00Ool0000DOol00`00Ool0000COol01000Oomo
o`004goo0`004goo00@007ooOol001=oo`04001oogoo000COol01000Oomoo`004goo00@007ooOol0
09aoo`00Hgoo00<007oo00004goo00@007ooOol001Aoo`03001oo`0001=oo`04001oogoo000COol2
00000goo001oo`0AOol01000Oomoo`004goo00@007ooOol001=oo`04001oogoo000COol01000Oomo
o`00W7oo001SOol00`00Ool0000COol01000Oomoo`0057oo00<007oo00004goo00@007ooOol001=o
o`@0019oo`05001oogooOol0000BOol01000Oomoo`004goo00@007ooOol001=oo`04001oogoo002L
Ool006=oo`03001oo`0001=oo`04001oogoo000COol01000Oomoo`004goo00@007ooOol001=oo`80
0003Ool007oo015oo`05001oogooOol0000BOol01@00Oomoogoo00004Woo00@007ooOol001=oo`04
001oogoo002LOol006=oo`03001oo`0001=oo`04001oogoo000COol01000Oomoo`004goo00@007oo
Ool001=oo`800003Ool007oo015oo`05001oogooOol0000BOol01@00Oomoogoo00004Woo00@007oo
Ool001=oo`04001oogoo002LOol006=oo`03001oo`0001=oo`04001oogoo000COol01000Oomoo`00
4goo00@007ooOol001=oo`800003Ool007oo015oo`05001oogooOol0000BOol01@00Oomoogoo0000
4Woo00D007ooOomoo`00019oo`04001oogoo002LOol006=oo`03001oo`0001=oo`04001oogoo000C
Ool01000Oomoo`004goo00@007ooOol001=oo`800003Ool007oo015oo`05001oogooOol0000BOol0
1@00Oomoogoo00004Woo00D007ooOomoo`00019oo`04001oogoo002LOol0069oo`04001oogoo000C
Ool01000Oomoo`004goo00@007ooOol001=oo`@000=oo`04001oogooOol30008Ool01@00Ool007oo
00004Woo00D007ooOomoo`00019oo`05001oogooOol0000BOol01@00Oomoogoo00004Woo00D007oo
Oomoo`0009]oo`00HWoo00D007ooOomoo`00019oo`04001oogoo000COol01000Oomoo`004Woo0P00
0Woo00<007ooOol017oo00D007ooOomoo`0000Moo`05001oo`00Ool0000BOol01@00Oomoogoo0000
4Woo00D007ooOomoo`00019oo`05001oogooOol0000AOol00`00Oomoo`02Ool00`00Oomoo`2IOol0
069oo`05001oogooOol0000BOol01@00Oomoogoo00004Woo00@007ooOol0015oo`03001oo`00009o
o`8000Aoo`03001oogoo00=oo`03001oogoo00Aoo`05001oo`00Ool0000BOol01@00Oomoogoo0000
4Woo00D007ooOomoo`00019oo`05001oogooOol0000AOol00`00Oomoo`02Ool00`00Oomoo`2IOol0
069oo`05001oogooOol0000BOol01@00Oomoogoo00004Woo00@007ooOol000Qoo`P00004Ool007oo
0002Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Ool00003000AOol01@00Oomoogoo
00004Woo00D007ooOomoo`00019oo`05001oogooOol0000AOol00`00Oomoo`02Ool00`00Oomoo`2I
Ool0069oo`05001oogooOol0000BOol01@00Oomoogoo00004Woo00D007ooOomoo`00011oo`03001o
o`00009oo`8000Aoo`03001oogoo00=oo`03001oogoo00Aoo`05001oo`00Ool0000BOol01@00Oomo
ogoo00004Goo00<007ooOol00Woo00<007ooOol047oo00D007ooOomoo`00015oo`03001oogoo009o
o`03001oogoo09Uoo`00HWoo00D007ooOomoo`00019oo`05001oogooOol0000BOol01@00Oomoogoo
000047oo00<007oo00000goo00<007ooOol00Woo0P000goo00<007ooOol01Goo00D007oo001oo`00
019oo`05001oogooOol0000AOol00`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo00004Goo
00<007ooOol00Woo00<007ooOol0VGoo001ROol01@00Oomoogoo00004Woo00D007ooOomoo`00019o
o`05001oogooOol0000@Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Ool000020008Ool01@00
Ool007oo00004Woo00D007ooOomoo`00015oo`03001oogoo009oo`03001oogoo011oo`05001oogoo
Ool0000AOol00`00Oomoo`02Ool00`00Oomoo`2IOol0069oo`05001oogooOol0000BOol01@00Oomo
ogoo00004Woo00D007ooOomoo`00011oo`03001oo`0000=oo`03001oogoo00=oo`03001oogoo00Uo
o`03001oo`00009oo`03001oogoo00moo`05001oogooOol0000AOol00`00Oomoo`02Ool00`00Oomo
o`0@Ool01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol0VGoo001ROol01@00Oomoogoo
00004Woo00D007ooOomoo`00019oo`05001oogooOol0000AOol20002Ool20006Ool20009Ool00`00
Ool00002Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol047oo
00D007ooOomoo`00015oo`03001oogoo009oo`03001oogoo09Uoo`00HWoo00D007ooOomoo`00019o
o`05001oogooOol0000BOol01@00Oomoogoo00004Goo100000=oo`00Ool01goo0`001Woo00<007oo
00000Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00Woo00<007oo
Ool047oo00D007ooOomoo`00015oo`03001oogoo009oo`03001oogoo09Uoo`00HWoo00D007ooOomo
o`00019oo`05001oogooOol0000BOol01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol0
3goo00<007oo00000`004Goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00Woo00<007oo
Ool03goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol0VGoo001ROol0
1@00Oomoogoo00004Woo00D007ooOomoo`00015oo`03001oogoo009oo`03001oogoo00moo`03001o
ogoo009oo`03001oogoo00moo`03001oo`00009oo`03001oogoo00moo`03001oogoo009oo`03001o
ogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00moo`03001o
ogoo009oo`03001oogoo09Uoo`00HWoo00D007ooOomoo`00019oo`05001oogooOol0000AOol00`00
Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Ool00002Ool00`00
Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00
Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`2IOol0069oo`05001oogooOol0
000BOol01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<0
07ooOol03goo00<007oo00000Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<0
07ooOol0VGoo001ROol01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol03goo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007oo00000Woo00<007oo
Ool03goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007oo
Ool00goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol0VGoo001ROol01@00Oomoogoo0000
4Goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0
0Woo00<007ooOol03goo00<007oo00000Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0
3Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0
0Woo00<007ooOol0VGoo001ROol01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol03goo
00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007oo00000Woo
00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo
00<007ooOol00goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol0VGoo001QOol00`00Oomo
o`03Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Ool00002Ool00`00Oomoo`0>Ool00`00Oomo
o`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomo
o`0>Ool00`00Oomoo`03Ool00`00Oomoo`2HOol0065oo`03001oogoo00=oo`03001oogoo00ioo`03
001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03
001oogoo00moo`03001oo`0000<0011oo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=o
o`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo09Qo
o`00HGoo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007oo00000Woo00<007oo
Ool03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007oo
Ool00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0V7oo001QOol00`00Oomoo`03Ool0
0`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Ool00002Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool0
0`00Oomoo`03Ool00`00Oomoo`2HOol0065oo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo
00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo
00moo`03001oo`00009oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo
00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo
09Qoo`00HGoo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol03goo00<007oo00000Woo00<0
07ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0V7oo001QOol00`00Oomoo`03
Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>
Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Ool00002Ool00`00Oomoo`0>Ool00`00Oomoo`03
Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Oomoo`2HOol0065oo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001o
ogoo00ioo`03001oo`00009oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001o
ogoo09Qoo`00HGoo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo
00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007oo00000Woo
00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo
00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0V7oo001QOol00`00Oomo
o`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomo
o`0>Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0300000goo001oo`0>Ool00`00Oomo
o`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomo
o`0>Ool00`00Oomoo`03Ool00`00Oomoo`2HOol0065oo`03001oogoo00=oo`03001oogoo00ioo`03
001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03
001oogoo00eoo`04001oogoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool0
0`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`2HOol0065oo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo
00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00eoo`04001oogoo
0003Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomo
o`0>Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`2HOol0065oo`03
001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03
001oogoo00ioo`03001oogoo00=oo`03001oogoo00eoo`04001oogoo0003Ool00`00Oomoo`0=Ool0
0`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`2HOol0065oo`03001oogoo00=oo`03001oogoo
00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo
00Aoo`03001oogoo00eoo`04001oogoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomo
o`0=Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomo
o`04Ool00`00Oomoo`2HOol0065oo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03
001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oo`000080009oo`03001oo`0000Io
o`03001oogoo00Aoo`04001oogoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=
Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool00`00Oomoo`2HOol0065oo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001o
ogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`8000=oo`03001oo`0000Qoo`03001oogoo00Ao
o`04001oogoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`2H
Ool004ioo`03001oogoo011oo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001o
ogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00=oo`8000Qoo`03001oogoo00Ao
o`04001oogoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`05
Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0?
Ool00`00Oomoo`26Ool004ioo`03001oogoo011oo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00Aoo`P00003Ool007oo00Aoo`80
00=oo`P000Aoo`03001oogoo00D000moo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00Eo
o`03001oogoo00eoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00mo
o`03001oogoo08Ioo`00CWoo00<007ooOol047oo00<007ooOol00goo00<007ooOol03Goo00<007oo
Ool017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol00goo0P000goo
00<007ooOol00Woo00<007ooOol017oo00@007ooOol000=oo`03001oogoo00eoo`03001oogoo00Ao
o`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00ao
o`03001oogoo00Aoo`03001oogoo00moo`03001oogoo08Ioo`00CWoo00<007ooOol047oo00<007oo
Ool00goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007oo
Ool03Goo00<007ooOol00goo0P0017oo00D007ooOomoo`0000Ioo`04001oogoo0003Ool00`00Oomo
o`0=Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomo
o`04Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`26Ool004ioo`03
001oogoo011oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03
001oogoo00Aoo`03001oogoo00eoo`03001oogoo00=oo`8000Eoo`04001oogoo0006Ool01000Oomo
o`000goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol017oo00<007ooOol03goo0P00Qgoo
001>Ool2000AOol00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool0
0`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool20006Ool00`00Ool00006Ool01000Oomo
o`000goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol017oo00<007ooOol03Woo00<007oo
0000Qgoo001>Ool2000@Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomo
o`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool20003Ool00`00Ool00007Ool20006Ool01000Oomo
o`000goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol01Goo00<007ooOol03Goo00<007oo
0000Qgoo001=Ool00`00Ool0000@Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool0
0`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Ool000020002Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool01000Oomoo`000goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol0
37oo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol0
1Goo00<007ooOol03Goo00<007oo0000Qgoo001=Ool00`00Ool0000@Ool00`00Oomoo`05Ool00`00
Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00
Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`0300000goo001oo`0>Ool00`00Oomoo`04Ool00`00
Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00
Oomoo`05Ool00`00Oomoo`0=Ool00`00Ool00027Ool004eoo`03001oo`00011oo`03001oogoo00Eo
o`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo00eo
o`03001oogoo00Aoo`03001oogoo00eoo`04001oogoo0003Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<
Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Ool00027Ool004eoo`03001oo`00011oo`03001o
ogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Aoo`03001o
ogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`04001oogoo0003Ool00`00Oomoo`0=Ool00`00
Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00
Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool01000Oomoo`00QWoo001=Ool00`00Ool0000@
Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05
Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool01000Oomoo`000goo00<007ooOol0
3Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol0
1Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol03Goo00@007ooOol008Ioo`00CGoo00@0
07ooOol000moo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03
001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo00eoo`04001oogoo0003Ool0
0`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool0
0`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool01@00Oomoogoo0000
QWoo001=Ool01000Oomoo`003goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<0
07ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol017oo00<007ooOol03Goo00@0
07ooOol000=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00Eoo`03
001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`05
001oogooOol00026Ool004eoo`04001oogoo000?Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00
Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00
Oomoo`0<Ool01000Oomoo`000goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<0
07ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<0
07ooOol037oo00D007ooOomoo`0008Ioo`00CGoo00@007ooOol000moo`03001oogoo00Eoo`03001o
ogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001o
ogoo00Eoo`03001oogoo00aoo`04001oogoo0003Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00
Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00
Oomoo`05Ool00`00Oomoo`0<Ool01@00Oomoogoo0000QWoo001=Ool01000Oomoo`003goo00<007oo
Ool01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol00`0000=oo`00Ool03Goo00<007oo
Ool01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool037oo00<007ooOol01Goo00<007ooOol037oo00D007ooOomoo`0008Ioo`00C7oo00D007ooOomo
o`0000moo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001o
ogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`04001oogoo0003Ool00`00
Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00
Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00
Oomoo`23Ool004aoo`05001oogooOol0000?Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomo
o`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomo
o`0;Ool01@00Oomoogoo000017oo00<007ooOol02goo00<007ooOol01Goo00<007ooOol037oo00<0
07ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<0
07ooOol037oo00<007ooOol00Woo00<007ooOol0Pgoo001<Ool01@00Oomoogoo00003goo00<007oo
Ool01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool037oo00<007ooOol01Goo00<007ooOol02goo00D007ooOomoo`0000Aoo`03001oogoo00]oo`03
001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03
001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo009oo`03001oogoo08=oo`00
C7oo00D007ooOomoo`0000moo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001o
ogoo00aoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`05001o
ogooOol00004Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool0
0`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool0
0`00Oomoo`02Ool00`00Oomoo`23Ool004aoo`05001oogooOol0000?Ool00`00Oomoo`05Ool00`00
Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00
Oomoo`06Ool00`00Oomoo`0;Ool01@00Oomoogoo000017oo00<007ooOol02goo00<007ooOol01Woo
00<007ooOol02goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo
00<007ooOol01Goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol0Pgoo001<Ool01@00Oomo
ogoo00003goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<0
07ooOol01Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00D007ooOomoo`0000Ao
o`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00ao
o`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo009o
o`03001oogoo08=oo`00C7oo00D007ooOomoo`0000moo`03001oogoo00Eoo`03001oogoo00aoo`03
001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03
001oogoo00]oo`05001oogooOol00004Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05
Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`23Ool004aoo`05001oogooOol0000?Ool0
0`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool01000Oomoogoo0`000Woo00<007ooOol0
2goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0
1Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol0
Pgoo001<Ool01@00Oomoogoo00003goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo
00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo
00D007ooOomoo`0000Aoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo
00Ioo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo08=oo`00Bgoo00<007ooOol00goo00<007ooOol037oo00<0
07ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01Woo00<0
07ooOol02goo00<007ooOol01Woo00<007ooOol02goo00D007ooOomoo`0000Aoo`03001oogoo00]o
o`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Eo
o`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo089o
o`00Bgoo00<007ooOol00goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol02goo00<007oo
Ool01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007oo
Ool02goo00D007ooOomoo`0000Aoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03
001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Eoo`03
001oogoo00aoo`03001oogoo00=oo`03001oogoo089oo`00Bgoo00<007ooOol00goo00<007ooOol0
37oo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0
1Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00D007ooOomoo`0000Aoo`03001o
ogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001o
ogoo00Ioo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo089oo`00Bgoo00<007ooOol00goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol02goo
00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol00`00
0goo0P0000=oo`00000010001Goo00D007ooOomoo`0000Aoo`03001oogoo00]oo`03001oogoo00Io
o`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]o
o`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo089oo`00Bgoo00<007oo
Ool00goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01Woo00<007oo
Ool02goo00<007ooOol01Woo00<007ooOol02goo00<007oo00000goo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`22Ool004]oo`03001oogoo
00=oo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo
00]oo`03001oogoo00Ioo`03001oogoo00]oo`8000Eoo`03001oo`0000=oo`03001oogoo00Moo`04
001oogooOol400000goo001oo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool0
0`00Oomoo`03Ool00`00Oomoo`22Ool004]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo
00=oo`X000Eoo`03001oo`0000Aoo`03001oogoo00Ioo`05001oogooOol00004Ool00`00Oomoo`0;
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06
Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`22
Ool004]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Yoo`03001o
ogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`8000Eoo`03001oo`0000Eo
o`03001oogoo00Eoo`05001oogooOol00004Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomo
o`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`22Ool004Yoo`03001oogoo00Aoo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03
001oogoo00Ioo`03001oogoo00]oo`8000Eoo`03001oo`0000Ioo`03001oogoo00Aoo`05001oogoo
Ool00004Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00
Oomoo`04Ool00`00Oomoo`21Ool004Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Mo
o`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]o
o`8000Eoo`03001oo`0000Moo`03001oogoo00=oo`05001oogooOol00004Ool00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool0
0`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`21Ool0
04Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo
00Moo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]oo`8000Eoo`03001oo`00009oo`03
001oogoo009oo`03001oogoo00=oo`05001oogooOol00004Ool00`00Oomoo`0;Ool00`00Oomoo`06
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:
Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`21Ool004Yoo`03001o
ogoo00Aoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001o
ogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oo`0000=oo`04001oogoo0003Ool01000
Oomoo`001Woo00D007ooOomoo`0000Aoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00Yo
o`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Mo
o`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo085oo`00BWoo00<007ooOol017oo00<007oo
Ool02goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007oo
Ool01goo00<007ooOol02Woo00<007ooOol00`000goo00<007ooOol00Woo0P001goo00D007ooOomo
o`0000Aoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Moo`03001o
ogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo085oo`00BWoo00<007ooOol017oo00<007ooOol02goo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo
00<007ooOol01Woo00<007ooOol02goo00@007ooOomoo`<0009oo`03001oogoo00]oo`03001oogoo
00Ioo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo
00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo085oo`00BGoo00<0
07ooOol01Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<0
07ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02goo00D0
07ooOomoo`0000Aoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Mo
o`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yo
o`03001oogoo00Ioo`03001oogoo081oo`00BGoo00<007ooOol01Goo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007oo
Ool02Woo00<007ooOol01goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo081oo`00
BGoo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol0
1goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol0
2Woo00D007ooOomoo`0000Aoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001o
ogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001o
ogoo00Yoo`03001oogoo00Ioo`03001oogoo081oo`00BGoo00<007ooOol01Goo00<007ooOol02goo
00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo
00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo
081oo`00BGoo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol02Woo00<0
07ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<0
07ooOol02Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02Goo00<007ooOol01goo00<0
07ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<0
07ooOol01goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol0P7oo0018Ool00`00Oomoo`06
Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:
Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07
Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:
Ool00`00Oomoo`07Ool00`00Oomoo`1oOol003=oo`H000Aoo`<000Aoo`<00003Ool007oo00Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Yoo`03001oo`00008000Eoo`<000Aoo`<000=o
o`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Mo
o`03001oogoo00Aoo`<000=oo`03001oo`00008000Aoo`<000]oo`03001oogoo00Moo`03001oogoo
00Yoo`03001oogoo00Moo`03001oogoo00H000Aoo`<000Aoo`<006]oo`00<goo00<007ooOol00goo
00@007ooOol000=oo`04001oogoo0003Ool20009Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00
Oomoo`0:Ool01000Oomoo`001Goo0P000Woo00@007ooOol000=oo`04001oogoo0009Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool2
0003Ool02000Oomoo`00Ool007oo000:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07
Ool01000Oomoo`001Goo00@007ooOol000=oo`04001oogoo0003Ool00`00Oomoo`1XOol003Aoo`03
001oogoo00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo
00Moo`03001oogoo00Yoo`04001oogoo0004Ool00`00Ool00003Ool20005Ool00`00Ool00009Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool20002Ool01000Oomoo`002Goo00<007ooOol01goo00<007oo
Ool02Woo00<007ooOol01goo00D007ooOomoo`0000Ioo`03001oogoo00=oo`8000Eoo`03001oogoo
06Moo`00:Woo20000goo00<007ooOol00goo00<007ooOol00goo0P0017oo0P002Goo00<007ooOol0
2Woo00<007ooOol01goo00@007ooOomoo`P00005Ool007ooOol00004Ool00`00Ool00003Ool20005
Ool00`00Ool00009Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20002Ool01000Oomoo`002Goo00<0
07ooOol01goo00<007ooOol02Woo00<007ooOol027oo00D007ooOomoo`0000Eoo`03001oogoo00=o
o`8000Eoo`03001oogoo06Moo`00=Woo00<007ooOol00Woo00<007ooOol00goo0P0017oo0P002Goo
00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00@007ooOol000Aoo`03001oo`0000=o
o`8000Eoo`8000Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`80009oo`04001oogoo0009Ool00`00
Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool20005Ool00`00Oomoo`1WOol003Moo`05001oogooOol00005Ool20004Ool20009Ool0
0`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01000Oomoo`0017oo00<007oo00000goo
0P001Goo0P002Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo0P000Woo00@007ooOol000Uoo`03001o
ogoo00Moo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00=oo`05001oogooOol00005Ool2
0005Ool00`00Oomoo`1WOol003Qoo`04001oogoo0005Ool20003Ool00`00Ool00009Ool00`00Oomo
o`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01000Oomoo`0017oo00<007oo00000goo0P001Goo
0P002Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00goo0P000Woo00@007ooOol000Uoo`03001oogoo00Mo
o`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Aoo`04001oogoo0005Ool20005Ool00`00
Oomoo`1WOol003=oo`03001oogoo009oo`04001oogoo0005Ool20003Ool00`00Ool00009Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01000Oomoo`0017oo00<007oo00000goo0P00
1Goo0P002Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol00goo0P000Woo00@007ooOol000Uoo`03001oogoo
00Moo`03001oogoo00Yoo`03001oogoo00Uoo`8000Aoo`04001oogoo0005Ool20005Ool00`00Oomo
o`1WOol003Aoo`04001oogoo0004Ool01@00Oomoogoo00000Woo00D007oo001oo`0000Yoo`03001o
ogoo00Yoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo008000Eoo`80009oo`04001oogoo
0003Ool00`00Ool0000:Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`03Ool20004Ool20003Ool01000Oomoo`000Woo0P002Woo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol02Goo00<007oo00000Woo00<007ooOol00Woo00D007ooOomoo`00
009oo`05001oogooOol0001ZOol003Eoo`8000Ioo`<000Aoo`<000]oo`03001oogoo00Yoo`03001o
ogoo00Moo`03001oogoo00Uoo`05001oogooOol00006Ool30004Ool30002Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool30003Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Ool000020004Ool3000;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`020006Ool30004Ool3001[Ool004Aoo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo07aoo`00@goo00<007ooOol037oo00<007ooOol02Woo00<007ooOol01goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02Goo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol02goo0P00O7oo0012Ool00`00Oomoo`0=
Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0:
Ool00`00Oomoo`0=Ool00`00Oomoo`1EOol3000KOol30003Ool0045oo`03001oogoo00ioo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00ioo`03001oogoo05Aoo`03001oogoo01eoo`03001oogoo005oo`00?Goo10004Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool03goo1000BGoo0`001Woo00<007ooOol00Woo0`0000Eoo`00000007oo00<00005Ool00000001o
o`03000017oo0000000017oo00<007ooOol00Goo000iOol4000EOol00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0COol30016Ool0
1000Oomoo`001Goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00001Goo00<007ooOol00Goo003o0021000?Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomoo`01Ool0
00=oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oo`0000Uoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool0000:Ool00`00Oomo
o`09Ool20009Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
1Goo00D007ooOomoo`0000Qoo`03001oo`0000]oo`03001oogoo00Qoo`03001oo`0000Qoo`03001o
ogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Eoo`05001o
ogooOol00009Ool00`00Ool0000:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool20006Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomoo`01Ool000=oo`03
001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oo`0000Uoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool0000:Ool2000:Ool20009Ool0
1@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00D007ooOomo
o`0000Qoo`03001oo`0000Yoo`8000Yoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Eoo`05001oogooOol00009Ool00`00Ool0
000:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomoo`01Ool003Uoo`03001oogoo01Ioo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo01Ioo`03001oogoo04=oo`04001oogoo0005Ool0
0`00Oomoo`02Ool30002Ool20002Ool00`00Oomoo`030002Ool20002Ool00`00Oomoo`03Ool00`00
Oomoo`01Ool0059oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo05eoo`<000Eoo`03001oogoo00=oo`04001oo`000002Ool20004
Ool01000Ool000000Woo0P001Woo00<007ooOol00Goo001BOol00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`1UOol00`00Oomoo`0M
Ool00`00Oomoo`01Ool0059oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo06Eoo`03001oogoo01eoo`03001oogoo005oo`00Dgoo
00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol0IWoo0`006goo0`000goo001COol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`2:Ool005=oo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo
00Moo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo08Yoo`00Dgoo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol017oo00<007ooOol01goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol0RWoo001COol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`2:Ool005=oo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Moo`03001o
ogoo00Yoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Moo`03001o
ogoo00Yoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo08Yoo`00Dgoo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo
00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol017oo
00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Goo00<007ooOol027oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0RWoo
001COol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`2:Ool005=oo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo08Yoo`00Dgoo00<007ooOol027oo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol0
1goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol00goo0`0017oo00<007ooOol01goo00<0
07ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Goo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0RWoo001COol00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`0:
Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`2:
Ool005=oo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001o
ogoo00Yoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001o
ogoo00Qoo`03001oogoo08Yoo`00Dgoo00<007ooOol027oo00<007ooOol02Goo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo
00<007ooOol01goo00<007ooOol00goo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Woo
00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol0RWoo001COol00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomo
o`0:Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`2:Ool005=oo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo08Yoo`00Dgoo00<007ooOol027oo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
2Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Woo00<007ooOol0
1goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol0RWoo001COol00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00
Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00
Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`2:Ool005=oo`03001oogoo00Qo
o`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yo
o`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00=oo`<000Aoo`03001o
ogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001o
ogoo00Yoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo08Yoo`00Dgoo
00<007ooOol01goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo
00<007ooOol01goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01goo
00<007ooOol0RWoo001COol00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomo
o`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`2:Ool005=oo`03001oogoo00Moo`03001oogoo00]oo`03
001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Yoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]oo`03
001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo08Yoo`00Dgoo00<007ooOol0
1goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0
2Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol0
17oo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol0
1Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0
RWoo001COol00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00
Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`02Ool30004Ool80003Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00
Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00
Oomoo`07Ool00`00Oomoo`2:Ool005=oo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Io
o`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`05001oogooOol0
0003Ool00`00Oomoo`02Ool20005Ool01000Oomoo`001Goo00<007ooOol017oo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo
00<007ooOol01Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol0RWoo001COol00`00Oomo
o`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomo
o`0;Ool00`00Oomoo`06Ool01000Oomoo`001Goo00L007ooOomoo`00Ool00007Ool00`00Oomoo`03
Ool40003Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00
Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00
Oomoo`2:Ool005Aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]o
o`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`04001oogoo0005Ool01@00Oomoogoo
00000Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo00<007ooOol01goo00<007oo
Ool02Woo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007oo
Ool01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0Rgoo001DOol00`00Oomoo`06Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`06Ool01000Oomoo`001Goo00<007ooOol00Woo00@007ooOol000Eoo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]o
o`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Io
o`03001oogoo08]oo`00E7oo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007oo
Ool02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00@007ooOol000Eoo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`2;Ool005Aoo`03001oogoo
00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo
00]oo`03001oogoo00Ioo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomo
ogoo00001Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<0
07ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<0
07ooOol01Woo00<007ooOol0Rgoo001DOol00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool01000Oomoo`00
1Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo
00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo08]oo`00E7oo00<0
07ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<0
07ooOol02goo00<007ooOol01Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`80009oo`05001o
ogooOol00006Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`2;Ool005Aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo
00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo
009oo`<000Ioo`04001oo`000004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`2;Ool005Aoo`03001oogoo
00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo
00]oo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00Aoo`<000Eoo`03
001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Ioo`03
001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo08]oo`00
E7oo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0
1Woo00<007ooOol02goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol0
2goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0
1Woo00<007ooOol0Rgoo001DOol00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00
Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00
Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00
Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`2;Ool005Aoo`03001oogoo00Ioo`03001oogoo00]o
o`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eo
o`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00]o
o`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo08]oo`00E7oo00<007oo
Ool01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Goo00<007oo
Ool037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007oo
Ool01Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol01Woo00<007oo
Ool0Rgoo001DOol00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool0
0`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`2;Ool005Aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo
00Ioo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo
00aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo
00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo08]oo`00E7oo00<007ooOol01Woo00<0
07ooOol02goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<0
07ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<0
07ooOol037oo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0Rgoo001D
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05
Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool30005Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00
Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00
Oomoo`2;Ool005Aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00ao
o`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eo
o`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00]o
o`03001oogoo00Ioo`03001oogoo08]oo`00E7oo00<007ooOol01Woo00<007ooOol02goo00<007oo
Ool01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool037oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007oo
Ool01Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0Rgoo001DOol00`00Oomoo`06Ool0
0`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool0
0`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool0
0`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`2;Ool0
05Aoo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo
00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo
00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo
00Ioo`03001oogoo08]oo`00E7oo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol017oo00<0
07ooOol03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol037oo00<0
07ooOol01Goo00<007ooOol037oo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<0
07ooOol037oo00<007ooOol01Woo00<007ooOol0Rgoo001DOol00`00Oomoo`05Ool00`00Oomoo`0=
Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`05
Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`0=
Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`2;Ool005Aoo`03001o
ogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001o
ogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00Aoo`<000Eo
o`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Ao
o`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo08]o
o`00EGoo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007oo
Ool017oo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007oo
Ool037oo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol037oo00<007oo
Ool01Goo00<007ooOol0S7oo001EOol00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool0
0`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool0
0`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool0
0`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`2<Ool005Eoo`03001oogoo00Aoo`03001oogoo
00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo
00Aoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo
00eoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo08aoo`00EGoo00<0
07ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<0
07ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<0
07ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol01Goo00<0
07ooOol0S7oo001EOol00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=
Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`03Ool30004Ool01000
Oomoo`000goo00@007ooOol000Ioo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00eoo`03
001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03
001oogoo00aoo`03001oogoo00Eoo`03001oogoo08aoo`00EGoo00<007ooOol017oo00<007ooOol0
3Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol0
17oo00<007ooOol00Woo00D007ooOomoo`0000Ioo`05001oogooOol00002Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool0
0`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool0
0`00Oomoo`2<Ool005Eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo
00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`05001oogooOol00005Ool00`00
Oomoo`03Ool01`00Oomoogoo001oo`0000Moo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo
00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo
00Aoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo08aoo`00EGoo00<007ooOol017oo00<0
07ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<0
07ooOol017oo00D007ooOomoo`0000Eoo`03001oogoo009oo`P000Moo`@000Eoo`03001oogoo00=o
o`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eo
o`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo08aoo`00EGoo00<007oo
Ool017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007oo
Ool03Goo00<007ooOol017oo00D007ooOomoo`0000Eoo`03001oogoo009oo`8000=oo`03001oo`00
00Moo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo
00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo
00Aoo`03001oogoo08aoo`00EGoo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<0
07ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00goo00L007ooOomoo`00Ool00007Ool00`00Oomoo`06Ool00`00Oomo
o`03Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomo
o`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`2<Ool005Eoo`03
001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03
001oogoo00eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`80
009oo`03001oo`0000Moo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo
00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo
00eoo`03001oogoo00Aoo`03001oogoo08aoo`00EGoo00<007ooOol017oo00<007ooOol03Goo00<0
07ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol00goo00L007oo001oo`00Ool00007Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomo
o`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomo
o`2<Ool005Eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03
001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00006
Ool00`00Oomoo`0200000goo001oo`06Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0=
Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`2<Ool005Eoo`03001oogoo00Aoo`03001o
ogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo00Aoo`<000Moo`07001oogooOol007oo00001goo00<007ooOol01Woo00<0
07ooOol00goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol00goo00<0
07ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol0S7oo001E
Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`03
Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04
Ool00`00Oomoo`2<Ool005Eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00=oo`03001o
ogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo00Eoo`<000Ioo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Ao
o`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eo
o`03001oogoo00Aoo`03001oogoo08aoo`00EGoo00<007ooOol017oo00<007ooOol03Goo00<007oo
Ool00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007oo
Ool03Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00goo00<007oo
Ool03Goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Goo00<007oo
Ool017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol0S7oo001EOol00`00Oomoo`04Ool0
0`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool0
0`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`2<Ool0
05Eoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00ioo`03001oogoo
00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo
00ioo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo
00Aoo`03001oogoo08aoo`00EGoo00<007ooOol017oo00<007ooOol03Woo00<007ooOol00Woo00<0
07ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Goo00<007ooOol00goo00<0
07ooOol03Woo00<007ooOol017oo00<007ooOol0S7oo001EOol00`00Oomoo`03Ool00`00Oomoo`0?
Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`03
Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`03
Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`2<Ool005Eoo`03001o
ogoo00=oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001o
ogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo009oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00Aoo`03001o
ogoo08aoo`00EGoo00<007ooOol00goo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo
00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo
00<007ooOol017oo00<007ooOol0S7oo001FOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomo
o`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomo
o`0>Ool00`00Oomoo`03Ool00`00Oomoo`05Ool30006Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool0
0`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`2=Ool005Ioo`03001oogoo009oo`03001oogoo
00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo
009oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo
00=oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo
00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo08eoo`00EWoo00<0
07ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<0
07ooOol03goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol03goo00<0
07ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00goo00<0
07ooOol0SGoo001FOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?
Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02
Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Oomoo`2=Ool005Ioo`03001oogoo009oo`03001oogoo00moo`03001o
ogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001o
ogoo00moo`05001oogooOol00008Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`2=Ool005Ioo`03001oogoo009oo`03001oogoo
00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo
009oo`03001oogoo00moo`05001oogooOol00008Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00
Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00
Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`2=Ool005Ioo`03001oogoo009o
o`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00mo
o`03001oogoo009oo`03001oogoo00moo`05001oogooOol00008Ool00`00Oomoo`06Ool00`00Oomo
o`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`2=Ool005Ioo`03
001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03
001oogoo00moo`05001oogooOol0000BOol01@00Oomoogoo000027oo0`001Woo00<007ooOol00Woo
00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo
00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0SGoo001FOol00`00Oomo
o`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool01@00Oomoogoo00004Woo00D007ooOomoo`0000Qoo`03001oogoo00Ioo`03001oogoo009o
o`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00mo
o`03001oogoo009oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo08eoo`00EWoo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00D007ooOomoo`00019oo`05
001oogooOol0000BOol01@00Oomoogoo000027oo00<007ooOol01Woo00<007ooOol00Woo00<007oo
Ool03goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007oo
Ool00Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0SGoo001FOol00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Woo00D007ooOomo
o`00019oo`05001oogooOol00008Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`2=Ool005Ioo`03001oogoo009oo`03001oogoo
00moo`03001oogoo009oo`03001oogoo00moo`05001oogooOol0000BOol01@00Oomoogoo00004Woo
00D007ooOomoo`0000Qoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00moo`03001oogoo
009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo
00ioo`03001oogoo00=oo`03001oogoo08eoo`00EWoo00<007ooOol00Woo00<007ooOol03goo00D0
07ooOomoo`00019oo`05001oogooOol0000BOol01@00Oomoogoo00001goo0`0017oo00@007ooOomo
o`<00003Ool007oo00Moo`03001oogoo00Moo`05001oogooOol0000AOol00`00Oomoo`02Ool00`00
Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00
Oomoo`03Ool00`00Oomoo`2=Ool005Ioo`03001oogoo009oo`03001oogoo011oo`04001oogoo000B
Ool01@00Oomoogoo00004Woo00D007ooOomoo`0000Ioo`05001oogooOol00006Ool20002Ool20008
Ool00`00Oomoo`07Ool01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol03goo00<007oo
Ool00Woo00<007ooOol03goo00D007ooOomoo`00015oo`03001oogoo00=oo`03001oogoo08eoo`00
EWoo00<007ooOol00Woo00<007ooOol047oo00@007ooOol0019oo`05001oogooOol0000BOol01@00
Oomoogoo00001Goo00<007ooOol00goo00<007ooOol00Woo00<007oo00000goo00<007ooOol01Woo
00<007ooOol01goo00D007ooOomoo`00015oo`03001oogoo009oo`03001oogoo00moo`03001oogoo
009oo`03001oogoo00moo`05001oogooOol0000AOol00`00Oomoo`03Ool00`00Oomoo`2=Ool005Io
o`03001oogoo009oo`03001oogoo011oo`04001oogoo000COol01000Oomoo`004Woo00D007ooOomo
o`0000Eoo`03001oogoo00=oo`03001oogoo009oo`03001oo`0000=oo`03001oogoo00Ioo`@000Io
o`05001oogooOol0000AOol00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Woo00D0
07ooOomoo`00015oo`03001oogoo00=oo`03001oogoo08eoo`00EWoo00D007ooOomoo`0001=oo`04
001oogoo000COol01000Oomoo`004Woo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo
009oo`03001oo`0000=oo`03001oogoo00Ioo`03001oogoo00Moo`05001oogooOol0000AOol00`00
Oomoo`02Ool00`00Oomoo`0@Ool01000Oomoo`004Woo00D007ooOomoo`00019oo`03001oogoo009o
o`03001oogoo08eoo`00Egoo00@007ooOol001=oo`04001oogoo000COol01000Oomoo`004goo00@0
07ooOol000Eoo`03001oogoo00=oo`03001oogoo009oo`<0009oo`8000Qoo`03001oogoo00Moo`05
001oogooOol0000AOol01@00Oomoogoo00004goo00@007ooOol0019oo`05001oogooOol0000BOol0
1@00Oomoogoo0000T7oo001GOol01000Oomoo`004goo00@007ooOol001=oo`04001oogoo000COol0
1000Oomoo`001Goo00<007ooOol00goo00<007ooOol00Woo00<007oo00000P0000=oo`00Ool01goo
00<007ooOol01goo00D007ooOomoo`00015oo`05001oogooOol0000COol01000Oomoo`004Woo00D0
07ooOomoo`00019oo`05001oogooOol0002@Ool005Moo`04001oogoo000COol01000Oomoo`004goo
00@007ooOol001=oo`04001oogoo0005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20003Ool00`00
Oomoo`06Ool00`00Oomoo`07Ool01000Oomoo`004Woo00D007ooOomoo`0001=oo`04001oogoo000B
Ool01@00Oomoogoo00004Woo00D007ooOomoo`00091oo`00Egoo00@007ooOol001=oo`04001oogoo
000COol01000Oomoo`004goo00@007ooOol000Ioo`05001oogooOol00007Ool20002Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool01000Oomoo`004Woo00D007ooOomoo`0001=oo`04001oogoo000BOol0
1@00Oomoogoo00004Woo00D007ooOomoo`00091oo`00Egoo00@007ooOol001=oo`04001oogoo000C
Ool01000Oomoo`004goo00@007ooOol000Moo`<000Qoo`03001oo`00008000Qoo`03001oogoo00Mo
o`04001oogoo000BOol01@00Oomoogoo00004goo00@007ooOol0019oo`05001oogooOol0000BOol0
1@00Oomoogoo0000T7oo001GOol01000Oomoo`004goo00@007ooOol001=oo`04001oogoo000COol0
0`00Ool0000COol01000Oomoo`002Goo00<007ooOol01goo00@007ooOol001=oo`04001oogoo000C
Ool01000Oomoo`004Woo00D007ooOomoo`00019oo`05001oogooOol0002@Ool005Moo`04001oogoo
000COol01000Oomoo`004goo00@007ooOol001=oo`03001oo`0001=oo`04001oogoo0009Ool30007
Ool01000Oomoo`004goo00@007ooOol001=oo`04001oogoo000BOol01@00Oomoogoo00004Woo00D0
07ooOomoo`00091oo`00Egoo00@007ooOol001=oo`04001oogoo000COol00`00Ool0000DOol00`00
Ool0000DOol00`00Ool00009Ool00`00Oomoo`07Ool01000Oomoo`004goo00@007ooOol001=oo`04
001oogoo000BOol01@00Oomoogoo00004Woo00D007ooOomoo`00091oo`00Egoo00@007ooOol001=o
o`03001oo`0001Aoo`03001oo`0001Aoo`03001oo`0001Aoo`03001oo`0000Uoo`03001oogoo00Mo
o`04001oogoo000COol01000Oomoo`004goo00@007ooOol001=oo`04001oogoo000BOol01@00Oomo
ogoo0000T7oo001GOol01000Oomoo`004goo00<007oo000057oo00<007oo000057oo00<007oo0000
57oo00<007oo00002Goo00<007ooOol01goo00@007ooOol001=oo`04001oogoo000COol01000Oomo
o`004goo00<007oo00004goo00D007ooOomoo`00091oo`00Egoo00@007ooOol001=oo`03001oo`00
01Aoo`03001oo`0001Aoo`03001oo`0001Aoo`03001oo`0000Uoo`03001oogoo00Moo`04001oogoo
000COol01000Oomoo`004goo00@007ooOol001=oo`03001oo`0001=oo`05001oogooOol0002@Ool0
05Moo`04001oogoo000COol00`00Ool0000EOol2000DOol00`00Ool0000DOol00`00Ool00009Ool0
0`00Oomoo`07Ool01000Oomoo`004goo00<007oo000057oo00<007oo000057oo00<007oo00004goo
00D007ooOomoo`00091oo`00Egoo00<007oo00005Goo0P005Goo0P0057oo00<007oo000057oo00<0
07oo00002Goo00<007ooOol01goo00@007ooOol001=oo`03001oo`0001Aoo`03001oo`0001Aoo`03
001oo`0001Aoo`04001oogoo002@Ool005Qoo`8001Eoo`8001Eoo`8001Eoo`8001Aoo`8000Yoo`03
001oogoo00Qoo`8001Aoo`03001oo`0001Aoo`03001oo`0001Aoo`03001oo`0001Aoo`03001oo`00
095oo`00F7oo0P005Goo0P005Goo0P005Goo00<007ooOol04goo0P002Woo0`0027oo0P005Goo0P00
57oo00<007oo000057oo00<007oo000057oo00<007oo0000TGoo001HOol2000EOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0COol2000:Ool00`00Oomoo`08Ool2000EOol2000EOol2000E
Ool2000DOol00`00Ool0002AOol005Qoo`8001Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01=oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo01=oo`03001oogoo01Eoo`03001o
ogoo01=oo`03001oogoo01=oo`03001oo`00095oo`00F7oo0P005Goo00<007ooOol0:goo00<007oo
Ool04goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol04goo00<007ooOol0:goo00<007oo
Ool04goo00<007oo0000TGoo001HOol2000EOol00`00Oomoo`1=Ool00`00Oomoo`1=Ool00`00Oomo
o`0COol3002AOol005Qoo`03001oogoo06Aoo`03001oogoo06Eoo`03001oogoo08moo`00_goo00<0
07ooOol0mgoo002oOol3003gOol00;moo`03001oogoo0?Moo`00_goo00<007ooOol0mgoo002oOol0
0`00Oomoo`3gOol00;moo`03001oogoo0?Moo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo
003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mo
okYoo`00`7oo0`003Goo0`00iWoo0030Ool00`00Oomoo`0?Ool00`00Oomoo`3TOol00:eoo`L0009o
o`H000Aoo`03001oogoo00Eoo`<000Moo`03001oogoo0>Aoo`00[Woo00<007ooOol00goo00@007oo
Ool000=oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo0>Aoo`00[Woo
00<007ooOol00goo00D007ooOomoo`0000Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
0>Aoo`00[Woo00<007ooOol00goo00D007ooOomoo`0000Moo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo0>Aoo`00[Woo00<007ooOol00Woo0P0017oo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol0i7oo002^Ool50003Ool01@00Oomoogoo00001Goo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol0i7oo002^Ool00`00Oomoo`02Ool200000goo000000040004
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`3TOol00:ioo`03001oogoo00=oo`03001o
ogoo00Uoo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`3TOol0
0:ioo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`02Ool00`00Oomoo`3TOol00:eoo`L000aoo`<0009oo`T0009oo`<00>Ioo`00ogoo^Woo003o
OonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00\
\>"],
  ImageRangeCache->{{{0, 440.938}, {271.938, 0}} -> {-285.603, -0.788354, 
  1.8609, 0.00808832}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.308858 0.0638146 [
[.2619 .29636 -8 -14 ]
[.2619 .29636 8 0 ]
[.5 .29636 -11 -14 ]
[.5 .29636 11 0 ]
[.7381 .29636 -11 -14 ]
[.7381 .29636 11 0 ]
[.97619 .29636 -11 -14 ]
[.97619 .29636 11 0 ]
[1.025 .30886 0 -7 ]
[1.025 .30886 38.125 7 ]
[.01131 .0536 -18.25 -7 ]
[.01131 .0536 0 7 ]
[.01131 .18123 -18.25 -7 ]
[.01131 .18123 0 7 ]
[.01131 .43649 -10 -7 ]
[.01131 .43649 0 7 ]
[.01131 .56412 -10 -7 ]
[.01131 .56412 0 7 ]
[.02381 .64303 -36.3438 0 ]
[.02381 .64303 36.3438 17.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30886 m
.2619 .31511 L
s
gsave
.2619 .29636 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .30886 m
.5 .31511 L
s
gsave
.5 .29636 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 .30886 m
.7381 .31511 L
s
gsave
.7381 .29636 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 .30886 m
.97619 .31511 L
s
gsave
.97619 .29636 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 .30886 m
.07143 .31261 L
s
.11905 .30886 m
.11905 .31261 L
s
.16667 .30886 m
.16667 .31261 L
s
.21429 .30886 m
.21429 .31261 L
s
.30952 .30886 m
.30952 .31261 L
s
.35714 .30886 m
.35714 .31261 L
s
.40476 .30886 m
.40476 .31261 L
s
.45238 .30886 m
.45238 .31261 L
s
.54762 .30886 m
.54762 .31261 L
s
.59524 .30886 m
.59524 .31261 L
s
.64286 .30886 m
.64286 .31261 L
s
.69048 .30886 m
.69048 .31261 L
s
.78571 .30886 m
.78571 .31261 L
s
.83333 .30886 m
.83333 .31261 L
s
.88095 .30886 m
.88095 .31261 L
s
.92857 .30886 m
.92857 .31261 L
s
.25 Mabswid
0 .30886 m
1 .30886 L
s
gsave
1.025 .30886 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.625000 14.000000 moveto
(@) show
74.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.187500 14.000000 moveto
(D) show
97.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .0536 m
.03006 .0536 L
s
gsave
.01131 .0536 -79.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .18123 m
.03006 .18123 L
s
gsave
.01131 .18123 -79.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .43649 m
.03006 .43649 L
s
gsave
.01131 .43649 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.02381 .56412 m
.03006 .56412 L
s
gsave
.01131 .56412 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.02381 .08551 m
.02756 .08551 L
s
.02381 .11741 m
.02756 .11741 L
s
.02381 .14932 m
.02756 .14932 L
s
.02381 .21314 m
.02756 .21314 L
s
.02381 .24504 m
.02756 .24504 L
s
.02381 .27695 m
.02756 .27695 L
s
.02381 .34077 m
.02756 .34077 L
s
.02381 .37267 m
.02756 .37267 L
s
.02381 .40458 m
.02756 .40458 L
s
.02381 .46839 m
.02756 .46839 L
s
.02381 .5003 m
.02756 .5003 L
s
.02381 .53221 m
.02756 .53221 L
s
.02381 .02169 m
.02756 .02169 L
s
.02381 .59602 m
.02756 .59602 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -97.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.375 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 21.375000 moveto
 541.000000 21.375000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 21.375000 lineto
closepath
clip newpath
63.000000 17.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 17.375000 moveto
(\\331) show
70.937500 17.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bzds) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
97.875000 17.375000 moveto
(@) show
101.812500 17.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Tmm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
127.750000 17.375000 moveto
(D) show
131.687500 17.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02857 .30884 m
.03333 .30883 L
.0381 .30881 L
.04286 .3088 L
.04762 .30878 L
.05238 .30875 L
.05714 .30873 L
.0619 .3087 L
.06667 .30867 L
.07143 .30863 L
.07619 .30858 L
.08095 .30854 L
.08571 .30848 L
.09048 .30841 L
.09524 .30833 L
.1 .30824 L
.10476 .30813 L
.10952 .30801 L
.11429 .30785 L
.11905 .30767 L
.12381 .30744 L
.12857 .30716 L
.13333 .30682 L
.1381 .30638 L
.14286 .30583 L
.14762 .30513 L
.15238 .30421 L
.15714 .30299 L
.1619 .30136 L
.16667 .29913 L
.17143 .29603 L
.17619 .29163 L
.18095 .28526 L
.18571 .27581 L
.19048 .26141 L
.19524 .2388 L
.2 .20232 L
.20476 .14541 L
.20952 .07517 L
.21429 .02217 L
.21905 .01472 L
.22381 .06308 L
.22857 .162 L
.23333 .28948 L
.2381 .41624 L
.24286 .51254 L
.24762 .55444 L
.25238 .53331 L
.25714 .45406 L
.2619 .33721 L
Mistroke
.26667 .21256 L
.27143 .11058 L
.27619 .05802 L
.28095 .0672 L
.28571 .13633 L
.29048 .2485 L
.29524 .37489 L
.3 .48509 L
.30476 .55065 L
.30952 .55568 L
.31429 .49917 L
.31905 .39446 L
.32381 .26882 L
.32857 .15267 L
.33333 .07557 L
.3381 .05693 L
.34286 .10065 L
.34762 .19693 L
.35238 .32069 L
.35714 .4416 L
.3619 .52955 L
.36667 .56184 L
.37143 .53151 L
.37619 .44508 L
.38095 .32479 L
.38571 .2007 L
.39048 .10316 L
.39524 .05761 L
.4 .07434 L
.40476 .14989 L
.40952 .26531 L
.41429 .39118 L
.41905 .49708 L
.42381 .55548 L
.42857 .55253 L
.43333 .48884 L
.4381 .37978 L
.44286 .25362 L
.44762 .14075 L
.45238 .07019 L
.45714 .05936 L
.4619 .11049 L
.46667 .21179 L
.47143 .33683 L
.47619 .45522 L
.48095 .53712 L
.48571 .56166 L
.49048 .52365 L
.49524 .43146 L
.5 .30902 L
Mistroke
.50476 .18658 L
.50952 .09439 L
.51429 .05637 L
.51905 .08091 L
.52381 .16281 L
.52857 .28121 L
.53333 .40624 L
.5381 .50754 L
.54286 .55867 L
.54762 .54784 L
.55238 .47728 L
.55714 .36442 L
.5619 .23825 L
.56667 .1292 L
.57143 .06551 L
.57619 .06256 L
.58095 .12095 L
.58571 .22686 L
.59048 .35273 L
.59524 .46815 L
.6 .54369 L
.60476 .56043 L
.60952 .51488 L
.61429 .41734 L
.61905 .29325 L
.62381 .17295 L
.62857 .08652 L
.63333 .05619 L
.6381 .08849 L
.64286 .17643 L
.64762 .29734 L
.65238 .4211 L
.65714 .51738 L
.6619 .56111 L
.66667 .54247 L
.67143 .46536 L
.67619 .34921 L
.68095 .22358 L
.68571 .11886 L
.69048 .06235 L
.69524 .06738 L
.7 .13294 L
.70476 .24314 L
.70952 .36953 L
.71429 .4817 L
.71905 .55083 L
.72381 .56002 L
.72857 .50745 L
.73333 .40547 L
.7381 .28083 L
Mistroke
.74286 .16397 L
.74762 .08473 L
.75238 .0636 L
.75714 .10549 L
.7619 .2018 L
.76667 .32855 L
.77143 .45604 L
.77619 .55496 L
.78095 .60332 L
.78571 .59586 L
.79048 .54287 L
.79524 .47263 L
.8 .41572 L
.80476 .37924 L
.80952 .35662 L
.81429 .34223 L
.81905 .33278 L
.82381 .3264 L
.82857 .32201 L
.83333 .31891 L
.8381 .31668 L
.84286 .31504 L
.84762 .31383 L
.85238 .31291 L
.85714 .3122 L
.8619 .31165 L
.86667 .31122 L
.87143 .31087 L
.87619 .31059 L
.88095 .31037 L
.88571 .31018 L
.89048 .31003 L
.89524 .3099 L
.9 .30979 L
.90476 .3097 L
.90952 .30962 L
.91429 .30956 L
.91905 .3095 L
.92381 .30945 L
.92857 .30941 L
.93333 .30937 L
.9381 .30934 L
.94286 .30931 L
.94762 .30928 L
.95238 .30926 L
.95714 .30924 L
.9619 .30922 L
.96667 .3092 L
.97143 .30919 L
.97619 .30918 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{353.562, 218.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006i000141000`40O003h00Oogoo^Woo003oOonj
Ool00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00
ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo000]Ool00`00Oomoo`3oOon:Ool002eoo`03001o
ogoo0?moohYoo`00;Goo00<007ooOol0ogooRWoo000]Ool00`00Oomoo`3oOon:Ool002eoo`03001o
ogoo0?moohYoo`00;Goo00<007ooOol0@Goo00<007ooOol0ogooAWoo000]Ool00`00Oomoo`11Ool0
0`00Oomoo`3oOom6Ool002eoo`03001oogoo041oo`800?moodQoo`00;Goo0P00@7oo00<007oo0000
ogooB7oo000]Ool00`00Oomoo`0oOol00`00Ool0003oOom8Ool002eoo`03001oogoo03moo`03001o
o`000?moodQoo`00;Goo00<007ooOol0?goo00<007oo0000ogooB7oo000]Ool00`00Oomoo`0oOol0
0`00Ool0003oOom8Ool002eoo`03001oogoo03ioo`04001oogoo003oOom8Ool002eoo`03001oogoo
03ioo`05001oogooOol0003oOom7Ool002eoo`03001oogoo03ioo`05001oogooOol0003oOom7Ool0
02Aoo`03001oogoo00Ioo`03001oogoo03ioo`05001oogooOol0003oOom7Ool002Aoo`03001oogoo
00Ioo`03001oogoo03ioo`05001oogooOol0003oOom7Ool002Aoo`03001oogoo00Ioo`03001oogoo
03ioo`05001oogooOol0003oOom7Ool001Eoo`P0009oo`P000Ioo`<003ioo`05001oogooOol0002>
Ool00`00Oomoo`2eOol001moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03ioo`05001o
ogooOol0000BOol00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0VOol00`00Oomoo`0WOol0
0`00Oomoo`2eOol0021oo`05001oogooOol00008Ool00`00Oomoo`0nOol01@00Oomoogoo00004Woo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol09goo
00<007ooOol0]Goo000QOol01000Oomoo`0027oo00<007ooOol0?Goo00<007ooOol00Woo00<007oo
Ool047oo0P004Woo0P004goo0P004goo00<007ooOol04Goo00<007ooOol04Woo0P004goo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol0S7oo000ROol00`00Ool00008Ool00`00Oomoo`0mOol0
0`00Oomoo`02Ool00`00Oomoo`0@Ool2000BOol2000COol2000BOol2000COol2000BOol00`00Ool0
000BOol2000COol2000COol00`00Oomoo`2<Ool002=oo`8000Qoo`03001oogoo03eoo`03001oogoo
009oo`03001oogoo011oo`80019oo`8001=oo`80019oo`8001=oo`80019oo`03001oo`00019oo`80
01=oo`8001=oo`03001oogoo08aoo`0097oo00<007ooOol01Woo00<007ooOol0?Goo00<007ooOol0
0Woo00<007ooOol03goo00<007oo00004Goo00@007ooOol0015oo`04001oogoo000AOol2000COol2
000BOol00`00Ool0000BOol2000COol2000BOol2002>Ool002eoo`03001oogoo03eoo`03001oogoo
009oo`03001oogoo00moo`03001oo`00015oo`04001oogoo000AOol01000Oomoo`004Goo00<007oo
00004Woo0P004Woo00<007oo00004Woo00<007oo00004Woo0P004Woo0P00SWoo000]Ool00`00Oomo
o`0mOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Ool0000AOol01000Oomoo`004Goo00@007oo
Ool0015oo`03001oo`00015oo`04001oogoo000AOol00`00Ool0000BOol00`00Ool0000BOol2000B
Ool00`00Ool0002=Ool002eoo`03001oogoo03eoo`03001oogoo009oo`03001oogoo00moo`03001o
o`00015oo`04001oogoo000AOol01000Oomoo`004Goo00<007oo00004Goo00@007ooOol0015oo`04
001oogoo000@Ool01000Oomoo`004Goo00<007oo00004Goo00@007ooOol008eoo`00;Goo00<007oo
Ool0?Goo00<007ooOol00Woo00<007ooOol03goo00<007oo00004Goo00@007ooOol0015oo`04001o
ogoo000AOol00`00Ool0000AOol01000Oomoo`004Goo00@007ooOol0011oo`04001oogoo000AOol0
0`00Ool0000AOol01000Oomoo`00SGoo000]Ool2000nOol00`00Oomoo`02Ool00`00Oomoo`0?Ool0
1000Oomoo`0047oo00@007ooOol0015oo`04001oogoo000AOol00`00Ool0000AOol01000Oomoo`00
4Goo00@007ooOol0011oo`04001oogoo000AOol01000Oomoo`0047oo00@007ooOol008eoo`00;Goo
00<007ooOol0?Goo00<007ooOol00goo00<007ooOol03Woo00@007ooOol0011oo`04001oogoo000A
Ool01000Oomoo`0047oo00@007ooOol0015oo`04001oogoo000AOol01000Oomoo`0047oo00@007oo
Ool0015oo`04001oogoo000@Ool01000Oomoo`00SGoo000]Ool00`00Oomoo`0mOol00`00Oomoo`03
Ool00`00Oomoo`0>Ool01000Oomoo`0047oo00D007ooOomoo`00011oo`04001oogoo000@Ool01000
Oomoo`004Goo00@007ooOol0015oo`04001oogoo000@Ool01000Oomoo`004Goo00@007ooOol0011o
o`04001oogoo002=Ool002eoo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo00ioo`04001o
ogoo000@Ool01@00Oomoogoo00003goo00D007ooOomoo`00011oo`04001oogoo000AOol01000Oomo
o`004Goo00@007ooOol0011oo`04001oogoo000AOol01000Oomoo`0047oo00@007ooOol008eoo`00
;Goo00<007ooOol0?Goo00<007ooOol00goo00<007ooOol03Goo00D007ooOomoo`00011oo`05001o
ogooOol0000?Ool01@00Oomoogoo000047oo00@007ooOol0015oo`04001oogoo000AOol01000Oomo
o`0047oo00@007ooOol0015oo`04001oogoo000@Ool01@00Oomoogoo0000S7oo000]Ool00`00Oomo
o`0mOol00`00Oomoo`03Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo00D007ooOomoo`0000mo
o`05001oogooOol0000@Ool01@00Oomoogoo000047oo00@007ooOol0011oo`05001oogooOol0000@
Ool01000Oomoo`004Goo00@007ooOol0011oo`05001oogooOol0002<Ool002eoo`03001oogoo03eo
o`03001oogoo00=oo`03001oogoo00eoo`05001oogooOol0000@Ool01@00Oomoogoo00003goo00D0
07ooOomoo`00011oo`05001oogooOol0000@Ool01@00Oomoogoo00003goo00D007ooOomoo`00011o
o`04001oogoo000AOol01000Oomoo`0047oo00D007ooOomoo`0008aoo`00;Goo00<007ooOol0?Goo
00<007ooOol00goo00<007ooOol03Goo00D007ooOomoo`00011oo`05001oogooOol0000?Ool01@00
Oomoogoo000047oo00D007ooOomoo`00011oo`05001oogooOol0000?Ool01@00Oomoogoo000047oo
00@007ooOol0011oo`05001oogooOol0000@Ool01@00Oomoogoo0000S7oo000]Ool00`00Oomoo`0m
Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo00D007ooOomoo`0000moo`05
001oogooOol0000@Ool01@00Oomoogoo000047oo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00aoo`05001oogooOol0000@Ool01@00Oomoogoo000047oo00D007ooOomoo`0008aoo`00
;Goo00<007ooOol0?7oo00<007ooOol017oo00<007ooOol03Goo00D007ooOomoo`00011oo`05001o
ogooOol0000?Ool01@00Oomoogoo000047oo00D007ooOomoo`00011oo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo0000
47oo00D007ooOomoo`0008aoo`00;Goo00<007ooOol0?7oo00<007ooOol017oo00<007ooOol03Goo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo
00eoo`05001oogooOol0000@Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol037oo
00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`00011oo`05001oogooOol0002<Ool002eo
o`8003eoo`03001oogoo00Aoo`03001oogoo00eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo00D007ooOomo
o`0000moo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00eoo`03001o
ogoo009oo`03001oogoo00eoo`05001oogooOol0002<Ool002eoo`03001oogoo03aoo`03001oogoo
00Aoo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo009oo`03001oogoo00eoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00
Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo0000S7oo000]Ool00`00Oomoo`0lOol00`00Oomo
o`04Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomo
o`0=Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<0
07ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0008aoo`00;Goo00<007ooOol0?7oo00<007oo
Ool017oo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007oo
Ool03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007oo
Ool00Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007oo
Ool03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol0RWoo000]Ool0
0`00Oomoo`0lOol00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool0
0`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool0
0`00Oomoo`2:Ool002eoo`03001oogoo03aoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo
009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo
009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo08Yoo`00;Goo00<007ooOol0?7oo00<007ooOol017oo00<0
07ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<0
07ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol0RWoo000]Ool00`00Oomoo`0l
Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<
Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`2:
Ool002eoo`03001oogoo03aoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001o
ogoo00aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo009oo`03001oogoo08Yoo`00;Goo00<007ooOol0?7oo00<007ooOol01Goo00<007ooOol02goo
00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo
00<007ooOol037oo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo
00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo
00<007ooOol037oo00<007ooOol00Woo00<007ooOol0RWoo000]Ool00`00Oomoo`0lOol00`00Oomo
o`05Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomo
o`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomo
o`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomo
o`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`2:Ool002eoo`80
03eoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo
00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo
00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
08Yoo`00;Goo00<007ooOol0?7oo00<007ooOol01Goo00<007ooOol02goo00<007ooOol00goo00<0
07ooOol037oo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol037oo00<0
07ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol037oo00<0
07ooOol00Woo00<007ooOol0RWoo000]Ool00`00Oomoo`0lOol00`00Oomoo`05Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03
Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<
Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03
Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`29Ool002eoo`03001oogoo03aoo`03001o
ogoo00Eoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo08Uoo`00;Goo
00<007ooOol0>goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo
00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo
00<007ooOol037oo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo
00<007ooOol0RGoo000]Ool00`00Oomoo`0kOol00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomo
o`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomo
o`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomo
o`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomo
o`0;Ool00`00Oomoo`03Ool00`00Oomoo`29Ool002eoo`03001oogoo03]oo`03001oogoo00Ioo`03
001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03
001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo08Uoo`00;Goo00<007ooOol0
>goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol0
0goo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol0
2goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
17oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
RGoo000OOol60008Ool00`00Oomoo`0kOol00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`04
Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<
Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03
Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`29Ool001moo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo03]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo08Uoo`0087oo00<007ooOol02Woo00<007ooOol0>goo00<007ooOol01Woo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo
00<007ooOol037oo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo
00<007ooOol02goo00<007ooOol00goo00<007ooOol0RGoo000EOol80004Ool00`00Oomoo`09Ool3
000kOol00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomo
o`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomo
o`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomo
o`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomo
o`29Ool0029oo`03001oogoo00Qoo`03001oogoo03]oo`03001oogoo00Ioo`03001oogoo00]oo`03
001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03
001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo08Uoo`008goo00<007ooOol01goo00<007ooOol0
>goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0
17oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
2goo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0
17oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
RGoo000TOol00`00Oomoo`06Ool00`00Oomoo`0jOol00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00
Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00
Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00
Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`29Ool001moo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo03Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Yo
o`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Ao
o`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yo
o`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=o
o`03001oogoo08Uoo`0087oo00@007ooOol000Uoo`03001oogoo03Yoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001o
ogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo08Uoo`008Goo0P002Woo00<007oo
Ool0>Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007oo
Ool02Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool0RGoo000]Ool00`00Oomoo`0jOol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`05Ool0
0`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool0
0`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool0
0`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`04Ool00`00Oomoo`29Ool002eoo`03001oogoo03Yoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo
00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo08Uoo`00;Goo00<007ooOol0>Woo00<0
07ooOol027oo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<0
07ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol0RGoo000]
Ool00`00Oomoo`0jOol00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:
Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04
Ool00`00Oomoo`29Ool002eoo`8003Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Eo
o`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yo
o`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eo
o`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yo
o`03001oogoo00Aoo`03001oogoo08Uoo`00;Goo00<007ooOol0>Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007oo
Ool017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool02Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007oo
Ool01Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol0RGoo000]Ool00`00Oomoo`0iOol0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool0
0`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool0
0`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`29Ool0
02eoo`03001oogoo03Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
00Uoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo
00Aoo`03001oogoo08Uoo`00;Goo00<007ooOol0>Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol01Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<0
07ooOol02Goo00<007ooOol017oo00<007ooOol0RGoo000]Ool00`00Oomoo`0iOol00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06
Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`29Ool002eoo`03001o
ogoo03Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Aoo`03001o
ogoo08Uoo`00;Goo00<007ooOol0>7oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo
00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo
00<007ooOol017oo00<007ooOol0RGoo000]Ool00`00Oomoo`0hOol00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`28Ool002eoo`03001oogoo03Qoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03
001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo08Qoo`00
;Goo00<007ooOol0>7oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol0R7oo000]Ool2000iOol00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`06
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09
Ool00`00Oomoo`05Ool00`00Oomoo`28Ool002eoo`03001oogoo03Qoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001o
ogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001o
ogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001o
ogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo08Qoo`00;Goo00<007ooOol0>7oo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0R7oo
000]Ool00`00Oomoo`0gOol00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`28Ool002eoo`03001oogoo03Moo`03001oogoo00]oo`03001oogoo00Uoo`03
001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03
001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo08Qoo`00;Goo00<007ooOol0=goo00<007ooOol0
2goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
1Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0R7oo000]Ool00`00
Oomoo`0gOol00`00Oomoo`0<Ool00`00Ool000040004Ool40005Ool00`00Oomoo`08Ool00`00Oomo
o`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Ool0
00020005Ool30004Ool300000goo001oo`0:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomo
o`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Ool000020003Ool50004Ool4000nOol60004
Ool30004Ool3000hOol002eoo`03001oogoo03Moo`03001oogoo00aoo`03001oogoo00Aoo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool01000Oomoo`001Goo00<007ooOol00P00
0Woo00@007ooOomoo`8000]oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo00Uoo`03001oogoo00Ioo`04001oogoo0007Ool00`00Ool00002Ool01@00Oomoogoo0000?Woo
00<007ooOol00goo00@007ooOol000=oo`04001oogoo0003Ool00`00Oomoo`0eOol002eoo`03001o
ogoo03Ioo`03001oogoo00eoo`03001oogoo00Eoo`04001oo`000004Ool01@00Oomoogoo00002Woo
00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo
00@007ooOol000Aoo`06001oogooOol007oo0P001Goo00<007ooOol02Goo00<007ooOol01Woo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00@007ooOol000Moo`03
001oogoo008000Aoo`8003ioo`03001oogoo00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo03Ao
o`00;Goo00<007ooOol0=Woo00<007ooOol03Goo00<007ooOol01Goo00@007oo000000Aoo`05001o
ogooOol0000:Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`05Ool01000Oomoo`0017oo00H007ooOomoo`00Ool20005Ool00`00Oomoo`09Ool00`00
Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01000
Oomoo`001goo00<007ooOol00P0017oo0P00?goo00<007ooOol00goo00<007ooOol00goo0P001Goo
00<007ooOol0=7oo000]Ool00`00Oomoo`0fOol00`00Oomoo`0=Ool00`00Oomoo`05Ool01000Ool0
000017oo00D007ooOomoo`0000Yoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03
001oogoo00Uoo`03001oogoo00Eoo`04001oogoo0004Ool01P00Oomoogoo001oo`8000Eoo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo00Ioo`04001oogoo0007Ool00`00Oomoo`020004Ool20010Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool20005Ool00`00Oomoo`0dOol002eoo`8003Ioo`03001oogoo00ioo`03001oogoo00Aoo`04
001oogoo0005Ool01@00Oomoogoo00002Woo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
1Woo00<007ooOol02Goo00<007ooOol01Woo00<007oo000017oo00H007ooOomoo`00Ool20005Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`06Ool01000Oomoo`001goo00D007oo001oo`0000Aoo`80045oo`05001oogooOol00005
Ool20005Ool00`00Oomoo`0dOol002eoo`03001oogoo03Eoo`03001oogoo00ioo`03001oogoo00@0
00=oo`03001oogoo00=oo`05001oogooOol0000:Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Ool00004Ool01000Oomoo`000Woo0P00
1Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol01Woo00@007ooOol000Eoo`@0009oo`03001oogoo009oo`80049oo`04001oogoo
0005Ool20005Ool00`00Oomoo`0dOol002eoo`03001oogoo03Aoo`03001oogoo00moo`04001oogoo
0006Ool00`00Oomoo`03Ool01@00Oomoogoo00002Woo00<007ooOol01Woo00<007ooOol02Goo00<0
07ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007oo000017oo00@007ooOol0009oo`80
00Eoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Qoo`03001oogoo00Ioo`04001oogoo0005Ool00`00Ool00003Ool00`00Oomoo`02Ool2000mOol0
0`00Oomoo`02Ool01000Oomoo`001Goo0P001Goo00<007ooOol0=7oo000]Ool00`00Oomoo`0dOol0
0`00Oomoo`0?Ool01@00Oomoogoo00001Goo0P000goo00<007ooOol00Woo00<007ooOol027oo00<0
07ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo0`00
1Goo00D007oo001oo`00009oo`04001oogooOol2000:Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01000Ool000001Woo0P0017oo00D007oo
Oomoo`0003moo`04001oogoo0004Ool01@00Oomoogoo00000Woo00D007ooOomoo`0003Moo`00;Goo
00<007ooOol0<goo00<007ooOol047oo00@007ooOomoo`D00003Ool007oo00<000Eoo`03001oogoo
00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo
00Moo`03001oo`0000Ioo`<000Aoo`<00003Ool007oo00Uoo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`04001oogoo0006Ool50002Ool40010
Ool20006Ool30004Ool3000hOol002eoo`03001oogoo039oo`03001oogoo015oo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Io
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo08Qoo`00;Goo00<007ooOol0<Goo00<007oo
Ool04Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007oo
Ool027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0R7oo000]Ool0
0`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`1TOol3000KOol30003Ool002eoo`03001oogoo02ioo`8001Ioo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo06=oo`03001oogoo01eoo`03001oogoo005oo`00
;Goo00<007ooOol0:goo0`0067oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol0FWoo0`001Woo00<007ooOol00Woo0`0000Eoo`00000007oo00<00005Ool00000001oo`03
000017oo0000000017oo00<007ooOol00Goo000]Ool00`00Oomoo`0TOol7000KOol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`1JOol01000Oomoo`001Goo00<007ooOol0
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00<007ooOol0
0Goo000UOooo001M000>Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomoo`01Ool002eoo`03001oogoo00eoo`03
001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Moo`03001oo`0000Moo`03
001oogoo00Eoo`04001oogoo0009Ool01@00Oomoogoo00001Goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol017oo00D007ooOomoo`0000Uoo`03001oo`0000Qoo`03001oogoo00Eoo`03001o
o`0000Uoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Aoo`03001oogoo00eoo`03001oogoo00EooaD000Aoo`03001oogoo00ioo`03001oogoo019o
o`8000Ioo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000Eoo`03001oogoo005oo`00;Goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Woo
00<007ooOol03Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol027oo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol01goo00<007oo00001goo00<007ooOol01Goo00@007ooOol000Uo
o`05001oogooOol00005Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`04Ool01@00Oomo
ogoo00002Goo00<007oo000027oo00<007ooOol01Goo00<007oo00002Goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol01goo00<007ooOol01goo00<007ooOol017oo00<007ooOol03Goo00<0
07ooOol01@002Goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol04Goo00<007ooOol01Woo
00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00001Goo
00<007ooOol00Goo000]Ool00`00Oomoo`16Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`0EOol20013Ool01000Oomoo`001Goo00<007ooOol00Woo0`000Woo0P000Woo
00<007ooOol00`000Woo0P000Woo00<007ooOol00goo00<007ooOol00Goo000]Ool00`00Oomoo`16
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0DOol00`00Oomoo`14
Ool30005Ool00`00Oomoo`03Ool01000Ool000000Woo0P0017oo00@007oo0000009oo`8000Ioo`03
001oogoo005oo`00;Goo00<007ooOol0AWoo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0
27oo00<007ooOol04Woo0P00Cgoo00<007ooOol07Goo00<007ooOol00Goo000]Ool00`00Oomoo`16
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0AOol00`00Oomoo`1?
Ool00`00Oomoo`0MOol00`00Oomoo`01Ool002eoo`03001oogoo04Ioo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo015oo`03001oogoo04moo`<001]oo`<000=oo`00;Goo
00<007ooOol0AWoo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol047oo
00<007ooOol0M7oo000]Ool00`00Oomoo`16Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`0?Ool00`00Oomoo`1eOol002eoo`03001oogoo04Ioo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03
001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo07Eoo`00;Goo0P00Agoo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol03Woo00<007ooOol0MWoo000]
Ool00`00Oomoo`16Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0>
Ool00`00Oomoo`1fOol002eoo`03001oogoo04Ioo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo00Qoo`03001oogoo00ioo`03001oogoo07Ioo`00;Goo00<007ooOol0AWoo00<007ooOol01goo
00<007ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01Woo00<007ooOol027oo00<007ooOol03Goo00<007ooOol0Mgoo000]Ool00`00Oomo
o`16Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomo
o`1gOol002eoo`03001oogoo04Ioo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03
001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo00eoo`03001oogoo07Moo`00;Goo00<007ooOol0Agoo00<007ooOol01Woo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
1Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1Woo00<007ooOol027oo00<007ooOol037oo00<007ooOol0N7oo000]Ool00`00Oomoo`17Ool00`00
Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`1hOol002eo
o`03001oogoo04Moo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uo
o`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uo
o`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00]o
o`03001oogoo07Qoo`00;Goo00<007ooOol0Agoo00<007ooOol01Woo00<007ooOol027oo00<007oo
Ool01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007oo
Ool027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<007oo
Ool01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol0NGoo000]Ool00`00Oomoo`17Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`1iOol002eoo`8004Qoo`03
001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo07Uoo`00
;Goo00<007ooOol0Agoo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol0NGoo000]Ool00`00Oomoo`17Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`1jOol002eoo`03001oogoo04Moo`03001oogoo00Eo
o`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yo
o`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eo
o`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uo
o`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo07Yoo`00;Goo00<007oo
Ool0Agoo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007oo
Ool01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool0NWoo000]Ool00`00Oomoo`17Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool0
0`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`1jOol002eoo`03001oogoo04Moo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo
00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo07Yoo`00;Goo00<007ooOol0Agoo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<0
07ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0NWoo000]
Ool00`00Oomoo`17Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09
Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05
Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`1jOol002eoo`03001oogoo04Moo`03001oogoo00Eoo`03001oogoo00Uoo`03001o
ogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo07Yoo`00;Goo00<007ooOol0Agoo00<007ooOol01Goo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol017oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol0Ngoo000]Ool00`00Oomo
o`17Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomo
o`1kOol002eoo`8004Qoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Qoo`03001oogoo07]oo`00;Goo00<007ooOol0Agoo00<007ooOol01Goo00<007ooOol02Woo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol027oo00<007ooOol0Ngoo000]Ool00`00Oomoo`17Ool00`00Oomoo`05
Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`1kOol002eoo`03001o
ogoo04Moo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Qoo`03001o
ogoo07]oo`00;Goo00<007ooOol0Agoo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo
00<007ooOol02Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo
00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo
00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo
00<007ooOol027oo00<007ooOol0Ngoo000]Ool00`00Oomoo`17Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomo
o`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomo
o`04Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`1kOol002eoo`03001oogoo04Moo`03
001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03
001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03
001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo07]oo`00
;Goo00<007ooOol0Agoo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol0
2goo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0
1Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol0
2Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol0
1goo00<007ooOol0Ngoo000OOol60008Ool00`00Oomoo`17Ool00`00Oomoo`04Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04
Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04
Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`1kOol001moo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo04Moo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001o
ogoo00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00Ioo`03001oogoo07aoo`0087oo00<007ooOol02Woo00<007ooOol0Agoo00<007ooOol017oo
00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo
00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol017oo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0O7oo000QOol00`00Oomo
o`09Ool30017Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool0
0`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool0
0`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool0
0`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`1lOol0029oo`03001oogoo00Qoo`03001oogoo04Moo`03001oogoo00Aoo`03001oogoo
00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo
00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo
00Aoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo07aoo`008goo00<007ooOol01goo00<0
07ooOol0B7oo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<0
07ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<0
07ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol01Woo00<0
07ooOol0O7oo000TOol00`00Oomoo`06Ool00`00Oomoo`18Ool00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03
Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`1lOol001moo`03001oogoo009oo`03001o
ogoo00Ioo`03001oogoo04Qoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00Ioo`03001oogoo07aoo`0087oo00@007ooOol000Uoo`03001oogoo04Qoo`03001oogoo00=o
o`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00ao
o`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=o
o`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00]o
o`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo07aoo`008Goo0P002Woo
00<007ooOol0B7oo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo
00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo
00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo
00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol02goo00<007ooOol01Woo
00<007ooOol0O7oo000]Ool00`00Oomoo`18Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomo
o`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomo
o`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomo
o`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomo
o`0<Ool00`00Oomoo`06Ool00`00Oomoo`1lOol002eoo`03001oogoo04Qoo`03001oogoo00=oo`03
001oogoo00aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03
001oogoo009oo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo07eoo`00;Goo00<007ooOol0
B7oo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
0goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol0
37oo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo00<007ooOol0
0goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol01Goo00<007ooOol0
OGoo000]Ool00`00Oomoo`18Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00
Oomoo`05Ool00`00Oomoo`1mOol002eoo`8004Uoo`03001oogoo00=oo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001o
ogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001o
ogoo00aoo`03001oogoo00Eoo`03001oogoo07eoo`00;Goo00<007ooOol0B7oo00<007ooOol00goo
00<007ooOol037oo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo
00<007ooOol00Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo
00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol037oo
00<007ooOol00Woo00<007ooOol037oo00<007ooOol01Goo00<007ooOol0OGoo000]Ool00`00Oomo
o`18Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomo
o`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomo
o`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomo
o`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomo
o`1mOol002eoo`03001oogoo04Qoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03
001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00eoo`03
001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03
001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo00Eoo`03001oogoo07eoo`00;Goo00<007ooOol0B7oo00<007ooOol00Woo00<007ooOol0
3Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol037oo00<007ooOol0
0Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol0
2goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol037oo00<007ooOol0
0Woo00<007ooOol037oo00<007ooOol01Goo00<007ooOol0OGoo000]Ool00`00Oomoo`18Ool00`00
Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00
Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00
Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`1mOol002eo
o`03001oogoo04Qoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00eo
o`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009o
o`03001oogoo00eoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00Eo
o`03001oogoo07eoo`00;Goo00<007ooOol0B7oo00<007ooOol00Woo00<007ooOol03Goo00<007oo
Ool00Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007oo
Ool03Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007oo
Ool00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007oo
Ool037oo00<007ooOol01Goo00<007ooOol0OGoo000]Ool00`00Oomoo`19Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00aoo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0
0`00Oomoo`04Ool00`00Oomoo`1nOol002eoo`03001oogoo04Uoo`05001oogooOol0000?Ool00`00
Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol03Goo
00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00D007ooOomoo`00
011oo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00
Oomoo`1nOol002eoo`03001oogoo04Uoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`0=Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<0
07ooOol03Goo00D007ooOomoo`0000moo`05001oogooOol0000@Ool01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol017oo00<007ooOol0OWoo000]Ool2001:Ool01@00
Oomoogoo00003goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00eoo`05001oogooOol0000?Ool01@00
Oomoogoo000047oo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
00Aoo`03001oogoo07ioo`00;Goo00<007ooOol0BGoo00D007ooOomoo`00011oo`05001oogooOol0
000?Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`00011o
o`05001oogooOol0000?Ool01@00Oomoogoo000047oo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo07ioo`00;Goo00<007ooOol0BGoo00D007oo
Oomoo`00011oo`05001oogooOol0000?Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool03Goo00D007ooOomoo`00011oo`05001oogooOol0000?Ool01@00Oomoogoo000047oo00D007oo
Oomoo`0000moo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo07ioo`00
;Goo00<007ooOol0BGoo00D007ooOomoo`00011oo`05001oogooOol0000?Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`00011oo`05001oogooOol0000?Ool0
1@00Oomoogoo000047oo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00eoo`03001o
ogoo00=oo`03001oogoo07ioo`00;Goo00<007ooOol0BGoo00D007ooOomoo`00011oo`05001oogoo
Ool0000?Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`00
011oo`05001oogooOol0000?Ool01@00Oomoogoo000047oo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo07ioo`00;Goo00<007ooOol0BGoo00@0
07ooOol0015oo`04001oogoo000@Ool01@00Oomoogoo000047oo00D007ooOomoo`0000moo`05001o
ogooOol0000@Ool01@00Oomoogoo00003goo00D007ooOomoo`00011oo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`1nOol002eoo`03001oogoo
04Uoo`04001oogoo000AOol01000Oomoo`0047oo00D007ooOomoo`00011oo`05001oogooOol0000?
Ool01@00Oomoogoo000047oo00D007ooOomoo`0000moo`05001oogooOol0000@Ool01@00Oomoogoo
000047oo00D007ooOomoo`0000moo`03001oogoo00=oo`03001oogoo07ioo`00;Goo00<007ooOol0
BGoo00@007ooOol0015oo`04001oogoo000@Ool01@00Oomoogoo000047oo00D007ooOomoo`00011o
o`04001oogoo000@Ool01@00Oomoogoo00003goo00D007ooOomoo`00011oo`05001oogooOol0000@
Ool01@00Oomoogoo00003goo00<007ooOol00goo00<007ooOol0OWoo000]Ool00`00Oomoo`19Ool0
1000Oomoo`004Goo00@007ooOol0011oo`05001oogooOol0000@Ool01000Oomoo`004Goo00@007oo
Ool0011oo`05001oogooOol0000?Ool01@00Oomoogoo000047oo00@007ooOol0015oo`04001oogoo
000@Ool00`00Oomoo`03Ool00`00Oomoo`1nOol002eoo`03001oogoo04Yoo`03001oo`00015oo`04
001oogoo000@Ool01@00Oomoogoo000047oo00@007ooOol0015oo`04001oogoo000@Ool01@00Oomo
ogoo000047oo00@007ooOol0011oo`04001oogoo000AOol01000Oomoo`0047oo00<007ooOol00goo
00<007ooOol0OWoo000]Ool00`00Oomoo`1:Ool00`00Ool0000AOol01000Oomoo`0047oo00D007oo
Oomoo`00011oo`04001oogoo000AOol01000Oomoo`0047oo00D007ooOomoo`00011oo`04001oogoo
000@Ool01000Oomoo`004Goo00@007ooOol0011oo`03001oogoo009oo`03001oogoo07moo`00;Goo
0P00Bgoo00<007oo00004Goo00@007ooOol0011oo`05001oogooOol0000@Ool01000Oomoo`004Goo
00@007ooOol0011oo`04001oogoo000AOol01000Oomoo`004Goo00<007oo00004Goo00@007ooOol0
011oo`03001oogoo009oo`03001oogoo07moo`00;Goo00<007ooOol0BWoo00<007oo00004Woo00<0
07oo000047oo00D007ooOomoo`00011oo`04001oogoo000AOol00`00Ool0000BOol00`00Ool0000A
Ool01000Oomoo`004Goo00<007oo00004Goo00@007ooOol0011oo`03001oogoo009oo`03001oogoo
07moo`00;Goo00<007ooOol0BWoo00<007oo00004Woo00<007oo000047oo00D007ooOomoo`00011o
o`04001oogoo000AOol00`00Ool0000BOol00`00Ool0000AOol01000Oomoo`004Goo00<007oo0000
4Goo00@007ooOol0011oo`03001oogoo009oo`03001oogoo07moo`00;Goo00<007ooOol0BWoo00<0
07oo00004Woo00<007oo00004Goo00<007oo00004Goo00@007ooOol0015oo`03001oo`00019oo`03
001oo`00015oo`03001oo`00019oo`03001oo`00015oo`04001oogoo000@Ool00`00Oomoo`02Ool0
0`00Oomoo`1oOol002eoo`03001oogoo04Yoo`03001oo`00019oo`80019oo`03001oo`00019oo`03
001oo`00015oo`03001oo`00019oo`03001oo`00015oo`03001oo`00019oo`03001oo`00015oo`04
001oogoo000@Ool00`00Oomoo`02Ool00`00Oomoo`1oOol002eoo`03001oogoo04]oo`03001oogoo
015oo`80019oo`03001oo`00019oo`03001oo`00015oo`03001oo`00019oo`03001oo`00015oo`03
001oo`00019oo`03001oo`00015oo`04001oogoo000@Ool00`00Oomoo`02Ool00`00Oomoo`1oOol0
02eoo`03001oogoo04]oo`03001oogoo015oo`80019oo`03001oo`00019oo`03001oo`00015oo`03
001oo`00019oo`03001oo`00019oo`80019oo`03001oo`00015oo`03001oo`00015oo`03001oogoo
009oo`03001oogoo07moo`00;Goo00<007ooOol0Bgoo00<007ooOol04Goo0P004Woo00<007oo0000
4Woo0`004Woo0P004Woo0P004goo0P004goo00<007ooOol047oo00<007oo00004Goo00<007ooOol0
0Woo00<007ooOol0Ogoo000TOol00`00Oomoo`06Ool00`00Oomoo`1;Ool00`00Oomoo`0BOol00`00
Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0AOol2000COol2000COol00`00
Oomoo`0AOol2000AOol00`00Oomoo`02Ool00`00Oomoo`1oOol002Aoo`03001oogoo00Ioo`03001o
ogoo07Aoo`03001oogoo02Ioo`03001oogoo015oo`03001oogoo01=oo`03001oogoo015oo`03001o
ogoo015oo`80015oo`03001oogoo009oo`03001oogoo07moo`0097oo00<007ooOol01Woo00<007oo
Ool0M7oo00<007ooOol09Woo00<007ooOol09goo00<007ooOol04Goo00<007ooOol04Woo00<007oo
Ool03goo00<007ooOol00Woo00<007ooOol0Ogoo000OOol80006Ool3003oOol3Ool00`00Oomoo`02
Ool00`00Oomoo`1oOol001moo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moo`=oo`03
001oogoo009oo`03001oogoo07moo`0087oo00D007ooOomoo`0000Qoo`03001oogoo0?moo`Aoo`05
001oogooOol00021Ool0025oo`04001oogoo0008Ool00`00Oomoo`3oOol4Ool01000Oomoo`00PWoo
000ROol00`00Ool00008Ool00`00Oomoo`3oOol4Ool01000Oomoo`00PWoo000SOol20008Ool00`00
Oomoo`3oOol4Ool01000Oomoo`00PWoo000TOol00`00Oomoo`06Ool00`00Oomoo`3oOol4Ool01000
Oomoo`00PWoo000]Ool00`00Oomoo`3oOol4Ool01000Oomoo`00PWoo000]Ool00`00Oomoo`3oOol4
Ool01000Oomoo`00PWoo000]Ool00`00Oomoo`3oOol4Ool01000Oomoo`00PWoo000]Ool00`00Oomo
o`3oOol4Ool01000Oomoo`00PWoo000]Ool2003oOol6Ool00`00Ool00022Ool002eoo`03001oogoo
0?moo`Eoo`03001oo`00089oo`00;Goo00<007ooOol0ogoo1Goo0P00Pgoo000]Ool00`00Oomoo`3o
Ool5Ool00`00Oomoo`22Ool002eoo`03001oogoo0?moohYoo`00;Goo00<007ooOol0ogooRWoo000]
Ool00`00Oomoo`3oOon:Ool002eoo`03001oogoo0?moohYoo`00;Goo00<007ooOol0ogooRWoo003o
OonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYo
o`00ogoo^Woo003oOonjOol0009oo`<00?mookEoo`000Woo00@007ooOol002Qoo`<002Aoo`<00?mo
of9oo`001Goo00<007ooOol09Woo00<007ooOol09Woo00<007ooOol0ogooH7oo0006Ool00`00Oomo
o`04Ool70002Ool60003Ool2000017oo001oogoo0`001Woo00<007ooOol01Goo0`000goo0`0000Eo
o`00000007oo00<00005Ool00000001oo`03000017oo0000000017oo00<007ooOol0ogooH7oo0006
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`000goo00@007ooOol0009oo`<00005Ool0
07ooOol00005Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00005Ool00`00Oomoo`3oOomPOol000Ioo`03001oogoo00Eoo`03001o
ogoo00=oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00005Ool00`00Oomoo`3oOomPOol000Ioo`03001oogoo00Eoo`03001oogoo00=oo`05001o
ogooOol00004Ool00`00Oomoo`02Ool01000Oomoogoo0P001Woo00<007ooOol01Woo00<007ooOol0
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00<007ooOol0
ogooH7oo0006Ool00`00Oomoo`05Ool00`00Oomoo`02Ool20004Ool01@00Oomoogoo000017oo00@0
07ooOol000Qoo`03001oogoo00Ioo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000Eoo`03001oogoo0?moof1oo`001Woo00<007ooOol01Goo1@000goo
00D007ooOomoo`0000=oo`03001oogoo0080009oo`04001oogoo0005Ool00`00Oomoo`06Ool00`00
Oomoo`02Ool30002Ool20002Ool00`00Oomoo`030002Ool20002Ool00`00Oomoo`03Ool00`00Oomo
o`3oOomPOol000Ioo`03001oogoo00Eoo`03001oogoo009oo`800003Ool0000000@000=oo`800003
Ool007oo009oo`<000Eoo`03001oogoo00Ioo`03001oogoo00=oo`04001oo`000002Ool20004Ool0
1000Ool000000Woo0P001Woo00<007ooOol0ogooH7oo0006Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo
Ool06Goo00<007ooOol0ogooH7oo0006Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0:
Ool2000;Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol06Goo00<007ooOol0ogoo
H7oo0006Ool00`00Oomoo`04Ool7000>Ool00`00Oomoo`09Ool30002Ool9000IOol3003oOomROol0
00Ioo`03001oogoo0?mook5oo`001Woo00<007ooOol0ogoo/Goo0007Ool00`00Oomoo`3oOon`Ool0
00Moo`04001oogoo003oOon_Ool000Qoo`<00?moojmoo`00ogoo^Woo003oOonjOol00?mookYoo`00
ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonj
Ool00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00\
\>"],
  ImageRangeCache->{{{0, 440.938}, {271.938, 0}} -> {-27.4601, -5.44449, 
  0.755539, 0.0563789}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.0047619 0.59314 0.00745869 [
[.2619 .58064 -8 -14 ]
[.2619 .58064 8 0 ]
[.5 .58064 -11 -14 ]
[.5 .58064 11 0 ]
[.7381 .58064 -11 -14 ]
[.7381 .58064 11 0 ]
[.97619 .58064 -11 -14 ]
[.97619 .58064 11 0 ]
[1.025 .59314 0 -7 ]
[1.025 .59314 38.125 7 ]
[.01131 .14562 -24.25 -7 ]
[.01131 .14562 0 7 ]
[.01131 .29479 -24.25 -7 ]
[.01131 .29479 0 7 ]
[.01131 .44397 -24.25 -7 ]
[.01131 .44397 0 7 ]
[.02381 .64303 -43.3125 0 ]
[.02381 .64303 43.3125 17.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .59314 m
.2619 .59939 L
s
gsave
.2619 .58064 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.5 .59314 m
.5 .59939 L
s
gsave
.5 .58064 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.7381 .59314 m
.7381 .59939 L
s
gsave
.7381 .58064 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 .59314 m
.97619 .59939 L
s
gsave
.97619 .58064 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 .59314 m
.07143 .59689 L
s
.11905 .59314 m
.11905 .59689 L
s
.16667 .59314 m
.16667 .59689 L
s
.21429 .59314 m
.21429 .59689 L
s
.30952 .59314 m
.30952 .59689 L
s
.35714 .59314 m
.35714 .59689 L
s
.40476 .59314 m
.40476 .59689 L
s
.45238 .59314 m
.45238 .59689 L
s
.54762 .59314 m
.54762 .59689 L
s
.59524 .59314 m
.59524 .59689 L
s
.64286 .59314 m
.64286 .59689 L
s
.69048 .59314 m
.69048 .59689 L
s
.78571 .59314 m
.78571 .59689 L
s
.83333 .59314 m
.83333 .59689 L
s
.88095 .59314 m
.88095 .59689 L
s
.92857 .59314 m
.92857 .59689 L
s
.25 Mabswid
0 .59314 m
1 .59314 L
s
gsave
1.025 .59314 -61 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
70.625000 14.000000 moveto
(@) show
74.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.187500 14.000000 moveto
(D) show
97.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .14562 m
.03006 .14562 L
s
gsave
.01131 .14562 -85.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(60) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .29479 m
.03006 .29479 L
s
gsave
.01131 .29479 -85.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(40) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.02381 .44397 m
.03006 .44397 L
s
gsave
.01131 .44397 -85.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.125 Mabswid
.02381 .03374 m
.02756 .03374 L
s
.02381 .07103 m
.02756 .07103 L
s
.02381 .10832 m
.02756 .10832 L
s
.02381 .18291 m
.02756 .18291 L
s
.02381 .22021 m
.02756 .22021 L
s
.02381 .2575 m
.02756 .2575 L
s
.02381 .33209 m
.02756 .33209 L
s
.02381 .36938 m
.02756 .36938 L
s
.02381 .40667 m
.02756 .40667 L
s
.02381 .48126 m
.02756 .48126 L
s
.02381 .51855 m
.02756 .51855 L
s
.02381 .55585 m
.02756 .55585 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -104.312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.375 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 21.375000 moveto
 541.000000 21.375000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 21.375000 lineto
closepath
clip newpath
63.000000 17.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 17.375000 moveto
(\\331) show
70.937500 17.375000 moveto
(\\331) show
78.875000 17.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bzds) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.812500 17.375000 moveto
(@) show
109.750000 17.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Tmm2) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.687500 17.375000 moveto
(D) show
145.625000 17.375000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02857 .59314 m
.03333 .59313 L
.0381 .59311 L
.04286 .59309 L
.04762 .59307 L
.05238 .59303 L
.05714 .59299 L
.0619 .59294 L
.06667 .59288 L
.07143 .59281 L
.07619 .59272 L
.08095 .59262 L
.08571 .5925 L
.09048 .59236 L
.09524 .59219 L
.1 .59199 L
.10476 .59176 L
.10952 .59149 L
.11429 .59117 L
.11905 .59079 L
.12381 .59034 L
.12857 .5898 L
.13333 .58916 L
.1381 .58837 L
.14286 .58741 L
.14762 .58622 L
.15238 .58474 L
.15714 .58288 L
.1619 .58049 L
.16667 .5774 L
.17143 .57332 L
.17619 .56784 L
.18095 .56034 L
.18571 .54983 L
.19048 .53475 L
.19524 .51247 L
.2 .4786 L
.20476 .42664 L
.20952 .35234 L
.21429 .2612 L
.21905 .16769 L
.22381 .08955 L
.22857 .04286 L
.23333 .03671 L
.2381 .07084 L
.24286 .1356 L
.24762 .21367 L
.25238 .28503 L
.25714 .33119 L
.2619 .3402 L
Mistroke
.26667 .30959 L
.27143 .24655 L
.27619 .16681 L
.28095 .08998 L
.28571 .03513 L
.29048 .01595 L
.29524 .03694 L
.3 .09297 L
.30476 .16984 L
.30952 .24831 L
.31429 .30881 L
.31905 .33602 L
.32381 .3233 L
.32857 .27364 L
.33333 .19948 L
.3381 .11938 L
.34286 .05319 L
.34762 .01761 L
.35238 .02137 L
.35714 .06357 L
.3619 .13373 L
.36667 .21416 L
.37143 .28494 L
.37619 .32825 L
.38095 .33332 L
.38571 .29893 L
.39048 .23353 L
.39524 .15366 L
.4 .0791 L
.40476 .02856 L
.40952 .01472 L
.41429 .04089 L
.41905 .10072 L
.42381 .17913 L
.42857 .2566 L
.43333 .31381 L
.4381 .33636 L
.44286 .3188 L
.44762 .26536 L
.45238 .18948 L
.45714 .11016 L
.4619 .0471 L
.46667 .01624 L
.47143 .02513 L
.47619 .07166 L
.48095 .14423 L
.48571 .2246 L
.49048 .29289 L
.49524 .33186 L
.5 .33191 L
Mistroke
.50476 .29304 L
.50952 .22485 L
.51429 .14459 L
.51905 .07212 L
.52381 .02569 L
.52857 .0169 L
.53333 .04786 L
.5381 .11102 L
.54286 .19044 L
.54762 .26642 L
.55238 .31996 L
.55714 .33763 L
.5619 .31518 L
.56667 .25806 L
.57143 .1807 L
.57619 .1024 L
.58095 .04266 L
.58571 .01659 L
.59048 .03054 L
.59524 .08118 L
.6 .15583 L
.60476 .23581 L
.60952 .30131 L
.61429 .3358 L
.61905 .33083 L
.62381 .28763 L
.62857 .21695 L
.63333 .13662 L
.6381 .06656 L
.64286 .02446 L
.64762 .0208 L
.65238 .05648 L
.65714 .12278 L
.6619 .20297 L
.66667 .27724 L
.67143 .32699 L
.67619 .33982 L
.68095 .31271 L
.68571 .25231 L
.69048 .17394 L
.69524 .09717 L
.7 .04124 L
.70476 .02035 L
.70952 .03964 L
.71429 .09459 L
.71905 .17152 L
.72381 .25136 L
.72857 .3145 L
.73333 .34522 L
.7381 .3363 L
Mistroke
.74286 .29024 L
.74762 .21899 L
.75238 .14102 L
.75714 .07636 L
.7619 .04233 L
.76667 .04859 L
.77143 .09538 L
.77619 .17362 L
.78095 .26723 L
.78571 .35847 L
.79048 .43287 L
.79524 .48493 L
.8 .5189 L
.80476 .54128 L
.80952 .55646 L
.81429 .56707 L
.81905 .57468 L
.82381 .58026 L
.82857 .58444 L
.83333 .58763 L
.8381 .59012 L
.84286 .59208 L
.84762 .59366 L
.85238 .59495 L
.85714 .59602 L
.8619 .5969 L
.86667 .59765 L
.87143 .59829 L
.87619 .59885 L
.88095 .59933 L
.88571 .59975 L
.89048 .60012 L
.89524 .60045 L
.9 .60075 L
.90476 .60102 L
.90952 .60126 L
.91429 .60148 L
.91905 .60168 L
.92381 .60187 L
.92857 .60205 L
.93333 .60221 L
.9381 .60236 L
.94286 .6025 L
.94762 .60264 L
.95238 .60277 L
.95714 .60289 L
.9619 .603 L
.96667 .60311 L
.97143 .60322 L
.97619 .60332 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{353.562, 218.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006i000141000`40O003h00Oogoo^Woo003oOonj
Ool00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00
ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo000fOol0
0`00Oomoo`3oOon1Ool003Ioo`03001oogoo0?mooh5oo`00=Woo00<007ooOol0ogooPGoo000fOol0
0`00Oomoo`3oOon1Ool003Ioo`03001oogoo0?mooh5oo`00=Woo00<007ooOol0Egoo00<007ooOol0
9Goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol047oo00<007ooOol0`Woo000fOol00`00
Oomoo`1GOol00`00Oomoo`0@Ool2000COol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0@
Ool00`00Oomoo`32Ool003Ioo`03001oogoo05Moo`03001oogoo011oo`03001oo`00019oo`03001o
ogoo015oo`80019oo`80019oo`80019oo`80019oo`03001oogoo09Yoo`00=Woo00<007ooOol0EWoo
00<007oo00004Goo00<007oo00004Goo00<007oo00004Woo0P004Goo00<007oo00004Goo00<007oo
00004Goo00<007oo00004Woo00<007ooOol0VWoo000fOol00`00Oomoo`1FOol00`00Ool0000AOol0
0`00Ool0000AOol00`00Ool0000AOol00`00Ool0000AOol00`00Ool0000AOol00`00Ool0000AOol0
0`00Ool0000BOol2002KOol003Ioo`03001oogoo05Ioo`03001oo`00015oo`03001oo`00015oo`03
001oo`00015oo`03001oo`00015oo`03001oo`00015oo`04001oogoo000@Ool00`00Ool0000BOol2
002KOol003Ioo`8005Ioo`05001oogooOol0000@Ool01000Oomoo`0047oo00<007oo00004Goo00<0
07oo00004Goo00@007ooOol0011oo`04001oogoo000@Ool01000Oomoo`0047oo00<007oo0000Vgoo
000fOol00`00Oomoo`14Ool00`00Oomoo`0>Ool01@00Oomoogoo000047oo00@007ooOol0011oo`03
001oo`00015oo`03001oo`00015oo`04001oogoo000@Ool01000Oomoo`0047oo00@007ooOol0011o
o`04001oogoo002JOol003Ioo`03001oogoo04=oo`80011oo`05001oogooOol0000?Ool01@00Oomo
ogoo000047oo00@007ooOol0011oo`04001oogoo000?Ool01@00Oomoogoo00003goo00D007ooOomo
o`00011oo`04001oogoo000@Ool01000Oomoo`00VWoo000fOol00`00Oomoo`12Ool00`00Ool0000@
Ool01@00Oomoogoo00003goo00D007ooOomoo`0000moo`05001oogooOol0000?Ool01@00Oomoogoo
00003goo00D007ooOomoo`0000moo`05001oogooOol0000@Ool01000Oomoo`0047oo00@007ooOol0
015oo`03001oogoo08Ioo`00=Woo00<007ooOol0@Woo00<007oo000047oo00D007ooOomoo`0000mo
o`05001oogooOol0000?Ool01@00Oomoogoo00003goo00D007ooOomoo`0000moo`05001oogooOol0
000?Ool01@00Oomoogoo000047oo00@007ooOol0011oo`04001oogoo000AOol00`00Oomoo`26Ool0
03Ioo`03001oogoo049oo`03001oo`00011oo`05001oogooOol0000?Ool01@00Oomoogoo00003goo
00D007ooOomoo`0000moo`05001oogooOol0000?Ool01@00Oomoogoo00003goo00D007ooOomoo`00
00moo`05001oogooOol0000@Ool01000Oomoo`004Goo0P00Qgoo000fOol00`00Oomoo`12Ool00`00
Ool0000@Ool01@00Oomoogoo00003goo00D007ooOomoo`0000moo`05001oogooOol0000?Ool01@00
Oomoogoo00003goo00D007ooOomoo`0000moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00
Oomoo`0=Ool01000Oomoo`004Goo0P00Qgoo000fOol00`00Oomoo`12Ool00`00Ool0000@Ool01@00
Oomoogoo00003goo00<007ooOol00Woo00<007ooOol037oo00D007ooOomoo`0000moo`05001oogoo
Ool0000?Ool01@00Oomoogoo00003goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo
00eoo`04001oogoo000@Ool00`00Ool00027Ool003Ioo`03001oogoo045oo`05001oogooOol0000?
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol037oo00D007ooOomoo`0000moo`05
001oogooOol0000?Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol037oo00<007oo
Ool00Woo00<007ooOol03Goo00D007ooOomoo`0000moo`03001oo`0008Moo`00=Woo00<007ooOol0
@Goo00D007ooOomoo`0000moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0
0`00Oomoo`02Ool00`00Oomoo`0<Ool01@00Oomoogoo00003goo00D007ooOomoo`0000moo`03001o
ogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001o
ogoo00eoo`03001oo`0008Moo`00=Woo00<007ooOol0@Goo00D007ooOomoo`0000moo`05001oogoo
Ool0000?Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00
Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00
Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01000
Oomoo`00QWoo000fOol00`00Oomoo`11Ool01@00Oomoogoo00003Woo00<007ooOol00goo00<007oo
Ool037oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol02goo00<007oo
Ool00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<007oo
Ool037oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00@007oo
Ool008Ioo`00=Woo00<007ooOol0@Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00eoo`04001oogoo
0026Ool003Ioo`80049oo`05001oogooOol0000>Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00
Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00
Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool01@00Oomoogoo0000QWoo
000fOol00`00Oomoo`11Ool01@00Oomoogoo00003Woo00<007ooOol00goo00<007ooOol02goo00<0
07ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol037oo00D007ooOomoo`0008Io
o`00=Woo00<007ooOol0@Goo00D007ooOomoo`0000ioo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03
001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`05001oogooOol00026
Ool003Ioo`03001oogoo041oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`05001o
ogooOol00026Ool003Ioo`03001oogoo041oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo
00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo
00]oo`05001oogooOol00026Ool003Ioo`03001oogoo041oo`03001oogoo009oo`03001oogoo00ao
o`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=o
o`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]o
o`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Ao
o`03001oogoo00]oo`03001oogoo009oo`03001oogoo08=oo`00=Woo00<007ooOol0@7oo00<007oo
Ool00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007oo
Ool02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol00goo00<007ooOol02goo00<007oo
Ool00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007oo
Ool02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00Woo00<007ooOol0Pgoo000fOol0
0`00Oomoo`10Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool0
0`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool0
0`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool0
0`00Oomoo`23Ool003Ioo`03001oogoo041oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00=oo`03001oogoo08=oo`00=Woo00<007ooOol0@7oo00<007ooOol00goo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<0
07ooOol017oo00<007ooOol02Goo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol00goo00<007ooOol0Pgoo000fOol00`00Oomoo`10
Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04
Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`23
Ool003Ioo`03001oogoo041oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001o
ogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001o
ogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00=oo`03001oogoo08=oo`00=Woo0P00@Goo00<007ooOol00goo00<007ooOol02goo00<007oo
Ool00goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool02Goo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007oo
Ool017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool02Woo00<007ooOol00goo00<007ooOol0Pgoo000fOol00`00Oomoo`10Ool00`00Oomoo`03Ool0
0`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool0
0`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool0
0`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`23Ool003Ioo`03001oogoo
041oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo
00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo
08=oo`00=Woo00<007ooOol0@7oo00<007ooOol00goo00<007ooOol02Woo00<007ooOol01Goo00<0
07ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<0
07ooOol00goo00<007ooOol0Pgoo000fOol00`00Oomoo`10Ool00`00Oomoo`03Ool00`00Oomoo`0:
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`05
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`22Ool003Ioo`03001oogoo041oo`03001o
ogoo00Aoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo089oo`00=Woo
00<007ooOol0@7oo00<007ooOol017oo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo
00<007ooOol0PWoo000fOol00`00Oomoo`10Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`22Ool003Ioo`03001oogoo03moo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo089oo`00=Woo00<007ooOol0
?goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
PWoo000ROol30005Ool30009Ool00`00Oomoo`0oOol00`00Oomoo`05Ool00`00Oomoo`09Ool00`00
Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00
Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`22Ool0025oo`05001oogooOol00003Ool01@00Oomo
ogoo000027oo00<007ooOol0?goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<0
07ooOol02Goo00<007ooOol01Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<0
07ooOol027oo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<0
07ooOol01Goo00<007ooOol0PWoo000POol00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`05
Ool00`00Oomoo`0oOol00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`08
Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`05
Ool00`00Oomoo`22Ool001Moo`P00003Ool007oo00Aoo`03001oo`0000Eoo`03001oogoo00Eoo`<0
03moo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo
00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo
00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo
089oo`0087oo00<007ooOol00goo00<007oo00001Goo00<007ooOol01Goo00<007ooOol0?goo00<0
07ooOol01Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0PWoo000P
Ool20003Ool01000Oomoo`001Goo00<007ooOol01Goo00<007ooOol0?goo00<007ooOol01Goo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<0
07ooOol01Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0PWoo000POol00`00Ool00002
0003Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0oOol00`00Oomoo`05Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`22Ool0025oo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo03moo`03001oogoo00Eoo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo085oo`008Woo0P001Goo00D007ooOomoo`0000Qo
o`03001oogoo03moo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Io
o`03001oogoo085oo`0097oo0`000goo0`002Goo00<007ooOol0?goo00<007ooOol01Goo00<007oo
Ool027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0PGoo000fOol00`00Oomoo`0oOol0
0`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`21Ool0
03Ioo`03001oogoo03moo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
00Ioo`03001oogoo085oo`00=Woo00<007ooOol0?goo00<007ooOol01Goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol0PGoo000fOol00`00Oomoo`0oOol00`00Oomoo`05
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`21Ool003Ioo`03001o
ogoo03moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo085oo`00=Woo00<007ooOol0?goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01Woo00<007ooOol0PGoo000fOol20010Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`21Ool003Ioo`03001oogoo03moo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo085oo`00=Woo00<0
07ooOol0?goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol0PGoo000fOol00`00Oomoo`0oOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`21Ool003Ioo`03001oogoo03ioo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo00Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo085oo`00=Woo00<007ooOol0?Woo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0PGoo
000fOol00`00Oomoo`0nOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`21Ool003Ioo`03001oogoo03ioo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo085oo`00=Woo00<007ooOol0?Woo00<007ooOol0
1goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
1Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0PGoo000fOol00`00
Oomoo`0nOol00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00
Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`21Ool003Ioo`03001oogoo03ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Uo
o`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eo
o`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qo
o`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo085oo`00=Woo00<007ooOol0?Woo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007oo
Ool01Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool02Goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0PGoo000fOol2000oOol00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`21Ool003Ioo`03
001oogoo03ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo081oo`00=Woo00<007ooOol0?Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
1Woo00<007ooOol027oo00<007ooOol0P7oo000fOol00`00Oomoo`0nOol00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00
Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`20Ool003Ioo`03001oogoo03io
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uo
o`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eo
o`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uo
o`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo081o
o`00=Woo00<007ooOol0?Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol02Goo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007oo
Ool027oo00<007ooOol0P7oo000fOol00`00Oomoo`0nOol00`00Oomoo`08Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool0
0`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`20Ool003Ioo`03001oogoo03eoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo081oo`00=Woo00<0
07ooOol0?Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Goo00<0
07ooOol0P7oo000fOol00`00Oomoo`0mOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04
Ool00`00Oomoo`09Ool00`00Oomoo`20Ool003Ioo`03001oogoo03eoo`03001oogoo00Uoo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001o
ogoo00Yoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo081oo`00=Woo00<007ooOol0?Goo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol02goo
00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo
00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Goo00<007ooOol0P7oo
000fOol00`00Oomoo`0mOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomo
o`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomo
o`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomo
o`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomo
o`09Ool00`00Oomoo`20Ool003Ioo`8003ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Aoo`03001oogoo00Uoo`03001oogoo081oo`00=Woo00<007ooOol0?Goo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Goo00<007ooOol0P7oo000fOol00`00Oomoo`0m
Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03
Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`20
Ool003Ioo`03001oogoo03eoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001o
ogoo00Uoo`03001oogoo081oo`00=Woo00<007ooOol0?Goo00<007ooOol02Woo00<007ooOol00goo
00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo
00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo
00<007ooOol02Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02Goo00<007ooOol0P7oo000fOol00`00Oomoo`0mOol00`00Oomo
o`0:Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomo
o`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomo
o`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomo
o`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`20Ool003Ioo`03
001oogoo03eoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`03
001oogoo081oo`00=Woo00<007ooOol0?Goo00<007ooOol02Woo00<007ooOol00goo00<007ooOol0
2goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
0goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
2goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
0goo00<007ooOol02Woo00<007ooOol0P7oo000fOol00`00Oomoo`0mOol00`00Oomoo`0:Ool00`00
Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00
Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`20Ool003Ioo`03001oogoo03eo
o`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]o
o`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009o
o`03001oogoo00aoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]o
o`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo081o
o`009Goo00<007ooOol00Woo0`002Goo00<007ooOol0?Goo00<007ooOol02Woo00<007ooOol00goo
00<007ooOol02goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo
00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo
00<007ooOol037oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo
00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0P7oo000UOol01@00Oomoogoo00000goo00<0
07ooOol01Woo00<007ooOol0?Goo00<007ooOol02Woo00<007ooOol00goo00<007ooOol02goo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<0
07ooOol037oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol037oo00<0
07ooOol00Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<0
07ooOol02Woo00<007ooOol0P7oo000UOol01000Oomoo`001Goo00<007ooOol01Goo00<007ooOol0
?Goo00<007ooOol02Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol00Woo00<007ooOol0
37oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
0Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol0
37oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0
Ogoo000GOol800000goo000000070005Ool00`00Oomoo`05Ool3000mOol00`00Oomoo`0:Ool00`00
Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo00003Woo00<007ooOol00Woo00<007ooOol03Goo
00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
009oo`03001oogoo00]oo`03001oogoo07moo`0087oo00<007ooOol00Woo00@007ooOol000Eoo`03
001oogoo00Eoo`03001oogoo03eoo`03001oogoo00]oo`05001oogooOol0000?Ool01@00Oomoogoo
00003goo00D007ooOomoo`0000moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02
Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`1oOol0025oo`05001o
ogooOol00002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0mOol00`00Oomoo`0;Ool0
1@00Oomoogoo00003goo00D007ooOomoo`0000moo`05001oogooOol0000?Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol037oo00D007ooOomo
o`0000moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`1oOol0
029oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0mOol00`00Oomo
o`0;Ool01@00Oomoogoo00003goo00D007ooOomoo`0000moo`05001oogooOol0000?Ool01@00Oomo
ogoo00003goo00D007ooOomoo`0000moo`05001oogooOol0000?Ool01@00Oomoogoo00003goo00D0
07ooOomoo`0000moo`03001oogoo009oo`03001oogoo00]oo`03001oogoo07moo`008goo00<007oo
00000Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol0?7oo00<007ooOol037oo00D007oo
Oomoo`0000moo`05001oogooOol0000?Ool01@00Oomoogoo00003goo00D007ooOomoo`0000moo`05
001oogooOol0000@Ool01000Oomoo`003goo00D007ooOomoo`0000moo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`1oOol002Aoo`8000=oo`05001oogooOol00008
Ool00`00Oomoo`0lOol00`00Oomoo`0<Ool01@00Oomoogoo00003goo00D007ooOomoo`0000moo`05
001oogooOol0000?Ool01@00Oomoogoo00003goo00D007ooOomoo`00011oo`04001oogoo000?Ool0
1@00Oomoogoo00003goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00]oo`03001o
ogoo07moo`009Goo00<007ooOol00Woo0`002Goo00<007ooOol0?7oo00<007ooOol037oo00D007oo
Oomoo`0000moo`04001oogoo000@Ool01@00Oomoogoo00003goo00D007ooOomoo`00011oo`04001o
ogoo000@Ool01000Oomoo`0047oo00@007ooOol000moo`05001oogooOol0000?Ool00`00Oomoo`02
Ool00`00Oomoo`0;Ool00`00Oomoo`1oOol003Ioo`03001oogoo03aoo`03001oogoo00aoo`05001o
ogooOol0000@Ool00`00Ool0000@Ool01@00Oomoogoo00003goo00D007ooOomoo`00011oo`04001o
ogoo000@Ool01000Oomoo`0047oo00@007ooOol000moo`05001oogooOol0000?Ool01@00Oomoogoo
00003Woo00<007ooOol0Ogoo000fOol00`00Oomoo`0lOol00`00Oomoo`0<Ool01000Oomoo`004Goo
00<007oo00004Goo00<007oo000047oo00D007ooOomoo`00011oo`04001oogoo000@Ool01000Oomo
o`0047oo00@007ooOol0011oo`04001oogoo000?Ool01@00Oomoogoo00003Woo00<007ooOol0Ogoo
000fOol00`00Oomoo`0lOol00`00Oomoo`0=Ool00`00Ool0000AOol00`00Ool0000AOol00`00Ool0
000AOol01000Oomoo`0047oo00@007ooOol0011oo`04001oogoo000@Ool00`00Ool0000AOol01000
Oomoo`003goo00D007ooOomoo`0000ioo`03001oogoo07moo`00=Woo00<007ooOol0?7oo00<007oo
Ool03Goo00<007oo00004Goo00<007oo00004Goo00<007oo00004Goo00<007oo00004Goo00<007oo
00004Goo00<007oo00004Goo00<007oo00004Goo00@007ooOol0011oo`04001oogoo000>Ool00`00
Oomoo`1oOol003Ioo`03001oogoo03aoo`03001oogoo00eoo`03001oo`00015oo`03001oo`00015o
o`03001oo`00015oo`03001oo`00015oo`03001oo`00015oo`03001oo`00015oo`03001oo`00015o
o`03001oo`00015oo`04001oogoo000>Ool00`00Oomoo`1oOol003Ioo`8003eoo`03001oogoo00eo
o`03001oo`00019oo`03001oogoo015oo`80015oo`03001oo`00015oo`<0019oo`80019oo`80015o
o`03001oo`00015oo`04001oogoo000>Ool00`00Oomoo`1oOol003Ioo`03001oogoo03aoo`03001o
ogoo00eoo`8001=oo`03001oogoo019oo`03001oogoo011oo`03001oogoo02Eoo`03001oogoo015o
o`80019oo`80015oo`04001oogoo000>Ool00`00Oomoo`1oOol003Ioo`03001oogoo03aoo`03001o
ogoo00ioo`03001oogoo015oo`03001oogoo02Eoo`03001oogoo02Eoo`03001oogoo015oo`03001o
ogoo015oo`80015oo`04001oogoo000?Ool00`00Oomoo`1nOol003Ioo`03001oogoo03aoo`03001o
ogoo00ioo`03001oogoo08Yoo`03001oogoo011oo`03001oo`0000moo`03001oogoo07ioo`00=Woo
00<007ooOol0?7oo00<007ooOol0[Woo0P0047oo00<007ooOol0OWoo000fOol00`00Oomoo`0lOol0
0`00Oomoo`2^Ool00`00Oomoo`0?Ool00`00Oomoo`1nOol003Ioo`03001oogoo03aoo`03001oogoo
0<1oo`03001oogoo07ioo`00=Woo00<007ooOol0?7oo00<007ooOol0`7oo00<007ooOol0OWoo000f
Ool00`00Oomoo`0lOol00`00Oomoo`30Ool00`00Oomoo`1nOol003Ioo`03001oogoo03aoo`03001o
ogoo0<1oo`03001oogoo07ioo`00=Woo00<007ooOol0?7oo00<007ooOol0`7oo00<007ooOol0OWoo
000fOol00`00Oomoo`0lOol00`00Oomoo`30Ool00`00Oomoo`1nOol003Ioo`03001oogoo03aoo`03
001oogoo0<1oo`03001oogoo07ioo`00=Woo0P00?Goo00<007ooOol0`7oo00<007ooOol0OWoo000f
Ool00`00Oomoo`0kOol00`00Oomoo`31Ool00`00Oomoo`1nOol003Ioo`03001oogoo03]oo`03001o
ogoo0<5oo`03001oogoo07ioo`00=Woo00<007ooOol0>goo00<007ooOol0`Goo00<007ooOol0OWoo
000fOol00`00Oomoo`0kOol00`00Oomoo`31Ool00`00Oomoo`1nOol003Ioo`03001oogoo03]oo`03
001oogoo0<5oo`03001oogoo07ioo`00=Woo00<007ooOol0>goo00<007ooOol0`Goo00<007ooOol0
OWoo000fOol00`00Oomoo`0kOol00`00Oomoo`31Ool00`00Oomoo`1nOol003Ioo`03001oogoo03]o
o`03001oogoo0<5oo`03001oogoo07ioo`00=Woo00<007ooOol0>goo00<007ooOol0`Woo00<007oo
Ool0OGoo000fOol00`00Oomoo`0kOol00`00Oomoo`32Ool00`00Oomoo`1mOol003Ioo`03001oogoo
03]oo`03001oogoo0<9oo`03001oogoo07eoo`00=Woo00<007ooOol0>goo00<007ooOol0`Woo00<0
07ooOol0OGoo000fOol2000lOol00`00Oomoo`32Ool00`00Oomoo`1mOol003Ioo`03001oogoo03Yo
o`03001oogoo0<=oo`03001oogoo07eoo`00=Woo00<007ooOol0>Woo00<007ooOol0`goo00<007oo
Ool0OGoo000fOol00`00Oomoo`0jOol00`00Oomoo`33Ool00`00Oomoo`1mOol003Ioo`03001oogoo
03Yoo`03001oogoo0<=oo`03001oogoo07eoo`00=Woo00<007ooOol0>Woo00<007ooOol0`goo00<0
07ooOol0OGoo000fOol00`00Oomoo`0jOol00`00Oomoo`33Ool00`00Oomoo`1mOol003Ioo`03001o
ogoo03Yoo`03001oogoo0<=oo`03001oogoo07eoo`00=Woo00<007ooOol0>Woo00<007ooOol0`goo
00<007ooOol0OGoo000POol60004Ool30009Ool00`00Oomoo`0jOol00`00Oomoo`33Ool00`00Oomo
o`1mOol0021oo`03001oogoo00=oo`04001oogoo0003Ool00`00Oomoo`06Ool00`00Oomoo`0jOol0
0`00Oomoo`33Ool00`00Oomoo`1mOol0025oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo03Uoo`03001oogoo0<Aoo`03001oogoo07eoo`005goo20000goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol01Goo0`00>Goo00<007ooOol0a7oo00<007ooOol0OGoo000S
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0iOol00`00Oomoo`35
Ool00`00Oomoo`1lOol002Aoo`05001oogooOol00005Ool00`00Oomoo`05Ool00`00Oomoo`0iOol0
0`00Oomoo`35Ool00`00Oomoo`1lOol002Eoo`04001oogoo0005Ool00`00Oomoo`05Ool00`00Oomo
o`0iOol00`00Oomoo`35Ool00`00Oomoo`1lOol0021oo`03001oogoo009oo`04001oogoo0005Ool0
0`00Oomoo`05Ool00`00Oomoo`0iOol00`00Oomoo`35Ool00`00Oomoo`1lOol0025oo`04001oogoo
0004Ool01@00Oomoogoo000027oo00<007ooOol0>Goo00<007ooOol0aGoo00<007ooOol0O7oo000R
Ool20006Ool30009Ool00`00Oomoo`0iOol00`00Oomoo`35Ool00`00Oomoo`1lOol003Ioo`03001o
ogoo03Uoo`03001oogoo0<Eoo`03001oogoo07aoo`00=Woo00<007ooOol0>7oo00<007ooOol0aWoo
00<007ooOol0O7oo000fOol00`00Oomoo`0hOol00`00Oomoo`36Ool00`00Oomoo`1lOol003Ioo`03
001oogoo03Qoo`03001oogoo0<Moo`03001oogoo07]oo`00=Woo00<007ooOol0>7oo00<007ooOol0
agoo00<007ooOol0Ngoo000fOol00`00Oomoo`0hOol00`00Oomoo`37Ool00`00Oomoo`1kOol003Io
o`8003Uoo`03001oogoo0<Moo`03001oogoo07]oo`00=Woo00<007ooOol0>7oo00<007ooOol0agoo
00<007ooOol0Ngoo000fOol00`00Oomoo`0hOol00`00Oomoo`37Ool00`00Oomoo`1kOol003Ioo`03
001oogoo03Qoo`03001oogoo0<Moo`03001oogoo07]oo`00=Woo00<007ooOol0>7oo00<007ooOol0
agoo00<007ooOol0Ngoo000fOol00`00Oomoo`0gOol00`00Oomoo`39Ool00`00Oomoo`1jOol003Io
o`03001oogoo03Moo`03001oogoo0<Uoo`03001oogoo07Yoo`00=Woo00<007ooOol0=goo00<007oo
Ool0bGoo00<007ooOol0NWoo000fOol00`00Oomoo`0gOol00`00Oomoo`39Ool00`00Oomoo`1jOol0
03Ioo`03001oogoo03Moo`03001oogoo0<Uoo`03001oogoo07Yoo`00=Woo00<007ooOol0=goo00<0
07ooOol0bGoo00<007ooOol0NWoo000fOol00`00Oomoo`0gOol00`00Oomoo`3:Ool00`00Oomoo`1i
Ool003Ioo`8003Qoo`03001oogoo0<Yoo`03001oogoo07Uoo`00=Woo00<007ooOol0=Woo00<007oo
Ool0bgoo00<007ooOol0NGoo000fOol00`00Oomoo`0fOol00`00Oomoo`3;Ool00`00Oomoo`1iOol0
03Ioo`03001oogoo03Ioo`03001oogoo0<]oo`03001oogoo07Uoo`00=Woo00<007ooOol0=Woo00<0
07ooOol0bgoo00<007ooOol0NGoo000fOol00`00Oomoo`0eOol00`00Oomoo`3=Ool00`00Oomoo`1h
Ool003Ioo`03001oogoo03Eoo`03001oogoo0<eoo`03001oogoo07Qoo`00=Woo00<007ooOol0=Goo
00<007ooOol0cGoo00<007ooOol0N7oo000fOol00`00Oomoo`0dOol00`00Oomoo`3>Ool00`00Oomo
o`1hOol003Ioo`03001oogoo03Aoo`03001oogoo0<ioo`03001oogoo07Qoo`00=Woo00<007ooOol0
=7oo00<007ooOol03goo1@001Goo0`00@Woo0`001Goo0`0017oo0`00?Woo0`000goo1@0017oo0`00
3goo00<007ooOol0:goo1P0017oo0`0017oo0`00>7oo000fOol00`00Oomoo`0cOol00`00Oomoo`0E
Ool01@00Oomoogoo00000goo00<007ooOol0@7oo00<007ooOol00goo00D007ooOomoo`00009oo`05
001oogooOol0000nOol00`00Oomoo`07Ool01000Oomoo`000goo00<007ooOol037oo00<007ooOol0
:goo00<007ooOol00goo00@007ooOol000=oo`04001oogoo0003Ool00`00Oomoo`0eOol003Ioo`03
001oogoo03=oo`03001oogoo01Ioo`03001oo`0000Eoo`03001oogoo03moo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo03]oo`03001oogoo00Qoo`8000Eoo`03001oogoo00]oo`03
001oogoo02aoo`03001oogoo00Aoo`03001oogoo00=oo`8000Eoo`03001oogoo03Aoo`00=Woo0P00
=7oo00<007ooOol05Woo00<007oo00001Goo00<007ooOol0?goo00<007ooOol00Woo00<007ooOol0
0goo0P001Goo00<007ooOol0>goo00<007ooOol027oo0P001Goo00<007ooOol037oo00<007ooOol0
;7oo00<007ooOol00goo00<007ooOol00goo0P001Goo00<007ooOol0=7oo000fOol00`00Oomoo`0b
Ool00`00Oomoo`0GOol00`00Ool00005Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Oomoo`03
Ool20005Ool00`00Oomoo`0kOol00`00Oomoo`08Ool20005Ool00`00Oomoo`0<Ool00`00Oomoo`0]
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0dOol003Ioo`03001oogoo039o
o`03001oogoo01Ioo`04001oogoo0005Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Oomoo`03
Ool20005Ool00`00Oomoo`0kOol00`00Oomoo`07Ool00`00Ool00005Ool00`00Oomoo`0<Ool00`00
Oomoo`0^Ool01@00Oomoogoo00001Goo0P001Goo00<007ooOol0=7oo000fOol00`00Oomoo`0aOol0
0`00Oomoo`0COol40003Ool00`00Oomoo`03Ool00`00Oomoo`0oOol00`00Oomoo`02Ool00`00Oomo
o`03Ool20005Ool00`00Oomoo`0kOol00`00Oomoo`03Ool40002Ool00`00Oomoo`03Ool00`00Oomo
o`0=Ool00`00Oomoo`0^Ool01000Oomoo`001Goo0P001Goo00<007ooOol0=7oo000fOol00`00Oomo
o`0`Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0oOol00`00Oomo
o`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0kOol00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0YOol00`00Oomoo`02Ool01000Oomoo`001Goo
0P001Goo00<007ooOol0=7oo000fOol00`00Oomoo`0`Ool00`00Oomoo`0EOol00`00Oomoo`04Ool0
1@00Oomoogoo0000@Goo0P001Goo00D007ooOomoo`00009oo`05001oogooOol0000mOol20006Ool0
0`00Oomoo`03Ool01@00Oomoogoo00004Goo00<007ooOol0:Goo00@007ooOol000Aoo`05001oogoo
Ool00002Ool01@00Oomoogoo0000=goo000fOol00`00Oomoo`0^Ool2000HOol50003Ool30013Ool0
0`00Oomoo`04Ool30004Ool3000oOol00`00Oomoo`04Ool50002Ool3000COol00`00Oomoo`0YOol2
0006Ool30004Ool3000hOol003Ioo`03001oogoo02aoo`800=eoo`03001oogoo079oo`00=Woo00<0
07ooOol0:goo00<007ooOol0gWoo00<007ooOol0CGoo0`006goo0`000goo000fOol00`00Oomoo`0Y
Ool2003QOol00`00Oomoo`1=Ool00`00Oomoo`0MOol00`00Oomoo`01Ool003Ioo`03001oogoo02Io
o`<00>Aoo`8004Aoo`<000Ioo`03001oogoo009oo`<00005Ool00000001oo`0300001Goo00000000
Ool00`0000Aoo`00000000Aoo`03001oogoo005oo`00=Woo00<007ooOol08Goo1@00jGoo00<007oo
Ool0@Goo00@007ooOol000Eoo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000Eoo`03001oogoo005oo`00=Woo00<007ooOol04Goo4000kgoo1000@Woo
00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00001Goo00<007ooOol00Goo000^Oooo001D000<Ool20006Ool00`00Oomoo`03Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool00`00Oomoo`01Ool003Io
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eo
o`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eo
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00io
o`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00Eoo`H0009oo`03001oogoo00eoo`03001o
ogoo00eoo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo00=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`03001oogoo005oo`00=Woo00<007ooOol0CGoo
00<007ooOol0CWoo00<007ooOol0CWoo00<007ooOol0:goo3@005Goo00<007ooOol04Goo00@007oo
Ool000Eoo`03001oogoo009oo`<0009oo`80009oo`03001oogoo00<0009oo`80009oo`03001oogoo
00=oo`03001oogoo005oo`00=Woo00<007ooOol0ogoo:goo5P0057oo0`001Goo00<007ooOol00goo
00@007oo0000009oo`8000Aoo`04001oo`000002Ool20006Ool00`00Oomoo`01Ool003Ioo`03001o
ogoo0?mooeeoo`03001oogoo01eoo`03001oogoo005oo`00=Woo00<007ooOol0ogooGGoo00<007oo
Ool07Goo00<007ooOol00Goo000fOol00`00Oomoo`3oOomMOol3000KOol30003Ool003Ioo`03001o
ogoo0?mooh5oo`00=Woo00<007ooOol0ogooPGoo003oOonjOol00?mookYoo`00ogoo^Woo003oOonj
Ool00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00
0Woo0`001goo0`00ogooZgoo0002Ool01000Oomoo`001Woo00@007ooOol002Qoo`<002]oo`<00?mo
oe5oo`001Goo00<007ooOol01goo00<007ooOol09Woo00<007ooOol0;Goo00<007ooOol0ogooCgoo
0006Ool00`00Oomoo`07Ool00`00Oomoo`04Ool70002Ool60003Ool2000017oo001oogoo0`001Woo
00<007ooOol01Goo0`000goo0`0000Eoo`00000007oo00<00005Ool00000001oo`0300000goo0000
00070005Ool00`00Oomoo`3oOom?Ool000Ioo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
00=oo`04001oogoo0003Ool01000Oomoo`000Woo0`0000Eoo`00Oomoo`0000Eoo`03001oogoo00Io
o`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00L007ooOomoo`00Ool0
0005Ool00`00Oomoo`02Ool00`00Oomoo`3oOom?Ool000Ioo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo00=oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00002Ool00`00Oomoo`07Ool00`00Oomoo`3oOom?Ool000Ioo`03001oogoo00Mo
o`03001oogoo00Eoo`03001oogoo00=oo`05001oogooOol00004Ool00`00Oomoo`02Ool01000Oomo
ogoo0P001Woo00<007ooOol01Woo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00<007ooOol01Woo00<007ooOol0ogooCgoo0006Ool00`00Oomo
o`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool20004Ool01@00Oomoogoo000017oo00@007ooOol0
00Qoo`03001oogoo00Ioo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo0?moodmoo`001Woo00<007ooOol01goo
00<007ooOol01Goo1@000goo00D007ooOomoo`0000=oo`03001oogoo0080009oo`04001oogoo0005
Ool00`00Oomoo`06Ool00`00Oomoo`02Ool30002Ool20002Ool00`00Oomoo`030002Ool20002Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`3oOom?Ool000Ioo`03001oogoo00Moo`03001o
ogoo00Eoo`03001oogoo009oo`800003Ool0000000@000=oo`800003Ool007oo009oo`<000Eoo`03
001oogoo00Ioo`03001oogoo00=oo`04001oo`000002Ool20004Ool01000Ool000000Woo0P001goo
00<007ooOol00goo00<007ooOol0ogooCgoo0006Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo
00<007ooOol05Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0ogooCgoo0006Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool2000;Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00<007ooOol05Woo00@007ooOol000Ioo`03001oogoo0?moodmoo`00
1Woo00<007ooOol01goo00<007ooOol017oo1`003Woo00<007ooOol02Goo0`000Woo2@006Goo0P00
1Goo0`00ogooDGoo0006Ool00`00Oomoo`07Ool00`00Oomoo`3oOonWOol000Ioo`03001oogoo00Mo
o`03001oogoo0?moojMoo`001goo00<007ooOol01goo00<007ooOol0ogooYWoo0007Ool01000Oomo
o`001Woo00@007ooOol00?moojEoo`0027oo0`001goo0`00ogooYGoo003oOonjOol00?mookYoo`00
ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonj
Ool00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00ogoo^Woo003oOonjOol00?mookYoo`00
\
\>"],
  ImageRangeCache->{{{0, 440.938}, {271.938, 0}} -> {-33.5657, -85.9359, 
  0.774945, 0.494753}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
WindowSize->{803, 645},
WindowMargins->{{164, Automatic}, {Automatic, 60}},
ShowCellLabel->False,
Magnification->1.25,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
00T0001804P000000bD2@?omooH3AP997`<5N`?P0040004/0B`000003Ad9H04/
02d5X5k/02H20@4101P00BL?00400@00000000000000000106@0000000000000
0000000000000002000000@210D00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 73, 0, 106, "Title"],
Cell[1785, 51, 57, 3, 62, "Text"],

Cell[CellGroupData[{
Cell[1867, 58, 31, 0, 65, "Section"],
Cell[1901, 60, 314, 6, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2252, 71, 33, 0, 65, "Section"],

Cell[CellGroupData[{
Cell[2310, 75, 74, 1, 77, "Input"],
Cell[2387, 78, 359, 7, 28, "Print"],
Cell[2749, 87, 126, 2, 47, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2924, 95, 28, 0, 65, "Section"],
Cell[2955, 97, 124, 3, 31, "Text"],
Cell[3082, 102, 1286, 24, 609, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4405, 131, 39, 0, 65, "Section"],
Cell[4447, 133, 69, 0, 31, "Text"],

Cell[CellGroupData[{
Cell[4541, 137, 442, 7, 229, "Input"],
Cell[4986, 146, 107072, 5708, 22, 105740, 5687, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[112107, 5860, 43, 0, 65, "Section"],
Cell[112153, 5862, 1224, 19, 202, "Text"],

Cell[CellGroupData[{
Cell[113402, 5885, 1349, 22, 305, "Input"],
Cell[114754, 5909, 655, 13, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115446, 5927, 892, 16, 400, "Input"],

Cell[CellGroupData[{
Cell[116363, 5947, 68612, 1685, 233, 21672, 1101, "GraphicsData", 
"PostScript", "Graphics"],
Cell[184978, 7634, 58674, 1521, 233, 20558, 1046, "GraphicsData", 
"PostScript", "Graphics"],
Cell[243655, 9157, 36457, 1241, 233, 20617, 1041, "GraphicsData", 
"PostScript", "Graphics"],
Cell[280115, 10400, 32517, 1116, 233, 18481, 938, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[312693, 11523, 65, 0, 65, "Section"],
Cell[312761, 11525, 167, 4, 50, "Text"],

Cell[CellGroupData[{
Cell[312953, 11533, 860, 15, 382, "Input"],

Cell[CellGroupData[{
Cell[313838, 11552, 93361, 1897, 283, 19026, 975, "GraphicsData", 
"PostScript", "Graphics"],
Cell[407202, 13451, 77826, 1586, 283, 16293, 822, "GraphicsData", 
"PostScript", "Graphics"],
Cell[485031, 15039, 61913, 1366, 283, 15657, 790, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

